-- Advanced  Tools for Mission Editor

local moduleName = "DirectSpawnWithMenu"
local thisModule
local menu1 

-- Function for F10 menu "Spawn group"
local F10SpawnCommand
F10SpawnCommand = function(args)      
    local player = args[1]
	
	-- ATME.C_Group.getByName :
	-- Return ATME.C_Group instance which name is "copy0", or 
	-- nil if doesn't exist when that function is called
	
    local group = ATME.C_Group.getByName("copy0")
	
	if group ~= nil then
		-- If exists, disable group ...

		group:setAutoRespawn("RANDOM 1 00:00:04")
		group:disable()
    end
end

local function respawnHelo(groupName)
	-- ATME.C_Group.getByName :
	-- Return ATME.C_Group instance which name is "copyPlane0", or 
	-- nil if doesn't exist when that function is called
	
	local group = ATME.C_Group.getByName(groupName)
	
	if group ~= nil then
		-- If exists, disable group ...
		group:setAutoRespawn(5)
		group:disable()
    end
end

local function respawnOnAlarm(alarm)
    local privateDatas = alarm:getUserPrivateDatas(thisModule)
    thisModule:output("Alarme activée...",1)
	respawnHelo(privateDatas.groupName)
end

-- Function for F10 menu "Spawn plane"
local F10SpawnPlaneCommand
F10SpawnPlaneCommand = function(args)      
    local player = args[1]

	if thisModule:getAlarmByName("TEST1") == nil then
		local alarm = thisModule:createAbsoluteAlarm("TEST1", "+00:00:10")
        thisModule:addAlarmCallback(alarm, respawnOnAlarm)
		
		local privateDatas = alarm:getUserPrivateDatas(thisModule)
		privateDatas.groupName = "copyPlane0"
	else
		thisModule:output("Alarme déjà programmée...",1)
	end
end


-- OnCreatePlayer handler : call when a player enters mission
local function onCreatePlayer(player)
    player:display("Welcome in " .. ATME.getTheatre(), 10)
    
	-- take root F10 menu and add item "Spawn group" to player
    local menu = player:getF10MenuRoot(thisModule)
	menu:append(1, "Spawn ground group", F10SpawnCommand , {player})
	menu:append(1, "Spawn helo using alarm 10 sec", F10SpawnPlaneCommand , {player})
end


local function onSpawn(group)
	local player = ATME.C_Player.getByName("Pilot #001")
	local r = math.random(1,2)
	player:display("Spawn group ".. group:getName() .. "(" .. r .. ")",5)
	if group:getName() == "copyPlane0" then
		local unit = group:getFirstUnit()
		
		while unit ~= nil do
			local name, id1, id2 = unit:getCallsign()
			if name ~= nil then
				if id1 ~= nil then -- Blue coalition
					player:display("Callsign spawn " .. unit:getName() .. " = " .. name .. " " .. id1 .. "-" .. id2, 5)
				else -- Red coalition
					player:display("Callsign spawn " .. unit:getName() .. " = " .. name, 5)
				end
			end
			unit = group:getNextUnit()
		end
		
		if r == 2 then
			local route = ATME.C_Route("HELICOPTER")
			route:addInitialWaypointsFrom("originPlane")
			group:setRoute(route)
		end
	else
		if r == 2 then
			local route = ATME.C_Route("GROUND")
			route:addInitialWaypointsFrom("ref1")
			group:setRoute(route)
		end
	end
end

local function onStart(areUnitsAndPlayersInitialized)
	if areUnitsAndPlayersInitialized == true then
		local unit = ATME.C_AIUnit.getByName("Pilot #004")
		
		if unit ~= nil then
			local name, id1, id2 = unit:getCallsign()
			thisModule:output("Callsign = " .. name, 1)
		end
		
		unit = ATME.C_AIUnit.getByName("Pilot #006")
		
		if unit ~= nil then
			local name, id1, id2 = unit:getCallsign()
			thisModule:output("Callsign = " .. name .. " " .. id1 .. "-" .. id2, 1)
		end
	end
end

-- MAIN
do
	local newHandlers = {
		onCreatePlayerHandler = onCreatePlayer,
		onDeletePlayerHandler = nil,
		onUpdatePlayerHandler = nil,
		onTakeoffPlayerHandler = nil,
		onLandingPlayerHandler = nil,
		onStartEnginePlayerHandler = nil,
		onStopEnginePlayerHandler = nil,
		
		onCreateAIUnitHandler = nil,
		onDeleteAIUnitHandler = nil,
		onDisableAIUnitHandler = nil,
		onTakeoffAIUnitHandler = nil,
		onLandingAIUnitHandler = nil,
		onStartEngineAIUnitHandler = nil,
		onStopEngineAIUnitHandler = nil,
		
		onCreateGroupHandler = nil,
		onSpawnGroupHandler = onSpawn,
		onDeleteGroupHandler = nil,
		onDisableGroupHandler = nil,
		
		onCreateStaticObjectHandler = nil,
		onDeleteStaticObjectHandler = nil,
	
		onTimerHandler = nil,
		onModuleStartHandler = onStart,
	}
		
	thisModule = ATME.C_Module(moduleName, newHandlers, true)
end
