--[[
			Advanced Tools for Mission Editor - ATME
			Author : Sunski34
			
			Testers : Snowsniper/Sunski34

			Oriented Object lua core module
			
			V.1.4.5 - Beta Version - 09/2018
				-> New optimizations
				-> Bug when crash or eject then respawn fixed
				-> Bug in ATME.C_Route class with altitude waypoints fixed
				-> Add new function isPilotDead in ATME.C_Player and ATME.C_AIUnit classes
				-> Add new function isPilotEjected in ATME.C_Player and ATME.C_AIUnit classes
				
			DO NOT MODIFY ANYTHING - For any idea or bug, please send a message on the forum
			
			Notes :
			-----
			ATME function initObjectsInMission is based on existing MIST function to initialize mission context
			
			All comments in that file are in french because of ATMECore software debugging. If you want 
			informations about ATME, classes, functions, events or handlers, please refer to english documentation.
]]--


local versionATME = "V1.4.5"


----------------------------------------------------------------------------------------------------------
-- DEFINITION DES VALEURS CONSTANTES & VARIABLES GLOBALES
----------------------------------------------------------------------------------------------------------

local ATMEConst = {
	smokeColors = {
		["GREEN"] = trigger.smokeColor.Green,
		["RED"] = trigger.smokeColor.Red,
		["WHITE"] = trigger.smokeColor.White,
		["ORANGE"] = trigger.smokeColor.Orange,
		["BLUE"] = trigger.smokeColor.Blue,
		["RANDOM"] = -1,
	},
	flareColors = {
		["GREEN"] = trigger.flareColor.Green,
		["RED"] = trigger.flareColor.Red,
		["WHITE"] = trigger.flareColor.White,
		["YELLOW"] = trigger.flareColor.Yellow,
		["RANDOM"] = -1,
	},
	flareColorsIndex = {
		"GREEN",
		"RED",
		"WHITE",
		"YELLOW"
	},
	smokeColorsIndex = {
		"GREEN",
		"RED",
		"WHITE",
		"ORANGE",
		"BLUE",
	},
	groupCategories = {
		["plane"] = Group.Category.AIRPLANE,
		["helicopter"] = Group.Category.HELICOPTER,
		["vehicle"] = Group.Category.GROUND,
		["ship"] = Group.Category.SHIP,
	},
	categoryNames = {
		[Group.Category.AIRPLANE] = "AIRPLANE",
		[Group.Category.HELICOPTER] = "HELICOPTER",
		[Group.Category.GROUND] = "GROUND",
		[Group.Category.SHIP] = "SHIP",
	},
	categoryNameFilters = {
		["AIRPLANE"] = "plane",
		["HELICOPTER"] = "helicopter",
		["GROUND"] = "vehicle",
		["SHIP"] = "ship",
	},
	coalitionNames = {
		[coalition.side.RED] = "RED",
		[coalition.side.BLUE] = "BLUE",
	},
	coalitionIds = {
		["RED"] = coalition.side.RED,
		["BLUE"] = coalition.side.BLUE,
	},
	countries = {
		["RUSSIA"] = 0,
		["UKRAINE"] = 1,
		["USA"] = 2,
		["TURKEY"] = 3,
		["UK"] = 4,
		["FRANCE"] = 5,
		["GERMANY"] = 6,
		["AGGRESSORS"] = 7,
		["CANADA"] = 8,
		["SPAIN"] = 9,
		["THE_NETHERLANDS"] = 10,
		["BELGIUM"] = 11,
		["NORWAY"] = 12,
		["DENMARK"] = 13,
		["ISRAEL"] = 15,
		["GEORGIA"] = 16,
		["INSURGENTS"] = 17,
		["ABKHAZIA"] = 18,
		["SOUTH_OSETIA"] = 19,
		["ITALY"] = 20,
		["AUSTRALIA"] = 21,
		["SWITZERLAND"] = 22,
		["AUSTRIA"] = 23,
		["BELARUS"] = 24,
		["BULGARIA"] = 25,
		["CHEZH_REPUBLIC"] = 26,
		["CHINA"] = 27,
		["CROATIA"] = 28,
		["EGYPT"] = 29,
		["FINLAND"] = 30,
		["GREECE"] = 31,
		["HUNGARY"] = 32,
		["INDIA"] = 33,
		["IRAN"] = 34,
		["IRAQ"] = 35,
		["JAPAN"] = 36,
		["KAZAKHSTAN"] = 37,
		["NORTH_KOREA"] = 38,
		["PAKISTAN"] = 39,
		["POLAND"] = 40,
		["ROMANIA"] = 41,
		["SAUDI_ARABIA"] = 42,
		["SERBIA"] = 43,
		["SLOVAKIA"] = 44,
		["SOUTH_KOREA"] = 45,
		["SWEDEN"] = 46,
		["SYRIA"] = 47,
		["YEMEN"] = 48,
		["VIETNAM"] = 49,
		["VENEZUELA"] = 50,
		["TUNISIA"] = 51,
		["THAILAND"] = 52,
		["SUDAN"] = 53,
		["PHILIPPINES"] = 54,
		["MOROCCO"] = 55,	
		["MEXICO"] = 56,	
		["MALAYSIA"] = 57,		
		["LIBYA"] = 58,	
		["JORDAN"] = 59,
		["INDONESIA"] = 60,	
		["HONDURAS"] = 61,		
		["ETHIOPIA"] = 62,		
		["CHILE"] = 63,		
		["BRAZIL"] = 64,		 
		["BAHRAIN"] = 65,
		["THIRDREICH"] = 66,
		["YUGOSLAVIA"] = 67,
		["USSR"] = 68,
		["ITALIAN_SOCIAL_REPUBLIC"] = 69,
		["ALGERIA"] = 70,
		["KUWAIT"] = 71,
		["QATAR"] = 72,
		["OMAN"] = 73,
		["UNITED_ARAB_EMIRATES"] = 74,
	},
	personnelCarrierAttributes = {
		["UH-1H"] = {maxUnits = 8, minDistance = 25,},
		["Mi-8MT"] = {maxUnits = 16, minDistance = 28,},
		["SA342M"] = {maxUnits = 2, minDistance = 22,},
		["SA342L"] = {maxUnits = 2, minDistance = 22,},
		["SA342Mistral"] = {maxUnits = 2, minDistance = 22,},
		["AAV7"] = {maxUnits = 25, minDistance = 20,},
		["M-113"] = {maxUnits = 11, minDistance = 20,},
		["LAV-25"] = {maxUnits = 6, minDistance = 20,},
		["M1126 Stryker ICV"] = {maxUnits = 9, minDistance = 20,},
		["M-2 Bradley"] = {maxUnits = 6, minDistance = 20,},
		["BTR-80"] = {maxUnits = 9, minDistance = 20,},
		["BTR_D"] = {maxUnits = 12, minDistance = 20,},
		["MTLB"] = {maxUnits = 10, minDistance = 20,},
		["BMD-1"] = {maxUnits = 4, minDistance = 20,},
		["BMP-1"] = {maxUnits = 8, minDistance = 20,},
		["BMP-2"] = {maxUnits = 7, minDistance = 20,},
		["BMP-3"] = {maxUnits = 7, minDistance = 20,},
		["UAZ-469"] = {maxUnits = 6, minDistance = 20,},
		["Tigr_233036"] = {maxUnits = 6, minDistance = 20,},
		["GAZ-3307"] = {maxUnits = 16, minDistance = 20,},
		["GAZ-3308"] = {maxUnits = 16, minDistance = 20,},
		["Ural-4320T"] = {maxUnits = 20, minDistance = 20,},
		["Ural-4320-31"] = {maxUnits = 20, minDistance = 20,},
		["M 818"] = {maxUnits = 20, minDistance = 20,},
		["KAMAZ Truck"] = {maxUnits = 20, minDistance = 20,},
	},
	cargos = {
		["BASIC"] = {
			type = "uh1h_cargo",
			shape = "ab-212_cargo",
		},
		["TRUNKS SMALL"] = {
			type = "trunks_small_cargo",
			shape = "trunks_small_cargo",
		},
		["TRUNKS LONG"] = {
			type = "trunks_long_cargo",
			shape = "trunks_long_cargo",
		},
		["TETRAPOD"] = {
			type = "tetrapod_cargo",
			shape = "tetrapod_cargo",
		},
		["PIPE SMALL"] = {
			type = "pipes_small_cargo",
			shape = "pipes_small_cargo",
		},
		["PIPE BIG"] = {
			type = "pipes_big_cargo",
			shape = "pipes_big_cargo",
		},
		["OIL TANK"] = {
			type = "oiltank_cargo",
			shape = "oiltank_cargo",
		},
		["M117"] = {
			type = "m117_cargo",
			shape = "m117_cargo",
		},
		["SMALL CONTAINER"] = {
			type = "iso_container_small",
			shape = "iso_container_small_cargo",
		},
		["F BAR"] = {
			type = "f_bar_cargo",
			shape = "f_bar_cargo",
		},
		["FUEL TANK"] = {
			type = "fueltank_cargo",
			shape = "fueltank_cargo",
		},
		["BW CONTAINER"] = {
			type = "container_cargo",
			shape = "bw_container_cargo",
		},
		["CONTAINER"] = {
			type = "iso_container",
			shape = "iso_container_cargo",
		},
		["BARRELS"] = {
			type = "barrels_cargo",
			shape = "barrels_cargo",
		},
		["AMMO BOX"] = {
			type = "ammo_cargo",
			shape = "ammo_box_cargo",
		},
	},
	staticObjectCategories = {
		-- Bug DCS sur certains objets dont le nom est toujours 'static'
		-- LTAvehicles ne fonctionne pas en spawn.
		
		["SHIP"]= {
			category = "Ships",
		},
		["PLANE"]= {
			category = "Planes",
		},
		["HELICOPTER"]= {
			category = "Helicopters",
		},
		["WAREHOUSE"]= {
			category = "Warehouses",
		},
		["UNARMED"]= {
			category = "Unarmed",
		},
		["FORTIFICATION"]= {
			category = "Fortifications",
		},
		--[[["LTA_VEHICLE"] = {
			category = "LTAvehicles",
		},]]--
	},
	supportedLanguages = {
		["FR"] = "French",
		["EN"] = "English",
		["RUS"] = "Russian",
		["GER"] = "German",
	},
	groupEventTypes = {
		["TRACKING_WAYPOINT"] = true,
		["TRACKING_LAST_WAYPOINT"] = true,
		["AREA_GROUP_ENTERS"] = true,
		["AREA_GROUP_LEAVES"] = true,
	},
	blueCallsigns = {
		aircrafts = {
			["ENFIELD"] = {
				name = "Enfield",
				id = 1,
			},
			["SPRINGFIELD"] = {
				name = "SpringField",
				id = 2,
			},
			["UZI"] = {
				name = "Uzi",
				id = 3,
			},
			["COLT"] = {
				name = "Colt",
				id = 4,
			},
			["DODGE"] = {
				name = "Dodge",
				id = 5,
			},
			["FORD"] = {
				name = "Ford",
				id = 6,
			},
			["CHEVY"] = {
				name = "Chevy",
				id = 7,
			},
			["PONTIAC"] = {
				name = "Pontiac",
				id = 8,
			},
			["HAWG"] = {
				name = "Hawg",
				id = 9,
			},
			["BOAR"] = {
				name = "Boar",
				id = 10,
			},
			["PIG"] = {
				name = "Pig",
				id = 11,
			},
			["TUSK"] = {
				name = "Tusk",
				id = 12,
			},
		},
		jtacs = {
			["AXEMAN"] = {
				name = "Axeman",
				id = 1,
			},
			["DARKNIGHT"] = {
				name = "Darknight",
				id = 2,
			},
			["WARRIOR"] = {
				name = "Warrior",
				id = 3,
			},
			["POINTER"] = {
				name = "Pointer",
				id = 4,
			},
			["EYEBALL"] = {
				name = "Eyeball",
				id = 5,
			},
			["MOONBEAM"] = {
				name = "Moonbeam",
				id = 6,
			},
			["WHIPLASH"] = {
				name = "Whiplash",
				id = 7,
			},
			["FINGER"] = {
				name = "Finger",
				id = 8,
			},
			["PINPOINT"] = {
				name = "Pinpoint",
				id = 9,
			},
			["FERRET"] = {
				name = "Ferret",
				id = 10,
			},
			["SHABA"] = {
				name = "Shaba",
				id = 11,
			},
			["PLAYBOY"] = {
				name = "Playboy",
				id = 12,
			},
			["HAMMER"] = {
				name = "Hammer",
				id = 13,
			},
			["JAGUAR"] = {
				name = "Jaguar",
				id = 14,
			},
			["DEATHSTAR"] = {
				name = "Deathstar",
				id = 15,
			},
			["ANVIL"] = {
				name = "Anvil",
				id = 16,
			},
			["FIREFLY"] = {
				name = "Firefly",
				id = 17,
			},
			["MANTIS"] = {
				name = "Mantis",
				id = 18,
			},
			["BADGER"] = {
				name = "Badger",
				id = 19,
			},
		},
	},
	directionValue = {					-- Table de gestion des directions
		[-1] = "RIGHT_TO_LEFT",
		[1] = "LEFT_TO_RIGHT",
	},
	weaponFlags = {
		["NO_WEAPON"] = 0,
		["LGB"] = 2,
		["TVGB"] = 4,
		["SNSGB"] = 8,
		["HE_BOMB"] = 16,
		["PENETRATOR"] = 32,
		["NAPALM_BOMB"] = 64,
		["FAE_BOMB"] = 128,
		["CLUSTER_BOMB"] = 256,
		["DISPENCER"] = 512,
		["CANDLE_BOMB"] = 1024,
		["PARACHUTE_BOMB"] = 16,
		["GUIDED_BOMB"] = 14,
		["UNGUIDED_BOMB"] = 2147485680,
		["ANY_BOMB"] = 2147485694,
		["LIGHT_ROCKET"] = 2048,
		["MARKER_ROCKET"] = 4096,
		["CANDLE_ROCKET"] = 8192,
		["HEAVY_ROCKET"] = 16384,
		["ANY_ROCKET"] = 30720,
		["ANTI_RADAR_MISSILE"] = 32768,
		["ANTI_SHIP_MISSILE"] = 65536,
		["ANTI_TANK_MISSILE"] = 131072,
		["FIRE_AND_FORGET_ASM"] = 262144,
		["LASER_ASM"] = 524288,
		["TELE_ASM"] = 1048576,
		["CRUISE_MISSILE"] = 2097152,
		["ANTI_RADAR_MISSILE_2"] = 1073741824,
		["GUIDED_ASM"] = 1572864,
		["TACTICAL_ASM"] = 1835008,
		["ANY_ASM"] = 4161536,
		["LR_AAM"] = 16777216,
		["SR_AAM"] = 4194304,
		["MR_AAM"] = 8388608,
		["IR_AAM"] = 33554432,
		["SAR_AAM"] = 67108864,
		["AR_AAM"] = 134217728,
		["ANY_AAM"] = 264241152,
		["ANY_MISSILE"] = 268402688,
		["GUN_POD"] = 268435456,
		["BUILT_IN_CANNON"] = 536870912,
		["ANY_GUN"] = 805306368,
		["AG_WEAPON"] = 2956984318,
		["AA_WEAPON"] = 1069547520,
		["UNGUIDED_WEAPON"] = 2952822768,
		["GUIDED_WEAPON"] = 268402702,
		["ANY_WEAPON"] = 3221225470,
		["MARKER_WEAPON"] = 13312,
		["ARM_WEAPON"] = 3221212158,
	},
	weaponExpend = {
		["QUARTER"] = AI.Task.WeaponExpend.QUARTER,
		["TWO"] = AI.Task.WeaponExpend.TWO,
		["ONE"] = AI.Task.WeaponExpend.ONE,
		["FOUR"] = AI.Task.WeaponExpend.FOUR,
		["HALF"] = AI.Task.WeaponExpend.HALF,
		["ALL"] = AI.Task.WeaponExpend.ALL,
	},
	orbitPattern = {
		["CIRCLE"] = AI.Task.OrbitPattern.CIRCLE,
		["RACE_TRACK"] = AI.Task.OrbitPattern.RACE_TRACK,
	},
	designationAI = {
		["NO"] = AI.Task.Designation.NO,
		["WP"] = AI.Task.Designation.WP,
		["IR_POINTER"] = AI.Task.Designation.IR_POINTER,
		["LASER"] = AI.Task.Designation.LASER,
		["AUTO"] = AI.Task.Designation.AUTO,
	},
	TargetsType = {
		["AIR"] = "Air",
		["PLANES"] = "Planes",
		["HELICOPTERS"] = "Helicopters",
		["BATTLE_AIRPLANES"] = "Battle airplanes",
		["ATTACK_HELICOPTERS"] = "Attack helicopters",
		["FIGHTERS"] = "Fighters",
		["INTERCEPTORS"]= "Interceptors",
		["BOMBERS"] = "Bombers",
		["STRATEGIC_BOMBERS"] = "Strategic Bombers",
		["MULTIROLE_FIGHTERS"] = "Multirole fighters",
		["TRANSPORT_AIRPLANES"] = "Transports",
		["TRANSPORT_HELICOPTERS"] = "Transport helicopters",
		["AWACS"] = "AWACS",
		["TANKERS"] = "Tankers",
		["AUX"] = "Aux",
	},
	WPActions = {
		["plane"] = {
			["TURNING_POINT"] = "Turning Point",
			["FLY_OVER_POINT"] = "Fly Over Point",
		},
		["helicopter"] = {
			["TURNING_POINT"] = "Turning Point",
			["FLY_OVER_POINT"] = "Fly Over Point",
		},
		["vehicle"] = {
			["VEE"] = "Vee",
			["ECHELON_RIGHT"] = "EchelonR",
			["OFF_ROAD"] = "Off Road",
			["RANK"] = "Rank",
			["ECHELON_LEFT"]  = "EchelonL",
			["ON_ROAD"] = "On Road",
			["CONE"] = "Cone",
			["DIAMOND"] = "Diamond",
		},
		["ship"] = {
			["TURNING_POINT"] = "Turning Point",
		},
	},	
	taskAI = {
		["REFUELING"] = { -- Main task
			id = "Refueling",
			filters = {
				type = {
					["plane"] = true,
				},
			},
			args = {
				{
				}, -- fin Obligatoire
				{
				}, -- fin Optionnel
			},
		},
		["FOLLOW"] = { -- Main task
			id = "Follow",
			filters = {
				type = {
					["plane"] = true,
					["helicopter"] = true,
				},
			},
			args = {
				{
					{
						params = {
							["groupId"] = {
								fct = "C_Group_getID",
							},
						},
						multi = false,
						type = "C_Group",
					},
					{
						params = {
							["pos"] = {
								fct = "C_Vector_getPos",
							},
						},
						multi = false,
						type = "C_Vector3D",
					},
				}, -- fin Obligatoire
				{
					{
						params = {
							["lastWptIndex"] = {
								fct = "C_getNumberWithFlag",
								linkedParams = {
									"lastWptIndexFlag",
								},
							},
						},
						multi = false,
						type = "number",
						min = 0,
					},
				}, -- fin Optionnel
			},
		},
		["FOLLOW_BIG_FORMATION"] = { -- Main task
			id = "FollowBigFormation",
			filters = {
				type = {
					["plane"] = true,
					["helicopter"] = true,
				},
			},
			args = {
				{
					{
						params = {
							["groupId"] = {
								fct = "C_Group_getID",
							},
						},
						multi = false,
						type = "C_Group",
					},
					{
						params = {
							["pos"] = {
								fct = "C_Vector_getPos",
							},
						},
						multi = false,
						type = "C_Vector3D",
					},
				}, -- fin Obligatoire
				{
					{
						params = {
							["lastWptIndex"] = {
								fct = "C_getNumberWithFlag",
								linkedParams = {
									"lastWptIndexFlag",
								},
							},
						},
						multi = false,
						type = "number",
						min = 0,
					},
				}, -- fin Optionnel
			},
		},
		["ESCORT"] = { -- Main task
			id = "Escort",
			filters = {
				type = {
					["plane"] = true,
					["helicopter"] = true,
				},
			},
			args = {
				{
					{
						params = {
							["groupId"] = {
								fct = "C_Group_getID",
							},
						},
						multi = false,
						type = "C_Group",
					},
					{
						params = {
							["pos"] = {
								fct = "C_Vector_getPos",
							},
						},
						multi = false,
						type = "C_Vector3D",
					},
					{
						params = {
							["engagementDistMax"] = {
							},
						},
						multi = false,
						type = "number",
						min = 0,
					},
					{
						params = {
							["targetTypes"] = {
								fct = "C_getTargetsType",
							},
						},
						type = "string",
						multi = true,
					},
				}, -- fin Obligatoire
				{
					{
						params = {
							["lastWptIndex"] = {
								fct = "C_getNumberWithFlag",
								linkedParams = {
									"lastWptIndexFlag",
								},
							},
						},
						multi = false,
						type = "number",
						min = 0,
					},
				}, -- fin Optionnel
			},
		},
		["LAND"] = { -- Main task
			id = "Land",
			filters = {
				type = {
					["helicopter"] = true,
				},
			},
			args = {
				{
					{
						params = {
							["point"] = {
								fct = "C_getPoint2D",
							},
						},
						multi = false,
						type = "table",
					},
				
				}, -- fin Obligatoire
				{
					{
						params = {
							["duration"] = {
								fct = "C_getNumberWithFlag",
								linkedParams = {
									"durationFlag",
								},
							},
						},
						multi = false,
						type = "number",
						min = 1,
					},
				}, -- fin Optionnel
			},
		},
		["FIRE_AT_POINT"] = { -- Main task
			id = "FireAtPoint",
			filters = {
				type = {
					["vehicle"] = true,
					["ship"] = true,
				},
			},
			const = {
				["radius"] = 100,
			},
			args = {
				{
					{
						params = {
							["point"] = {
								fct = "C_Circle_getCenterRadius",
								linkedParams = {
									"radius",
								},
							},
						},
						multi = false,
						type = "C_Circle",
						onZone = true,
					},
				}, -- fin Obligatoire
				{
					{
						params = {
							["weaponType"] = {
								fct = "C_getWeaponFlag",
							},
						},
						multi = false,
						type = "string",
					},
					{
						params = {
							["expendQty"] = {
								fct = "C_getNumberWithFlag",
								linkedParams = {
									"expendQtyEnabled",
								},
							},
						},
						multi = false,
						type = "number",
						min = 1,
					},
				}, -- fin Optionnel
			},
		},
		["BOMBING"] = { -- Main task
			id = "Bombing",
			filters = {
				type = {
					["plane"] = true,
					["helicopter"] = true,
				},
			},
			args = {
				{
					{
						params = {
							["point"] = {
								fct = "C_getPoint2D",
							},
						},
						multi = false,
						type = "table",
						onZone = true,
					},
					{
						params = {
							["attackQty"] = {
							},
						},
						multi = false,
						type = "number",
						min = 1,
					},
				}, -- fin Obligatoire
				{
					{
						params = {
							["weaponType"] = {
								fct = "C_getWeaponFlag",
							},
						},
						multi = false,
						type = "string",
					},
					{
						params = {
							["expend"] = {
								fct = "C_getExpend",
							},
						},
						multi = false,
						type = "string",
					},
					{
						params = {
							["direction"] = {
							},
						},
						multi = false,
						type = "number",
					},
					{
						params = {
							["altitude"] = {
								fct = "C_getNumberWithFlag",
								linkedParams = {
									"altitudeEnabled",
								},
							},
						},
						multi = false,
						type = "number",
						min = 1,
					},
					{
						params = {
							["groupAttack"] = {
							},
						},
						multi = false,
						type = "boolean",
					},
				}, -- fin Optionnel
			},
		},
		["BOMBING_RUNWAY"] = { -- Main task
			id = "BombingRunway",
			filters = {
				type = {
					["plane"] = true,
					["helicopter"] = true,
				},
			},
			args = {
				{
					{
						params = {
							["runwayId"] = {
								fct = "C_getAirbase",
							},
						},
						multi = false,
						type = "string",
					},
				}, -- fin Obligatoire
				{
					{
						params = {
							["weaponType"] = {
								fct = "C_getWeaponFlag",
							},
						},
						multi = false,
						type = "string",
					},
					{
						params = {
							["expend"] = {
								fct = "C_getExpend",
							},
						},
						multi = false,
						type = "string",
					},
					{
						params = {
							["attackQty"] = {
							},
						},
						multi = false,
						type = "number",
						min = 1,
					},
					{
						params = {
							["direction"] = {
							},
						},
						multi = false,
						type = "number",
					},
					{
						params = {
							["groupAttack"] = {
							},
						},
						multi = false,
						type = "boolean",
					},
				}, -- fin Optionnel
			},
		},
		["CARPET_BOMBING"] = { -- Main task
			id = "CarpetBombing",
			filters = {
				type = {
					["plane"] = true,
					["helicopter"] = true,
				},
			},
			const = {
				["attackType"] = "Carpet",
			},
			args = {
				{
					{
						params = {
							["point"] = {
								fct = "C_getPoint2D",
							},
						},
						multi = false,
						type = "table",
					},
					{
						params = {
							["attackQty"] = {
							},
						},
						multi = false,
						type = "number",
						min = 1,
					},
					{
						params = {
							["carpetLength"] = {
							},
						},
						multi = false,
						type = "number",
						min = 1,
					},
				}, -- fin Obligatoire
				{
					{
						params = {
							["weaponType"] = {
								fct = "C_getWeaponFlag",
							},
						},
						multi = false,
						type = "string",
					},
					{
						params = {
							["expend"] = {
								fct = "C_getExpend",
							},
						},
						multi = false,
						type = "string",
					},
					{
						params = {
							["altitude"] = {
								fct = "C_getNumberWithFlag",
								linkedParams = {
									"altitudeEnabled",
								},
							},
						},
						multi = false,
						type = "number",
						min = 1,
					},
					{
						params = {
							["groupAttack"] = {
							},
						},
						multi = false,
						type = "boolean",
					},
				}, -- fin Optionnel
			},
		},
		["ATTACK_MAP_OBJECT"] = { -- Main task
			id = "AttackMapObject",
			filters = {
				type = {
					["plane"] = true,
					["helicopter"] = true,
				},
			},
			args = {
				{
					{
						params = {
							["point"] = {
								fct = "C_getPoint2D",
							},
						},
						multi = false,
						type = "table",
					},
				}, -- fin Obligatoire
				{
					{
						params = {
							["weaponType"] = {
								fct = "C_getWeaponFlag",
							},
						},
						multi = false,
						type = "string",
					},
					{
						params = {
							["expend"] = {
								fct = "C_getExpend",
							},
						},
						multi = false,
						type = "string",
					},
					{
						params = {
							["attackQty"] = {
							},
						},
						multi = false,
						type = "number",
						min = 1,
					},
					{
						params = {
							["direction"] = {
							},
						},
						multi = false,
						type = "number",
					},
					{
						params = {
							["groupAttack"] = {
							},
						},
						multi = false,
						type = "boolean",
					},
				}, -- fin Optionnel
			},
		},
		["ATTACK_GROUP"] = { -- Main task
			id = "AttackGroup",
			filters = {
				type = {
					["plane"] = true,
					["helicopter"] = true,
				},
			},
			args = {
				{
					{
						params = {
							["groupId"] = {
								fct = "C_Group_getID",
							},
						},
						multi = false,
						type = "C_Group",
						onZone = true,
					},
				}, -- fin Obligatoire
				{
					{
						params = {
							["weaponType"] = {
								fct = "C_getWeaponFlag",
							},
						},
						multi = false,
						type = "string",
					},
					{
						params = {
							["expend"] = {
								fct = "C_getExpend",
							},
						},
						multi = false,
						type = "string",
					},
					{
						params = {
							["attackQty"] = {
								fct = "C_getNumberWithFlag",
								linkedParams = {
									"attackQtyLimit",
								},
							},
						},
						multi = false,
						type = "number",
						min = 1,
					},
					{
						params = {
							["direction"] = {
								fct = "C_getNumberWithFlag",
								linkedParams = {
									"directionEnabled",
								},
							},
						},
						multi = false,
						type = "number",
					},
					{
						params = {
							["altitude"] = {
								fct = "C_getNumberWithFlag",
								linkedParams = {
									"altitudeEnabled",
								},
							},
						},
						multi = false,
						type = "number",
						min = 1,
					},
				}, -- fin Optionnel
			},
		},
		["ATTACK_UNIT"] = { -- Main task
			id = "AttackUnit",
			filters = {
				type = {
					["plane"] = true,
					["helicopter"] = true,
				},
			},
			args = {
				{
					{
						params = {
							["unitId"] = {
								fct = "C_Unit_getID",
							},
						},
						multi = false,
						type = "C_Unit",
					},
				}, -- fin Obligatoire
				{
					{
						params = {
							["weaponType"] = {
								fct = "C_getWeaponFlag",
							},
						},
						multi = false,
						type = "string",
					},
					{
						params = {
							["expend"] = {
								fct = "C_getExpend",
							},
						},
						multi = false,
						type = "string",
					},
					{
						params = {
							["attackQty"] = {
								fct = "C_getNumberWithFlag",
								linkedParams = {
									"attackQtyLimit",
								},
							},
						},
						multi = false,
						type = "number",
						min = 1,
					},
					{
						params = {
							["direction"] = {
							},
						},
						multi = false,
						type = "number",
					},
					{
						params = {
							["groupAttack"] = {
							},
						},
						multi = false,
						type = "boolean",
					},
				}, -- fin Optionnel
			},
		},
		["FAC_ATTACK_GROUP"] = { -- Main task
			id = "FAC_AttackGroup",
			filters = {
				type = {
					["plane"] = true,
					["helicopter"] = true,
					["vehicle"] = true,
				},
			},
			args = {
				{
					{
						params = {
							["groupId"] = {
								fct = "C_Group_getID",
							},
						},
						multi = false,
						type = "C_Group",
						onZone = true,
					},
				}, -- fin Obligatoire
				{
					{
						params = {
							["weaponType"] = {
								fct = "C_getWeaponFlag",
							},
						},
						multi = false,
						type = "string",
					},
					{
						params = {
							["designation"] = {
								fct = "C_getDesignation",
							},
						},
						multi = false,
						type = "string",
					},
					{
						params = {
							["datalink"] = {
							},
						},
						multi = false,
						type = "boolean",
					},
					{
						params = {
							["frequency"] = {
							},
						},
						multi = false,
						type = "number",
						min = 1,
					},
					{
						params = {
							["modulation"] = {
								fct = "C_getModulation",
							},
						},
						multi = false,
						type = "string",
					},
					{
						params = {
							["callname"] = {
								fct = "C_getCallname",
								linkedParams = {
									"number",
								},
							},
						},
						multi = false,
						type = "string",
					},
				}, -- fin Optionnel
			},
		},
		["ORBIT"] = { -- Main task
			id = "Orbit",
			filters = {
				type = {
					["plane"] = true,
					["helicopter"] = true,
				},
			},
			args = {
				{
					{
						params = {
							["pattern"] = {
								fct = "C_getOrbitPattern",
							},
						},
						multi = false,
						type = "string",
					},
				}, -- fin Obligatoire
				{
					{
						params = {
							["point"] = {
								fct = "C_getPoint2D",
							},
						},
						multi = false,
						type = "table",
					},
					{
						params = {
							["point2"] = {
								fct = "C_getPoint2D",
							},
						},
						multi = false,
						type = "table",
					},
					{
						params = {
							["speed"] = {
							},
						},
						multi = false,
						min = 0,
						type = "number",
					},
					{
						params = {
							["altitude"] = {
							},
						},
						multi = false,
						min = 0,
						type = "number",
					},
				}, -- fin Optionnel
			},
		},
		["AWACS"] = { -- Enroute task
			id = "AWACS",
			filters = {
				type = {
					["plane"] = true,
					["helicopter"] = true,
				},
			},
			args = {
				{
				}, -- fin Obligatoire
				{
				}, -- fin Optionnel
			},
		},
		["TANKER"] = { -- Enroute task
			id = "Tanker",
			filters = {
				type = {
					["plane"] = true,
					["helicopter"] = true,
				},
			},
			args = {
				{
				}, -- fin Obligatoire
				{
				}, -- fin Optionnel
			},
		},
		["ENGAGE_GROUP"] = { -- Enroute task
			id = "EngageGroup",
			filters = {
				type = {
					["plane"] = true,
					["helicopter"] = true,
				},
			},
			args = {
				{
					{
						params = {
							["groupId"] = {
								fct = "C_Group_getID",
							},
						},
						multi = false,
						type = "C_Group",
					},
				}, -- fin Obligatoire
				{
					{
						params = {
							["priority"] = {
							},
						},
						multi = false,
						type = "number",
						min = 0,
					},
					{
						params = {
							["weaponType"] = {
								fct = "C_getWeaponFlag",
							},
						},
						multi = false,
						type = "string",
					},
					{
						params = {
							["expend"] = {
								fct = "C_getExpend",
							},
						},
						multi = false,
						type = "string",
					},
					{
						params = {
							["attackQty"] = {
								fct = "C_getNumberWithFlag",
								linkedParams = {
									"attackQtyLimit",
								},
							},
						},
						multi = false,
						type = "number",
						min = 1,
					},
					{
						params = {
							["direction"] = {
							},
						},
						multi = false,
						type = "number",
					},
				}, -- fin Optionnel
			},
		},
		["ENGAGE_TARGETS"] = { -- Enroute task
			id = "EngageTargets",
			filters = {
				type = {
					["plane"] = true,
					["helicopter"] = true,
				},
			},
			args = {
				{
					{
						params = {
							["targetTypes"] = {
								fct = "C_getTargetsType",
							},
						},
						type = "string",
						multi = true,
					},
				}, -- fin Obligatoire
				{
					{
						params = {
							["priority"] = {
							},
						},
						multi = false,
						type = "number",
						min = 0,
					},
					{
						params = {
							["maxDist"] = {
							},
						},
						multi = false,
						type = "number",
						min = 1,
					},
				}, -- fin Optionnel
			},
		},
		["ENGAGE_TARGETS_IN_ZONE"] = { -- Enroute task
			id = "EngageTargetsInZone",
			filters = {
				type = {
					["plane"] = true,
					["helicopter"] = true,
				},
			},
			args = {
				{
					{
						params = {
							["point"] = {
								fct = "C_Circle_getCenterRadius",
								linkedParams = {
									"zoneRadius",
								},
							},
						},
						multi = false,
						type = "C_Circle",
					},
					{
						params = {
							["targetTypes"] = {
								fct = "C_getTargetsType",
							},
						},
						type = "string",
						multi = true,
					},
				}, -- fin Obligatoire
				{
					{
						params = {
							["priority"] = {
							},
						},
						multi = false,
						type = "number",
						min = 0,
					},
				}, -- fin Optionnel
			},
		},
		["ENGAGE_UNIT"] = { -- Enroute task
			id = "EngageUnit",
			filters = {
				type = {
					["plane"] = true,
					["helicopter"] = true,
				},
			},
			args = {
				{
					{
						params = {
							["unitId"] = {
								fct = "C_Unit_getID",
							},
						},
						multi = false,
						type = "C_Unit",
					},
				}, -- fin Obligatoire
				{
					{
						params = {
							["priority"] = {
							},
						},
						multi = false,
						type = "number",
						min = 0,
					},
					{
						params = {
							["weaponType"] = {
								fct = "C_getWeaponFlag",
							},
						},
						multi = false,
						type = "string",
					},
					{
						params = {
							["expend"] = {
								fct = "C_getExpend",
							},
						},
						multi = false,
						type = "string",
					},
					{
						params = {
							["attackQty"] = {
								fct = "C_getNumberWithFlag",
								linkedParams = {
									"attackQtyLimit",
								},
							},
						},
						multi = false,
						type = "number",
						min = 1,
					},
					{
						params = {
							["direction"] = {
							},
						},
						multi = false,
						type = "number",
					},
					{
						params = {
							["groupAttack"] = {
							},
						},
						multi = false,
						type = "boolean",
					},
				}, -- fin Optionnel
			},
		},
		["FAC_ENGAGE_GROUP"] = { -- Enroute task
			id = "FAC_EngageGroup",
			filters = {
				type = {
					["plane"] = true,
					["helicopter"] = true,
					["vehicle"] = true,
				},
			},
			args = {
				{
					{
						params = {
							["groupId"] = {
								fct = "C_Group_getID",
							},
						},
						multi = false,
						type = "C_Group",
					},
				}, -- fin Obligatoire
				{
					{
						params = {
							["priority"] = {
							},
						},
						multi = false,
						type = "number",
						min = 0,
					},
					{
						params = {
							["weaponType"] = {
								fct = "C_getWeaponFlag",
							},
						},
						multi = false,
						type = "string",
					},
					{
						params = {
							["designation"] = {
								fct = "C_getDesignation",
							},
						},
						multi = false,
						type = "string",
					},
					{
						params = {
							["datalink"] = {
							},
						},
						multi = false,
						type = "boolean",
					},
					{
						params = {
							["frequency"] = {
							},
						},
						multi = false,
						type = "number",
						min = 1,
					},
					{
						params = {
							["modulation"] = {
								fct = "C_getModulation",
							},
						},
						multi = false,
						type = "string",
					},
					{
						params = {
							["callname"] = {
								fct = "C_getCallname",
								linkedParams = {
									"number",
								},
							},
						},
						multi = false,
						type = "string",
					},
				}, -- fin Optionnel
			},
		},
	},
	badOptionAIFormationValues = {
		[9] = true,
		[10] = true,
		[655360] = true,
		[655616] = true,
		[720897] = true,
		[720898] = true,
		[851969] = true,
		[851970] = true,
		[917506] = true,
	},
	optionAI = {
		["plane"] = {
			["ROE"] = {
				id = AI.Option.Air.id.ROE,
				values = {
					args = {
						{
							type = "string",
							enum = {
								["WEAPON_FREE"] = AI.Option.Air.val.ROE.WEAPON_FREE,
								["OPEN_FIRE_WEAPON_FREE"] = AI.Option.Air.val.ROE.OPEN_FIRE_WEAPON_FREE,
								["OPEN_FIRE"] = AI.Option.Air.val.ROE.OPEN_FIRE,
								["RETURN_FIRE"] = AI.Option.Air.val.ROE.RETURN_FIRE,
								["WEAPON_HOLD"] = AI.Option.Air.val.ROE.WEAPON_HOLD,
							},
						},
					},
				},
			},
			["FORMATION"] = {
				id = AI.Option.Air.id.FORMATION,
				values = {
					validFct = "C_testFormation",
					args = {
						{
							type = "string",
							enum = {
								["LINE_ABREAST"] = 65536, 
								["TRAIL"] = 131072, 
								["WEDGE"] = 196608, 
								["ECHELON_RIGHT"] = 262144, 
								["ECHELON_LEFT"] = 327680, 
								["FINGER_FOUR"] = 393216, 
								["SPREAD"] = 458752, 
								["BOMBER_ELEMENT"] = 786432,
								["BOMBER_ELEMENT_HEIGHT"] = 851967,
								["FIGHTER_VIC"] = 917504,
							},
						},
						{
							type = "string",
							enum = {
								["CLOSE"] = 1, 
								["OPEN"] = 2,
								["GROUP_CLOSE"] = 3,
							},
						},
					},
				},
			},
			["REACTION_ON_THREAT"] = {
				id = AI.Option.Air.id.REACTION_ON_THREAT,
				values = {
					args = {
						{
							type = "string",
							enum = {
								["NO_REACTION"] = AI.Option.Air.val.REACTION_ON_THREAT.NO_REACTION,
								["PASSIVE_DEFENCE"] = AI.Option.Air.val.REACTION_ON_THREAT.PASSIVE_DEFENCE,
								["EVADE_FIRE"] = AI.Option.Air.val.REACTION_ON_THREAT.EVADE_FIRE,
								["BYPASS_AND_ESCAPE"] = AI.Option.Air.val.REACTION_ON_THREAT.BYPASS_AND_ESCAPE,
								["ALLOW_ABORT_MISSION"] = AI.Option.Air.val.REACTION_ON_THREAT.ALLOW_ABORT_MISSION,
							},
						},
					},
				},
			},
			["RADAR_USING"] = {
				id = AI.Option.Air.id.RADAR_USING,
				values = {
					args = {
						{
							type = "string",
							enum = {
								["NEVER"] = AI.Option.Air.val.RADAR_USING.NEVER,
								["FOR_ATTACK_ONLY"] = AI.Option.Air.val.RADAR_USING.FOR_ATTACK_ONLY,
								["FOR_SEARCH_IF_REQUIRED"] = AI.Option.Air.val.RADAR_USING.FOR_SEARCH_IF_REQUIRED,
								["FOR_CONTINUOUS_SEARCH"] = AI.Option.Air.val.RADAR_USING.FOR_CONTINUOUS_SEARCH,
							},
						},
					},
				},
			},
			["FLARE_USING"] = {
				id = AI.Option.Air.id.FLARE_USING,
				values = {
					args = {
						{
							type = "string",
							enum = {
								["NEVER"] = AI.Option.Air.val.FLARE_USING.NEVER,
								["AGAINST_FIRED_MISSILE"] = AI.Option.Air.val.FLARE_USING.AGAINST_FIRED_MISSILE,
								["FLYING_IN_SAM_WEZ"] = AI.Option.Air.val.FLARE_USING.WHEN_FLYING_IN_SAM_WEZ,
								["FLYING_NEAR_ENEMIES"] = AI.Option.Air.val.FLARE_USING.WHEN_FLYING_NEAR_ENEMIES,
							},
						},
					},
				},
			},
			["ECM_USING"] = {
				id = AI.Option.Air.id.ECM_USING,
				values = {
					args = {
						{
							type = "string",
							enum = {
								["NEVER"] = AI.Option.Air.val.ECM_USING.NEVER_USE,
								["ONLY_LOCKED_BY_RADAR"] = AI.Option.Air.val.ECM_USING.USE_IF_ONLY_LOCK_BY_RADAR,
								["DETECTED_LOCK_BY_RADAR"] = AI.Option.Air.val.ECM_USING.USE_IF_DETECTED_LOCK_BY_RADAR,
								["ALWAYS"] = AI.Option.Air.val.ECM_USING.ALWAYS_USE,
							},
						},
					},
				},
			},
			["MISSILE_ATTACK"] = {
				id = AI.Option.Air.id.MISSILE_ATTACK,
				values = {
					args = {
						{
							type = "string",
							enum = {
								["MAX_RANGE"] = AI.Option.Air.val.MISSILE_ATTACK.MAX_RANGE,
								["NEZ_RANGE"] = AI.Option.Air.val.MISSILE_ATTACK.NEZ_RANGE,
								["HALF_WAY_RMAX_NEZ"] = AI.Option.Air.val.MISSILE_ATTACK.HALF_WAY_RMAX_NEZ,
								["TARGET_THREATEST"] = AI.Option.Air.val.MISSILE_ATTACK.TARGET_THREAT_EST,
								["RANDOM_RANGE"] = AI.Option.Air.val.MISSILE_ATTACK.RANDOM_RANGE,
							},
						},
					},
				},
			},
			["SILENCE"] = {
				id = AI.Option.Air.id.SILENCE,
				values = {
					args = {
						{
							type = "boolean",
						},
					},
				},
			},
			["RTB_BINGO"] = {
				id = AI.Option.Air.id.RTB_ON_BINGO,
				values = {
					args = {
						{
							type = "boolean",
						},
					},
				},
			},
			["PROHIBIT_AA"] = {
				id = AI.Option.Air.id.PROHIBIT_AA,
				values = {
					args = {
						{
							type = "boolean",
						},
					},
				},
			},
			["PROHIBIT_AG"] = {
				id = AI.Option.Air.id.PROHIBIT_AG,
				values = {
					args = {
						{
							type = "boolean",
						},
					},
				},
			},
			["PROHIBIT_AFTER_BURNER"] = {
				id = AI.Option.Air.id.PROHIBIT_AB,
				values = {
					args = {
						{
							type = "boolean",
						},
					},
				},
			},
			["PROHIBIT_JETTISON"] = {
				id = AI.Option.Air.id.PROHIBIT_JETT,
				values = {
					args = {
						{
							type = "boolean",
						},
					},
				},
			},
			["PROHIBIT_WP_REPORT"] = {
				id = AI.Option.Air.id.PROHIBIT_WP_PASS_REPORT,
				values = {
					args = {
						{
							type = "boolean",
						},
					},
				},
			},
			["RTB_OUT_OF_AMMO"] = {
				id = AI.Option.Air.id.RTB_ON_OUT_OF_AMMO,
				values = {
					args = {
						{
							fct = "C_getWeaponFlag",
							type = "string",
						},
					},
				},
			},
		},
		["helicopter"] = {
			["ROE"] = {
				id = AI.Option.Air.id.ROE,
				values = {
					args = {
						{
							type = "string",
							enum = {
								["WEAPON_FREE"] = AI.Option.Air.val.ROE.WEAPON_FREE,
								["OPEN_FIRE_WEAPON_FREE"] = AI.Option.Air.val.ROE.OPEN_FIRE_WEAPON_FREE,
								["OPEN_FIRE"] = AI.Option.Air.val.ROE.OPEN_FIRE,
								["RETURN_FIRE"] = AI.Option.Air.val.ROE.RETURN_FIRE,
								["WEAPON_HOLD"] = AI.Option.Air.val.ROE.WEAPON_HOLD,
							},
						},
					},
				},
			},
			["FORMATION"] = {
				id = AI.Option.Air.id.FORMATION,
				values = {
					validFct = "C_testFormation",
					args = {
						{
							type = "string",
							enum = {
								["COLUMN"] = 720895, 
								["WEDGE"] = 7, 
								["FRONT_RIGHT"] = 655359,
								["FRONT_LEFT"] = 655615,
								["ECHELON_RIGHT"] = 589824, 
								["ECHELON_LEFT"] = 590080, 
							},
						},
						{
							type = "string",
							enum = {
								["70"] = 1, 
								["300"] = 2, 
								["600"] = 3, 
							},
						},
					}
				},
			},
			["REACTION_ON_THREAT"] = {
				id = AI.Option.Air.id.REACTION_ON_THREAT,
				values = {
					args = {
						{
							type = "string",
							enum = {
								["NO_REACTION"] = AI.Option.Air.val.REACTION_ON_THREAT.NO_REACTION,
								["PASSIVE_DEFENCE"] = AI.Option.Air.val.REACTION_ON_THREAT.PASSIVE_DEFENCE,
								["EVADE_FIRE"] = AI.Option.Air.val.REACTION_ON_THREAT.EVADE_FIRE,
								["BYPASS_AND_ESCAPE"] = AI.Option.Air.val.REACTION_ON_THREAT.BYPASS_AND_ESCAPE,
								["ALLOW_ABORT_MISSION"] = AI.Option.Air.val.REACTION_ON_THREAT.ALLOW_ABORT_MISSION,
							},
						},
					},
				},
			},
			["RADAR_USING"] = {
				id = AI.Option.Air.id.RADAR_USING,
				values = {
					args= {
						{
							type = "string",
							enum = {
								["NEVER"] = AI.Option.Air.val.RADAR_USING.NEVER,
								["FOR_ATTACK_ONLY"] = AI.Option.Air.val.RADAR_USING.FOR_ATTACK_ONLY,
								["FOR_SEARCH_IF_REQUIRED"] = AI.Option.Air.val.RADAR_USING.FOR_SEARCH_IF_REQUIRED,
								["FOR_CONTINUOUS_SEARCH"] = AI.Option.Air.val.RADAR_USING.FOR_CONTINUOUS_SEARCH,
							},
						},
					},
				},
			},
			["FLARE_USING"] = {
				id = AI.Option.Air.id.FLARE_USING,
				values = {
					args = {
						{
							type = "string",
							enum = {
								["NEVER"] = AI.Option.Air.val.FLARE_USING.NEVER,
								["AGAINST_FIRED_MISSILE"] = AI.Option.Air.val.FLARE_USING.AGAINST_FIRED_MISSILE,
								["FLYING_IN_SAM_WEZ"] = AI.Option.Air.val.FLARE_USING.WHEN_FLYING_IN_SAM_WEZ,
								["FLYING_NEAR_ENEMIES"] = AI.Option.Air.val.FLARE_USING.WHEN_FLYING_NEAR_ENEMIES,
							},
						},
					},
				},
			},
			["ECM_USING"] = {
				id = AI.Option.Air.id.ECM_USING,
				values = {
					args = {
						{
							type = "string",
							enum = {
								["NEVER"] = AI.Option.Air.val.ECM_USING.NEVER_USE,
								["ONLY_LOCKED_BY_RADAR"] = AI.Option.Air.val.ECM_USING.USE_IF_ONLY_LOCK_BY_RADAR,
								["DETECTED_LOCK_BY_RADAR"] = AI.Option.Air.val.ECM_USING.USE_IF_DETECTED_LOCK_BY_RADAR,
								["ALWAYS"] = AI.Option.Air.val.ECM_USING.ALWAYS_USE,
							},
						},
					},
				},
			},
			["MISSILE_ATTACK"] = {
				id = AI.Option.Air.id.MISSILE_ATTACK,
				values = {
					args = {
						{
							type = "string",
							enum = {
								["MAX_RANGE"] = AI.Option.Air.val.MISSILE_ATTACK.MAX_RANGE,
								["NEZ_RANGE"] = AI.Option.Air.val.MISSILE_ATTACK.NEZ_RANGE,
								["HALF_WAY_RMAX_NEZ"] = AI.Option.Air.val.MISSILE_ATTACK.HALF_WAY_RMAX_NEZ,
								["TARGET_THREATEST"] = AI.Option.Air.val.MISSILE_ATTACK.TARGET_THREAT_EST,
								["RANDOM_RANGE"] = AI.Option.Air.val.MISSILE_ATTACK.RANDOM_RANGE,
							},
						},
					},
				},
			},
			["SILENCE"] = {
				id = AI.Option.Air.id.SILENCE,
				values = {
					args = {
						{
							type = "boolean",
						},
					},
				},
			},
			["RTB_BINGO"] = {
				id = AI.Option.Air.id.RTB_ON_BINGO,
				values = {
					args = {
						{
							type = "boolean",
						},
					},
				},
			},
			["PROHIBIT_AA"] = {
				id = AI.Option.Air.id.PROHIBIT_AA,
				values = {
					args = {
						{
							type = "boolean",
						},
					},
				},
			},
			["PROHIBIT_AG"] = {
				id = AI.Option.Air.id.PROHIBIT_AG,
				values = {
					args = {
						{
							type = "boolean",
						},
					},
				},
			},
			["PROHIBIT_JETTISON"] = {
				id = AI.Option.Air.id.PROHIBIT_JETT,
				values = {
					args = {
						{
							type = "boolean",
						},
					},
				},
			},
			["PROHIBIT_WP_REPORT"] = {
				id = AI.Option.Air.id.PROHIBIT_WP_PASS_REPORT,
				values = {
					args = {
						{
							type = "boolean",
						},
					},
				},
			},
			["RTB_OUT_OF_AMMO"] = {
				id = AI.Option.Air.id.RTB_ON_OUT_OF_AMMO,
				values = {
					args = {
						{
							fct = "C_getWeaponFlag",
							type = "string",
						},
					}
				},
			},
		},
		["vehicle"] = {
			["ROE"] = {
				id = AI.Option.Ground.id.ROE,
				values = {
					args = {
						{
							type = "string",
							enum = {
								["OPEN_FIRE"] = AI.Option.Ground.val.ROE.OPEN_FIRE,
								["RETURN_FIRE"] = AI.Option.Ground.val.ROE.RETURN_FIRE,
								["WEAPON_HOLD"] = AI.Option.Ground.val.ROE.WEAPON_HOLD,
							},
						},
					},
				},
			},
			["ALARM_STATE"] = {
				id = AI.Option.Ground.id.ALARM_STATE,
				values = {
					args = {
						{
							type = "string",
							enum = {
								["AUTO"] = AI.Option.Ground.val.ALARM_STATE.AUTO,
								["RED"] = AI.Option.Ground.val.ALARM_STATE.RED,
								["GREEN"] = AI.Option.Ground.val.ALARM_STATE.GREEN,
							},
						},
					},
				},
			},
			["DISPERSE_ON_ATTACK"] = {
				id = AI.Option.Ground.id.DISPERSE_ON_ATTACK,
				values = {
					args = {
						{
							type = "number",
							min = 0,
							max = 120,
						},
					},
				},
			},
			["SILENCE"] = {
				id = AI.Option.Ground.id.SILENCE,
				values = {
					args = {
						{
							type = "boolean",
						},
					},
				},
			},
		},
		["ship"] = {
			["ROE"] = {
				id = AI.Option.Naval.id.ROE,
				values = {
					args = {
						{
							type = "string",
							enum = {
								["OPEN_FIRE"] = AI.Option.Naval.val.ROE.OPEN_FIRE,
								["RETURN_FIRE"] = AI.Option.Naval.val.ROE.RETURN_FIRE,
								["WEAPON_HOLD"] = AI.Option.Naval.val.ROE.WEAPON_HOLD,
							},
						},
					},
				},
			},
			["SILENCE"] = {
				id = AI.Option.Naval.id.SILENCE,
				values = {
					args = {
						{
							type = "boolean",
						},
					},
				},
			},
		},
	},
	targetAttributePriority = {
		vehicle = {
			["SAM"] = {
				["SAM LL"] = 1,
				["SAM TR"] = 9,
				["SAM SR"] = 5,
			},
			["LR SAM"] = 8,
			["MR SAM"] = 7,
			["SR SAM"] = 6,
			["EWR"] = 5,
			["AAA"] = 4,
			["Armored vehicles"] = 3,
			["Battle airplanes"] = 2,
			["Attack helicopters"] = 2,
			["Unarmed vehicles"] = 1,
		},
		aircraftType = {
			["RQ-1A Predator"] = true,
			["MQ-9 Reaper"] = true,
		},
	},
	typesOfSensor = {
		["VISUAL"] = Controller.Detection.VISUAL,
		["OPTIC"] = Controller.Detection.OPTIC,
		["RADAR"] = Controller.Detection.RADAR,
		["IRST"] = Controller.Detection.IRST,
		["RWR"] = Controller.Detection.RWR,
		["DLINK"] = Controller.Detection.DLINK,
		["ALL"] = true,
	},
	cardinal = {
		["N"] = "NORTH",
		["S"] = "SOUTH",
		["E"] = "EAST",
		["W"] = "WEST",
	},
	weapons = {  -- Unused in ATME actually
		categories = {
			"SHELL",
			"MISSILE",
			"ROCKET",
			"BOMB",
		},
		guidanceType = {
			"INS",
			"IR",
			"RADAR_ACTIVE",
			"RADAR_SEMI_ACTIVE",
			"RADAR_PASSIVE",
			"TV",
			"LASER",
			"TELE",
		},
		missileCategories = {
			"AAM",
			"SAM",
			"BM",
			"ANTI_SHIP",
			"CRUISE",
			"OTHER",    
		},
		warheadTypes = {
			"AP",
			"HE",
			"SHAPED_CHARGE",
		},
	},
	stackTypeExtract = {
		["HEAD"] = {
			start = "last",
			direction = "previous",
		},
		["TAIL"] = {
			start = "first",
			direction = "next",
		},
	},
	multiSegmentMaxPoints = 20,
	polygonMaxVertices = 40,
	debugSwitch = true,					-- Activation ou non du mode affichage debug pour le module Core
	maxTimeSmoke = 300,
	stackTimerMaxTotalCharge = 120,		-- Valeurs de tuning pour optimiser la gestion du timer sur les traitements sécables (stacktimer)
}


-- Données locales à ATME y compris descripteurs de classe créés ultérieurement
local ATMEDatas = {
	exitATME = false,					-- Flag de sortie d'ATME, en cas d'erreur. cf ATMEFct.errorOutputCore
	debugSwitch = false,				-- Activation ou non du mode affichage debug pour le module Core
	error = nil,						-- Erreur : code en cas de retour nil sur une fonction.
	language = "FR",					-- Langue utilisée par défaut
	isRunning = false,					-- isRunning est à false jusqu'au lancement par ATME.run après chargement des modules
	theatreName = "",
	debugLevel = 0,						-- Niveau de debug pour affichage à l'écran
	newPlayer = false,					-- Contournement bug DCS pour les loop radio transmissions
	allInitialGroupNames = {},			-- Contient les nom des groupes initiaux : de la mission ou premier spawn de création directe hors copie.
	allGroupsInMission = {},			-- Fixe les objets définis dans la mission
	allAIUnitsInMission = {},			-- Fixe les objets définis dans la mission
	allStaticObjectsInMission = {},		-- Fixe les objets définis dans la mission
	allPlayerUnitsInMission = {},		-- Fixe les objets définis dans la mission
	allStaticAirbasesInMission = {},	-- Fixe et pas de spawn sur les airfields et FARP
	allAIUnitsAndPlayers = {},			-- Liste de toutes les unités actives joueurs et AI.
	signalCapabilityUnitsToDelete = {},	-- Liste des unités actives venant d'être supprimées et pouvant déclencher un signal 
	players = {},						-- Liste des joueurs actifs
	proxyPlayers = nil, 				-- Table proxy des joueurs pour les modules externes
	oldNbPlayers = 0,
	nbPlayers = 0,
	groups = {},						-- Groupes actifs
	proxyGroups = nil, 					-- Table proxy des groupes pour les modules externes
	AIUnits = {},						-- AIUnit actifs
	proxyAIUnits = nil, 				-- Table proxy des AIUnits pour les modules externes
	spawnedGroups = {},					-- Table de gestion des id XXX max de groupes avec suffixe "Spawned #XXX", une entrée pour un nom de groupe donné
	spawnedUnits = {},					-- Table de gestion des id XXX max de groupes avec suffixe "Spawned #XXX", une entrée pour un nom d'unité donné
	repeatSpawnGroupId = 1,            	-- Nombre total de groupes spawnés en répétition automatique : permet de gérer l'ID repeat des groupes et unités
	staticObjects = {},					-- Objets statiques actifs
	proxyStaticObjects = nil, 			-- Table proxy des AIUnits pour les modules externes
	races = {},							-- Courses créées
	airbasesByID = {},					-- Liste des airbases du théatre indexés par ID (y compris FARP et ship)
	airbases = {},						-- Liste des airbases (y compris FARP et ship)
	modules = {},						-- Liste nommée des modules (utilisée pour ATME & les classes disposant de la variable modules)
	refModules = {},					-- Table référencant les noms de fichier temporaires des modules dans la mission
	readyToBoardGroups = {},			-- Liste des groupes prêts à embarquer
	groupsAlreadyDeleted = {},			-- Liste des noms de groupes déjà détruit une fois au moins
	spawnedGroupsWaypoints = {},		-- Liste pour mémoriser les WP des groupes spawnés.
	groupsOnBoard = {},					-- Liste des groupes embarqués, en cas de destruction du transport
	autoUnloadDatas = {}, 				-- Liste pour le débarquement automatique (à l'arrêt ou dès que posé)
	groupsToRespawn = {}, 				-- Liste des groupes à respawner au prochain cycle timer
	onZoneTaskReady = {},				-- Liste comportant les groupes avec gestion tâche principale pilotée par ATME
	pickupZones = {},					-- Liste des zones DCS déclarées pickupZones.
	newStaticObjectsCategory = {},		-- Liste des objets statiques spawnés et non encore créés suite à S_EVENT_BIRTH
	spawnGroupDatasRepeat = {},			-- Liste des données pour les groupes datas à multiple spawn
	spots = {},							-- Gestion des spots laser et IR associé aux unités AI
	spotsToReassign = {},				-- Spots à réassigner après changement de cibles
	missionsDelayed = {},				-- Missions (taches) à créer avec un délai
	idDCSRadioTransmissions = 0,		-- Compteur de création des radios transmissions
	targetsTracking = {},				-- Table de unités traquant des cibles ennemies
	activatedRadioTransmissions = nil,  -- Table des radios transmissions actives
	waitIfFrequencyLocked = false,		-- Permet de mémoriser une radio transmission si la frequence est verrouillée
	locked = false,						-- Verrouillage lors d'une émission à partir d'un point
	lockedRadioFrequencies = {},		-- Table des radios fréquences verrouillées : Emission en cours, pas de coupure
	radioFrequencyId = {},				-- Table de l'ID pour une fréquence radio donnée
	activatedSmokes = nil,				-- Table pour les smokes actifs
	activatedFlares = nil, 				-- Table pour les flares actifs
	activatedSounds = nil, 				-- Table pour les sounds actifs
	groupsToBoard = nil,				-- Table pour les groupes à embarquer
	signals = nil, 						-- Table de gestion des signaux,
	patrolsToUpdate = nil, 				-- Table des patrouilles en tracking
	markId = 0,							-- Identifiant pour les marqueurs de la carte F10
	totalCharge = 0,					-- Valeur pour le calcul de charge dans le main timer pour lisser (traitements sécables)
	sounds = {},						-- Sons créés dans ATME.
	currentVoice = "",					-- Voix spécifique, vient préfixer les fichiers sons
	unitsReadyToCreate = {},			-- Unités ayant déclenché un S_EVENT_BIRTH pendant un addGroup. Parfois le groupe DCS n'est
										-- alors pas encore initialisé. Aussi, elles sont ensuite intégrées à ATME dès la fin d'exécution
										-- de addgroup.
	groupsReadyToBirth = {},			-- Pour les groupes aircraft, le S_EVENT_BIRTH est déclenché bien après le addGroup. Cette table
										-- permet la mémorisation des informations qui sera utilisée lors du S_EVENT_BIRTH
	newCreatedGroups = {},				-- Liste de gestion des groupes créés et/ou spawnés entre deux cycles timer. Ces listes sont
										-- mises à jour dans la fonction lors de la création d'un groupe pour ATMEDatas.newCreatedGroups. 
										-- Cette table est aussi utilisée pour le spawn avec une key isSpawned mise à jour.
}

-- Tables des fonctions locales à ATME core
local ATMEFct = {}
local ATMEAIIndFct = {}

local POINT_BAD = 0
local POINT_2D = 1
local POINT_3D = 2

local customEventHandler = {}			-- Déclaration du handler d'événements DCS


----------------------------------------------------------------------------------------------------------
-- DEFINITION DES FONCTIONS UTILES DIRECTEMENT A ATME
----------------------------------------------------------------------------------------------------------


ATMEFct.errorOutputCore = function(_module, _fctDefinition, _text, _needObjectPrecision)
	-- errorOutputCore : fonction de base de gestion des erreurs, engendre un arrêt de ATME (plus de réarmement des timers
	
	if ATMEDatas.exitATME == false then
		ATMEFct.setError("FATAL_ERROR")
		
		if (_module == nil or ATMEFct.isObjectClass(_module, ATME.C_Module) == true) and type(_text) == "string" then
			
			local err = debug.traceback()

			local id, text, stack = ATMEFct.analyzeTraceback(err)
		
			local label = "[ATME"
			if ATMEDatas.refModules[id] ~= nil then
				label = label .. "-" .. ATMEDatas.refModules[id]
			end
			
			label = label .. "] Error in "
			
			if ATMEDatas.refModules[id] ~= nil then
				label = label .. "module lua file" 
			else
				label = label .. "script lua (out of a module lua file)"
			end
			
			if text ~= nil then
				label = label .. "\n" .. text .. _fctDefinition .. "\n   -> " .. _text
				
				if _needObjectPrecision == true then
					label = label .. " (or missing ':' before function name)"
				end
			end
			
			label = label .. "\n\nATME STOPPED"
			env.error(label .. "\n\nstack traceback:\n" .. stack, true)
		else
			env.error("[ATME] Function errorOutputCore : Bad parameters\nATME STOPPED", true)
		end
		
		ATMEDatas.exitATME = true
	end
end

ATMEFct.outputCore = function(_module, _text, _level)
	-- outputCore : fonction de base des messages de debug en fonction du niveau et de l'activation ou non du mode debug
	
	if ATMEDatas.exitATME == false then
		if (_module == nil or ATMEFct.isObjectClass(_module, ATME.C_Module) == true) and type(_text) == "string" and type(_level) == "number" then
			local label = "[ATME"
			local debugMode = ATMEConst.debugSwitch
			
			if _module ~= nil then
				label = label .. "-" .. _module:getName()
				debugMode = _module:isDebugOn()
			end
			
			label = label .. "] " .. _text
			if _level > 0 and _level <= ATMEDatas.debugLevel and debugMode == true then
				trigger.action.outText(label, 5)
			end
			
			env.info(label, false)
		else
			env.error("[ATME] Function outputCore : Bad parameters\nATME STOPPED", true)
			ATMEFct.setError("FATAL_ERROR")
			ATMEDatas.exitATME = true
		end
	end
end

ATMEFct.outputVarCore = function(_module, _title, _var, _level)
	if ATMEDatas.exitATME == false then
		if (_module == nil or ATMEFct.isObjectClass(_module, ATME.C_Module) == true) and type(_title) == "string" and type(_level) == "number" then
			local debugMode = ATMEConst.debugSwitch
			local startLabel = "[ATME"
			
			if _module ~= nil then
				startLabel = startLabel .. "-" .. _module:getName()
				debugMode = _module:isDebugOn()
			end
			
			startLabel = startLabel .. "] "
			
			local function outText(_label)
				if _level > 0 and _level <= ATMEDatas.debugLevel then
					trigger.action.outText(_label, 5)
				end
				
				env.info(_label, false)
			end
			
			local function logVar(_v, _title)
				local label = _title
				
				if type(_v) == "boolean" then
					local v = "True"
					if _v == false then
						v = "False"
					end
					label = label .. " : " .. v
				elseif _v ~= nil and type(_v) ~= "function" then
					label = label ..  " : " .. _v
				end
				
				outText(label)
			end
			
			local function logTable(_t, _indent)
				if _indent == nil then
					_indent = "  "
				else
					_indent = _indent .. "  "
				end
				
				local found = false
				for _k, _v in pairs(_t) do
					found = true
					
					if type(_v) == "table" then
						outText(_indent .. "table '" .. _k .. "' listing\n")
						if logTable(_v, _indent) == false then
							outText(_indent .. "  Empty table")
						elseif type(_v.x) == "number" and type(_v.y) == "number" and (_v.z == nil or type(_v.z) == "number") then
							local point = ATME.convertToPoint3D(_v)
							
							local lat, lon, alt = ATME.convertPointToLL(point)
					
							local dirlon, dlon, mlon, slon = ATME.convertToDMS(lon, false)
							local dirlat, dlat, mlat, slat = ATME.convertToDMS(lat, false)
							
							local label 
							if  _v.z == nil then
								label = _indent .. "  Found keys x,y point 2D at lat : "
							else
								label = _indent .. "  Found keys x,y,z point 3D at lat : "
							end
							
							if dirlat < 0 then
								label = label .. "S"
							else
								label = label .. "N"
							end
							label = label .. string.format("%02d°%02d'%02d\"", dlat, mlat, slat) .. " - lon : "
							
							if dirlon < 0 then
								label = label .. "W"
							else
								label = label .. "E"
							end
							
							
							outText(label .. string.format("%03d°%02d'%02d\"", dlon, mlon, slon) .. " - alt : " .. math.floor(alt) .. " m (" .. math.floor(ATME.convertMtoFts(alt)) .. " feet)\n")
						end
					else
						logVar(_v, _indent .. "key '" .. _k .. "' - Type " .. type(_v))
					end
				end
				
				return found
			end
			
			if debugMode == true then
				if type(_var) == "table" then
					startLabel = startLabel .. "Start Table '" .. _title .. "' :\n"
					outText(startLabel)
					if logTable(_var) == false then
						outText("  Empty table")
					end
				else
					logVar(_var, startLabel .. "Var '" .. _title .. "' - Type " .. type(_var))
				end
			end
		else
			env.error("[ATME] Function outputVarCore : Bad parameters\nATME STOPPED", true)
			ATMEFct.setError("FATAL_ERROR")
			ATMEDatas.exitATME = true
		end
	end
end

ATMEFct.setError = function(_code, _datas)
	ATMEDatas.error = {
		code = _code,
		datas = _datas,
	}
end

ATMEFct.copyTable = function(_datas)
	local err = false
	local function _copy(datas)
		if err == false then
			if type(datas) ~= "table" then
				return datas
			end
			
			if getmetatable(_datas) == nil then
				local newTable = {}
				for _index, _value in pairs(datas) do
					newTable[_index] = _copy(_value)
				end
				
				return newTable
			else
				err = true
			end
		end
	end
	
	local t = _copy(_datas)
	if err == false then
		return t
	end
end

ATMEFct.fctZoneTask = {
	[1] = function(_param, _item)
		_param.groupId = ATMEAIIndFct.C_Group_getID(ATMEDatas.groups[_item.targetGroupName])[1]
	end,
}

ATMEFct.onZoneTasks = {	-- Tâche principale pilotable par ATME pour traiter des zones
					-- La fonction d'initialisation des paramètres est indiquée
	["FAC_AttackGroup"] = ATMEFct.fctZoneTask[1],
	["AttackGroup"] = ATMEFct.fctZoneTask[1],
}

ATMEFct.initDCSRadioTransmission = function(_extraDatas)
	-- initDCSRadioTransmission : fonction d'initialisation des paramètres pour les transmissions radio
	-- 						      pour une mise en forme au format DCS
	
	local newRadioTransmission = {
		playlist = _extraDatas.playlist,
		unitName = _extraDatas.unitName,
		autoRestartDCS = _extraDatas.autoRestartDCS,
		tips10 = 0,
		idFrequency = _extraDatas.idFrequency,
		readOnce = _extraDatas.readOnce,
		randomRead = _extraDatas.randomRead,
		replay = true,
		currentReadIndex = 1,
		timeToUnlock = nil,
		started = false,
		voice = _extraDatas.voice,
	}
		
	if _extraDatas.unitName == nil then 			-- Pour la transmission à partir d'un point
		newRadioTransmission.point = _extraDatas.point
		newRadioTransmission.frequency = _extraDatas.frequency
		newRadioTransmission.power = _extraDatas.power
		newRadioTransmission.textId = "Z" .. ATMEDatas.idDCSRadioTransmissions
		ATMEDatas.idDCSRadioTransmissions = ATMEDatas.idDCSRadioTransmissions + 1
		if _extraDatas.modulation == "FM" then 
			newRadioTransmission.modulation = radio.modulation.FM
			newRadioTransmission.modulationString = "FM"
		else
			newRadioTransmission.modulation = radio.modulation.AM
			newRadioTransmission.modulationString = "AM"
		end
	end

	newRadioTransmission.entry = ATMEDatas.activatedRadioTransmissions:add(newRadioTransmission)
	
	if _extraDatas.locked == true then
		if ATMEDatas.lockedRadioFrequencies[_extraDatas.idFrequency] == nil then	
			ATMEDatas.lockedRadioFrequencies[_extraDatas.idFrequency] = {
				bufferedRadioTransmissions = {},
				unitName = _name,
				radioTransmissionEntry = newRadioTransmission.entry,
			}
		end
	else
		if ATMEDatas.lockedRadioFrequencies[_extraDatas.idFrequency] ~= nil then	
			ATMEDatas.lockedRadioFrequencies[_extraDatas.idFrequency] = nil
		end
	end
	
	return newRadioTransmission
end

ATMEFct.startDCSRadioTransmission = function(_radioTransmission)
	-- Pour "trigger.action.radioTransmission", si 4è paramètre à true, la boucle est gérée par DCS directement.

	if _radioTransmission.started == false and _radioTransmission.playlist[_radioTransmission.currentReadIndex].pause == false then
		trigger.action.radioTransmission("l10n/DEFAULT/" .. _radioTransmission.voice .. _radioTransmission.playlist[_radioTransmission.currentReadIndex].fileName,
											_radioTransmission.point , _radioTransmission.modulation,
											_radioTransmission.autoRestartDCS, _radioTransmission.frequency,
											_radioTransmission.power, _radioTransmission.textId)
		_radioTransmission.started = true
	end
end

ATMEFct.stopDCSRadioTransmission = function(_radioTransmission)
	-- Pour "trigger.action.radioTransmission", si 4è paramètre à true, la boucle est gérée par DCS directement.
	
	if _radioTransmission.started == true then
		trigger.action.stopRadioTransmission(_radioTransmission.textId)
		_radioTransmission.started = false
	end
end

ATMEFct.initSoundPlaylist = function(_datas)
	local datas = {}
	local localMembers
	
	if _datas.player ~= nil then
		localMembers = ATMEDatas.C_Player_MT:get(_datas.player:getIndex())
		datas.playerName = _datas.player:getName()
		if localMembers.entry ~= 0 then
			local sound = ATMEDatas.activatedSounds:get(localMembers.entry)
			
			_datas.player:soundStop()
			
			if sound.readOnce == false and _datas.readOnce == true then
				localMembers.soundPause = sound
			end
		end
		
		datas.voice = localMembers.currentVoice
	else
		datas.voice = ATMEDatas.currentVoice
		
		if _datas.coalition ~= nil then
			datas.coalition = _datas.coalition
		elseif _datas.country ~= nil then
			datas.country = _datas.country
		end
	end
	
	datas.randomRead = _datas.randomRead
	datas.readOnce = _datas.readOnce
	datas.playlist = _datas.playlist
	datas.currentReadIndex = 1
	datas.tips = 0
	
	local entry = ATMEDatas.activatedSounds:add(datas)
	
	if localMembers ~= nil then
		localMembers.entry = entry
	else
		ATMEDatas.soundEntry = entry
	end
end

ATMEFct.whichSide = function(_A, _B, _C)
	local vectAB = ATMEFct.C_Vector3D_create(nil, nil, _A, _B)
	local vectAC = ATMEFct.C_Vector3D_create(nil, nil, _A, _C)
	
	local det = vectAB:getX() * vectAC:getZ() - vectAB:getZ() * vectAC:getX()
	
	-- det < 0, C est à gauche de la droite AB
	-- det > 0,  C est à droite de la droite AB
	-- det = 0, C est dans sur la droite AB
	
	if det > 0 then
		return 1
	elseif det < 0 then
		return -1
	else
		return 0
	end
end	

ATMEFct.whichSideLine2D = function(_line2D, _C)
	local vector = _line2D:getVector3D()
	local origin = _line2D:getOrigin()
	
	local vectAC = ATMEFct.C_Vector3D_create(nil, nil, origin, _C)
	
	local det = vector:getX() * vectAC:getZ() - vector:getZ() * vectAC:getX()
	
	-- det < 0, C est à gauche de la droite orientée line2D
	-- det > 0,  C est à droite de la droite orientée line2D
	-- det = 0, C est dans sur la droite orientée line2D
	
	if det > 0 then
		return 1
	elseif det < 0 then
		return -1
	else
		return 0
	end
end		


ATMEFct.isAzimuthInLimits = function(_referencePoint, _azimuth, _targetPoint)
	local vector = ATMEFct.C_Vector3D_create(nil, nil, _referencePoint, _targetPoint)
	local radius = 1000
	
	if vector:getHModule() > 10000 then
		radius = 0.1 * vector:getHModule()
	end
	
	local h = math.sqrt(vector:getHModule()^2 + radius^2)
	local deltaAzimuth = math.deg(math.asin(radius/h))
	local vectorHeading = vector:getAzimuth()

	local minAzimuth = vectorHeading - deltaAzimuth
	local maxAzimuth = vectorHeading + deltaAzimuth

	if maxAzimuth >= 360 then
		maxAzimuth = maxAzimuth - 360
	end
	
	if minAzimuth < 0 then
		minAzimuth = minAzimuth + 360
	end
	
	if _azimuth >= minAzimuth and _azimuth <= maxAzimuth then
		return true
	end
	
	return false
end

ATMEFct.decompString = function(_sequence)
	local tokens = {}
	
	for _word in _sequence:gmatch("[^%s]+") do
		table.insert(tokens, _word)
    end 
   
	if #tokens > 0 then
		return tokens
	end
end

ATMEFct.joinWordsInString = function(_sequence)
	local noSpaceString = ""
	
	for _word in _sequence:gmatch("[^%s]+") do
		noSpaceString = noSpaceString .. _word
    end 
	
	return noSpaceString
end

ATMEFct.compareTags = function(_tags, _tagsToCompare)
	local function findTags(_sequence)
		local index = 1
		local cursor = 1
		local tags = {}
		local err = false
		local lg = _sequence:len()

		while cursor <= lg and err == false do
			local d,f = _sequence:find("[|]", cursor)
			if d ~= nil then
				local s = _sequence:sub(cursor, d - 1)
				local tagsTemp = ATMEFct.decompString(s)

				if tagsTemp ~= nil and #tagsTemp <= 1 then
					if #tagsTemp == 1 then
						tags[index] = tagsTemp[1]
					end
				end
				
				index = index + 1
				cursor = d + 1 
			else
				local s = _sequence:sub(cursor, lg) 
				local tagsTemp = ATMEFct.decompString(s)

				if tagsTemp ~= nil and #tagsTemp == 1 then
					tags[index] = tagsTemp[1]
					index = index + 1
					cursor = lg + 1 
				else
					err = true
				end  
			end
		end

		return err, tags
	end
	
	local err, tags = findTags(_tagsToCompare)

	if err == false then
		local ok = true
		for _i, _tag in ipairs(_tags) do
			if tags[_i] ~= nil and _tag ~= tags[_i] then
				ok = false
			end
		end

		return ok
	else
		ATMEFct.setError("BAD_SEARCH_TAG")
	end
end

ATMEFct.analyzeString = function(_sequence)
	local pBegin = {}
	local pEnd = {}
	local pString = {}
	local index = 1
	
	local cursor = 1
	local lg =  _sequence:len()

	local relativeStatus = {
		"ABSOLUTE",
		"RELATIVE",
	}
      

	local function defineToken(_token)
		local sign = 1
		
		local function returnRelativeStatus(_token)
			local c = string.sub(_token, 1, 1)
			local relative = 1

			if c == "+" then
				relative = 2
			elseif c == "-" then
				relative = 2
				sign = -1
			end

			return relative
		end
		
		local function tokenColor(_token, _item)
			local token = string.upper(_token)
			
			if (ATMEConst.flareColors[token] ~= nil or ATMEConst.smokeColors[token] ~= nil) and token ~= "RANDOM" then
				_item.type = "TOKEN_COLOR"
				_item.status = "ABSOLUTE"
				_item.value = token
				return true
			end
			
			return false
		end
		
		local function tokenTypeSignal(_token, _item)
			local token = string.upper(_token)
			
			if token == "FLARE" or token == "SMOKE" then
				_item.type = "TOKEN_SIGNAL_TYPE"
				_item.status = "ABSOLUTE"
				_item.value = token
				return true
			end
			
			return false
		end
		
		local function tokenAircraftCallsignName(_token, _item)
			local token = string.upper(_token)
			
			if ATMEConst.blueCallsigns.aircrafts[token] ~= nil then
				_item.type = "TOKEN_AIRCRAFT_CALLSIGN_NAME"
				_item.status = "ABSOLUTE"
				_item.value = token
				return true
			end
			
			return false
		end
		
		local function tokenJtacCallsignName(_token, _item)
			local token = string.upper(_token)
			
			if ATMEConst.blueCallsigns.jtacs[token] ~= nil then
				_item.type = "TOKEN_JTAC_CALLSIGN_NAME"
				_item.status = "ABSOLUTE"
				_item.value = token
				return true
			end
			
			return false
		end

		local function tokenTime(_token, _item)
			local str 

			_item.status = relativeStatus[returnRelativeStatus(_token)]
			
			local pos = 1 
			if _item.status == "RELATIVE" then
				pos = 2
			end

			str = string.match(_token,"^%d%d:%d%d:%d%d$",pos)

			if str ~= nil then
				local hd = tonumber(string.sub(str,1,2))
				local md = tonumber(string.sub(str,4,5))
				local sd = tonumber(string.sub(str,7,8))

				if hd >= 0 and hd <= 23 and md >= 0 and md <= 59 and sd >= 0 and sd <= 59 then
					_item.type = "TOKEN_TIME"
					_item.value = (hd * 3600 + md * 60 + sd) * sign
					return true
				end
			end

			return false
		end

		local function tokenNumber(_token, _item)
			local percent = 1
			local s

			if string.sub(_token, _token:len(), _token:len()) == "%" then
				s = string.sub(_token, 1, _token:len() - 1)
				percent = 0.01
			else
				s = string.sub(_token, 1, _token:len())
			end

			local n = tonumber(s)

			if n ~= nil then
				if n == math.floor(n) then
					_item.type = "TOKEN_INTEGER"
				else
					_item.type = "TOKEN_FLOAT"
				end

				_item.status = relativeStatus[returnRelativeStatus(_token)]
				_item.value = n * percent
				return true
			end

			return false
		end
		
		local function tokenBoolean(_token, _item)
			local token = string.upper(_token)

			if token == "TRUE" then  
				_item.type = "TOKEN_INTEGER"
				_item.status = "ABSOLUTE"
				_item.value = 1
				return true
			elseif token == "FALSE" then  
				_item.type = "TOKEN_INTEGER"
				_item.type = "ABSOLUTE"
				_item.value = 0
				return true
			end

			return false
		end
		
		local function tokenTypeRandom(_token, _item)
			local token = string.upper(_token)
			
			if token == "RANDOM" then
				_item.type = "TOKEN_TYPE_RANDOM"
				_item.status = "ABSOLUTE"
				_item.value = token
				return true
			end
			
			return false
		end
		
		local function tokenTypeTime(_token, _item)
			local token = string.upper(_token)
			if token == "TIME" then
				_item.type = "TOKEN_TYPE_TIME"
				_item.status = "ABSOLUTE"
				_item.value = token
				return true
			end
			
			return false
		end
		
		local function tokenTypeFlag(_token, _item)
			local token = string.upper(_token)
			
			if token == "FLAG" then
				_item.type = "TOKEN_TYPE_FLAG"
				_item.status = "ABSOLUTE"
				_item.value = token
				return true
			end
			
			return false
		end
		
		local function tokenTypeWaypoint(_token, _item)
			local token = string.upper(_token)
			
			if token == "WAYPOINT" then
				_item.type = "TOKEN_TYPE_WAYPOINT"
				_item.status = "ABSOLUTE"
				_item.value = token
				return true
			end
			
			return false
		end
		
		local function tokenTypeMaxTurns(_token, _item)
			local token = string.upper(_token)
			
			if token == "MAX_TURNS" then
				_item.type = "TOKEN_TYPE_MAX_TURNS"
				_item.status = "ABSOLUTE"
				_item.value = token
				return true
			end
			
			return false
		end
		
		local function tokenTypeFuel(_token, _item)
			local token = string.upper(_token)
			
			if token == "FUEL_RATIO" then
				_item.type = "TOKEN_TYPE_FUEL_RATIO"
				_item.status = "ABSOLUTE"
				_item.value = token
				return true
			end
			
			return false
		end
		

		local fcts = {
			[1] = tokenTime,
			[2] = tokenNumber,
			[3] = tokenBoolean,
			[4] = tokenTypeRandom,
			[5] = tokenTypeTime,
			[6] = tokenTypeFlag,
			[7] = tokenTypeWaypoint,
			[8] = tokenTypeMaxTurns,
			[9] = tokenTypeFuel,
			[10] = tokenTypeSignal,
			[11] = tokenColor,
			[12] = tokenAircraftCallsignName,
			[13] = tokenJtacCallsignName,
		}

		local item = {}
		local index = 1
		while index <= #fcts and fcts[index](_token, item) == false do
			index = index + 1
		end

		if index > #fcts then
			item.value = _token
			item.type = "TOKEN_ERROR"
			item.status = "ABSOLUTE"
		end

		return item
	end
	
	local function setValue(_start, _end)
		if _sequence:sub(_start,_start) == "'" then
			local ds,fs = string.find(_sequence, "'", _start + 1)
			if ds ~= nil then
				local d,f = string.find(_sequence, "%s+", fs)
				if fs == lg or d ~= nil then
					pBegin[index] = _start
					pEnd[index] = ds
					pString[index] = true

					if d ~= nil then
						return f
					else
						return fs
					end
				end
			end
		end
		
		pBegin[index] = _start
		pEnd[index] = _end
		pString[index] = false   
	end

	while cursor <= lg do
		local d,f = string.find(_sequence, "%s+", cursor)
		if d ~= nil then
			if d == cursor then
				cursor = f + 1
			else
				local fs = setValue(cursor, d - 1)
				
				if fs ~= nil then
					f = fs
				end
					
				cursor = f + 1
				if f < lg then
					index = index + 1
				end
			end
		else
			setValue(cursor, lg)
			cursor = lg + 1
		end
	end

	local tokens = {}
	for i = 1,index do
		if pString[i] == false then
			tokens[i] = defineToken(_sequence:sub(pBegin[i], pEnd[i]))
		else
			local value = ''
			
			if pEnd[i] - pBegin[i] > 1 then
				value = _sequence:sub(pBegin[i] + 1, pEnd[i] - 1)
			end
			tokens[i] = {
				value = value,
				type = "TOKEN_STRING",
				status = "ABSOLUTE",
			}
		end
		tokens[i].pStart = pBegin[i]
		tokens[i].pEnd = pEnd[i]
	end

	return tokens
end

ATMEFct.getTimeValue = function(_rules)
	local tokenError = false
	local timeStart
	local isRelative = false
	
	if type(_rules) == "string" then
		local tokens = ATMEFct.analyzeString(_rules)
		
		if #tokens >= 1 and #tokens <= 3 then
			if #tokens >= 2 and tokens[1].type == "TOKEN_TYPE_RANDOM" then
				if tokens[2].type == "TOKEN_INTEGER" or tokens[2].type == "TOKEN_TIME" then
					local ok = false
					local minRandom = 0
					local maxRandom = 0
					
					if tokens[2].value >= 0 then
						maxRandom = tokens[2].value
						
						if #tokens == 3 then
							minRandom = tokens[2].value
							
							if tokens[3].type == "TOKEN_INTEGER" or tokens[3].type == "TOKEN_TIME" then
								if tokens[3].value >= 0 then
									maxRandom = tokens[3].value
									if tokens[3].status == tokens[2].status then
										ok = true
									else
										tokenError = true
										timeStart = "Parameters #2 & #3 must have same status (+ for all or nothing for all) in string format rules"
									end
								else
									tokenError = true
									timeStart = "Parameter #3 must be >= 0 in string format rules"
								end
							else
								tokenError = true
								timeStart = "Parameter #3 must be number or time value in string format rules"
							end
						else
							ok = true
						end
					else
						tokenError = true
						timeStart = "Parameter #2 must be >= 0 in string format rules"
					end
					
					if ok == true then
						if minRandom >= maxRandom  then
							tokenError = true
							timeStart = "Parameter #2 must be <= Parameter #3 in string format rules"
						else
							if tokens[2].status == "RELATIVE" then
								isRelative = true
							end
						
							timeStart = math.random(minRandom, maxRandom)
						end
					end
				else
					tokenError = true
					timeStart = "Parameter #2 must be number or time value in string format rules"
				end
			elseif tokens[1].type == "TOKEN_INTEGER" or tokens[1].type == "TOKEN_TIME" then
				if tokens[1].value >= 0 then
					if tokens[1].status == "RELATIVE" then
						isRelative = true
					end
					
					timeStart = tokens[1].value
				else
					tokenError = true
					timeStart = "Parameter #1 must be >= 0 in string format rules"
				end
			else
				tokenError = true
				timeStart = "Parameter #1 must be number or time value or 'RANDOM' in string format rules"
			end
		else
			tokenError = true
			timeStart = "Bad string format rules"
		end
	elseif _rules == nil then
		isRelative = true
		timeStart = 0
	else
		isRelative = true
		if _rules >= 0 then
			timeStart = math.floor(_rules)
		else
			tokenError = true
			timeStart = "rules must be >= 0"
		end
	end

	return tokenError, timeStart, isRelative
end

ATMEFct.getRandomDatas = function(_datas)
	local randomSet = false
	local minValue = 0
	local maxValue
	
	if type(_datas) == "string" then
		local tokens = ATMEFct.analyzeString(_datas)
		local ok = false

		if #tokens >= 1 and #tokens <= 3 and (tokens[1].type == "TOKEN_TYPE_RANDOM" or tokens[1].type == "TOKEN_INTEGER") then
			if tokens[1].type == "TOKEN_TYPE_RANDOM" then
				randomSet = true
				if #tokens >= 2 and tokens[2].type == "TOKEN_INTEGER" then
					minValue = tokens[2].value
					
					if #tokens == 3 and tokens[3].type == "TOKEN_INTEGER" then
						maxValue = tokens[3].value
						ok = true
					elseif #tokens == 2 then
						maxValue = minValue
						minValue = 1
						ok = true
					else
						return "Parameter #3 must be number in string format "
					end
				else
					return "Parameter #2 must be number in string format "
				end
				
				if ok == true then
					if minValue >= maxValue then
						return "Parameter #2 must be < Parameter #3 in string format "
					end
				end
			else
				minValue = tokens[1].value
				ok = true
			end
		else
			return "Parameter #1 must be number or 'RANDOM' in string format "
		end
		
		if ok == false then
			return "Bad string format "
		end
	else
		minValue = math.floor(_datas)
	end
	
	return nil, randomSet, minValue, maxValue
end

ATMEFct.searchMainChunk = function(_err)
	local line = string.match(_err,'[^\n]*$')

	local id = string.match(line,'mis%w%w%w%w%w%w%w%w')
	
	return id
end

ATMEFct.analyzeTraceback = function (_err)
	local line = _err
	local id
	local startBack = 1
	local found = false
	local refName
	local last = false
	local numLine

	local _, pos = string.find(_err, "\n") -- La première ligne est ignorée
	pos = pos + 1

	while last == false and found == false do
		local _, f = string.find(_err, "\n", pos)

		if f ~= nil then
			line = string.sub(_err, pos, f - 1)
			id = string.match(line,'mis%w%w%w%w%w%w%w%w')
			startBack = pos
			pos = f + 1
		else -- Dernière ligne
			local d, f = string.find(_err,'[^\n]*$')
			line = string.sub(_err, d, f)
			id = string.match(line,'mis%w%w%w%w%w%w%w%w')

			startBack = d
			last = true
		end
		
		if refName == nil then
			refName = id
		elseif refName ~= id then 
			numLine = string.match(line, ":%d+:")
			if numLine ~= nil then
				found = true
			end	
		end
	end
	
	local text
	if numLine ~= nil then
		numLine = string.sub(numLine, 2, numLine:len() - 1)
		text = "At line " .. numLine .. " - "
	end
	
	return id, text, string.sub(_err, startBack, _err:len())
end

ATMEFct.getErrorPrefix = function(_object)
	ATMEDatas.error = nil
	if _object ~= nil then
		return "Class ATME." .. _object:getClassName().. "\nFunction :\n"
	else
		return "Function ATME."
	end
end

ATMEFct.errUserHandler = function(_handlerName, _isMenuHandler)
	if _isMenuHandler == nil or _isMenuHandler == false then
		ATMEFct.errorOutputCore(nil, "User function assigned to '" .. _handlerName .. "'", "fatal error or try to access a nil value", false)
	else
		ATMEFct.errorOutputCoreerrorOutputCore(nil, "User function assigned to menu '" .. _handlerName .. "'", "fatal error or try to access a nil value", false)
	end
end

ATMEFct.addMark = function(_coalitionName, _groupId, _text, _point, _readOnly, _message)
	ATMEDatas.markId = ATMEDatas.markId + 1
	if _coalitionName ~= nil then
		trigger.action.markToCoalition(ATMEDatas.markId, _text, _point, _coalitionName, _readOnly, _message)
	elseif _groupId ~= nil then
		trigger.action.markToGroup(ATMEDatas.markId, _text, _point, _groupId, _readOnly, _message)
	else
		trigger.action.markToAll(ATMEDatas.markId, _text, _point, _readOnly, _message)
	end
	
	return ATMEDatas.markId
end

ATMEFct.getRandomPlayerFromCoalition = function(_coalitionName)
	local playerUnits = coalition.getPlayers(ATMEConst.coalitionIds[_coalitionName])
	
	return ATMEDatas.players[playerUnits[math.random(1,#playerUnits)]:getName()]
end

ATMEFct.lockFrequency = function(_idFrequency, _radioTransmissionID, _name)			
	if ATMEDatas.lockedRadioFrequencies[_idFrequency] == nil then	
		ATMEDatas.lockedRadioFrequencies[_idFrequency] = {
			bufferedRadioTransmissions = {},
			unitName = _name,
			radioTransmissionID = _radioTransmissionID,
		}
		
		return true
	else
		return false
	end
end

-- isObjectClass : fonction interne ATME pour vérifier si une table est une instance
-- de classe ATME particulière.
ATMEFct.isObjectClass = function(_object, _class)
	local function testObjectClass(_object, _class)
		if _object:getClassName() == _class:getClassName() then
			return true
		else
			local object = _object:getParentClass()
			if object ~= nil then
				return testObjectClass(object, _class)
			end
		end
		
		return false
	end
	
	local function testObjectClassFromName(_object, _name)
		if _object:getClassName() == _name then
			return true
		else
			local object = _object:getParentClass()
			if object ~= nil then
				return testObjectClass(object, _class)
			end
		end
		
		return false
	end

	if type(_object) == "table" and type(_class) == "table" and type(_class.getClassName) == "function" and
			type(_object.getClassName) == "function" then
		return testObjectClass(_object, _class)
	elseif type(_object) == "table" and type(_class) == "string" and type(_object.getClassName) == "function" then
		return testObjectClassFromName(_object, _class)
	end
	
	return false
end

ATMEFct.isReference = function(_reference)
	return ATME.isPoint(_reference) ~= POINT_BAD or ATMEFct.isObjectClass(_reference, ATME.C_Unit) == true or ATMEFct.isObjectClass(_reference, ATME.C_StaticObject) == true 
end

ATMEFct.getPointFromReference = function(_reference)
	if ATME.isPoint(_reference) ~= POINT_BAD then
		return ATME.convertToPoint3D(_reference)
	else
		return _reference:getPosition()
	end
end

ATMEFct.getSurfaceAltitude = function(_point)
	-- getSurfaceAltitude : Donne l'altitude du terrain à la verticale du point
	if  _point.z == nil then
		return land.getHeight({x = _point.x, y = _point.y})
	else
		return land.getHeight({x = _point.x, y = _point.z})
	end
end

ATMEFct.createUserGetPlayersEntry = function()
	-- Gestion des accès dans la table privée players lors d'un accès à partir d'un
	-- module externe. Dans ce cas, seul la lecture de l'instance est possible.
	-- Pas de modification ou de création -> C'est une lecture seule de la table.
	-- Utilisation de ATME.isObjectClass car __index et __newindex appelé directement par lua (externe)
	local proxy = {}
	local mtProxy = {
		__index = function (t, k)
			return ATMEDatas.players[k]
		end,

		__newindex = function (t,k,v)
			-- On ne fait rien, pas de mise à jour
		end,
	}
	
	function proxy.pairs(self)
		return pairs(ATMEDatas.players)
	end

	setmetatable(proxy, mtProxy)
	
	return proxy
end

ATMEFct.createUserGetAIUnitsEntry = function()
	-- Gestion des accès dans la table privée units lors d'un accès à partir d'un
	-- module externe. Dans ce cas, seul la lecture de l'instance est possible.
	-- Pas de modification ou de création -> C'est une lecture seule de la table.
	-- Utilisation de ATME.isObjectClass car __index et __newindex appelé directement par lua (externe)
	local proxy = {}
	local mtProxy = {
		__index = function (t, k)
			return ATMEDatas.AIUnits[k]
		end,

		__newindex = function (t,k,v)
			-- On ne fait rien, pas de mise à jour
		end,
	}
	
	function proxy.pairs(self)
		return pairs(ATMEDatas.AIUnits)
	end

	setmetatable(proxy, mtProxy)
	
	return proxy
end

ATMEFct.createUserGetGroupsEntry = function()
	-- Gestion des accès dans la table privée groups lors d'un accès à partir d'un
	-- module externe. Dans ce cas, seul la lecture de l'instance est possible.
	-- Pas de modification ou de création -> C'est une lecture seule de la table.
	-- Utilisation de ATME.isObjectClass car __index et __newindex appelé directement par lua (externe)
	local proxy = {}
	local mtProxy = {
		__index = function (t, k)
			return ATMEDatas.groups[k]
		end,

		__newindex = function (t,k,v)
			-- On ne fait rien, pas de mise à jour
		end,
	}
	
	function proxy.pairs(self)
		return pairs(ATMEDatas.groups)
	end

	setmetatable(proxy, mtProxy)
	
	return proxy
end

ATMEFct.createUserGetStaticObjectsEntry = function()
	-- Gestion des accès dans la table privée staticObjects lors d'un accès à partir d'un
	-- module externe. Dans ce cas, seul la lecture de l'instance est possible.
	-- Pas de modification ou de création -> C'est une lecture seule de la table.
	-- Utilisation de ATME.isObjectClass car __index et __newindex appelé directement par lua (externe)
	local proxy = {}
	local mtProxy = {
		__index = function (t, k)
			return ATMEDatas.staticObjects[k]
		end,

		__newindex = function (t,k,v)
			-- On ne fait rien, pas de mise à jour
		end,
	}
	
	function proxy.pairs(self)
		return pairs(ATMEDatas.staticObjects)
	end
	
	setmetatable(proxy, mtProxy)
	
	return proxy
end


ATMEDatas.proxyGroups = ATMEFct.createUserGetGroupsEntry()
ATMEDatas.proxyPlayers = ATMEFct.createUserGetPlayersEntry()
ATMEDatas.proxyAIUnits = ATMEFct.createUserGetAIUnitsEntry()
ATMEDatas.proxyStaticObjects = ATMEFct.createUserGetStaticObjectsEntry()

----------------------------------------------------------------------------------------------------------
-- DEFINITION DE LA TABLE ATME ET DES FONCTIONS GENERALES
--
-- Bien que reprenant la structure des classes définie plus loin, ATME n'est pas une classe en tant que telle.
-- ATME définit des fonctions de base et la liste des classes existantes dans ATME_Core. A ce titre, elle n'est
-- pas préfixée par C_
--
-- ATME_MT définit une métatable pour ATME (mt) et pour les extensions de modules afin d'avoir une variable globales
-- ATME.modules["nom du module"] pour les modules lancés. L'entrée "keys" interdit la création de clés nouvelles
-- dans la table ATME.
----------------------------------------------------------------------------------------------------------

ATMEDatas.ATME_MT = {
	mt = {},
	mtModules = {},
	mtStaticObjects = {},
	keys = {
		["C_Vector3D"] = true,
		["C_Line2D"] = true,
		["C_IndexList"] = true,
		["C_Stack"] = true,
		["C_Airbase"] = true,
		["C_Area"] = true,
		["C_F10Menu"] = true,
		["C_Alarm"] = true,
		["C_Module"] = true, 
		["C_Smoke"] = true,
		["C_Flare"] = true,
		["C_StaticObjectSpawn"] = true,
		["C_CoreEvent"] = true,
		["C_EventsMgr"] = true,
		["C_CloningContext"] = true,
		["C_Group"] = true,
		["C_Player"] = true,
		["C_AIUnit"] = true,
		["C_StaticObject"] = true, 
		["C_Race"] = true,
		["C_Task"] = true,
		["C_Route"] = true,
		["C_Sound"] = true,
		["C_Circle"] = true,
		["C_Ring"] = true,
		["C_Rectangle"] = true,
		["C_Polygon"] = true,
		["C_Zone2D"] = true,
		["C_DynamicObject"] = true,
		["C_Unit"] = true,
		["C_MultiSegment2D"] = true,
		["C_PickupZone"] = true,
		["run"] = true,
		["modules"] = true,
		["staticObjects"] = true,
		["onTrackWaypoints"] = true,
	},
	
	keysStaticObjects = {}
}

ATME = {
	getLanguage = function()
		return ATMEDatas.language
	end,
	
	getGroups = function()
		-- getGroups : Retourne le proxy de la table interne -> Limité en lecture seule.
		
		return ATMEDatas.proxyGroups
	end,
	
	getAIUnits = function()
		-- getAIUnits : Retourne le proxy de la table interne -> Limité en lecture seule.
		
		return ATMEDatas.proxyAIUnits
	end,
	
	getStaticObjects = function()
		-- getStaticObjects : Retourne le proxy de la table interne -> Limité en lecture seule.
		
		return ATMEDatas.proxyStaticObjects
	end,
	
	getPlayers = function()
		-- getPlayers : Retourne le proxy de la table interne -> Limité en lecture seule.
		
		return ATMEDatas.proxyPlayers
	end,
	
	isPoint = function(_point)
		-- isPoint : Vérifie si la table passée en paramètre est un point et retourne POINT_BAD (0) si ce n'est pas un point :
		--           Si point 2D si présence de deux nombres _point.x et _point.y -> Retourne POINT_2D (1)
		--			 Si point 3D si présence de trois nombres _point.x, _point.y et _point.z/gModule -> Retourne POINT_3D (2)
		if type(_point) == "table" then
			if type(_point.x) == "number" and type(_point.y) == "number" then
				if type(_point.z) == "number" then
					return POINT_3D
				else
					return POINT_2D
				end
			end
		end
		
		return POINT_BAD
	end,
	
	isPoint2D = function(_point)
		-- isPoint2D : Vérifie si la table passée en paramètre est un point 2D, avec x et y renseignés
		--             Ces nombres sont relatifs au plan horizontal XZ de DCS, y étant en 2D la coordonnée sur Z.
		if type(_point) == "table" then
			if type(_point.x) == "number" and type(_point.y) == "number" then
				return true
			end
		end
		
		return false
	end,
	
	isPoint3D = function(_point)
		-- isPoint3D : Vérifie si la table passée en paramètre est un point 3D, avec x, y et z renseignés
		--             Ces nombres sont relatifs au repère XYZ de DCS
		if type(_point) == "table" then
			if type(_point.x) == "number" and type(_point.y) == "number" then
				if type(_point.z) == "number" then
					return true
				end
			end
		end
		
		return false
	end,
	
	getError = function()
		if ATMEDatas.error ~= nil then
			local errorCode = ATMEDatas.error.code
			local errorDatas = ATMEDatas.error.datas
			ATMEDatas.error = nil
			
			return errorCode, errorDatas
		end
	end,
	
	isObjectClass = function(_object, _class)
		-- isObjectClass : Vérifie la classe d'une instance.
		
		if type(_object) == "table" and type(_class) == "table" and type(_class.getClassName) == "function" and
			type(_object.getClassName) == "function" then
			
			return ATMEFct.isObjectClass(_object, _class)
		end
			  
		return false
	end,
	
	getTheatre = function()
		-- getTheatre : Retourne la carte (map) associée à la mission
		-- 			    actuellement "NEVADA", "CAUCASUS", "NORMANDY" ou ""
		
		return ATMEDatas.theatreName
	end,
	
	getFlag = function(_id)
		-- getFlag : Retourne la valeur d'un flag. 
		-- 			 Pour être compatible avec le flags de l'éditeur de mission, il faut un id entier positif.
		
		local fctDefinition = ATMEFct.getErrorPrefix() .. "getFlag(id)"
		
		if type(_id) == "number" or type(_id) == "string" then
			local id
			if type(_id) == "number" then
				if _id > 0 then
					id = tostring(math.floor(_id))
				else
					ATMEFct.errorOutputCore(nil, fctDefinition, "id must be > 0 if number type", false)
					return
				end
			else
				id = _id
			end
			
			return trigger.misc.getUserFlag(id)
		else
			ATMEFct.errorOutputCore(nil, fctDefinition, "id type must be number", false)
		end
	end,
	
	setFlag = function(_id, _value)
		-- setFlag : Modifie la valeur l'état d'un flag.
		--			 Pour être compatible avec le flags de l'éditeur de mission, il faut un id entier positif. Si le flag
		--			 est modifié ici et qu'il existe un trigger dans l'éditeur sur ce même flag pour la valeur renseignée,
		--           le trigger défini dans l'éditeur de mission sera déclenché
		
		local fctDefinition = ATMEFct.getErrorPrefix() .. "setFlag(id, value)"
		
		if (type(_id) == "number" or type(_id) == "string") and (type(_value) == "number" or type(_value) == "boolean") then
			local id
			if type(_id) == "number" then
				if _id > 0 then
					id = tostring(math.floor(_id))
				else
					ATMEFct.errorOutputCore(nil, fctDefinition, "id must be > 0 if number type", false)
					return
				end
			else
				id = _id
			end
			
			if (type(_value) == "number" and _value >= 0) or type(_value) == "boolean" then
				if type(_value) == "number" then
					_value = math.floor(_value)
				end
				
				trigger.action.setUserFlag(id, _value)
			else
				ATMEFct.errorOutputCore(nil, fctDefinition, "value must be > 0 or true/false", false)
			end
		else
			if type(_id) ~= "number" and type(_id) ~= "string" then
				ATMEFct.errorOutputCore(nil, fctDefinition, "id type must be number or string", false)
			elseif type(_value) ~= "number" and type(_value) ~= "boolean" then
				ATMEFct.errorOutputCore(nil, fctDefinition, "value type must be number or boolean", false)
			end
		end
	end,
	
	getDCSZone = function(_name)
		-- getDCSZone : Retourne une zone définie dans l'éditeur de mission, nil si inexistante.
		
		local fctDefinition = ATMEFct.getErrorPrefix() .. "getDCSZone(name)"
		
		if type(_name) == "string" then
			return trigger.misc.getZone(_name) 
		else
			ATMEFct.errorOutputCore(nil, fctDefinition, "name type must be string", false)
		end
	end,
	
	getTime = function()
		-- getTime : Retourne le temps de la mission.
		
		return timer.getTime()
	end,
	
	copyTable = function(_tableToCopy)
		local fctDefinition = ATMEFct.getErrorPrefix() .. "copyTable(tableToCopy)"
		
		if type(_tableToCopy) == "table" then
			return ATMEFct.copyTable(_tableToCopy)
		else
			ATMEFct.errorOutputCore(nil, fctDefinition, "tableToCopy type must be table", false)
		end
	end,
	
	markToAll = function(_text, _reference, _readOnly, _message)
		local fctDefinition = ATMEFct.getErrorPrefix() .. "markToAll(text, reference, readOnly, [message])"
		
		if type(_text) == "string" and ATMEFct.isReference(_reference) == true and type(_readOnly) == "boolean" and 
					(_message == nil or type(_message) == "string") then
			local point = ATMEFct.getPointFromReference(_reference)
			
			return ATMEFct.addMark(nil, nil, _text, point, _readOnly, _message)
		else
			if type(_text) ~= "string" then
				ATMEFct.errorOutputCore(nil, fctDefinition, "text type must be string", false)
			elseif ATMEFct.isReference(_reference) == false then
				ATMEFct.errorOutputCore(nil, fctDefinition, "reference type must be ATME.C_AIUnit or ATME.C_Player or ATME.C_StaticObject or table (x,y) or (x,y,z)", false)
			elseif type(_readOnly) ~= "boolean" then
				ATMEFct.errorOutputCore(nil, fctDefinition, "readOnly type must be boolean", false)
			elseif _message ~= nil and type(_message) ~= "string" then
				ATMEFct.errorOutputCore(nil, fctDefinition, "message type must be nil or string", false)
			end
		end
	end,
	
	markToCoalition = function(_coalitionName, _text, _reference, _readOnly, _message)
		local fctDefinition = ATMEFct.getErrorPrefix() .. "markToCoalition(coalitionName, text, reference, readOnly, [message])"
		
		if type(_coalitionName) == "string" and type(_text) == "string" and ATMEFct.isReference(_reference) == true and
					type(_readOnly) == "boolean" and (_message == nil or type(_message) == "string") then
					
			local point = ATMEFct.getPointFromReference(_reference)
			local coalitionName = string.upper(_coalitionName)
			
			if ATMEConst.coalitionIds[coalitionName] ~= nil then
				return ATMEFct.addMark(ATMEConst.coalitionIds[coalitionName], nil, _text, point, _readOnly, _message)
			else
				ATMEFct.errorOutputCore(nil, fctDefinition, "coalitionName must be 'RED' or 'BLUE'", false)
			end
		else
			if type(_coalitionName) ~= "string" then
				ATMEFct.errorOutputCore(nil, fctDefinition, "coalitionName type must be string", false)
			elseif type(_text) ~= "string" then
				ATMEFct.errorOutputCore(nil, fctDefinition, "text type must be string", false)
			elseif ATMEFct.isReference(_reference) == false then
				ATMEFct.errorOutputCore(nil, fctDefinition, "reference type must be ATME.C_AIUnit or ATME.C_Player or ATME.C_StaticObject or table (x,y) or (x,y,z)", false)
			elseif type(_readOnly) ~= "boolean" then
				ATMEFct.errorOutputCore(nil, fctDefinition, "readOnly type must be boolean", false)
			elseif _message ~= nil and type(_message) ~= "string" then
				ATMEFct.errorOutputCore(nil, fctDefinition, "message type must be nil or string", false)
			end
		end
	end,
	
	markRemove = function(_id)
		local id = math.floor(_id)
		
		if id > 0 and id <= ATMEDatas.markId then
			trigger.action.removeMark(id)
		end
	end,
	
	transmissionLock = function (_locked)
		local fctDefinition = ATMEFct.getErrorPrefix() .. "transmissionLock(locked)"
		
		if type(_locked) == "boolean" then
			ATMEDatas.locked = _locked
		else
			ATMEFct.errorOutputCore(nil, fctDefinition, "locked type must be boolean", false)
		end
	end,
	
	setVoice = function(_name)
		local fctDefinition = ATMEFct.getErrorPrefix() .. "setVoice([name])"
		
		if _name == nil or type(_name) == "string" then
			if _name ~= nil then
				local d, f, temp = _name:find("^(%a[%a%d_]*)")
				
				if temp == _name then
					ATMEDatas.currentVoice = _name
				else
					ATMEFct.errorOutputCore(nil, fctDefinition, "name bad format", false)
				end
			else
				ATMEDatas.currentVoice = ""
			end
		else
			ATMEFct.errorOutputCore(nil, fctDefinition, "name type must be nil or string", false)
		end
	end,
	
	getVoice = function()
		if ATMEDatas.currentVoice ~= "" then
			return ATMEDatas.currentVoice
		end
	end,
	
	soundForAll = function(_text, _randomRead)
		local fctDefinition = ATMEFct.getErrorPrefix() .. "soundForAll(text, [randomRead])"
		
		if type(_text) == "string" and (_randomRead == nil or type(_randomRead) == "boolean") then
			local randomRead = false
			
			if type(_randomRead) == "boolean" then
				randomRead = _randomRead
			end
			
			local err, playlist = ATMEFct.C_Sound_getPlaylist(_text, randomRead)

			if err == true then
				ATMEFct.errorOutputCore(nil, fctDefinition, playlist, false)
				return
			end

			if playlist == nil then
				ATMEFct.errorOutputCore(nil, fctDefinition, "text string has no sound token", false)
				return
			end
		
			ATMEFct.initSoundPlaylist({
										randomRead = randomRead, 
										readOnce = true, 
										playlist = playlist,
									})
		else
			if type(_text) ~= "string" then
				ATMEFct.errorOutputCore(nil, fctDefinition, "text type must be string", false)
			elseif _randomRead ~= nil and type(_randomRead) ~= "boolean" then
				ATMEFct.errorOutputCore(nil, fctDefinition, "randomRead type must be nil or boolean", false)
			end
		end
	end,
	
	soundForCoalition = function(_coalitionName, _text, _randomRead)
		local fctDefinition = ATMEFct.getErrorPrefix() .. "soundForCoalition(coalitionName, text, [randomRead])"
		
		if type(_coalitionName) == "string" and type(_text) == "string" and (_randomRead == nil or type(_randomRead) == "boolean") then
			local coalitionName = string.upper(_coalitionName)
			if ATMEConst.coalitionIds[coalitionName] ~= nil then
				local randomRead = false
				
				if type(_randomRead) == "boolean" then
					randomRead = _randomRead
				end
				
				local err, playlist = ATMEFct.C_Sound_getPlaylist(_text, randomRead)

				if err == true then
					ATMEFct.errorOutputCore(nil, fctDefinition, playlist, false)
					return
				end

				if playlist == nil then
					ATMEFct.errorOutputCore(nil, fctDefinition, "text string has no sound token", false)
					return
				end
			
				ATMEFct.initSoundPlaylist({
											coalition = ATMEConst.coalitionIds[coalitionName],
											randomRead = randomRead, 
											readOnce = true, 
											playlist = playlist,
										})
			else
				ATMEFct.errorOutputCore(nil, fctDefinition, "coalitionName must be 'RED' or 'BLUE'", false)
			end
		else
			if type(_coalitionName) ~= "string" then
				ATMEFct.errorOutputCore(nil, fctDefinition, "coalitionName type must be string", false)
			elseif type(_text) ~= "string" then
				ATMEFct.errorOutputCore(nil, fctDefinition, "text type must be string", false)
			elseif _randomRead ~= nil and type(_randomRead) ~= "boolean" then
				ATMEFct.errorOutputCore(nil, fctDefinition, "randomRead type must be nil or boolean", false)
			end
		end
	end,
	
	soundForCountry = function(_countryName, _text, _randomRead)
		local fctDefinition = ATMEFct.getErrorPrefix() .. "soundForCountry(countryName, text, [randomRead])"
		
		if type(_country) == "string" and type(_text) == "string" and (_randomRead == nil or type(_randomRead) == "boolean") then
			local countryName = string.upper(_countryName)
			if ATMEConst.countries[countryName] ~= nil then
				local randomRead = false
				
				if type(_randomRead) == "boolean" then
					randomRead = _randomRead
				end
				
				local err, playlist = ATMEFct.C_Sound_getPlaylist(_text, randomRead)

				if err == true then
					ATMEFct.errorOutputCore(nil, fctDefinition, playlist, false)
					return
				end

				if playlist == nil then
					ATMEFct.errorOutputCore(nil, fctDefinition, "text string has no sound token", false)
					return
				end
			
				ATMEFct.initSoundPlaylist({
											country = ATMEConst.countries[countryName],
											randomRead = randomRead, 
											readOnce = true, 
											playlist = playlist,
										})
			else
				ATMEFct.errorOutputCore(nil, fctDefinition, "Country " .. _countryName .. " doesn't exist", false)
			end
		else
			if type(_countryName) ~= "string" then
				ATMEFct.errorOutputCore(nil, fctDefinition, "countryName type must be string", false)
			elseif type(_text) ~= "string" then
				ATMEFct.errorOutputCore(nil, fctDefinition, "text type must be string", false)
			elseif _randomRead ~= nil and type(_randomRead) ~= "boolean" then
				ATMEFct.errorOutputCore(nil, fctDefinition, "randomRead type must be nil or boolean", false)
			end
		end
	end,
	
	transmissionOnce = function(_text, _reference, _modulation, _frequency, _power, _randomRead)
		local fctDefinition = ATMEFct.getErrorPrefix() .. "transmissionOnce(text, reference, modulation, frequency, power, [randomRead])"
		
		if type(_text) == "string" and ATMEFct.isReference(_reference) == true and type(_modulation) == "string" and 
					type(_frequency) == "number" and type(_power) == "number" and
					(_randomRead == nil or type(_randomRead) == "boolean") then
			local randomRead = false

			if type(_randomRead) == "boolean" then
				randomRead = _randomRead
			end
			
			if _modulation == "AM" or _modulation == "FM" then
				local powerValue = math.floor(_power)
				local frequencyValue = math.floor(_frequency)
				if frequencyValue > 0 then
					if powerValue > 0 then
						local idFrequency = "FR_" .. string.format("%09d", frequencyValue) .. _modulation
						local err, playlistNew = ATMEFct.C_Sound_getPlaylist(_text, randomRead)

						if err == true then
							ATMEFct.errorOutputCore(nil, fctDefinition, playlistNew, false)
							return
						end

						if playlistNew == nil then
							ATMEFct.errorOutputCore(nil, fctDefinition, "text string has no sound token", false)
							return
						end
						
						local extraDatas = {
							unitName = name,
							playlist = playlistNew,
							autoRestartDCS = false,
							readOnce = true,
							randomRead = randomRead,
							idFrequency = idFrequency,
							point = ATMEFct.getPointFromReference(_reference),
							frequency = frequencyValue,
							modulation = _modulation,
							power = powerValue,
							locked = ATMEDatas.locked,
							voice = ATMEDatas.currentVoice,
						}
						
						if ATMEDatas.lockedRadioFrequencies[idFrequency] == nil then
							local newRadioTransmission = ATMEFct.initDCSRadioTransmission(extraDatas)
							ATMEDatas.radioFrequencyId[idFrequency] = newRadioTransmission.entry
						elseif ATMEDatas.waitIfFrequencyLocked == true then			
							table.insert(ATMEDatas.lockedRadioFrequencies[idFrequency].bufferedRadioTransmissions, extraDatas)
						end
					else
						ATMEFct.errorOutputCore(nil, fctDefinition, "power must be > 0", false)
					end
				else
					ATMEFct.errorOutputCore(nil, fctDefinition, "frequency must be > 0", false)
				end
			else
				ATMEFct.errorOutputCore(nil, fctDefinition, "modulation must be 'AM' or 'FM'", false)
			end
		else
			if type(_text) ~= "string" then
				ATMEFct.errorOutputCore(nil, fctDefinition, "text type must be string", false)
			elseif ATMEFct.isReference(_reference) == false then
				ATMEFct.errorOutputCore(nil, fctDefinition, "reference type must be ATME.C_AIUnit or ATME.C_Player or ATME.C_StaticObject or table (x,y) or (x,y,z)", false)
			elseif type(_modulation) ~= "string" then
				ATMEFct.errorOutputCore(nil, fctDefinition, "modulation type must be string", false)
			elseif type(_frequency) ~= "number" then
				ATMEFct.errorOutputCore(nil, fctDefinition, "frequency type must be number", false)
			elseif type(_power) ~= "number" then
				ATMEFct.errorOutputCore(nil, fctDefinition, "power type must be number", false)
			elseif _randomRead ~= nil and type(_randomRead) ~= "boolean" then
				ATMEFct.errorOutputCore(nil, fctDefinition, "randomRead type must be nil or boolean", false)
			end
		end
	end,
	
	transmissionStart = function(_text, _reference, _modulation, _frequency, _power, _randomRead)
		local fctDefinition = ATMEFct.getErrorPrefix() .. "transmissionStart(text, reference, modulation, frequency, power, [randomRead])"
		
		if type(_text) == "string" and ATMEFct.isReference(_reference) == true and type(_modulation) == "string" and 
				type(_frequency) == "number" and type(_power) == "number" and
				(_randomRead == nil or type(_randomRead) == "boolean") then
				
			local randomRead = false

			if type(_randomRead) == "boolean" then
				randomRead = _randomRead
			end
			
			if _modulation == "AM" or _modulation == "FM" then
				local powerValue = math.floor(_power)
				local frequencyValue = math.floor(_frequency)
				if frequencyValue > 0 then
					if powerValue > 0 then
						local idFrequency = "FR_" .. string.format("%09d", frequencyValue) .. _modulation					
						local err, playlistNew = ATMEFct.C_Sound_getPlaylist(_text, randomRead)

						if err == true then
							ATMEFct.errorOutputCore(nil, fctDefinition, playlistNew, false)
							return
						end

						if playlistNew == nil then
							ATMEFct.errorOutputCore(nil, fctDefinition, "text string has no sound token", false)
							return
						end
						
						local extraDatas = {
							unitName = name,
							playlist = playlistNew,
							autoRestartDCS = false,
							readOnce = false,
							randomRead = randomRead,
							idFrequency = idFrequency,
							point = ATMEFct.getPointFromReference(_reference),
							frequency = frequencyValue,
							modulation = _modulation,
							power = powerValue,
							locked = ATMEDatas.locked,
							voice = ATMEDatas.currentVoice,
						}
						
						if ATMEDatas.lockedRadioFrequencies[idFrequency] == nil then
							local newRadioTransmission = ATMEFct.initDCSRadioTransmission(extraDatas)
							ATMEDatas.radioFrequencyId[idFrequency] = newRadioTransmission.entry
						elseif ATMEDatas.waitIfFrequencyLocked == true then			
							table.insert(ATMEDatas.lockedRadioFrequencies[idFrequency].bufferedRadioTransmissions, extraDatas)
						end
					else
						ATMEFct.errorOutputCore(nil, fctDefinition, "power must be > 0", false)
					end
				else
					ATMEFct.errorOutputCore(nil, fctDefinition, "frequency must be > 0", false)
				end
			else
				ATMEFct.errorOutputCore(nil, fctDefinition, "modulation must be 'AM' or 'FM'", false)
			end
		else
			if type(_text) ~= "string" then
				ATMEFct.errorOutputCore(nil, fctDefinition, "text type must be string", false)
			elseif ATMEFct.isReference(_reference) == false then
				ATMEFct.errorOutputCore(nil, fctDefinition, "reference type must be ATME.C_AIUnit or ATME.C_Player or ATME.C_StaticObject or table (x,y) or (x,y,z)", false)
			elseif type(_modulation) ~= "string" then
				ATMEFct.errorOutputCore(nil, fctDefinition, "modulation type must be string", false)
			elseif type(_frequency) ~= "number" then
				ATMEFct.errorOutputCore(nil, fctDefinition, "frequency type must be number", false)
			elseif type(_power) ~= "number" then
				ATMEFct.errorOutputCore(nil, fctDefinition, "power type must be number", false)
			elseif _randomRead ~= nil and type(_randomRead) ~= "boolean" then
				ATMEFct.errorOutputCore(nil, fctDefinition, "randomRead type must be nil or boolean", false)
			end
		end			
	end,
	
	transmissionLoop = function(_text, _reference, _modulation, _frequency, _power)
		local fctDefinition = ATMEFct.getErrorPrefix() .. "transmissionLoop(text, reference, modulation, frequency, power)"
		
		if type(_text) == "string" and  ATMEFct.isReference(_reference) == true and type(_modulation) == "string" and 
				type(_frequency) == "number" and type(_power) == "number" then
			if _modulation == "AM" or _modulation == "FM" then
				local powerValue = math.floor(_power)
				local frequencyValue = math.floor(_frequency)
				if frequencyValue > 0 then
					if powerValue > 0 then
						local idFrequency = "FR_" .. string.format("%09d", frequencyValue) .. _modulation					
						local err, playlistNew = ATMEFct.C_Sound_getPlaylist(_text, false, true)

						if err == true then
							ATMEFct.errorOutputCore(nil, fctDefinition, playlistNew, false)
							return
						end

						if playlistNew == nil then
							ATMEFct.errorOutputCore(nil, fctDefinition, "text string has no sound token", false)
							return
						end
						
						local extraDatas = {
							unitName = nil,
							playlist = {
								playlistNew[1],
							},
							autoRestartDCS = true,
							readOnce = true,
							randomRead = false,
							idFrequency = idFrequency,
							point = ATMEFct.getPointFromReference(_reference),
							frequency = frequencyValue,
							modulation = _modulation,
							power = powerValue,
							locked = ATMEDatas.locked,
							voice = ATMEDatas.currentVoice,
						}
						
						if ATMEDatas.lockedRadioFrequencies[idFrequency] == nil then
							local newRadioTransmission = ATMEFct.initDCSRadioTransmission(extraDatas)
							ATMEDatas.radioFrequencyId[idFrequency] = newRadioTransmission.entry
						elseif ATMEDatas.waitIfFrequencyLocked == true then			
							table.insert(ATMEDatas.lockedRadioFrequencies[idFrequency].bufferedRadioTransmissions, extraDatas)
						end
					else
						ATMEFct.errorOutputCore(nil, fctDefinition, "power must be > 0", false)
					end
				else
					ATMEFct.errorOutputCore(nil, fctDefinition, "frequency must be > 0", false)
				end
			else
				ATMEFct.errorOutputCore(nil, fctDefinition, "modulation must be 'AM' or 'FM'", false)
			end
		else
			if ATMEFct.isReference(_reference) == false then
				ATMEFct.errorOutputCore(nil, fctDefinition, "reference type must be ATME.C_AIUnit or ATME.C_Player or ATME.C_StaticObject or table (x,y) or (x,y,z)", true)
			elseif type(_modulation) ~= "string" then
				ATMEFct.errorOutputCore(nil, fctDefinition, "modulation type must be string", false)
			elseif type(_frequency) ~= "number" then
				ATMEFct.errorOutputCore(nil, fctDefinition, "frequency type must be number", false)
			elseif type(_power) ~= "number" then
				ATMEFct.errorOutputCore(nil, fctDefinition, "power type must be number", false)
			end
		end		
	end,
	
	transmissionStop = function(_modulation, _frequency, _all)
		-- transmissionStop : Arrête l'émission en cours ou toutes les émissions à partir d'un point.
		
		local fctDefinition = ATMEFct.getErrorPrefix() .. "transmissionStop(modulation, frequency, [all])"
		
		if type(_modulation) == "string" and type(_frequency) == "number" and (_all == nil or type(_all) == "boolean") then
			local all = false
			if type(_all) == "boolean" then
				all = _all
			end
			
			if _modulation == "AM" or _modulation == "FM" then
				local frequencyValue = math.floor(_frequency)
				if frequencyValue > 0 then
					local idFrequency = "FR_" .. string.format("%09d", frequencyValue) .. _modulation
					
					if ATMEDatas.radioFrequencyId[idFrequency] ~= nil then
						local radioTransmission = ATMEDatas.activatedRadioTransmissions:get(ATMEDatas.radioFrequencyId[idFrequency])
						if radioTransmission ~= nil then
							ATMEFct.stopDCSRadioTransmission(radioTransmission)
							
							ATMEDatas.activatedRadioTransmissions:remove(ATMEDatas.radioFrequencyId[idFrequency])
							ATMEDatas.radioFrequencyId[idFrequency] = nil
							
							if ATMEDatas.lockedRadioFrequencies[idFrequency] ~= nil then
								if all == true then
									local index = #ATMEDatas.lockedRadioFrequencies[idFrequency].bufferedRadioTransmissions
									
									while index > 0 do
										if ATMEDatas.lockedRadioFrequencies[idFrequency].bufferedRadioTransmissions[index].unitName == nil then
											table.remove(ATMEDatas.lockedRadioFrequencies[idFrequency].bufferedRadioTransmissions, index)
										end
										
										index = index - 1
									end
								else
									local extraDatas
									local found = false
									while #ATMEDatas.lockedRadioFrequencies[radioTransmission.idFrequency].bufferedRadioTransmissions > 0 and found == false do		
										-- On dépile les transmission en attente sans verrouillage sauf si c'est la dernière
										extraDatas = table.remove(ATMEDatas.lockedRadioFrequencies[radioTransmission.idFrequency].bufferedRadioTransmissions, 1)
										found = extraDatas.locked
									end
									
									if extraDatas ~= nil then
										local newRadioTransmission = ATMEFct.initDCSRadioTransmission(extraDatas)
										ATMEDatas.radioFrequencyId[idFrequency] = newRadioTransmission.entry
									end
								end
								
								if #ATMEDatas.lockedRadioFrequencies[idFrequency].bufferedRadioTransmissions == 0 then
									ATMEDatas.lockedRadioFrequencies[idFrequency] = nil
								end
							end
						end
					end
				else
					ATMEFct.errorOutputCore(nil, fctDefinition, "frequency must be > 0", false)
				end
			else
				ATMEFct.errorOutputCore(nil, fctDefinition, "modulation must be 'AM' or 'FM'", false)
			end
		else
			if type(_modulation) ~= "string" then
				ATMEFct.errorOutputCore(nil, fctDefinition, "modulation type must be string", false)
			elseif type(_frequency) ~= "number" then
				ATMEFct.errorOutputCore(nil, fctDefinition, "frequency type must be number", false)
			elseif _all ~= nil and type(_all) ~= "string" then
				ATMEFct.errorOutputCore(nil, fctDefinition, "all type must be nil or boolean", false)
			end
		end
	end,
	
	transmissionDelayed = function(_wait)
		local fctDefinition = ATMEFct.getErrorPrefix() .. "transmissionDelayed(wait)"
		
		if type(_wait) == "boolean" then
			ATMEDatas.waitIfFrequencyLocked = _wait
		else
			ATMEFct.errorOutputCore(nil, fctDefinition, "wait type must be boolean", false)
		end
	end,
	
	explode = function(_reference, _power)
		-- explode : Génère une explosion au point indiqué.
		
		local fctDefinition = ATMEFct.getErrorPrefix() .. "explode(reference, power)"

		if ATMEFct.isReference(_reference) == true and type(_power) == "number" then
			local power = math.floor(_power)
			if power > 0 then
				trigger.action.explosion(ATMEFct.getPointFromReference(_reference), power)
			else
				ATMEFct.errorOutputCore(nil, fctDefinition, "power must be > 0", false)
			end
		else
			if ATMEFct.isReference(_reference) == false then
				ATMEFct.errorOutputCore(nil, fctDefinition, "reference type must be ATME.C_AIUnit or ATME.C_Player or ATME.C_StaticObject or table (x,y) or (x,y,z)", false)
			elseif type(_power) ~= "number" then
				ATMEFct.errorOutputCore(nil, fctDefinition, "power type must be number", false)
			end
		end
	end,
	
	displayForAll = function(_text, _duration)
		-- displayForAll : Affiche un message à tous les joueurs actifs avec un durée donnée
		
		local fctDefinition = ATMEFct.getErrorPrefix() .. "displayForAll(text, duration)"
		
		if type(_text) == "string" and type(_duration) == "number" then
			if _duration >= 0 then
				trigger.action.outText(_text, _duration)
			else
				ATMEFct.errorOutputCore(nil, fctDefinition, "duration type must be >= 0", false)
			end
		else
			if type(_text) ~= "string" then
				ATMEFct.errorOutputCore(nil, fctDefinition, "text type must be string", false)
			elseif type(_duration) ~= "number" then
				ATMEFct.errorOutputCore(nil, fctDefinition, "duration type must be string", false)
			end
		end
	end,
	
	displayForCoalition = function(_coalitionName, _text, _duration)
		-- displayForCoalition : Affiche un message à tous les joueurs actifs d'une coalition avec une durée donnée
		--                       La coalition doit être "NEUTRAL", "RED" ou "BLUE"
		
		local fctDefinition = ATMEFct.getErrorPrefix() .. "displayForCoalition(coalitionName, text, duration)"
		
		if type(_coalitionName) == "string" and type(_text) == "string" and type(_duration) == "number" then
			if _duration >= 0 then
				local coalitionName = string.upper(_coalitionName)
				if ATMEConst.coalitionIds[coalitionName] ~= nil then
					trigger.action.outTextForCoalition(ATMEConst.coalitionIds[coalitionName], _text, _duration)
				else
					ATMEFct.errorOutputCore(nil, fctDefinition, "coalitionName must be 'RED' or 'BLUE'", false)
				end
			else
				ATMEFct.errorOutputCore(nil, fctDefinition, "duration type must be >= 0", false)
			end
		else
			if type(_coalitionName) ~= "string" then
				ATMEFct.errorOutputCore(nil, fctDefinition, "coalitionName type must be string", false)
			elseif type(_text) ~= "string" then
				ATMEFct.errorOutputCore(nil, fctDefinition, "text type must be string", false)
			elseif type(_duration) ~= "number" then
				ATMEFct.errorOutputCore(nil, fctDefinition, "duration type must be string", false)
			end
		end
	end,
	
	displayForCountry = function(_country, _text, _duration)
		-- displayForCoalition : Affiche un message à tous les joueurs actifs d'une coalition avec une durée donnée
		--                       La nation est celle définie par DCS.
		
		local fctDefinition = ATMEFct.getErrorPrefix() .. "displayForCountry(country, text, duration)"
		
		if type(_country) == "string" and type(_text) == "string" and type(_duration) == "number" then
			if _duration >= 0 then
				_country = string.upper(_country)
				if country.id[_country] ~= nil then
					trigger.action.outTextForCountry(country.id[_country], _text, _duration, false)
				else
					ATMEFct.errorOutputCore(nil, fctDefinition, "country bad name", false)
				end
			else
				ATMEFct.errorOutputCore(nil, fctDefinition, "duration type must be >= 0", false)
			end
		else
			if type(_country) ~= "string" then
				ATMEFct.errorOutputCore(nil, fctDefinition, "country type must be string", false)
			elseif type(_text) ~= "string" then
				ATMEFct.errorOutputCore(nil, fctDefinition, "text type must be string", false)
			elseif type(_duration) ~= "number" then
				ATMEFct.errorOutputCore(nil, fctDefinition, "duration type must be string", false)
			end
		end
	end,
	
	setDebugLevel = function(_level)
		-- setDebugLevel : Définit le niveau de débug. Tout module en mode debug est concerné. 
		--				   Les modules en mode normal ne sont pas concernés
		--                 Ce niveau permet de filtre l'affichage des messages d'erreur pour les niveaux supérieurs ou égaux
		--                (niveau 1, le plus haut à niveau 9 le plus bas).
		
		local fctDefinition = ATMEFct.getErrorPrefix() .. "setDebugLevel(level)"
		
		if type(_level) == "number" then
			if _level >= 0 then
				ATMEDatas.debugLevel = math.floor(_level)
			else
				ATMEFct.errorOutputCore(nil, fctDefinition, "level type must be >= 0", false)
			end
		else
			ATMEFct.errorOutputCore(nil, fctDefinition, "level type must be number", false)
		end
	end,
	
	isSurfaceWater = function(_reference)
		-- isSurfaceWater : Vérifie si un point est au dessus de l'eau
		
		local fctDefinition = ATMEFct.getErrorPrefix() .. "isSurfaceWater(reference)"
		
		if ATMEFct.isReference(_reference) == true then
			local point = ATMEFct.getPointFromReference(_reference)
			
			local landType = land.getSurfaceType({
													x = point.x,
													y = point.z,
												})
			
			return landType == land.SurfaceType.WATER or landType == land.SurfaceType.SHALLOW_WATER
		else
			ATMEFct.errorOutputCore(nil, fctDefinition, "reference type must be ATME.C_AIUnit or ATME.C_Player or ATME.C_StaticObject or table (x,y) or (x,y,z)", false)
		end
	end,
	
	isSurfaceRunway = function(_reference)
		-- isSurfaceRunway : Vérifie si un point est au dessus d'une piste ou d'un taxiway
		
		local fctDefinition = ATMEFct.getErrorPrefix() .. "isSurfaceRunway(reference)"
		
		if ATMEFct.isReference(_reference) == true then
			local point = ATMEFct.getPointFromReference(_reference)
			
			local landType = land.getSurfaceType({
													x = point.x,
													y = point.z,
												})
			
			return landType == land.SurfaceType.RUNWAY
		else
			ATMEFct.errorOutputCore(nil, fctDefinition, "reference type must be ATME.C_AIUnit or ATME.C_Player or ATME.C_StaticObject or table (x,y) or (x,y,z)", false)
		end
	end,
	
	isSurfaceLand = function(_reference)
		-- isSurfaceRunway : Vérifie si un point est au dessus de la terre hors piste ou taxiway
		
		local fctDefinition = ATMEFct.getErrorPrefix() .. "isSurfaceLand(reference)"
		
		if ATMEFct.isReference(_reference) == true then
			local point = ATMEFct.getPointFromReference(_reference)
			
			local landType = land.getSurfaceType({
													x = point.x,
													y = point.z,
												})
			
			return landType == land.SurfaceType.LAND
		else
			ATMEFct.errorOutputCore(nil, fctDefinition, "reference type must be ATME.C_AIUnit or ATME.C_Player or ATME.C_StaticObject or table (x,y) or (x,y,z)", false)
		end
	end,
	
	isSurfaceRoad = function(_reference)
		-- isSurfaceRoad : Vérifie si un point est au dessus de la terren hors piste ou taxiway
		
		local fctDefinition = ATMEFct.getErrorPrefix() .. "isSurfaceRoad(reference)"
		
		if ATMEFct.isReference(_reference) == true then
			local point = ATMEFct.getPointFromReference(_reference)
			
			local landType = land.getSurfaceType({
													x = point.x,
													y = point.z,
												})
			
			return landType == land.SurfaceType.ROAD
		else
			ATMEFct.errorOutputCore(nil, fctDefinition, "reference type must be ATME.C_AIUnit or ATME.C_Player or ATME.C_StaticObject or table (x,y) or (x,y,z)", false)
		end
	end,

	getSurfaceAltitude = function(_reference)
		-- getSurfaceAltitude : Donne l'altitude du terrain à la verticale du point
		
		local fctDefinition = ATMEFct.getErrorPrefix() .. "getSurfaceAltitude(reference)"
		
		if  ATMEFct.isReference(_reference) == true then
			return ATMEFct.getSurfaceAltitude(ATMEFct.getPointFromReference(_reference))
		else
			ATMEFct.errorOutputCore(nil, fctDefinition, "reference type must be ATME.C_AIUnit or ATME.C_Player or ATME.C_StaticObject or table (x,y) or (x,y,z)", false)
		end
	end,
	
	getPointAltitude = function(_point)
		-- getPointAltitude : Donne l'altitude du point. Si le point est 2D, ce sera
		--					  l'altitude du terrain
		
		local fctDefinition = ATMEFct.getErrorPrefix() .. "getPointAltitude(point)"
		
		local isPoint = ATME.isPoint(_point)
		if  isPoint ~= POINT_BAD then
			if isPoint == POINT_3D then
				return _point.y
			else
				return ATMEFct.getSurfaceAltitude(_point)
			end
		else
			ATMEFct.errorOutputCore(nil, fctDefinition, "point type must be table (x,y) or (x,y,z)", false)
		end
	end,
	
	convertToPoint3D = function(_point)
		-- Permet de convertir un point en point 3D
		-- afin de s'assurer que le point retourné est bien 3D.
		
		local fctDefinition = ATMEFct.getErrorPrefix() .. "convertToPoint3D(point)"
		
		if ATME.isPoint(_point) ~= POINT_BAD then
			local point = {}
			
			point.x = _point.x
			if ATME.isPoint(_point) == POINT_2D then
				point.z = _point.y
				point.y = ATMEFct.getSurfaceAltitude(_point)
			else
				point.y = _point.y
				point.z = _point.z
			end
			
			return point
		else
			ATMEFct.errorOutputCore(nil, fctDefinition, "point type must be table (x,y) or (x,y,z)", false)
		end
	end,
	
	arePointsVisible = function(_pA, _pB)
		-- arePointsVisible : Vérifie si deux points sont mutuellement visibles (ie non masqués) par le terrain
		
		local fctDefinition = ATMEFct.getErrorPrefix() .. "arePointsVisible(pA, pB)"
		
		local isPointA = ATME.isPoint(_pA)
		local isPointB = ATME.isPoint(_pB)
		
		if isPointA ~= POINT_BAD and isPointB ~= POINT_BAD then
			local pA = ATME.convertToPoint3D(_pA)
			local pB = ATME.convertToPoint3D(_pB)
			
			-- Ajout d'un offset sur l'altitude pour éviter un pb si l'objet est sur le 
			-- sol avec une altitude dans le sol (cf doc DCS pour land.isVisible)
			pA.y = pA.y + 3
			pB.y = pB.y + 3
			return land.isVisible(pA, pB)
		else
			if isPointA == POINT_BAD then
				ATMEFct.errorOutputCore(nil, fctDefinition, "pA type must be table (x,y) or (x,y,z)", false)
			elseif isPointB == POINT_BAD then
				ATMEFct.errorOutputCore(nil, fctDefinition, "pB type must be table (x,y) or (x,y,z)", false)
			end
		end
	end,
	
	getTemperatureAndPressure = function(_reference)
		-- getWindVector : Retourne un instance de ATME.C_Vector3D correspond au vecteur vent
		--                 avec ou sans turbulences
		
		local fctDefinition = ATMEFct.getErrorPrefix() .. "getTemperatureAndPressure(reference)"
		
		if  ATMEFct.isReference(_reference) == true then
			local point = ATMEFct.getPointFromReference(_reference)
			
			return atmosphere.getTemperatureAndPressure(point) 
		else
			ATMEFct.errorOutputCore(nil, fctDefinition, "reference type must be ATME.C_AIUnit or ATME.C_Player or ATME.C_StaticObject or table (x,y) or (x,y,z)", false)
		end
	end,
	
	getWindVector = function(_reference, _withTurbulence)
		-- getWindVector : Retourne un instance de ATME.C_Vector3D correspond au vecteur vent
		--                 avec ou sans turbulences
		
		local fctDefinition = ATMEFct.getErrorPrefix() .. "getWindVector(reference, withTurbulence)"
		
		if  ATMEFct.isReference(_reference) == true and type(_withTurbulence) == "boolean" then
			local point = ATMEFct.getPointFromReference(_reference)
			
			local alt = ATMEFct.getSurfaceAltitude(point)
			if point.y - alt < 20 then 
				point.y = alt + 20
			end
			
			if _withTurbulence == true then
				local wind = atmosphere.getWindWithTurbulence(point)
				return ATMEFct.C_Vector3D_create(nil, nil, wind) 
			else
				local wind = atmosphere.getWind(point)
				return ATMEFct.C_Vector3D_create(nil, nil, wind) 
			end
		else
			if ATMEFct.isReference(_reference) == false then
				ATMEFct.errorOutputCore(nil, fctDefinition, "reference type must be ATME.C_AIUnit or ATME.C_Player or ATME.C_StaticObject or table (x,y) or (x,y,z)", false)
			elseif type(_withTurbulence) ~= "boolean" then
				ATMEFct.errorOutputCore(nil, fctDefinition, "withTurbulence type must be boolean", false)
			end
		end
	end,
	
	getWindSpeed = function(_reference, _withTurbulence)
		-- getWindSpeed : Retourne la vitesse du vent calculée sur les 3 dimensions
		
		local fctDefinition = ATMEFct.getErrorPrefix() .. "getWindSpeed(reference, withTurbulence)"
		
		if ATMEFct.isReference(_reference) == true and type(_withTurbulence) == "boolean" then
			local wind = ATME.getWindVector(_reference, _withTurbulence)

			return wind:getModule()
		else
			if ATMEFct.isReference(_reference) == false then
				ATMEFct.errorOutputCore(nil, fctDefinition, "reference type must be ATME.C_AIUnit or ATME.C_Player or ATME.C_StaticObject or table (x,y) or (x,y,z)", false)
			elseif type(_withTurbulence) ~= "boolean" then
				ATMEFct.errorOutputCore(nil, fctDefinition, "withTurbulence type must be boolean", false)
			end
		end
	end,
	
	getWindHSpeed = function(_reference, _withTurbulence)
		-- getWindSpeed : Retourne la vitesse horizontale du vent calculée sur les 2 dimensions x et z
		
		local fctDefinition = ATMEFct.getErrorPrefix() .. "getWindHSpeed(reference, withTurbulence)"
		
		if ATMEFct.isReference(_reference) == true and type(_withTurbulence) == "boolean" then
			local wind = ATME.getWindVector(_reference, _withTurbulence)

			return wind:getHModule()
		else
			if ATMEFct.isReference(_reference) == false then
				ATMEFct.errorOutputCore(nil, fctDefinition, "reference type must be ATME.C_AIUnit or ATME.C_Player or ATME.C_StaticObject or table (x,y) or (x,y,z)", false)
			elseif type(_withTurbulence) ~= "boolean" then
				ATMEFct.errorOutputCore(nil, fctDefinition, "withTurbulence type must be boolean", false)
			end
		end
	end,
	
	getWindAzimuth = function(_reference, _withTurbulence)
		-- getWindAzimuth : Retourne l'azimuth du vent (attention pas son origine mais sa direction)
		
		local fctDefinition = ATMEFct.getErrorPrefix() .. "getWindAzimuth(reference, withTurbulence)"
		
		if ATMEFct.isReference(_reference) == true and type(_withTurbulence) == "boolean" then
			local wind = ATME.getWindVector(_reference, _withTurbulence)

			return wind:getAzimuth()
		else
			if ATMEFct.isReference(_reference) == false then
				ATMEFct.errorOutputCore(nil, fctDefinition, "reference type must be ATME.C_AIUnit or ATME.C_Player or ATME.C_StaticObject or table (x,y) or (x,y,z)", false)
			elseif type(_withTurbulence) ~= "boolean" then
				ATMEFct.errorOutputCore(nil, fctDefinition, "withTurbulence type must be boolean", false)
			end
		end
	end,
	
	getTags = function(_text)
		local fctDefinition = ATMEFct.getErrorPrefix() .. "getTags(text)"
		
		if type(_text) == "string" then
			return ATMEFct.decompString(_text)
		else
			ATMEFct.errorOutputCore(nil, fctDefinition, "text type must be string", false)
		end
	end,
		
	convertMtoNM = function(_distance)
		-- convertMtoNM : Convertit des mètres en miles nautiques
		
		local fctDefinition = ATMEFct.getErrorPrefix() .. "convertMtoNM(distance)"
		
		if type(_distance) == "number" then
			return _distance * 0.000539957
		else
			ATMEFct.errorOutputCore(nil, fctDefinition, "distance type must be number", false)
		end
	end,

	convertNMtoM = function(_distance)
		-- convertNMtoM : Convertit des miles nautiques en mètres
		
		local fctDefinition = ATMEFct.getErrorPrefix() .. "convertNMtoM(distance)"
		
		if type(_distance) == "number" then
			return _distance / 0.000539957
		else
			ATMEFct.errorOutputCore(nil, fctDefinition, "distance type must be number", false)
		end
	end,
	
	convertMtoFts = function(_distance)
		-- convertMtoFts : Convertit des mètres en pieds
		
		local fctDefinition = ATMEFct.getErrorPrefix() .. "convertMtoFts(distance)"
		
		if type(_distance) == "number" then
			return _distance * 3.28084
		else
			ATMEFct.errorOutputCore(nil, fctDefinition, "distance type must be number", false)
		end	
	end,
	
	convertFtstoM =  function(_distance)
		-- convertFtstoM : Convertit des pieds en mètres
		
		local fctDefinition = ATMEFct.getErrorPrefix() .. "convertFtstoM(distance)"
		
		if type(_distance) == "number" then
			return _distance / 3.28084
		else
			ATMEFct.errorOutputCore(nil, fctDefinition, "distance type must be number", false)
		end
	end,
	
	convertMpstoNds = function(_speed)
		-- convertMpstoNds : Convertit des m/s en noeuds
		
		local fctDefinition = ATMEFct.getErrorPrefix() .. "convertMpstoNds(speed)"
		
		if type(_speed) == "number" then
			return _speed * 1.9438
		else
			ATMEFct.errorOutputCore(nil, fctDefinition, "speed type must be number", false)
		end
	end,
	
	convertNdstoMps = function(_speed)
		-- convertNdstoMps : Convertit des noeuds en m/s
		
		local fctDefinition = ATMEFct.getErrorPrefix() .. "convertNdstoMps(speed)"
		
		if type(_speed) == "number" then
			return _speed / 1.9438
		else
			ATMEFct.errorOutputCore(nil, fctDefinition, "speed type must be number", false)
		end
	end,

	convertMpstoKph = function(_speed)
		-- convertMpstoKph : Convertit des m/s en km/h
		
		local fctDefinition = ATMEFct.getErrorPrefix() .. "convertMpstoKph(speed)"
		
		if type(_speed) == "number" then
			return _speed * 3.6
		else
			ATMEFct.errorOutputCore(nil, fctDefinition, "speed type must be number", false)
		end
	end,

	convertKphtoMps = function(_speed)
		-- convertKphtoMps : Convertit des km/h en m/s
		
		local fctDefinition = ATMEFct.getErrorPrefix() .. "convertKphtoMps(speed)"
		
		if type(_speed) == "number" then
			return _speed / 3.6
		else
			ATMEFct.errorOutputCore(nil, fctDefinition, "speed type must be number", false)
		end
	end,
	
	convertToDMS = function(_degrees, _secdec)
		-- convertToDMS : Convertit des angles en degrés décimaux soit :
		--                - en degrés/minutes/secondes si _secdec vaut false
		--                - en degrés/minutes/décimales si _secdec vaut true
		
		local fctDefinition = ATMEFct.getErrorPrefix() .. "convertToDMS(degrees, secdec)"
		
		if type(_degrees) == "number" and type(_secdec) == "boolean" then
			local dir = 1
			if _degrees < 0 then
				dir = -1
			end
			
			local dabs = math.abs(_degrees)
			local m = (dabs - math.floor(dabs)) * 60
			local mfrac = m - math.floor(m)
			local s = mfrac * 60
			
			if _secdec == true then
				s = mfrac * 100
			end
			
			return dir, math.floor(dabs), math.floor(m), math.floor(s)
		else
			if type(_degrees) ~= "number" then
				ATMEFct.errorOutputCore(nil, fctDefinition, "degrees type must be number", false)
			elseif type(_secdec) ~= "boolean" then
				ATMEFct.errorOutputCore(nil, fctDefinition, "secdec type must be boolean", false)
			end
		end
	end,
	
	convertToHMSd = function (_seconds)
		-- convertToHMSd : Convertit un temps en secondes en heures/minutes/secondes/100ème
		-- En cas de temps négatif, retourne une valeur négative sur la première valeur significative,
		-- h, m ou s -> exemple : -60s donnera m = -1
		
		local fctDefinition = ATMEFct.getErrorPrefix() .. "convertToHMSd(seconds)"
		
		if type(_seconds) == "number" then
			local seconds = _seconds
			local sign = 1
			if _seconds < 0 then
				seconds = -_seconds
				sign = -1
			end
	
			local h = math.floor(seconds/3600)
			local m =  math.floor((seconds - h * 3600)/60)
			local s = math.floor(seconds - h * 3600 - m * 60)
			local d = (seconds - math.floor(seconds)) * 100
			
			if h > 0 then
				h = h * sign
			elseif m > 0 then
				m = m * sign
			elseif s > 0 then
				s = s * sign
			else
				d = d * sign
			end
			
			return h, m, s, d
		else
			ATMEFct.errorOutputCore(nil, fctDefinition, "seconds type must be number", false)
		end
	end,

	convertPointToLL = function(_point)
		-- convertPointToLL : Convertit un point en coordonnées latitude/longitude/altitude
		
		local fctDefinition = ATMEFct.getErrorPrefix() .. "convertPointToLL(point)"
		
		if ATME.isPoint(_point) ~= POINT_BAD then
			local point = {}
			
			point.x = _point.x
			if ATME.isPoint(_point) == POINT_2D then
				point.z = _point.y
				point.y = ATMEFct.getSurfaceAltitude(_point)
			else
				point.y = _point.y
				point.z = _point.z
			end
			
			return coord.LOtoLL(point)
		else
			ATMEFct.errorOutputCore(nil, fctDefinition, "point type must be table (x,y) or (x,y,z)", false)
		end
	end,
	
	convertLLToPoint = function(_latitude, _longitude, _altitude)
		-- convertLLToPoint : Convertit un triplet latitude/longitude/altitude en un point 3D
		
		local fctDefinition = ATMEFct.getErrorPrefix() .. "convertLLToPoint(latitude, longitude, altitude)"
		
		if type(_latitude) == "number" and type(_longitude) == "number" and type(_altitude) == "number" then
			return coord.LLtoLO(_latitude, _longitude, _altitude)
		else
			if type(_latitude) ~= "number" then
				ATMEFct.errorOutputCore(nil, fctDefinition, "latitude type must be number", false)
			elseif type(_longitude) ~= "number" then
				ATMEFct.errorOutputCore(nil, fctDefinition, "longitude type must be number", false)
			elseif type(_altitude) ~= "number" then
				ATMEFct.errorOutputCore(nil, fctDefinition, "altitude type must be number", false)
			end
		end
	end,
	
	convertLLToMGRS = function(_latitude, _longitude)
		-- convertLLToMGRS : Convertit une latitude/longitude en référence MGRS
		
		local fctDefinition = ATMEFct.getErrorPrefix() .. "convertLLToMGRS(latitude, longitude)"
		
		if type(_latitude) == "number" and type(_longitude) == "number" then
			return coord.LLtoMGRS(_latitude, _longitude)
		else
			if type(_latitude) ~= "number" then
				ATMEFct.errorOutputCore(nil, fctDefinition, "latitude type must be number", false)
			elseif type(_longitude) ~= "number" then
				ATMEFct.errorOutputCore(nil, fctDefinition, "longitude type must be number", false)
			end
		end
	end,
	
	convertMGRSToLL = function(_tableMGRS)
		-- convertMGRSToLL : Convertit une référence MGRS en latitude/longitude
		
		local fctDefinition = ATMEFct.getErrorPrefix() .. "convertMGRSToLL(tableMGRS)"
		
		if type(_tableMGRS) == "table" and type(table.UTMZone) == "string" and type(table.MGRSDigraph) == "string" and type(table.Easting) == "number" and type(table.Northing ) == "number" then
			return coord.MGRStoLL(_tableMGRS)
		else
			ATMEFct.errorOutputCore(nil, fctDefinition, "tableMGRS must have MGRS format", false)
		end
	end,
	
	getHScalarProductFromPoints = function(_A, _B, _C)
		-- HScalarProductFromPoints : Calcule le produit scalaire des vecteurs AB et AC, sur leurs coordonnées x,z
		
		local fctDefinition = ATMEFct.getErrorPrefix() .. "getHScalarProductFromPoints(A, B, C)"
		
		if ATME.isPoint(_A) ~= POINT_BAD and ATME.isPoint(_B) ~= POINT_BAD and ATME.isPoint(_C) ~= POINT_BAD then
			local vectAB = ATMEFct.C_Vector3D_create(nil, nil, _A, _B)
			local vectAC = ATMEFct.C_Vector3D_create(nil, nil, _A, _C)
			
			return vectAB:getX() * vectAC:getX() + vectAB:getZ() * vectAC:getZ()
		else
			if ATME.isPoint(_A) == POINT_BAD then
				ATMEFct.errorOutputCore(nil, fctDefinition, "A type must be table (x,y) or (x,y,z)", false)
			elseif ATME.isPoint(_B) == POINT_BAD then
				ATMEFct.errorOutputCore(nil, fctDefinition, "B type must be table (x,y) or (x,y,z)", false)
			elseif ATME.isPoint(_C) == POINT_BAD then
				ATMEFct.errorOutputCore(nil, fctDefinition, "C type must be table (x,y) or (x,y,z)", false)
			end
		end
	end,
	
	whichSide = function(_referenceA, _referenceB, _referenceC)
		-- whichSide : Vérifie si un point C est à droite ou à gauche d'un axe orienté AB :
		--               - 0 si le point est sur la droite
		--				 - 1 si le point est à droite
		--               - -1 si le point est à gauche
		
		local fctDefinition = ATMEFct.getErrorPrefix() .. "whichSide(referenceA, referenceB, referenceC)"
		
		if ATMEFct.isReference(_referenceA) == true and ATMEFct.isReference(_referenceB) == true and ATMEFct.isReference(_referenceC) == true then
			return ATMEFct.whichSide(ATMEFct.getPointFromReference(_referenceA), ATMEFct.getPointFromReference(_referenceB), ATMEFct.getPointFromReference(_referenceC))
		else
			if ATMEFct.isReference(_referenceA) == false then
				ATMEFct.errorOutputCore(nil, fctDefinition, "referenceA type must be ATME.C_AIUnit or ATME.C_Player or ATME.C_StaticObject or table (x,y) or (x,y,z)", false)
			elseif ATMEFct.isReference(_referenceB) == false then
				ATMEFct.errorOutputCore(nil, fctDefinition, "referenceB type must be ATME.C_AIUnit or ATME.C_Player or ATME.C_StaticObject or table (x,y) or (x,y,z)", false)
			elseif ATMEFct.isReference(_referenceC) == false then
				ATMEFct.errorOutputCore(nil, fctDefinition, "referenceC type must be ATME.C_AIUnit or ATME.C_Player or ATME.C_StaticObject or table (x,y) or (x,y,z)", false)
			end
		end
	end,
	
	coordLocalToDCS = function(_reference, _originReference, _azimuth)
		-- coordLocalToDCS : Transforme les coordonnées locales relatives au repère défini par sa référence d'origine et son azimuth
		-- L'azimuth est en degrés. A noter : le repère est inversé x en vertical et repère xOy indirect (norme DCS)
		
		local fctDefinition = ATMEFct.getErrorPrefix() .. "coordLocalToDCS(reference, originReference, azimuth)"

		if ATMEFct.isReference(_reference) == true and ATMEFct.isReference(_originReference) == true and type(_azimuth) == "number" then
			local angle = math.rad(_azimuth)
			local point = ATMEFct.getPointFromReference(_reference)
			local origin = ATMEFct.getPointFromReference(_originReference)

			return {
				x = origin.x + point.x * math.cos(angle) - point.z * math.sin(angle),
				y = point.y,
				z = origin.z + point.x * math.sin(angle) + point.z * math.cos(angle),
			}
		else
			if ATMEFct.isReference(_reference) == false then
				ATMEFct.errorOutputCore(nil, fctDefinition, "reference type must be ATME.C_AIUnit or ATME.C_Player or ATME.C_StaticObject or table (x,y) or (x,y,z)", false)
			elseif ATMEFct.isReference(_originReference) == false  then
				ATMEFct.errorOutputCore(nil, fctDefinition, "centerReference type must be ATME.C_AIUnit or ATME.C_Player or ATME.C_StaticObject or table (x,y) or (x,y,z)", false)
			elseif type(_azimuth) ~= "number" then
				ATMEFct.errorOutputCore(nil, fctDefinition, "azimuth type must be number", false)
			end
		end
	end,
	
	coordDCSToLocal = function(_reference, _originReference, _azimuth)		
		-- localCoord : Transforme les coordonnées DCS d'une référence en coordonnées locales relatives au repère défini par sa référence 
		-- d'origine en coordonnées DCS et son azimuth
		-- L'azimuth est en degrés. A noter : le repère est inversé x en vertical et repère xOy indirect (norme DCS)
		
		local fctDefinition = ATMEFct.getErrorPrefix() .. "coordDCSToLocal(reference, originReference, azimuth)"
		
		if ATMEFct.isReference(_reference) == true and ATMEFct.isReference(_originReference) == true and type(_azimuth) == "number" then
			local angle = math.rad(_azimuth)
			local point = ATMEFct.getPointFromReference(_reference)
			local origin = ATMEFct.getPointFromReference(_originReference)
			
			return {
				x = (point.x - origin.x) * math.cos(angle) + (point.z - origin.z) * math.sin(angle),
				y = point.y,
				z = -(point.x - origin.x) * math.sin(angle) + (point.z - origin.z) * math.cos(angle),
			}
		else
			if ATMEFct.isReference(_reference) == false then
				ATMEFct.errorOutputCore(nil, fctDefinition, "reference type must be ATME.C_AIUnit or ATME.C_Player or ATME.C_StaticObject or table (x,y) or (x,y,z)", false)
			elseif ATMEFct.isReference(_originReference) == false  then
				ATMEFct.errorOutputCore(nil, fctDefinition, "centerReference type must be ATME.C_AIUnit or ATME.C_Player or ATME.C_StaticObject or table (x,y) or (x,y,z)", false)
			elseif type(_azimuth) ~= "number" then
				ATMEFct.errorOutputCore(nil, fctDefinition, "azimuth type must be number", false)
			end
		end
	end,
}

setmetatable(ATME, ATMEDatas.ATME_MT.mt)

ATMEDatas.ATME_MT.mt.__metatable = "Private"
ATMEDatas.ATME_MT.mt.__newindex = function(t, k, v)
	if ATMEDatas.ATME_MT.keys[k] ~= nil then 
		rawset(t, k, v)
	else
		ATMEFct.errorOutputCore(nil, "ATME : Bad key " .. k, "table locked", false)
	end
end



ATME.staticObjects = {
	createCargo = function(_countryName, _staticObjectName, _typeCargo, _position, _mass, _heading)
		local fctDefinition = "Function ATME.staticObjects.createCargo(countryName, name, typeName, position, mass, [heading])"
		
		if type(_countryName) == "string" and type(_staticObjectName) == "string" and type(_typeCargo) == "string" and 
				(type(_position) == "string" or ATME.isPoint(_position) ~= POINT_BAD) and
				type(_mass) == "number" and (_heading == nil or type(_heading) == "number") then
			if ATMEConst.countries[_countryName] ~= nil then
				if ATMEDatas.staticObjects[_staticObjectName] == nil and 
						ATMEDatas.newStaticObjectsCategory[_staticObjectName] == nil then
						
					local d,f = string.find(_staticObjectName, "|", 1)
							if d == nil then
								d,f = string.find(_staticObjectName:upper(), "%s+SPAWNED%s+", 1)
								if d == nil then
							local point
							local headingValue = _heading
							
							if type(_position) == "string" then
								local zone = ATME.getDCSZone(_position)
								if zone ==  nil then
									ATMEFct.errorOutputCore(nil, fctDefinition, "DCS zone " .. _position .. " unknown", false)
									return
								end
								
								point = {}			
								local angle = 2 * math.pi * math.random()
								local radius = math.random(0, zone.radius)
								point.x = zone.point.x + radius * math.sin(angle)
								point.z = zone.point.z + radius * math.cos(angle)
							else
								point = ATME.convertToPoint3D(_position) 
							end
							
							if _heading == nil then
								headingValue = math.random(0,359)
							end
							
							local typeCargo = string.upper(_typeCargo)
							if ATMEConst.cargos[typeCargo] ~= nil then
								local rateSpecial = ATMEConst.cargos[typeCargo].rate
								if rateSpecial == nil then
									rateSpecial = 100
								end
								
								if _mass > 0 then
									-- L'objet statique est ajouté aux objets de la mission
									-- contrairement aux AIUnit et Players.
									
									if headingValue >= 0 and headingValue <= 359 then
									
										local newStaticObjectDatas = {
											name = _staticObjectName,
											type = ATMEConst.cargos[typeCargo].type,
											x = point.x,
											y = point.z,
											canCargo = true,
											heading = headingValue,
											category = "Cargos",
											dead = false,
											shape_name = ATMEConst.cargos[typeCargo].shape,
											mass = math.floor(_mass),
											rate = rateSpecial,
										}
										
										-- Permet de transmettre la catégorie lors de la création de l'objet. A ce moment
										-- là sera remis à nil
										ATMEDatas.newStaticObjectsCategory[_staticObjectName] = "Cargos"
										
										coalition.addStaticObject(ATMEConst.countries[_countryName], newStaticObjectDatas)
									else
										ATMEFct.errorOutputCore(nil, fctDefinition, "heading must be >= 0 and <= 359", false)
									end
								else
									ATMEFct.errorOutputCore(nil, fctDefinition, "mass must be > 0", false)
								end
							else
								ATMEFct.errorOutputCore(nil, fctDefinition, "TypeCargo " .. _typeCargo .. " unknown", false)
							end
						else
							ATMEFct.errorOutputCore(nil, fctDefinition, "name " .. _staticObjectName .. " can't contain 'Spawned' word", false)
						end
					else
						ATMEFct.errorOutputCore(nil, fctDefinition, "name " .. _staticObjectName .. " can't contain '|' character", false)
					end
				else
					ATMEFct.errorOutputCore(nil, fctDefinition, "Static object " .. _staticObjectName .. " already exists", false)
				end
			else
				ATMEFct.errorOutputCore(nil, fctDefinition, "Country " .. _countryName .. " unknown", false)
			end
		else
			if type(_countryName) ~= "string" then 
				ATMEFct.errorOutputCore(nil, fctDefinition, "countryName type must be string", false)
			elseif type(_staticObjectName) ~= "string" then 
				ATMEFct.errorOutputCore(nil, fctDefinition, "staticObjectName type must be string", false)
			elseif type(_typeCargo) ~= "string" then 
				ATMEFct.errorOutputCore(nil, fctDefinition, "typeCargo type must be string", false)
			elseif ATME.isPoint(_position) == POINT_BAD and type(_position) ~= string then
				ATMEFct.errorOutputCore(nil, fctDefinition, "position type must be string or table (x,y) or (x,y,z)", false)
			elseif type(_mass) ~= "number" then 
				ATMEFct.errorOutputCore(nil, fctDefinition, "mass type must be number", false)
			elseif _heading ~= nil and type(_heading) ~= "number" then
				ATMEFct.errorOutputCore(nil, fctDefinition, "heading type must be number or nil", false)
			end
		end
	end,
	
	createObject = function(_countryName, _staticObjectName, _staticObjectDatas, _position, _heading)
		local fctDefinition = "Function ATME.staticObjects.createObject(countryName, name, datas, position, [heading])"
		
		if type(_countryName) == "string" and type(_staticObjectDatas) == "table" and type(_staticObjectName) == "string" and 
				(type(_position) == "string" or ATME.isPoint(_position) ~= POINT_BAD) and 
				(_heading == nil or type(_heading) == "number") then
			if ATMEConst.countries[_countryName] ~= nil then
				if ATMEDatas.staticObjects[_staticObjectName] == nil and 
							ATMEDatas.newStaticObjectsCategory[_staticObjectName] == nil then
					if type(_staticObjectDatas.category) == "string" and type(_staticObjectDatas.type) == "string" then
						if ATMEConst.staticObjectCategories[string.upper(_staticObjectDatas.category)] ~= nil then
							local d,f = string.find(_staticObjectName, "|", 1)
							if d == nil then
								d,f = string.find(_staticObjectName:upper(), "%s+SPAWNED%s+", 1)
								if d == nil then
									local point
									local headingValue = _heading
									
									if type(_position) == "string" then
										local zone = ATME.getDCSZone(_position)
										if zone ==  nil then
											ATMEFct.errorOutputCore(nil, fctDefinition, "DCS zone " .. _position .. " unknown", false)
											return
										end

										point = {}
										local angle = 2 * math.pi * math.random()
										local radius = math.random(0, zone.radius)
										point.x = zone.point.x + radius * math.sin(angle)
										point.z = zone.point.z + radius * math.cos(angle)
									else
										point = ATME.convertToPoint3D(_position) 
									end
									
									if _heading == nil then
										headingValue = math.random(0,359)
									end
										
									if headingValue >= 0 and headingValue <= 359 then
										local newStaticObjectDatas = {
											name = _staticObjectName,
											type = _staticObjectDatas.type,
											x = point.x,
											y = point.z,
											canCargo = false,
											heading = headingValue,
											category = ATMEConst.staticObjectCategories[string.upper(_staticObjectDatas.category)].category,
											dead = false,
											shape_name = _staticObjectDatas.shape_name,
											livery_id = _staticObjectDatas.livery_id,
										}
										
										-- Permet de transmettre la catégorie lors de la création de l'objet. A ce moment
										-- là sera remis à nil
										ATMEDatas.newStaticObjectsCategory[_staticObjectName] = newStaticObjectDatas.category
										
										coalition.addStaticObject(ATMEConst.countries[_countryName], newStaticObjectDatas)
									else
										ATMEFct.errorOutputCore(nil, fctDefinition, "heading must be >= 0 and <= 359", false)
									end
								else
									ATMEFct.errorOutputCore(nil, fctDefinition, "name " .. _staticObjectName .. " can't contain 'Spawned' word", false)
								end
							else
								ATMEFct.errorOutputCore(nil, fctDefinition, "name " .. _staticObjectName .. " can't contain '|' character", false)
							end
						else
							ATMEFct.errorOutputCore(nil, fctDefinition, "Category " .. _staticObjectDatas.category .. " unknown", false)
						end
					else
						ATMEFct.errorOutputCore(nil, fctDefinition, "Bad type for staticObjectDatas entries", false)
					end
				else
					ATMEFct.errorOutputCore(nil, fctDefinition, "Static object " .. _staticObjectName .. " already exists", false)
				end
				
			else
				ATMEFct.errorOutputCore(nil, fctDefinition, "Country " .. _countryName .. " unknown", false)
			end
		else
			if type(_countryName) ~= "string" then 
				ATMEFct.errorOutputCore(nil, fctDefinition, "countryName type must be string", false)
			elseif type(_staticObjectData) ~= "table" then 
				ATMEFct.errorOutputCore(nil, fctDefinition, "staticObjectDatas type must be table", false)
			elseif type(_staticObjectName) ~= "string" then 
				ATMEFct.errorOutputCore(nil, fctDefinition, "staticObjectName type must be string", false)
			elseif ATME.isPoint(_position) == POINT_BAD and type(_position) ~= string then
				ATMEFct.errorOutputCore(nil, fctDefinition, "position type must be string or table (x,y) or (x,y,z)", false)
			elseif _heading ~= nil and type(_heading) ~= "number" then
				ATMEFct.errorOutputCore(nil, fctDefinition, "heading type must be number or nil", false)
			end
		end
	end,
}

setmetatable(ATME.staticObjects, ATMEDatas.ATME_MT.mtStaticObjects)
ATMEDatas.ATME_MT.mtStaticObjects.__metatable = "Private"
ATMEDatas.ATME_MT.mtStaticObjects.__newindex = function(t, k, v)
	if ATMEDatas.ATME_MT.keysStaticObjects[k] ~= nil then 
		rawset(t, k, v)
	else
		ATMEFct.errorOutputCore(nil,"ATME : ATME.staticObjects Bad key " .. k, "table locked", false)
	end
end


ATME.modules = {}  -- Déclaration de ATME.modules pour les variables globales des modules

setmetatable(ATME.modules, ATMEDatas.ATME_MT.mtModules)
ATMEDatas.ATME_MT.mtModules.__metatable = "Private"
ATMEDatas.ATME_MT.mtModules.__newindex = function(t, k, v)
	if ATMEDatas.modules[k] ~= nil then
		rawset(t, k, v)
	else  
		ATMEFct.errorOutputCore(nil,"ATME : ATME.modules Bad key " .. k, "table locked", false)
	end
end



----------------------------------------------------------------------------------------------------------
-- DEFINITION DES CLASSES D'OBJETS DEFINIS DANS ATME
--
-- Quelques points essentiels :
-- 			- Une classe d'objet est une table lua particulière, préfixée de "C_"
--			- Il existe une notion de classes virtuelles qui sont des regroupements de classes
--			- Une instance d'objet est un objet créé à partir d'une classe, c'est donc aussi une table qui peut
--			  être cependant étendue par le création de méthodes dans le constructeur local C_Class_create.
--			- Les fonctions liées à une classe et non à une instance sont définies dans la classe.
--			- Une classe d'objet a également une classe spéciale suffixée par _MT et locale à ATME_Core. Cette
--            classe définit : 
--				-> la metatable des instances (entrée "mt")
--				-> l'entrée "keys" des instances pour en interdire la création, lors de la création de l'instance. En effet,
--                 le constructeur local C_Class_create crée l'instance et lui associe des méthodes spécifique pour  
--				   les variables locales (closure). Ce sont ces méthodes, non gérées par la metaclasse qui sont listées
--				   dans l'entrée "keys" pour le contrôle des entrées de la table représentant l'instance.
--				-> le nom de la classe entrée "className"
--				-> la création du constructeur "public" de la classe (__call). Par défaut seule la fonction locale
--                 C_Class_create est créée ce qui interdit toute création d'instance dans les modules externes. C'est
--				   le cas pour les classes C_Group (Groupes au format ATME), C_Player (unités joueurs au format ATME),
--                 C_AIUnit (Unités AI au format ATME) et C_StaticObject (objets statiques au format ATME sauf FARP et
--				   Airfields.
--				-> Certaines propriétés dont l'accès ne doit être que local et dont l'accès à la modification pourrait
--  			   engendrer des incohérences. Ces propriétés sont regroupées dans l'entrée "localMembers" et accessibles
--				   par les fonctions appropriées à partir du module ATME_Core uniquement (en lecture comme en écriture).
--				   L'instance contient un index spécifique accessible en lecture seule y compris à partir de modules
--				   externes, mais pour ces derniers cet index ne sert à rien.
----------------------------------------------------------------------------------------------------------


----------------------------------------------------------------------------------------------------------
-- DEFINITION DES CLASSES VIRTUELLES
----------------------------------------------------------------------------------------------------------

----------------------------------------------------------------------------------------------------------
--	ATME.Zone2D : 
--  Classe virtuelle pour
-- 		                   ATME.Polygon
--		                   ATME.C_Circle
--                         ATME.C_Ring
--						   ATME.C_PickupZone
--						   ATME.C_Rectangle
----------------------------------------------------------------------------------------------------------

ATMEDatas.C_Zone2D_MT = {
	className = "C_Zone2D",
	
	mt = {},
}

ATME.C_Zone2D = {
	getClassName = function(self)
		return ATMEDatas.C_Zone2D_MT.className
	end,
	
	getParentClass = function(self)
		return ATMEDatas.C_Zone2D_MT.parentClass
	end,
}

setmetatable(ATME.C_Zone2D, ATMEDatas.C_Zone2D_MT)

ATMEDatas.C_Zone2D_MT.mt.__metatable = "Private"
ATMEDatas.C_Zone2D_MT.mt.__index = ATME.C_Zone2D

ATMEDatas.C_Zone2D_MT.mt.__newindex = function(t, k, v)
	ATMEFct.errorOutputCore(nil, "Function ATME.C_Zone2D : Bad key " .. k, "table locked", false)
end

----------------------------------------------------------------------------------------------------------
--	ATME.C_DynamicObject : 
--  Classe virtuelle pour
-- 		                   ATME.C_Unit
--		                   ATME.C_Group
----------------------------------------------------------------------------------------------------------

ATMEDatas.C_DynamicObject_MT = {
	className = "C_DynamicObject",
	
	mt = {},
}

ATME.C_DynamicObject = {
	getClassName = function(self)
		return ATMEDatas.C_DynamicObject_MT.className
	end,
	
	getParentClass = function(self)
		return ATMEDatas.C_DynamicObject_MT.parentClass
	end,
}

setmetatable(ATME.C_DynamicObject, ATMEDatas.C_DynamicObject_MT)

ATMEDatas.C_DynamicObject_MT.mt.__metatable = "Private"
ATMEDatas.C_DynamicObject_MT.mt.__index = ATME.C_DynamicObject

ATMEDatas.C_DynamicObject_MT.mt.__newindex = function(t, k, v)
	ATMEFct.errorOutputCore(nil, "Function ATME.C_DynamicObject : Bad key " .. k, "table locked", false)
end

----------------------------------------------------------------------------------------------------------
--	ATME.C_Unit : 
--  Classe virtuelle pour
-- 		                   ATME.C_AIUnit
--		                   ATME.C_Player
----------------------------------------------------------------------------------------------------------

ATMEDatas.C_Unit_MT = {
	className = "C_Unit",
	parentClass = ATME.C_DynamicObject,
	
	mt = {},
}

ATME.C_Unit = {
	getClassName = function(self)
		return ATMEDatas.C_Unit_MT.className
	end,
	
	getParentClass = function(self)
		return ATMEDatas.C_Unit_MT.parentClass
	end,
	
	getByName = function(_name)
		if type(_name) == "string" then
			return ATMEDatas.allAIUnitsAndPlayers[_name]
		else
			ATMEFct.errorOutputCore(nil, "Function ATME.C_Unit.getByName(name)", "name type must be string", false)
		end
	end,
}

setmetatable(ATME.C_Unit, ATMEDatas.C_Unit_MT)

ATMEDatas.C_Unit_MT.mt.__metatable = "Private"
ATMEDatas.C_Unit_MT.mt.__index = ATME.C_Unit

ATMEDatas.C_Unit_MT.mt.__newindex = function(t, k, v)
	ATMEFct.errorOutputCore(nil, "Function ATME.C_Unit : Bad key " .. k, "table locked", false)
end
----------------------------------------------------------------------------------------------------------
-- DEFINITION DES CLASSES STANDARD
----------------------------------------------------------------------------------------------------------

----------------------------------------------------------------------------------------------------------
-- Classe ATME.C_IndexList : gère une liste indexée par des entiers. Constructeur de classe accessible aux modules 
-- externes. 
-- Elle optimise la place utilisée sans recourir aux fonctions table.insert etc...
-- Le premier indice commence à 1. En cas de suppression, l'entrée indexée est mise à nil et sera réutilisée
-- au prochain ajout dans la liste. Si toutes les entrées sont utilisées, la liste est étendue d'un élément.
-- De plus en cas de suppression, l'index des suivants ne change pas.
----------------------------------------------------------------------------------------------------------

ATMEDatas.C_IndexList_MT = {
	className = "C_IndexList",
	mt = {},
	
	keys = {
		["add"] = true,
		["remove"] = true,
		["get"] = true,
		["getRandom"] = true,
		["pairs"] = true,
		["getCount"] = true,
		["removeAll"] = true,
	},
}

ATME.C_IndexList = {
	getClassName = function(self)
		return ATMEDatas.C_IndexList_MT.className
	end,
	
	getParentClass = function(self)
		return ATMEDatas.C_IndexList_MT.parentClass
	end,
}

ATMEFct.C_IndexList_create = function()
	local maxIndex = 1
	local freeIndex = {}
	local list = {}
	local nbItems = 0
	local newList = {}
		
	setmetatable(newList, ATMEDatas.C_IndexList_MT.mt)
	
	function newList.add(self, _item)
		local index
		if #freeIndex > 0 then
			index = freeIndex[1]
			table.remove(freeIndex, 1)
		else
			index = maxIndex
			maxIndex = maxIndex + 1
		end
		
		list[index] = _item
		
		nbItems = nbItems + 1
		return index
	end
	
	function newList.remove(self, _id)
		if list[_id] ~= nil then
			list[_id] = nil
			nbItems = nbItems - 1
			
			table.insert(freeIndex, _id)
			
			table.sort(freeIndex,
							function(a, b) 
								return a < b
							end)
		end
	end
	
	function newList.get(self,_id)
		return list[_id]
	end
	
	function newList.getRandom(self)
		local itemsOk = {}
		
		for _i, _ in self:pairs() do
			table.insert(itemsOk, _i)
		end
		
		if #itemsOk > 0 then
			return list[itemsOk[math.random(1, #itemsOk)]]
		end
	end
	
	function newList.getCount(self)
		return nbItems
	end
	
    function newList.pairs(self)
		local i = 0
		return function()
			repeat
				i = i + 1
			until list[i] ~= nil or i == maxIndex
			
			if i < maxIndex then
				return i, list[i]
			end
		end
    end
	
	function newList.removeAll(self)
		freeIndex = {}
		list = {}
		maxIndex = 1
		nbItems = 0
	end
	
	return newList
end

ATMEDatas.C_IndexList_MT.__call = function(t)
	return ATMEFct.C_IndexList_create()
end

setmetatable(ATME.C_IndexList,ATMEDatas.C_IndexList_MT)

ATMEDatas.C_IndexList_MT.mt.__metatable = "Private"
ATMEDatas.C_IndexList_MT.mt.__index = ATME.C_IndexList
ATMEDatas.C_IndexList_MT.mt.__newindex = function(t, k, v)
	if ATMEDatas.C_IndexList_MT.keys[k] ~= nil then 
		rawset(t, k, v)
	else  
		ATMEFct.errorOutputCore(nil, "Function ATME.C_IndexList : Bad key " .. k, "table locked", false)
	end
end

----------------------------------------------------------------------------------------------------------
-- Classe ATME.C_Stack : gère une pile. Constructeur de classe accessible aux modules 
-- externes. 
-- Elle permet une gestion des piles FIFO et LIFO
----------------------------------------------------------------------------------------------------------

ATMEDatas.C_Stack_MT = {
	className = "C_Stack",
	mt = {},
	
	keys = {
		["push"] = true,
		["extract"] = true,
		["pairs"] = true,
		["getCount"] = true,
		["removeAll"] = true,
	},
}

ATME.C_Stack = {
	getClassName = function(self)
		return ATMEDatas.C_Stack_MT.className
	end,
	
	getParentClass = function(self)
		return ATMEDatas.C_Stack_MT.parentClass
	end,
}

ATMEFct.C_Stack_create = function()
	local nbItems = 0
	local beginEnd = {}
	local newStack = {}
	
	setmetatable(newStack, ATMEDatas.C_Stack_MT.mt)
	
	function newStack.push(self, _item)
		local item = {
			item = _item,
			beginEnd = {
			},
		}

		if beginEnd.first == nil then
			beginEnd.first = item
			beginEnd.last = item
		else
			beginEnd.first.previous = item
			item.next = beginEnd.first

			beginEnd.first = item
		end

		nbItems = nbItems + 1
	end
	
	function newStack.extract(self, _typeExtract)
		local fctDefinition = ATMEFct.getErrorPrefix(newVector) .. "extract(type)"
		
		if _typeExtract == nil or type(_typeExtract) == "string" then
			local typeExtract
			if _typeExtract == nil then
				typeExtract = "HEAD"
			else
				typeExtract = _typeExtract:upper()
			end
			
			if ATMEConst.stackTypeExtract[typeExtract] ~= nil then
				if beginEnd[ATMEConst.stackTypeExtract[typeExtract].start] ~= nil then
					local item = beginEnd[ATMEConst.stackTypeExtract[typeExtract].start].item

					beginEnd[ATMEConst.stackTypeExtract[typeExtract].start] = beginEnd[ATMEConst.stackTypeExtract[typeExtract].start][ATMEConst.stackTypeExtract[typeExtract].direction]
					nbItems = nbItems - 1

					if nbItems == 0 then
						beginEnd = {}
					end
					
					return item
				end
			else
				ATMEFct.errorOutputCore(nil, fctDefinition, "type must be 'HEAD' or 'TAIL'", false)
			end
		else
			if _typeExtract ~= nil and type(_typeExtract) ~= "string" then
				ATMEFct.errorOutputCore(nil, fctDefinition, "type type must be nil or string", true)
			end
		end
	end
	
	function newStack.getCount(self)
		return nbItems
	end
	
    function newStack.pairs(self, _typeRead)
		local item
		local i = 0
		
		local typeRead
		if _typeRead == nil or type(_typeRead) ~= "string" then
			typeRead = "TAIL"
		else
			typeRead = _typeRead:upper()
			if ATMEConst.stackTypeExtract[typeRead] == nil then
				typeRead = "TAIL"
			end
		end
		
		return function()
			if item == nil then
				item = beginEnd[ATMEConst.stackTypeExtract[typeRead].start]
			else
				item = item[ATMEConst.stackTypeExtract[typeRead].direction]
			end
			
			i = i + 1
			
			if item ~= nil then
				return i, item.item
			end
		end
    end
	
	function newStack.removeAll(self)
		beginEnd = {}
		nbItems = 0
	end
	
	return newStack
end

ATMEDatas.C_Stack_MT.__call = function(t)
	return ATMEFct.C_Stack_create()
end

setmetatable(ATME.C_Stack,ATMEDatas.C_Stack_MT)

ATMEDatas.C_Stack_MT.mt.__metatable = "Private"
ATMEDatas.C_Stack_MT.mt.__index = ATME.C_Stack
ATMEDatas.C_Stack_MT.mt.__newindex = function(t, k, v)
	if ATMEDatas.C_Stack_MT.keys[k] ~= nil then 
		rawset(t, k, v)
	else  
		ATMEFct.errorOutputCore(nil, "Function ATME.C_Stack : Bad key " .. k, "table locked", false)
	end
end

----------------------------------------------------------------------------------------------------------
-- Variables globales utilisant les C_Index_List & C_Stack
----------------------------------------------------------------------------------------------------------
ATMEDatas.activatedRadioTransmissions = ATMEFct.C_IndexList_create() 
ATMEDatas.activatedSmokes = ATMEFct.C_IndexList_create()
ATMEDatas.activatedFlares = ATMEFct.C_IndexList_create()
ATMEDatas.activatedSounds = ATMEFct.C_IndexList_create()
ATMEDatas.groupsToBoard = ATMEFct.C_IndexList_create()
ATMEDatas.signals = ATMEFct.C_IndexList_create()
ATMEDatas.patrolsToUpdate = ATMEFct.C_IndexList_create()
ATMEDatas.stackTimer = ATMEFct.C_Stack_create()
ATMEDatas.signalCapabilityUnits = ATMEFct.C_Stack_create()

----------------------------------------------------------------------------------------------------------
-- Tables de fonctions associées à la pile stackTimer utilisées dans le timer main pour réaliser
-- les traitements sécables. Une entrée par type de traitement.
-- [1] : Traitement des franchissements de segments
-- [2] : Traitement des entrées/sorties d'aires (areas)
-- [3] : Traitement des pickupZones
--
-- 3 Tables :
--		stackTimerInL2Fcts : Table définissant les fonctions appelées dans la pile L2
--		stackTimerBeforeL2Fcts : Table définissant les fonctions appelées avant la pile L2
--		stackTimerAfterL2Fcts : Table définissant les fonctions appelées après la pile L2
----------------------------------------------------------------------------------------------------------

-- Fonction locale de détermination si dans pickupZone : utilisée dans stackTimerAfterL2Fcts
local function capabilityUnitsInPickupZone(_group, _pickupZone, _coalitionName, _isOk, _center, _signal, _index, _currentTipsCount)
	local foundUnit = false

	local nbStack = ATMEDatas.signalCapabilityUnits:getCount()
	
	while nbStack > 0 and ATMEDatas.totalCharge < ATMEConst.stackTimerMaxTotalCharge do
		local name = ATMEDatas.signalCapabilityUnits:extract("HEAD")
		if name ~= nil then
			if ATMEDatas.allAIUnitsAndPlayers[name] ~= nil then
				if ATMEDatas.signalCapabilityUnitsToDelete[name] == nil then
					local unit = ATMEDatas.allAIUnitsAndPlayers[name]
					if unit:getCoalitionName() == _coalitionName then
						if unit:inAir() == true then
							local v = ATMEFct.C_Vector3D_create(nil, nil, _center, unit:getPosition())
							local groupName 
							local pickupZone = _pickupZone
							if pickupZone == nil then
								groupName = _group:getName()
							end

							if _signal.coalitionUnitsInZone[name] == nil and v:getHModule() <= _signal.radius then
								local localMembers = ATMEFct.C_Player_C_AIUnit_getLocalMembers(unit)
								_signal.coalitionUnitsInZone[name] = unit
								localMembers.signalIndex[_index] = true
											
								-- Evénement signal enclenché si l'unité entre dans la zone de surveillance d'un groupe
								-- ou d'une pickup zone.
								local event = {
									type = "SIGNAL_UNIT_IN_ZONE",
									datas = {
										unitName = name,
										linkedPickupZone = pickupZone,
										linkedGroupName = groupName,
									},
								}

								ATMEFct.C_CoreEvent_add(event)
							elseif _signal.coalitionUnitsInZone[name] ~= nil and v:getHModule() > _signal.radius then
								local localMembers = ATMEFct.C_Player_C_AIUnit_getLocalMembers(unit)
								_signal.coalitionUnitsInZone[name] = nil
								localMembers.signalIndex[_index] = nil
								
								-- Evénement signal enclenché si l'unité sort de la zone de surveillance d'un groupe
								-- ou d'une pickup zone.
								local event = {
									type = "SIGNAL_UNIT_OUT_OF_ZONE",
									datas = {
										unitName = name,
										pickupZone = pickupZone,
										linkedGroupName = groupName,
									},
								}
								
								ATMEFct.C_CoreEvent_add(event)
							end

							if _signal.coalitionUnitsInZone[name] ~= nil then
								foundUnit = true
							end
							
							ATMEDatas.totalCharge = ATMEDatas.totalCharge + 1
						end
					end
					
					ATMEDatas.signalCapabilityUnits:push(name)
					nbStack = nbStack - 1;
				end
			end
			
			ATMEDatas.signalCapabilityUnitsToDelete[name] = nil
		end
	end
	
	local isFired = false
	if foundUnit == true and _isOk == true then
		if _signal.timeStart < 0 then
			_signal.timeStart = _currentTipsCount
			
			isFired = true
			
			if _signal.type == "SMOKE" then
				local newPoint = {}

				newPoint.x = _center.x + math.random(-20,20)
				newPoint.y = _center.z + math.random(-20,20)
				
				local smoke = ATMEFct.C_Smoke_create(_signal.color, newPoint)
				smoke:activate(false)
				
				_signal.offsetTime = math.random(5,20) + ATMEConst.maxTimeSmoke
			elseif _signal.type == "FLARE" then
				local flare = ATMEFct.C_Flare_create(_signal.color, _center)
				flare:fireOnce()
				
				_signal.offsetTime = math.random(5,10)
			end
		else
			if _signal.timeStart + _signal.offsetTime <= _currentTipsCount and _signal.type == "SMOKE" then
				ATMEFct.outputCore(nil, "restart smoke", 2)
				local newPoint = {}

				newPoint.x = _center.x + math.random(-20,20)
				newPoint.y = _center.z + math.random(-20,20)
				
				local smoke = ATMEFct.C_Smoke_create(_signal.color, newPoint)
				smoke:activate(false)
				
				_signal.timeStart = _currentTipsCount
				_signal.offsetTime = math.random(5,20) + ATMEConst.maxTimeSmoke
			elseif _signal.timeStart + _signal.offsetTime <= _currentTipsCount and _signal.type == "FLARE" then
				ATMEFct.outputCore(nil, "restart flare", 2)
				local flare = ATMEFct.C_Flare_create(_signal.color, _center)
				flare:fireOnce()
				
				_signal.offsetTime = math.random(5,10)
				_signal.timeStart = _currentTipsCount
			end
		end
	end
	
	return isFired
end
	
ATMEFct.stackTimerInL2Fcts = {
	[1] = function(_object, _localMembers, _currentTipsCount)
		local unitName = _localMembers.tracking.stack:extract("HEAD")
		
		if unitName ~= nil then
			if _localMembers.tracking.unitPosition[unitName] ~= nil then
				ATMEFct.outputCore(nil, "Tracking sur multisegment " .. _object:getName() .. " pour unit ".. unitName , 2)
				return ATMEFct.C_MultiSegment2D_crossMultiSegmentTracking(_object,_localMembers, unitName)
			end
		end
		
		return 0
	end,
	
	[2] = function(_object, _localMembers, _currentTipsCount)
		local item = _localMembers.tracking.stack:extract("HEAD")
		local charge = 0
		
		if item.unitName ~= nil then
			if ATMEDatas.allAIUnitsAndPlayers[item.unitName] ~= nil then
				if _localMembers.tracking.unitNames[item.unitName] == nil then
					local unit = ATMEDatas.allAIUnitsAndPlayers[item.unitName]
					local isInside

					isInside, _, charge = ATMEFct.C_Area_isInside(_object, ATMEFct.getPointFromReference(unit))
					if isInside == true then
						if item.flag == false then
							-- Entrée dans l'area (ou spawn dans l'area)
							item.flag = true
							local event = {
								type = "AREA_ENTERS",
								datas = {
									unitName = item.unitName,
									area = _object,
								},
							}
							
							ATMEFct.C_CoreEvent_add(event)
						end
					elseif item.flag == true then
						-- Sortie de l'area
						
						item.flag = false
						
						local event = {
							type = "AREA_LEAVES",
							datas = {
								unitName = item.unitName,
								area = _object,
							},
						}
						
						ATMEFct.C_CoreEvent_add(event)
					end
					
					_localMembers.tracking.stack:push(item)
				end
			end
			
			_localMembers.tracking.unitNames[item.unitName] = nil
		else
			if ATMEDatas.groups[item.groupName] ~= nil then
				if _localMembers.tracking.groupNames[item.groupName] == nil then
					local unit = ATMEDatas.groups[item.groupName]:getFirstUnit()
					local isInside = false

					while unit ~= nil and isInside == false do
						isInside, _, charge = ATMEFct.C_Area_isInside(_object, ATMEFct.getPointFromReference(unit))
						unit = ATMEDatas.groups[item.groupName]:getNextUnit()
					end

					if isInside == true then
						if item.flag == false then
							-- Entrée dans l'area (ou spawn dans l'area)
							item.flag = true
							
							local event = {
								type = "AREA_GROUP_ENTERS",
								datas = {
									groupName = item.groupName,
									area = _object,
								},
							}
							
							ATMEFct.C_CoreEvent_add(event)
						end
					elseif item.flag == true then
						-- Sortie de l'area
						
						item.flag = false
						
						local event = {
							type = "AREA_GROUP_LEAVES",
							datas = {
								groupName = item.groupName,
								area = _object,
							},
						}
						
						ATMEFct.C_CoreEvent_add(event)
					end

					_localMembers.tracking.stack:push(item)
				end
			end
			
			_localMembers.tracking.groupNames[item.groupName] = nil
		end
		
		return charge
	end,
	
	[3] = function(_object, _localMembers, _currentTipsCount)
		local item = _localMembers.tracking.stack:extract("HEAD")
		local charge = 0
		
		if ATMEDatas.groups[item.groupName] ~= nil then
			if _localMembers.tracking.groupNames[item.groupName] == nil then
				local group = ATMEDatas.groups[item.groupName]
				if group:isReadyToBoard() == false then
					local timeValue = timer.getTime()
					if timeValue - item.start > 2 then
						-- Lors d'un spawn la route du group n'est pas initialisée de suite : 
						-- stop (fait dans C_Group_changeReadyToBoard) est inefficace... donc
						-- on gère une délai de 2 secondes.
					
						local distance = group:getMinHDistance(item.zone.point)
						if distance <= item.zone.radius then
							item.isInZone = true
							
							local firstUnit = group:getFirstUnit()
							
							if firstUnit ~= nil then
								if math.random() < item.randomMax or firstUnit:getSpeed() == 0 then
									ATMEFct.C_Group_changeReadyToBoard(group, true, item.nextWaypoint)
								end
							end
						else
							-- Si le groupe ressort de la zone et que le groupe n'est pas passé à 
							-- readyToBoard -> True alors on force
							if item.isInZone == true  then
								ATMEFct.C_Group_changeReadyToBoard(group, true, item.nextWaypoint)
							end
						end
					end
				end
				
				if group:isReadyToBoard() == true then
					_localMembers.tracking.startSignal = true
				end
				
				_localMembers.tracking.stack:push(item)
				charge = 1
			end
		end
		
		_localMembers.tracking.groupNames[item.groupName] = nil
		
		return charge
	end,
}


ATMEFct.stackTimerBeforeL2Fcts = {
	[1] = nil,
	[2] = nil,
	[3] = function(_object, _localMembers, _currentTipsCount)
		_localMembers.tracking.startSignal = false
	end,
}
	
ATMEFct.stackTimerAfterL2Fcts = {
	[1] = nil,
	[2] = nil,
	[3] = function(_object, _localMembers, _currentTipsCount)
		if _localMembers.signalIndex ~= 0 then
			-- La pickup zone dispose d'une zone signalée
			
			local signal = ATMEDatas.signals:get(_localMembers.signalIndex)

			capabilityUnitsInPickupZone(nil, _object, _localMembers.coalitionName, _localMembers.tracking.startSignal, 
												signal.center, signal, _localMembers.signalIndex, _currentTipsCount)
		end
	end,
}

----------------------------------------------------------------------------------------------------------
-- Fonctions générales
----------------------------------------------------------------------------------------------------------		

-- Function de récupération des local members pour les AIUnits ou les players
ATMEFct.C_Player_C_AIUnit_getLocalMembers = function(_unit)
	local classNameMT = _unit:getClassName() .. "_MT"
	
	return ATMEDatas[classNameMT]:get(_unit:getIndex())
end						

-- Fonction pour mettre à jour le lien unité/zone signalée
ATMEFct.resetSignalUnits = function(_index)
	local signal = ATMEDatas.signals:get(_index)
			
	for _name, _ in pairs(signal.coalitionUnitsInZone) do
		if ATMEDatas.allAIUnitsAndPlayers[_name] ~= nil then
			local localMembers = ATMEFct.C_Player_C_AIUnit_getLocalMembers(ATMEDatas.allAIUnitsAndPlayers[_name])
			if localMembers.signalIndex[_index] ~= nil then
				localMembers.signalIndex[_index] = nil
			end
		end
	end
end

----------------------------------------------------------------------------------------------------------
-- Classe ATME.C_Vector3D : gère les vecteurs 3D. Constructeur de classe accessible aux modules externes.
-- Elle donne accès aux calculs de module (module du vecteur AB = distance AB), à l'angle formé avec le nord
-- par AB (Azimuth), à la transformation en vecteur unitaire (vecteur identique de module 1) et au produit
-- scalaire calculé pour les coordonnées horizontales (x et z).
----------------------------------------------------------------------------------------------------------

ATMEDatas.C_Vector3D_MT = {
	className = "C_Vector3D",
	mt = {},
	
	keys = {
		["getAzimuth"] = true, 
		["getHModule"] = true,
		["getModule"] = true,
		["get"] = true, 
		["getX"] = true,
		["getY"] = true,
		["getZ"] = true,
		["toUnitVector"] = true,
		["getHScalarProduct"] = true,
		["getName"] = true,
		["tagGetByID"] = true,
		["tagCompare"] = true,
		["tagGetCount"] = true,
	},
}

ATME.C_Vector3D = {
	getClassName = function(self)
		return ATMEDatas.C_Vector3D_MT.className
	end,
	
	getParentClass = function(self)
		return ATMEDatas.C_Vector3D_MT.parentClass
	end,
}

ATMEFct.C_Vector3D_create = function(_name, _vectors3D, ...)
	local args = {...}
	local x = 0
	local y = 0
	local z = 0
	
	local newVector = {}
	
	setmetatable(newVector, ATMEDatas.C_Vector3D_MT.mt)
	
	local name
	local tagsName
	
	if _name ~= nil and _vectors3D ~= nil then
		name = _name
		_vectors3D[name] = newVector
		tagsName = ATMEFct.decompString(_name)
	end
	
	if #args == 3 and type(args[1]) == "number" and type(args[2]) == "number" and type(args[3]) == "number" then
		x = args[1]
		y = args[2]
		z = args[3]
	elseif #args == 1 and ATME.isObjectClass(args[1], C_Vector3D) == true and type(args[1]:getX()) == "number" and type(args[1]:getY()) == "number" and type(args[1]:getZ()) == "number" then  
		x = args[1]:getX()
		y = args[1]:getY()
		z = args[1]:getZ()
	elseif #args == 1 and type(args[1]) == "table" and type(args[1].x) == "number" and type(args[1].y) == "number" and type(args[1].z) == "number" then
		x = args[1].x
		y = args[1].y
		z = args[1].z
	elseif #args == 2 and ATME.isPoint(args[1]) ~= POINT_BAD and ATME.isPoint(args[2]) ~= POINT_BAD then
		local p1 = ATME.convertToPoint3D(args[1])
		local p2 = ATME.convertToPoint3D(args[2])

		x = p2.x - p1.x
		y = p2.y - p1.y
		z = p2.z - p1.z
	end
	
	local hModule = math.sqrt(x^2 + z^2)
	local gModule = math.sqrt(x^2 + y^2 + z^2)
	
	local angle = 0
	if x ~= 0 and z~= 0 then
		angle = math.deg(math.atan2(z, x))
	end
	
	
	if angle < 0 then
		angle = angle + 360
	end
	
	function newVector.getName(self)
		return name
	end
	
	function newVector.tagGetByID(self, _position)
		local fctDefinition = ATMEFct.getErrorPrefix(newVector) .. "tagGetByID(position)"
		
		if type(_position) == "number" then
			local pos = math.floor(_position)
			if tagsName ~= nil and pos >= 1 and pos <= #tagsName then
				return tagsName[pos]
			end
		else
			ATMEFct.errorOutputCore(nil, fctDefinition, "position type must be number", true)
		end
	end
	
	function newVector.tagGetCount(self)
		if tagsName ~= nil then
			return #tagsName
		else
			return 0
		end
	end
	
	function newVector.tagCompare(self, _tagsToCompare)
		local fctDefinition = ATMEFct.getErrorPrefix(newVector) .. "tagCompare(tagsToCompare)"
		
		if type(_tagsToCompare) == "string" then
			if tagsName ~= nil then
				local ok = ATMEFct.compareTags(tagsName, _tagsToCompare)
				
				if ok ~= nil then
					return ok
				else
					ATMEFct.errorOutputCore(nil, fctDefinition, "tagsToCompare format must be 'T1|T2|..|Tn'", false)
				end
			else
				return false
			end
		else
			ATMEFct.errorOutputCore(nil, fctDefinition, "tagsToCompare type must be string", true)
		end
	end
	
	function newVector.getAzimuth(self)
		return angle
	end
	
	function newVector.getHModule(self)
		return hModule
	end
	
	function newVector.getModule(self)
		return gModule
	end
	
	function newVector.get(self)
		return x, y, z
	end
	
	function newVector.getX(self)
		return x
	end

	function newVector.getY(self)
		return y
	end

	function newVector.getZ(self)
		return z
	end
	
	function newVector.toUnitVector(self)
		local unitVector
		if gModule ~= 0 then
			unitVector = ATMEFct.C_Vector3D_create(nil, nil, x/gModule, y/gModule, z/gModule)
		else
			unitVector = ATMEFct.C_Vector3D_create(nil, nil)
		end
		
		return unitVector
	end
	
	function newVector.getHScalarProduct(self, v1)
		return v1:getX() * x + v1:getZ() * z
	end
	
	return newVector
end



ATMEDatas.C_Vector3D_MT.__call = function(t, ...)
	local args = {...}
	
	local fctDefinition = "Constructor :\nATME.C_Vector3D()\nATME.C_Vector3D(vector)\nATME.C_Vector3D(pA, pB)\nATME.C_Vector3D(x, y, z)"
	
	if  #args == 0 or (#args == 3 and type(args[1]) == "number" and type(args[2]) == "number" and type(args[3]) == "number") or
		(#args == 1 and ATME.isObjectClass(args[1], ATME.C_Vector3D) == true and type(args[1]:getX()) == "number" and type(args[1]:getY()) == "number" and type(args[1]:getZ()) == "number") or
		(#args == 1 and type(args[1]) == "table" and type(args[1].x) == "number" and type(args[1].y) == "number" and type(args[1].z) == "number") or
		(#args == 2 and ATME.isPoint(args[1]) ~= POINT_BAD and ATME.isPoint(args[2]) ~= POINT_BAD) then
		
		return ATMEFct.C_Vector3D_create(nil, nil, ...)
	else
		if #args == 3 then
			if type(args[1]) ~= "number" then
				ATMEFct.errorOutputCore(nil, fctDefinition, "x type must be number", false)
			elseif type(args[2]) ~= "number" then
				ATMEFct.errorOutputCore(nil, fctDefinition, "y type must be number", false)
			elseif type(args[3]) ~= "number" then
				ATMEFct.errorOutputCore(nil, fctDefinition, "z type must be number", false)
			end
		elseif #args == 2 then
			if ATME.isPoint(args[1]) == POINT_BAD then
				ATMEFct.errorOutputCore(nil, fctDefinition, "pA type must be table (x,y) or (x,y,z)", false)
			elseif ATME.isPoint(args[2]) == POINT_BAD then
				ATMEFct.errorOutputCore(nil, fctDefinition, "pB type must be table (x,y) or (x,y,z)", false)
			end
		elseif #args == 1 and ATME.isObjectClass(args[1], ATME.C_Vector3D) == false then
			ATMEFct.errorOutputCore(nil, fctDefinition, "vector type must be ATME.C_Vector3D", false)
		else
			ATMEFct.errorOutputCore(nil, fctDefinition, "must have 0 to 3 parameters", false)
		end
	end
end

setmetatable(ATME.C_Vector3D,ATMEDatas.C_Vector3D_MT)

ATMEDatas.C_Vector3D_MT.mt.__metatable = "Private"
ATMEDatas.C_Vector3D_MT.mt.__index = ATME.C_Vector3D

ATMEDatas.C_Vector3D_MT.mt.__newindex = function(t, k, v)
	if ATMEDatas.C_Vector3D_MT.keys[k] ~= nil then 
		rawset(t, k, v)
	else
		ATMEFct.errorOutputCore(nil, "Function ATME.C_Vector3D : Bad key " .. k, "table locked", false)
	end
end

ATMEDatas.C_Vector3D_MT.mt.__add = function(v1, v2)
	v1x, v1y, v1z = v1:get()
	v2x, v2y, v2z = v2:get()

	return C_Vector3D(v1x + v2x, v1y + v2y, v1z + v2z)
end

ATMEDatas.C_Vector3D_MT.mt.__sub = function(v1, v2)
	v1x, v1y, v1z = v1:get()
	v2x, v2y, v2z = v2:get()
	
	return C_Vector3D(v1x - v2x, v1y - v2y, v1z - v2z)
end



----------------------------------------------------------------------------------------------------------
-- Classe ATME.C_Line2D : gère les droites horizontales (2D). Format DCS repère z0x
--
-- Une droite est formée d'un vecteur et d'un point d'origine, référence 0 de la droite pour cette classe.
--
-- Forme Az + Bx + C = 0
-- Vecteur directeur v(xv, yv, zv) => A = xv et B = -zv
-- Point d'origine (xref, yref, zref) => C = -A * zref - B * xref
--
-- Droite perpendiculaire déduite et passant au point d'origine :
-- Vecteur directeur vp(xvp, yvp, zvp) => xvp = B et zvp = A
-- Forme : -Bz + Ax + C = 0 et C = -A * zref + B * xref
--
-- NOTE : l'axe y est non significatif
----------------------------------------------------------------------------------------------------------

ATMEDatas.C_Line2D_MT = {
	className = "C_Line2D",
	mt = {},
	
	keys = {
		["get"] = true,
		["getA"] = true,
		["getB"] = true,
		["getC"] = true,
		["getX"] = true,
		["getZ"] = true,
		["isNSAxis"] = true,
		["isWEAxis"] = true,
		["getOrigin"] = true,
		["getPerpendicular"] = true,
		["getPointFromOrigin"] = true,
		["getIntersection"] = true,
		["getPointHDistance"] = true,
		["getPointDistance"] = true,
		["getVector3D"] = true,
		["getName"] = true,
		["tagGetByID"] = true,
		["tagCompare"] = true,
		["tagGetCount"] = true,
		["getIndex"] = true,
	},
	
	localMembers = ATMEFct.C_IndexList_create(),
	
	add = function(self)
		local item = {
			units = {},
			nbUnits = 0,
		}
		
		return self.localMembers:add(item)
	end,
	
	remove = function(self, _id)
		self.localMembers:remove(_id)
	end,
	
	get = function(self, _id)
		return self.localMembers:get(_id)
	end,
}

ATME.C_Line2D = {
	getClassName = function(self)
		return ATMEDatas.C_Line2D_MT.className
	end,
	
	getParentClass = function(self)
		return ATMEDatas.C_Line2D_MT.parentClass
	end,
}

ATMEFct.C_Line2D_create = function(_name, _lines2D, ...)
	local args = {...}
	local a = 0
	local b = 0
	local c = 0
	local origin
	local newLine = {}
	
	setmetatable(newLine, ATMEDatas.C_Line2D_MT.mt)
	
	local index = ATMEDatas.C_Line2D_MT:add()
	local localMembers = ATMEDatas.C_Line2D_MT:get(index)
	
	local name
	local tagsName
	
	if _name ~= nil and _lines2D ~= nil then
		name = _name
		_lines2D[name] = newLine

		tagsName = ATMEFct.decompString(_name)
	end
	
	if #args == 1 then
		a = args[1]:getA()
		b = args[1]:getB()
		c = args[1]:getC()
		origin = args[1]:getOrigin()
	elseif #args == 2 then
		if ATME.isPoint(args[1]) ~= POINT_BAD and ATME.isPoint(args[2]) ~= POINT_BAD then
			origin = ATME.convertToPoint3D(args[1])
			local p2 = ATME.convertToPoint3D(args[2])

			if p2.x ~= origin.x or p2.z ~= origin.z then
				a = p2.x - origin.x
				b = origin.z - p2.z
				c = - b * origin.x - a * origin.z
			else
				return
			end
		else
			origin = ATME.convertToPoint3D(args[2])

			a = args[1]:getX()
			b = -args[1]:getZ()
			c = - b * origin.x - a * origin.z
		end
	end
	
	local vector = ATMEFct.C_Vector3D_create(nil, nil, a, 0, -b)
	
	function newLine.getIndex(self)
		return index
	end
	
	function newLine.getName(self)
		return name
	end
	
	function newLine.tagGetByID(self, _position)
		local fctDefinition = ATMEFct.getErrorPrefix(newLine) .. "tagGetByID(position)"
		
		if type(_position) == "number" then
			local pos = math.floor(_position)
			if tagsName ~= nil and pos >= 1 and pos <= #tagsName then
				return tagsName[pos]
			end
		else
			ATMEFct.errorOutputCore(nil, fctDefinition, "position type must be number", true)
		end
	end
	
	function newLine.tagGetCount(self)
		if tagsName ~= nil then
			return #tagsName
		else
			return 0
		end
	end
	
	function newLine.tagCompare(self, _tagsToCompare)
		local fctDefinition = ATMEFct.getErrorPrefix(newLine) .. "tagCompare(tagsToCompare)"
		
		if type(_tagsToCompare) == "string" then
			if tagsName ~= nil then
				local ok = ATMEFct.compareTags(tagsName, _tagsToCompare)
				
				if ok ~= nil then
					return ok
				else
					ATMEFct.errorOutputCore(nil, fctDefinition, "tagsToCompare format must be 'T1|T2|..|Tn'", false)
				end
			else
				return false
			end
		else
			ATMEFct.errorOutputCore(nil, fctDefinition, "tagsToCompare type must be string", true)
		end
	end
	
	function newLine.get(self)
		return a, b, c
	end
	
	function newLine.getA(self)
		return a
	end

	function newLine.getB(self)
		return b
	end

	function newLine.getC(self)
		return c
	end
	
	function newLine.getZ(self, _x)
		if a ~= 0 then
			return (-b * _x - c) / a
		end
	end
	
	function newLine.getX(self, _z)
		if b ~= 0 then
			return (-a * _z - c) / b
		end
	end
	
	function newLine.isNSAxis(self)
		return b == 0
	end
	
	function newLine.isWEAxis(self)
		return a == 0
	end
	
	function newLine.getOrigin(self)
		local point = {}
		
		point.x = origin.x
		point.y = origin.y
		point.z = origin.z
		
		return point
	end
	
	function newLine.getVector3D(self)
		return vector
	end
	
	function newLine.getPointFromOrigin(self, _offset)
		local fctDefinition = ATMEFct.getErrorPrefix(newLine) .. "getPointFromOrigin(offset)"
		
		if type(_offset) == "number" then
			local n = math.sqrt(_offset^2/(a^2 + b^2))
			local point = {}
			
			if _offset < 0 then
				n = -n
			end

			point.x = origin.x + n * a
			point.z = origin.z - n * b
			point.y = ATMEFct.getSurfaceAltitude(point)
			return point
		else
			ATMEFct.errorOutputCore(nil, fctDefinition, "offset type must be number", true)
		end
	end
		
	function newLine.getPerpendicular(self, _offset)
		local fctDefinition = ATMEFct.getErrorPrefix(newLine) .. "getPerpendicular(offset)"
		
		if type(_offset) == "number" then
			local v = ATMEFct.C_Vector3D_create(nil, nil, self:getB(), 0, self:getA())
			
			local perpendicularLine
			
			if _offset == 0 then
				perpendicularLine = ATMEFct.C_Line2D_create(nil, nil, v, self:getOrigin())
			else
				perpendicularLine = ATMEFct.C_Line2D_create(nil, nil, v, self:getPointFromOrigin(_offset))
			end
			
			return perpendicularLine
		else
			ATMEFct.errorOutputCore(nil, fctDefinition, "offset type must be number", true)
		end
	end
	
	function newLine.getPointHDistance(self, _point)
		local fctDefinition = ATMEFct.getErrorPrefix(newLine) .. "getPointHDistance(point)"
		
		if ATME.isPoint(_point) ~= POINT_BAD then
			local point = ATME.convertToPoint3D(_point)
			
			return math.abs(a * point.z + b * point.x + c) / math.sqrt(a * a + b * b)
		else
			ATMEFct.errorOutputCore(nil, fctDefinition, "point type must be table (x,y) or (x,y,z)", true)
		end
	end
	
	function newLine.getPointDistance(self, _point)
		local fctDefinition = ATMEFct.getErrorPrefix(newLine) .. "getPointDistance(point)"
		
		if ATME.isPoint(_point) ~= POINT_BAD then
			local point = ATME.convertToPoint3D(_point)
			
			local hdist = math.abs(a * point.z + b * point.x + c) / math.sqrt(a * a + b * b)
			
			return math.sqrt(hdist * hdist + point.y * point.y)
		else
			ATMEFct.errorOutputCore(nil, fctDefinition, "point type must be table (x,y) or (x,y,z)", true)
		end
	end
	
	function newLine.getIntersection(self, _line2D)
		local fctDefinition = ATMEFct.getErrorPrefix(newLine) .. "getIntersection(line2D)"
		
		if ATME.isObjectClass(_line2D, ATME.C_Line2D) == true then
			local a1 = _line2D:getA()
			local b1 = _line2D:getB()
			local c1 = _line2D:getC()
			
			local delta = a1 * b - b1 * a
			
			if delta ~= 0 then
				if a1 ~= 0 then
					if a ~= 0 then
						local xTemp = (a * c1 - a1 * c) / delta
						return ATME.convertToPoint3D({
											x = xTemp,
											y = (-b * xTemp - c) / a,
										})
					else
						local xTemp = -c / b
						return ATME.convertToPoint3D({
											x = xTemp,
											y = (-b1 * xTemp - c1) / a1,
										})
					end
				else
					local xTemp = -c1 / b1
					return ATME.convertToPoint3D({
										x = xTemp,
										y = (-b * xTemp - c) / a,
									})
					
				end
			elseif c1 == c then
				return self
			end
		else
			ATMEFct.errorOutputCore(nil, fctDefinition, "line2D type must be ATME.C_Line2D", true)
		end
	end
	
	return newLine
end

ATMEDatas.C_Line2D_MT.__call = function(t, ...)
	local args = {...}
	local fctDefinition = "Constructor :\nATME.C_Line2D(line)\nATME.C_Line2D(vector or pA, pB)"
	
	if (#args == 1 and ATME.isObjectClass(args[1], ATME.C_Line2D) == true)  or
			(#args == 2 and ATME.isPoint(args[1]) ~= POINT_BAD and ATME.isPoint(args[2]) ~= POINT_BAD) or
			(#args == 2 and ATME.isObjectClass(args[1], ATME.C_Vector3D) == true and ATME.isPoint(args[2]) ~= POINT_BAD) then
			
		local line2D = ATMEFct.C_Line2D_create(nil, nil, ...)
		
		if line2D == nil then
			ATMEFct.errorOutputCore(nil, fctDefinition, "pA and pB must be differents", false)
		else
			return line2D
		end
	else
		if #args == 2 then
			if ATME.isPoint(args[1]) == POINT_BAD and ATME.isObjectClass(args[1], ATME.C_Vector3D) == false then
				ATMEFct.errorOutputCore(nil, fctDefinition, "vector or pA type must be table (x,y) or (x,y,z) or ATME.C_Vector3D", false)
			elseif ATME.isPoint(args[2]) == POINT_BAD then
				ATMEFct.errorOutputCore(nil, fctDefinition, "pB or point type must be table (x,y) or (x,y,z)", false)
			end
		elseif #args == 1 and ATME.isObjectClass(args[1], ATME.C_Line2D) == false then
			ATMEFct.errorOutputCore(nil, fctDefinition, "line type must be ATME.C_Line2D", false)
		else
			ATMEFct.errorOutputCore(nil, fctDefinition, "must have 1 or 2 parameters", false)
		end
	end
end

setmetatable(ATME.C_Line2D,ATMEDatas.C_Line2D_MT)

ATMEDatas.C_Line2D_MT.mt.__metatable = "Private"
ATMEDatas.C_Line2D_MT.mt.__index = ATME.C_Line2D

ATMEDatas.C_Line2D_MT.mt.__newindex = function(t, k, v)
	if ATMEDatas.C_Line2D_MT.keys[k] ~= nil then 
		rawset(t, k, v)
	else
		ATMEFct.errorOutputCore(nil, "Function ATME.C_Line2D : Bad key " .. k, "table locked", false)
	end
end

----------------------------------------------------------------------------------------------------------
-- Classe ATME.C_MultiSegment2D : gère des segments 2D ayant ou non des points communs. 
-- Format DCS repère z0x.
--
-- Un ensemble de segments se caractérise par un ensemble de points consécutifs.
--
-- NOTE : l'axe y est non significatif
----------------------------------------------------------------------------------------------------------

ATMEFct.C_MultiSegment2D_intersect = function(_segment1, _pA, _pB)
	local p1 = _segment1.p1
	local p2 = _segment1.p2
	local vector1 = _segment1.vector
	
	local vector2 = {
		x = _pB.x - _pA.x,
		y = 0,
		z = _pB.z - _pA.z,
	}

	local det = vector1:getZ() * vector2.x - vector1:getX() * vector2.z
	
	if det == 0 then
		return false
	end
	
	local t = ((p1.x - _pA.x) * vector2.z - (p1.z - _pA.z) * vector2.x) / det
	if t < 0 or t > 1 then
		return false
	end
	
	local u = ((p1.x - _pA.x) * vector1:getZ() - (p1.z - _pA.z) * vector1:getX()) / det
	if u < 0 or u > 1 then
		return false
	end
	
	local side = ATMEFct.whichSide(p1, p2, _pB)
	if side < 0 then
		side = -1
	else
		side = 1
	end
	
	return true, side
end



ATMEDatas.C_MultiSegment2D_MT = {
	className = "C_MultiSegment2D",
	mt = {},
	
	keys = {
		["getName"] = true,
		["tagGetByID"] = true,
		["tagCompare"] = true,
		["tagGetCount"] = true,
		["getIndex"] = true,
		["getSegmentInfosByID"] = true,
		["getNbSegments"] = true,
	},
	
	localMembers = ATMEFct.C_IndexList_create(),
	
	add = function(self)
		local item = {
			nbUnits = 0,
			segments2D = {},
			tracking ={
				unitPosition = {},
				stack = ATMEFct.C_Stack_create(false),
			},
		}
		
		return self.localMembers:add(item)
	end,
	
	remove = function(self, _id)
		self.localMembers:remove(_id)
	end,
	
	get = function(self, _id)
		return self.localMembers:get(_id)
	end,
}

ATME.C_MultiSegment2D = {
	getClassName = function(self)
		return ATMEDatas.C_MultiSegment2D_MT.className
	end,
	
	getParentClass = function(self)
		return ATMEDatas.C_MultiSegment2D_MT.parentClass
	end,
}

ATMEFct.C_MultiSegment2D_remove = function(_multiSegment2D, _localMembers, _unitName)
	if _localMembers.tracking.unitPosition[_unitName] ~= nil then
		_localMembers.tracking.unitPosition[_unitName] = nil
		_localMembers.nbUnits = _localMembers.nbUnits - 1
	end
end

ATMEFct.C_MultiSegment2D_crossMultiSegmentTracking = function(_multiSegment2D, _localMembers, _unitName)
	if ATMEDatas.allAIUnitsAndPlayers[_unitName] ~= nil then
		local found = false
		local currentPos = ATMEDatas.allAIUnitsAndPlayers[_unitName]:getPosition()
		local segmentInfo = {}
		
		for _i, _ in ipairs(_localMembers.segments2D) do		
			local intersect, side = ATMEFct.C_MultiSegment2D_intersect(_localMembers.segments2D[_i], 
															_localMembers.tracking.unitPosition[_unitName], 
															currentPos)
		
			if intersect == true then -- intersection avec le segment courant, determination du sens
				found = true
				
				table.insert(segmentInfo, {
											id = _i,
											direction = ATMEConst.directionValue[side],
										})
			end
		end
		
		_localMembers.tracking.unitPosition[_unitName] = currentPos
		_localMembers.tracking.stack:push(_unitName)
		
		if found == true then
			-- Déclenchement de l'event Core
			local event = {
				type = "CROSSED_SEGMENTS",
				datas = {
					unitName = _unitName,
					multiSegment2D = _multiSegment2D,
					infos = segmentInfo,
				},
			}
							
			ATMEFct.C_CoreEvent_add(event)
		end
		
		return #_localMembers.segments2D
	else
		ATMEFct.C_MultiSegment2D_remove(_multiSegment2D, _localMembers, _unitName)
		return 0
	end
end

ATMEFct.C_MultiSegment2D_changeCrossingMultiSegmentTracking = function(_multiSegment2D, _unit, _toActivate)
	local localMembers = ATMEDatas.C_MultiSegment2D_MT:get(_multiSegment2D:getIndex())
	
	if _toActivate == true then
		local unitName = _unit:getName()
		if localMembers.tracking.unitPosition[unitName] == nil then
			localMembers.nbUnits = localMembers.nbUnits + 1
		end
		
		localMembers.tracking.unitPosition[unitName] = _unit:getPosition()
		localMembers.tracking.stack:push(unitName)
		
	else
		ATMEFct.C_MultiSegment2D_remove(_multiSegment2D, localMembers, unitName)
	end
end

ATMEFct.C_MultiSegment2D_create = function(_name, _multiSegment2D, _points)
	local newMultiSegment = {}
	
	setmetatable(newMultiSegment, ATMEDatas.C_MultiSegment2D_MT.mt)
	
	local index = ATMEDatas.C_MultiSegment2D_MT:add()
	local localMembers = ATMEDatas.C_MultiSegment2D_MT:get(index)
	
	local name
	local tagsName
	
	if _name ~= nil and _multiSegment2D ~= nil then
		name = _name
		_multiSegment2D[name] = newMultiSegment
		tagsName = ATMEFct.decompString(_name)
	end
	
	ATMEDatas.stackTimer:push({
								object = newMultiSegment,
								classMT = "C_MultiSegment2D_MT",
								id = 1,
							})
	
	local i = 1
	
	while i < #_points do
		table.insert(localMembers.segments2D, {
												p1 = {
													x = _points[i].x,
													y = _points[i].y,
													z = _points[i].z,
												},
												p2 = {
													x = _points[i + 1].x,
													y = _points[i + 1].y,
													z = _points[i + 1].z,
												},
												vector = ATMEFct.C_Vector3D_create(nil, nil, _points[i + 1].x - _points[i].x, 0, _points[i + 1].z - _points[i].z),
											})
		
		i = i + 1
	end
	
	function newMultiSegment.getIndex(self)
		return index
	end
	
	function newMultiSegment.getName(self)
		return name
	end
	
	function newMultiSegment.tagGetByID(self, _position)
		local fctDefinition = ATMEFct.getErrorPrefix(newMultiSegment) .. "tagGetByID(position)"
		
		if type(_position) == "number" then
			local pos = math.floor(_position)
			if tagsName ~= nil and pos >= 1 and pos <= #tagsName then
				return tagsName[pos]
			end
		else
			ATMEFct.errorOutputCore(nil, fctDefinition, "position type must be number", true)
		end
	end
	
	function newMultiSegment.tagGetCount(self)
		if tagsName ~= nil then
			return #tagsName
		else
			return 0
		end
	end
	
	function newMultiSegment.tagCompare(self, _tagsToCompare)
		local fctDefinition = ATMEFct.getErrorPrefix(newMultiSegment) .. "tagCompare(tagsToCompare)"
		
		if type(_tagsToCompare) == "string" then
			if tagsName ~= nil then
				local ok = ATMEFct.compareTags(tagsName, _tagsToCompare)
				
				if ok ~= nil then
					return ok
				else
					ATMEFct.errorOutputCore(nil, fctDefinition, "tagsToCompare format must be 'T1|T2|..|Tn'", false)
				end
			else
				return false
			end
		else
			ATMEFct.errorOutputCore(nil, fctDefinition, "tagsToCompare type must be string", true)
		end
	end
	
	function newMultiSegment.getSegmentInfosByID(self, _id)
		local fctDefinition = ATMEFct.getErrorPrefix(newMultiSegment) .. "getSegmentInfosByID(id)"
		
		if type(_id) == "number" then
			local id = math.floor(_id)
			
			if id > 0 and id <= #localMembers.segments2D then
				return localMembers.segments2D[id].p1, localMembers.segments2D[id].p2, localMembers.segments2D[id].vector
			else
				ATMEFct.errorOutputCore(nil, fctDefinition, "id must be >= 1 and < nb segments", false)
			end
		else
			ATMEFct.errorOutputCore(nil, fctDefinition, "id type must be number", true)
		end
	end
	
	function newMultiSegment.getNbSegments(self)
		return #localMembers.segments2D
	end
	
	return newMultiSegment
end

ATMEDatas.C_MultiSegment2D_MT.__call = function(t, _points)
	local fctDefinition = "Constructor :\nATME.C_MultiSegment2D(points)\nATME.C_MultiSegment2D(dcsZoneName)"
	
	if type(_points) == "table" or type(_points) == "string" then
		local pErr
		local points = {}
		if type(_points) == "table" then
			for _key, _value in ipairs(_points) do
				if pErr == nil then
					local point
					
					if ATME.isPoint(_value) ~= POINT_BAD then
						point = ATME.convertToPoint3D(_value)
					elseif type(_value) == "string" then
						local zone = ATME.getDCSZone(_value)
						
						if zone ~= nil then
							point = zone.point
						else
							pErr = "Bad zone in item key " .. _key .. " : DCS Zone " .. _value .. " doesn't exist"
						end
					else
						pErr = "Bad type for item key " .. _key
					end
					
					if pErr == nil then
						table.insert(points, point)
					end
				end
			end
		else
			for _i = 1, ATMEConst.multiSegmentMaxPoints do
				local currentName = _points .. string.format("#%03d", _i)
				local zone = ATME.getDCSZone(currentName)
				
				if zone ~= nil then
					table.insert(points, zone.point)
				end
			end
		end
		
		if pErr ~= nil then
			ATMEFct.errorOutputCore(nil, fctDefinition, pErr, false)
		else
			if #points >= 2 and #points <= ATMEConst.multiSegmentMaxPoints then
				return ATMEFct.C_MultiSegment2D_create(nil, nil, points)
			else
				ATMEFct.errorOutputCore(nil, fctDefinition, "#points must be >= 2 and <= " .. ATMEConst.multiSegmentMaxPoints, false)
			end
		end
	else
		ATMEFct.errorOutputCore(nil, fctDefinition, "points type must be table or string", false)
	end
end

setmetatable(ATME.C_MultiSegment2D,ATMEDatas.C_MultiSegment2D_MT)

ATMEDatas.C_MultiSegment2D_MT.mt.__metatable = "Private"
ATMEDatas.C_MultiSegment2D_MT.mt.__index = ATME.C_MultiSegment2D

ATMEDatas.C_MultiSegment2D_MT.mt.__newindex = function(t, k, v)
	if ATMEDatas.C_MultiSegment2D_MT.keys[k] ~= nil then 
		rawset(t, k, v)
	else
		ATMEFct.errorOutputCore(nil, "Function ATME.C_MultiSegment2D : Bad key " .. k, "table locked", false)
	end
end

----------------------------------------------------------------------------------------------------------
-- Classes 
--      ATME.C_Circle : gère les cercles sur le plan zOx.
--		ATME.C_Ring : gère les anneaux sur le plan zOx
--		ATME.C_Polygon : gère les polygones non complexes dans le plan zOx
-- 		ATME.C_Rectangle : gère les rectangles dans le plan zOx
-- 		ATME.C_PickupZone : gère les zones de chargement d'unité qui sont des zones DCS particulières
--                          donc aussi des cercles 2D.
----------------------------------------------------------------------------------------------------------

ATMEFct.C_Circle_isInside = function(_point, _center, _name, _radiusMin, _radiusMax)
	local actualCenter
	
	if _name ~= nil then
		if ATMEDatas.allAIUnitsAndPlayers[_name] ~= nil then
			actualCenter = ATMEDatas.allAIUnitsAndPlayers[_name]:getPosition()
		else 
			return false
		end
	else
		actualCenter = {
			x = _center.x,
			y = _center.y,
			z = _center.z,
		}
	end
	
	local dx2 = (_point.x - actualCenter.x) * (_point.x - actualCenter.x)
	local dz2 = (_point.z - actualCenter.z) * (_point.z - actualCenter.z)
	local distance = math.sqrt(dx2 + dz2) 
	
	return distance >= _radiusMin and distance <= _radiusMax
end

ATMEFct.C_Circle_getRandomPosition = function(_center, _name, _radiusMin, _radiusMax)
	local point
	
	local angle = 2 * math.pi * math.random()
	local radius = (_radiusMax - _radiusMin) * math.random() + _radiusMin
	
	if _name ~= nil then
		if ATMEDatas.allAIUnitsAndPlayers[_name] ~= nil then
			point = ATMEDatas.allAIUnitsAndPlayers[_name]:getPosition()
		else 
			return
		end
	else
		point = {
			x = _center.x,
			y = _center.y,
			z = _center.z,
		}
	end
	
	return ATME.convertToPoint3D({
									x = point.x + radius * math.sin(angle),
									y = point.z + radius * math.cos(angle),
								})
end

ATMEDatas.C_Circle_MT = {
	className = "C_Circle",
	parentClass = ATME.C_Zone2D,
	
	mt = {},
	
	keys = {
		["getIndex"] = true,
		["isInside"] = true,
		["getRandomPosition"] = true,
		["getCenter"] = true,
		["getRadius"] = true,
		["getBox"] = true,
	},
	
	localMembers = ATMEFct.C_IndexList_create(),
	
	add = function(self, _center, _radius, _linkedUnitName)
		local item = {
			center = _center,
			radius = _radius,
			box = {
				min = {
					x = _center.x - _radius,
					y = 0,
					z = _center.z - _radius,
				},
				max = {
					x = _center.x + _radius,
					y = 200000,
					z = _center.z + _radius,
				},
			},
			
			linkedUnitName = nil,			-- Mis à jour par ATME.C_Area
		}
		
		return self.localMembers:add(item)
	end,
	
	remove = function(self, _id)
		self.localMembers:remove(_id)
	end,
	
	get = function(self, _id)
		return self.localMembers:get(_id)
	end,
}

ATME.C_Circle = {
	getClassName = function(self)
		return ATMEDatas.C_Circle_MT.className
	end,
	
	getParentClass = function(self)
		return ATMEDatas.C_Circle_MT.parentClass
	end,
}

ATMEFct.C_Circle_create = function(_center, _radius)
	local newCircle = {}
	
	setmetatable(newCircle, ATMEDatas.C_Circle_MT.mt)
	
	local index = ATMEDatas.C_Circle_MT:add(_center, _radius)
	local localMembers = ATMEDatas.C_Circle_MT:get(index)

	function newCircle.getIndex(self)
		return index
	end
	
	function newCircle.getBox(self)
		return {
			min = {
				x = localMembers.box.min.x,
				y = localMembers.box.min.y,
				z = localMembers.box.min.z,
			},
			max = {
				x = localMembers.box.max.x,
				y = localMembers.box.max.y,
				z = localMembers.box.max.z,
			},
		}
	end
	
	function newCircle.isInside(self, _reference)
		local fctDefinition = ATMEFct.getErrorPrefix(newCircle) .. "isInside(reference)"
		
		if ATMEFct.isReference(_reference) == true then
			local point = ATMEFct.getPointFromReference(_reference)
			
			return ATMEFct.C_Circle_isInside(point, localMembers.center, nil, 0, localMembers.radius)
		else
			ATMEFct.errorOutputCore(nil, fctDefinition, "reference type must be ATME.C_AIUnit or ATME.C_Player or ATME.C_StaticObject or table (x,y) or (x,y,z)", true)
		end
		
		return false
	end
	
	function newCircle.getRandomPosition(self)
		return ATMEFct.C_Circle_getRandomPosition(localMembers.center, localMembers.linkedUnitName, 0, localMembers.radius)
	end
	
	function newCircle.getRadius(self)
		return localMembers.radius
	end
	
	function newCircle.getCenter(self)
		if localMembers.linkedUnitName == nil then
			return {
				x = localMembers.center.x,
				y = localMembers.center.y,
				z = localMembers.center.z,
			}
		else
			if ATMEDatas.allAIUnitsAndPlayers[localMembers.linkedUnitName] ~= nil then
				return ATMEDatas.allAIUnitsAndPlayers[localMembers.linkedUnitName]:getPosition()
			end
		end
	end
	
	return newCircle
end


ATMEDatas.C_Circle_MT.__call = function(t, ...)
	local args = {...}
	local fctDefinition = "Constructor :\nATME.C_Circle(DCSZoneName)\nATME.C_Circle(reference, radius)"
	local point, radius
	
	if #args > 0 then
		if type(args[1]) == "string" then
			if #args == 1 then
				local zone = ATME.getDCSZone(args[1])
				
				if zone ~=  nil then
					point = zone.point
					radius = zone.radius
				else
					ATMEFct.errorOutputCore(nil, fctDefinition, "DCS zone '" .. args[1] .. "' unknown", false)
					return
				end	
			else
				ATMEFct.errorOutputCore(nil, fctDefinition, "must have 1 parameter", false)
				return
			end
		elseif ATMEFct.isReference(args[1]) == true then
			if #args == 2 then
				if type(args[2]) == "number" then
					radius = math.floor(args[2])
					if radius > 0 then
						point = ATMEFct.getPointFromReference(args[1])
					else
						ATMEFct.errorOutputCore(nil, fctDefinition, "radius must be > 0", false)
						return
					end
				else
					ATMEFct.errorOutputCore(nil, fctDefinition, "radius type must be number", false)
					return
				end
			else
				ATMEFct.errorOutputCore(nil, fctDefinition, "must have 2 parameters", false)
				return
			end
		else
			ATMEFct.errorOutputCore(nil, fctDefinition, "Parameter #1 type must be string, ATME.C_AIUnit, ATME.C_Player, ATME.C_StaticObject or table (x,y) or (x,y,z)", false)
			return
		end
		
		return ATMEFct.C_Circle_create(point, radius)
	else
		ATMEFct.errorOutputCore(nil, fctDefinition, "must have at least 1 parameter", false)
	end
end

setmetatable(ATME.C_Circle, ATMEDatas.C_Circle_MT)

ATMEDatas.C_Circle_MT.mt.__metatable = "Private"
ATMEDatas.C_Circle_MT.mt.__index = ATME.C_Circle

ATMEDatas.C_Circle_MT.mt.__newindex = function(t, k, v)
	if ATMEDatas.C_Circle_MT.keys[k] ~= nil then 
		rawset(t, k, v)
	else
		ATMEFct.errorOutputCore(nil, "Function ATME.C_Circle : Bad key " .. k, "table locked", false)
	end
end

ATMEDatas.C_Ring_MT = {
	className = "C_Ring",
	parentClass = ATME.C_Zone2D,
	
	mt = {},
	
	keys = {
		["getIndex"] = true,
		["isInside"] = true,
		["getRandomPosition"] = true,
		["getCenter"] = true,
		["getBox"] = true,
	},
	
	localMembers = ATMEFct.C_IndexList_create(),
	
	add = function(self, _center, _radiusMin, _radiusMax)
		local item = {
			center = _center,
			radiusMin = _radiusMin,
			radiusMax = _radiusMax,
			box = {
				min = {
					x = _center.x - _radiusMax,
					y = 0,
					z = _center.z - _radiusMax,
				},
				max = {
					x = _center.x + _radiusMax,
					y = 200000,
					z = _center.z + _radiusMax,
				},
			},
			linkedUnitName = nil,			-- Mis à jour par ATME.C_Area
		}
		
		return self.localMembers:add(item)
	end,
	
	remove = function(self, _id)
		self.localMembers:remove(_id)
	end,
	
	get = function(self, _id)
		return self.localMembers:get(_id)
	end,
}

ATME.C_Ring = {
	getClassName = function(self)
		return ATMEDatas.C_Ring_MT.className
	end,
	
	getParentClass = function(self)
		return ATMEDatas.C_Ring_MT.parentClass
	end,
}

ATMEFct.C_Ring_create = function(_center, _radiusMin, _radiusMax)
	local newRing = {}
	
	setmetatable(newRing, ATMEDatas.C_Ring_MT.mt)
	
	local index = ATMEDatas.C_Ring_MT:add(_center, _radiusMin, _radiusMax)
	local localMembers = ATMEDatas.C_Ring_MT:get(index)
	
	function newRing.getIndex(self)
		return index
	end
	
	function newRing.getBox(self)
		return {
			min = {
				x = localMembers.box.min.x,
				y = localMembers.box.min.y,
				z = localMembers.box.min.z,
			},
			max = {
				x = localMembers.box.max.x,
				y = localMembers.box.max.y,
				z = localMembers.box.max.z,
			},
		}
	end
	
	function newRing.isInside(self, _reference)
		local fctDefinition = ATMEFct.getErrorPrefix(newRing) .. "isInside(reference)"
		
		if ATMEFct.isReference(_reference) == true then		
			local point = ATMEFct.getPointFromReference(_reference)
			
			return ATMEFct.C_Circle_isInside(point, localMembers.center, nil, localMembers.radiusMin, localMembers.radiusMax)
		else
			ATMEFct.errorOutputCore(nil, fctDefinition, "reference type must be ATME.C_AIUnit or ATME.C_Player or ATME.C_StaticObject or table (x,y) or (x,y,z)", true)
		end
		
		return false
	end
	
	function newRing.getRandomPosition(self)
		return ATMEFct.C_Circle_getRandomPosition(localMembers.center, localMembers.linkedUnitName, localMembers.radiusMin, localMembers.radiusMax)
	end
	
	function newRing.getCenter(self)
		if localMembers.linkedUnitName == nil then
			return {
				x = localMembers.center.x,
				y = localMembers.center.y,
				z = localMembers.center.z,
			}
		else
			local unit = ATMEDatas.allAIUnitsAndPlayers[localMembers.linkedUnitName]
			
			if unit ~= nil then
				return unit:getPosition()
			end
		end
	end
	
	return newRing
end


ATMEDatas.C_Ring_MT.__call = function(t, ...)
	local args = {...}
	local fctDefinition = "Constructor :\nATME.C_Ring(DCSZoneName, deltaRadius)\nATME.C_Ring(reference, radiusMin, radiusMax)"
	local center, radiusMin, radiusMax
	
	if #args > 1 then
		if type(args[1]) == "string" then
			if #args == 2 then
				if type(args[2]) == "number" then
					local zone = ATME.getDCSZone(args[1])
					
					if zone ~=  nil then
						if args[2] < 0 then
							radiusMin = zone.radius + math.floor(args[2]) 
							if radiusMin > 0 then
								center = zone.point
								radiusMax = zone.radius
							else
								ATMEFct.errorOutputCore(nil, fctDefinition, "DCSZone radius + deltaRadius can't be <= 0", false)
								return
							end
						else
							radiusMin = zone.radius
							radiusMax = zone.radius + math.floor(args[2])
						end
					else
						ATMEFct.errorOutputCore(nil, fctDefinition, "DCS zone '" .. args[1] .. "' unknown", false)
						return
					end
				else
					ATMEFct.errorOutputCore(nil, fctDefinition, "deltaRadius type must be number", false)
					return
				end
			else
				ATMEFct.errorOutputCore(nil, fctDefinition, "must have 2 parameters", false)
				return
			end
		elseif ATMEFct.isReference(args[1]) == true then
			if #args == 3 then
				if type(args[2]) == "number" and type(args[3]) == "number" then
					radiusMin = math.floor(args[2])
					radiusMax = math.floor(args[3])
					if radiusMin> 0 then
						if radiusMax > 0 then
							center = ATMEFct.getPointFromReference(args[1])
						else
							ATMEFct.errorOutputCore(nil, fctDefinition, "radiusMax must be > 0", false)
							return
						end
					else
						ATMEFct.errorOutputCore(nil, fctDefinition, "radiusMin must be > 0", false)
						return
					end
				else
					if type(args[2]) ~= "number" then
						ATMEFct.errorOutputCore(nil, fctDefinition, "radiusMin type must be number", false)
						return
					elseif type(args[3]) ~= "number" then
						ATMEFct.errorOutputCore(nil, fctDefinition, "radiusMax type must be number", false)
						return
					end
				end
			else
				ATMEFct.errorOutputCore(nil, fctDefinition, "must have 3 parameters", false)
				return
			end
		else
			ATMEFct.errorOutputCore(nil, fctDefinition, "Parameter #1 type must be string, ATME.C_AIUnit, ATME.C_Player, ATME.C_StaticObject or table (x,y) or (x,y,z)", false)
			return
		end
		
		return ATMEFct.C_Ring_create(center, radiusMin, radiusMax)
	else
		ATMEFct.errorOutputCore(nil, fctDefinition, "must have at least 2 parameters", false)
	end
end

setmetatable(ATME.C_Ring, ATMEDatas.C_Ring_MT)

ATMEDatas.C_Ring_MT.mt.__metatable = "Private"
ATMEDatas.C_Ring_MT.mt.__index = ATME.C_Ring

ATMEDatas.C_Ring_MT.mt.__newindex = function(t, k, v)
	if ATMEDatas.C_Ring_MT.keys[k] ~= nil then 
		rawset(t, k, v)
	else
		ATMEFct.errorOutputCore(nil, "Function ATME.C_Ring : Bad key " .. k, "table locked", false)
	end
end

ATMEDatas.C_PickupZone_MT = {
	className = "C_PickupZone",
	parentClass = ATME.C_Zone2D,
	
	mt = {},
	
	keys = {
		["getIndex"] = true,
		["getName"] = true,
		["setSignal"] = true,
		["resetSignal"] = true,
		["isSignalSet"] = true,
		["getRandomPosition"] = true,
		["isInside"] = true,
		["getBox"] = true,
	},
	
	localMembers = ATMEFct.C_IndexList_create(),
	
	add = function(self, _coalitionName, _center, _radius)
		local item = {
			coalitionName = _coalitionName,
			center = _center,
			radius = _radius,
			box = {
				min = {
					x = _center.x - _radius,
					y = 0,
					z = _center.z - _radius,
				},
				max = {
					x = _center.x + _radius,
					y = 200000,
					z = _center.z + _radius,
				},
			},
			signalIndex = 0,
			tracking ={
				groupNames = {},
				startSignal = false,
				stack = ATMEFct.C_Stack_create(false),
			},
		}
		
		return self.localMembers:add(item)
	end,
	
	remove = function(self, _id)
		self.localMembers:remove(_id)
	end,
	
	get = function(self, _id)
		return self.localMembers:get(_id)
	end,
}

ATME.C_PickupZone = {
	getClassName = function(self)
		return ATMEDatas.C_PickupZone_MT.className
	end,
	
	getParentClass = function(self)
		return ATMEDatas.C_PickupZone_MT.parentClass
	end,
	
	getByName = function(_name)
		if type(_name) == "string" then
			return ATMEDatas.pickupZones[_name]
		else
			ATMEFct.errorOutputCore(nil, "Function ATME.C_PickupZone.getByName(name)", "name type must be string", false)
		end
	end,
}

ATMEFct.C_PickupZone_create = function(_name, _coalitionName, _center, _radius)
	local newPickupZone = {}
	local name = _name
	
	setmetatable(newPickupZone, ATMEDatas.C_PickupZone_MT.mt)
	
	local index = ATMEDatas.C_PickupZone_MT:add(_coalitionName, _center, _radius)
	local localMembers = ATMEDatas.C_PickupZone_MT:get(index)
	
	ATMEDatas.stackTimer:push({
					object = newPickupZone,
					classMT = "C_PickupZone_MT",
					id = 3,
				})

	function newPickupZone.getIndex(self)
		return index
	end
	
	function newPickupZone.getName(self)
		return name
	end
	
	function newPickupZone.getBox(self)
		return {
			min = {
				x = localMembers.box.min.x,
				y = localMembers.box.min.y,
				z = localMembers.box.min.z,
			},
			max = {
				x = localMembers.box.max.x,
				y = localMembers.box.max.y,
				z = localMembers.box.max.z,
			},
		}
	end
	
	function newPickupZone.isInside(self, _reference)
		local fctDefinition = ATMEFct.getErrorPrefix(newPickupZone) .. "isInside(reference)"
		
		if ATMEFct.isReference(_reference) == true then		
			local point = ATMEFct.getPointFromReference(_reference)
			
			return ATMEFct.C_Circle_isInside(point, localMembers.center, nil, localMembers.radiusMin, localMembers.radiusMax)
		else
			ATMEFct.errorOutputCore(nil, fctDefinition, "reference type must be ATME.C_AIUnit or ATME.C_Player or ATME.C_StaticObject or table (x,y) or (x,y,z)", true)
		end
		
		return false
	end
	
	function newPickupZone.getRandomPosition(self)
		return ATMEFct.C_Circle_getRandomPosition(localMembers.center, nil, localMembers.radiusMin, localMembers.radiusMax)
	end
	
	function newPickupZone.setSignal(self, _radius, _signalType)
		local fctDefinition = ATMEFct.getErrorPrefix(newPickupZone) .. "setSignal(radius, signalType)"
		
		if type(_radius) == "number" and type(_signalType) == "string" then
			if _radius > 0 then
				local tokens = ATMEFct.analyzeString(_signalType)
				local ok = false
				
				if #tokens == 2 and tokens[1].type == "TOKEN_SIGNAL_TYPE" and (tokens[2].type == "TOKEN_COLOR" or tokens[2].type == "TOKEN_TYPE_RANDOM") then
					if (tokens[1].value == "SMOKE" and ATMEConst.smokeColors[tokens[2].value] ~= nil) or
							(tokens[1].value == "FLARE" and ATMEConst.flareColors[tokens[2].value] ~= nil) then
						
						local item = {
							radius = _radius,
							center = localMembers.center,
							type = tokens[1].value,
							color = tokens[2].value,
							timeStart = -1,
							offsetTime = 0,
							coalitionUnitsInZone = {},
						}
						
						self:resetSignal()
						localMembers.signalIndex = ATMEDatas.signals:add(item)

						ok = true
					end
				end
				
				if ok == false then
					ATMEFct.errorOutputCore(nil, fctDefinition, "signalType string bad format", false)
				end
			else
				ATMEFct.errorOutputCore(nil, fctDefinition, "radius must be > 0", false)
			end
		else
			if type(_radius) ~= "number" then
				ATMEFct.errorOutputCore(nil, fctDefinition, "radius type must be number", false)
			elseif type(_signalType) ~= "string" then
				ATMEFct.errorOutputCore(nil, fctDefinition, "signalType type must be string", false)
			end
		end
	end
	
	function newPickupZone.resetSignal(self)
		if localMembers.signalIndex > 0 then
			ATMEFct.resetSignalUnits(localMembers.signalIndex)
			ATMEDatas.signals:remove(localMembers.signalIndex)
			localMembers.signalIndex = 0
		end
	end
	
	function newPickupZone.isSignalSet(self)
		return localMembers.signalIndex ~= 0
	end
	
	ATMEDatas.pickupZones[_name] = newPickupZone

	return newPickupZone
end


ATMEDatas.C_PickupZone_MT.__call = function(t, _name, _coalitionName)
	local fctDefinition = "Constructor :\nATME.C_PickupZone(DCSZoneName, coalitionName)"
	
	if type(_name) == "string" and type(_coalitionName) == "string" then
		local coalitionName = string.upper(_coalitionName)
		if coalitionName == "BLUE" or coalitionName == "RED" then
			if ATMEDatas.pickupZones[_name] == nil then
				local zone = ATME.getDCSZone(_name)
					
				if zone ~=  nil then
					return ATMEFct.C_PickupZone_create(_name, coalitionName, zone.point, zone.radius)
				else
					ATMEFct.errorOutputCore(nil, fctDefinition, "DCS zone " .. _name .. " unknown", false)
				end
				
			else
				return nil
			end
		else
			ATMEFct.errorOutputCore(nil, fctDefinition, "coalitionName must be 'BLUE' or 'RED'", false)
		end
	else
		if type(_name) ~= "string" then
			ATMEFct.errorOutputCore(nil, fctDefinition, "DCSZoneName type must be string", false)
		elseif type(_coalitionName) ~= "string" then
			ATMEFct.errorOutputCore(nil, fctDefinition, "coalitionName type must be string", false)
		end
	end
end

setmetatable(ATME.C_PickupZone, ATMEDatas.C_PickupZone_MT)

ATMEDatas.C_PickupZone_MT.mt.__metatable = "Private"
ATMEDatas.C_PickupZone_MT.mt.__index = ATME.C_PickupZone

ATMEDatas.C_PickupZone_MT.mt.__newindex = function(t, k, v)
	if ATMEDatas.C_PickupZone_MT.keys[k] ~= nil then 
		rawset(t, k, v)
	else
		ATMEFct.errorOutputCore(nil, "Function ATME.C_PickupZone : Bad key " .. k, "table locked", false)
	end
end

ATMEFct.C_Polygon_isInTriangle = function(_points, _P)
	local dRef
	local isInside = true

	for _i = 1, 3 do
		local j = _i + 1
		if j == 4 then
			j = 1
		end

		local d = ATMEFct.whichSide(_points[_i], _points[j], _P)
		if d ~= 0 then
			if dRef == nil then
				dRef = d
			elseif dRef ~= d then
				isInside = false
			end
		end
	end

	return isInside
end

ATMEFct.C_Polygon_isInside = function(_P, _triangles)
	local isInside = true
	local index = 1

	repeat
		dInit = nil
		isInside = ATMEFct.C_Polygon_isInTriangle(_triangles[index].points, _P)
		index = index + 1
	until isInside == true or index == #_triangles + 1
	
	return isInside
end

ATMEDatas.C_Polygon_MT = {
	className = "C_Polygon",
	parentClass = ATME.C_Zone2D,
	
	mt = {},
	
	keys = {
		["isInside"] = true,
		["getRandomPosition"] = true,
		["getIndex"] = true,
		["getCenter"] = true,
		["getBox"] = true,
	},
	
	localMembers = ATMEFct.C_IndexList_create(),
	
	add = function(self, _points, _triangles)
		local point = {
			x = 0,
			y = 0,
		}
		
		local minPoint = {
			x = _points[1].x,
			y = 0,
			z = _points[1].z,
		}
			
		local maxPoint = {
			x = _points[1].x,
			y = 200000,
			z = _points[1].z,
		}
		
		for _, _point in ipairs(_points) do
			point.x = point.x + _point.x
			point.y = point.y + _point.z
			
			if minPoint.x > _point.x then
				minPoint.x = _point.x
			end
			if minPoint.z > _point.z then
				minPoint.z = _point.z
			end
			
			if maxPoint.x < _point.x then
				maxPoint.x = _point.x
			end
			if maxPoint.z < _point.z then
				maxPoint.z = _point.z
			end
		end
		
		point.x = point.x / #_points
		point.y = point.y / #_points
		
		local item = {
			points = _points,
			center = ATME.convertToPoint3D(point),
			triangles = _triangles,
			box = {
				min = minPoint,
				max = maxPoint,
			},
		}
		
		return self.localMembers:add(item)
	end,
	
	remove = function(self, _id)
		self.localMembers:remove(_id)
	end,
	
	get = function(self, _id)
		return self.localMembers:get(_id)
	end,
}

ATME.C_Polygon = {
	getClassName = function(self)
		return ATMEDatas.C_Polygon_MT.className
	end,
	
	getParentClass = function(self)
		return ATMEDatas.C_Polygon_MT.parentClass
	end,
}

ATMEFct.C_Polygon_create = function(_points)
	local triangles = {}
	
	local function zMin(_points)
		local zMin = _points[1].z
		local index = 1
		for _i = 2, #_points do
			if _points[_i].z < zMin then
				index = _i
				zMin = _points[_i].z
			end
		end

		return index
	end
  
	local function nextVertexIndex(_points, _index)
		local newIndex = _index + 1
		local nbPoints = #_points

		if newIndex > nbPoints then
			newIndex = 1
		end

		return newIndex
	end

	local function previousVertexIndex(_points, _index)
		local newIndex = _index - 1
		local nbPoints = #_points

		if newIndex == 0 then
			newIndex = nbPoints
		end

		return newIndex
	end

	local function newPolygon(_polygon, _start, _end)
		local points = {}
		local i = _start

		while i ~= _end do
			table.insert(points, {
									x = _polygon[i].x,
									y = _polygon[i].y,
									z = _polygon[i].z,
									})

			i = nextVertexIndex(_polygon, i)
		end
		
		table.insert(points, {
								x = _polygon[i].x,
								y = _polygon[i].y,
								z = _polygon[i].z,
								})

		return points
	end

	local function inTriangle(_points, _M)
		local det = -1
		
		if ATMEFct.C_Polygon_isInTriangle(_points, _M) == true then
			det = math.abs((_points[3].z - _points[2].z) * (_M.x - _points[2].x) - 
								(_points[3].x - _points[2].x) * (_M.z - _points[2].z))
		end

		return det
	end
	
	local function findVertexInTriangle(_points, _iP1, _iP2, _iP3)
		local nbPoints = #_points
		local j
		local maxDet = 0

		for _i = 1, nbPoints do
			if _i ~= _iP1 and _i ~= _iP2 and _i ~= _iP3 then
				local pts = {
					[1] = _points[_iP1], 
					[2] = _points[_iP2], 
					[3] = _points[_iP3],
				}
				local det = inTriangle(pts, _points[_i])

				if det > maxDet then
					maxDet = det
					j = _i  
				end
			end
		end

		return j
	end
  
	local function analyze(_points)
		-- Fonction récursive de triangulation d'un polygone
		-- Pour un polygone en cours défini par ses point, cette triangulation 
		-- est basée sur :
		--    - La recherche du z minimal dans le plan zOx appelé Start
		--    - Si aucun autre point du polygon coupe le segment défini par précédent/suivant, 
		--      le premier triangle est crée avec ces 3 points. Le point Start est supprimé et 
		--      une nouvelle analyse est faite.
		--    - sinon le point le plus loin (pour optimiser utilisation du produit vectoriel)
		--      du segment défini par précédent/suivant est mémorisé (ici M) et le nouveau segment
		--      défini par Start et M induisent la création de deux polygones à partir du premier,
		--      une nouvelle analyse est alors lancée pour chaque polygone.
		--
		-- Dans tous les cas, l'analyse s'arrête s'il ne reste que 3 points et ce tringle est alors
		-- mémorisé. Il faut noter que les triangles plats ne sont pas mémorisés. Le triangle ABC est 
		-- un triangle plat si le produit vectoriel vaut 0 pour les vecteurs AB et AC.
		
		local startIndex = zMin(_points)
		local nextIndex = nextVertexIndex(_points, startIndex)
		local prevIndex = previousVertexIndex(_points, startIndex)

		local j = findVertexInTriangle(_points, startIndex, nextIndex, prevIndex)
		
		if j == nil then
			if ATMEFct.whichSide(_points[startIndex], _points[nextIndex], _points[prevIndex]) ~= 0 then
				table.insert(triangles, {
											points = {
												_points[startIndex], 
												_points[nextIndex], 
												_points[prevIndex],
											}
										})
			end
			
			local poly = newPolygon(_points, nextIndex, prevIndex)
			if #poly == 3 then
				if ATMEFct.whichSide(poly[1], poly[2], poly[3]) ~= 0 then
					table.insert(triangles, {
												points = poly,
											})
				end
			else
				analyze(poly)
			end
		else
			local poly1 = newPolygon(_points, startIndex, j)
			local poly2 = newPolygon(_points, j, startIndex)
			if #poly1 == 3 then
				if ATMEFct.whichSide(poly1[1], poly1[2], poly1[3]) ~= 0 then
					table.insert(triangles, {
												points = poly1,
											})
				end
			else
				analyze(poly1)
			end
			if #poly2 == 3 then
				if ATMEFct.whichSide(poly2[1], poly2[2], poly2[3]) ~= 0 then
					table.insert(triangles, {
												points = poly2,
											})
				end
			else
				analyze(poly2)
			end
		end
	end
  
 
	analyze(_points)
	
	
	-- Calcul des barycentres et des droites rayon qui relient le barycentre à chaque sommet.
	-- Mémorisation des côtés représentés par des droites 2D. La droite 2D i relie le sommet i au 
	-- sommet i + 1. Un triangle = 3 côtés et 3 rayons, donc pas besoin de recherche de direction.
	-- L'angle de chaque rayon est également mémorisé. Toutes ces valeurs seront utilisées pour déterminer
	-- de manière déterministe un point aléatoire dans un polygone.
	
	-- Calcul du barycentre et des côtés de chaque triangle.
	
	for _, _triangle in ipairs(triangles) do
		_triangle.sides = {}
		
		local sx = 0
		local sy = 0
		for _i = 1, #_triangle.points - 1 do
			sx = sx + _triangle.points[_i].x
			sy = sy + _triangle.points[_i].z
			
			_triangle.sides[_i] = ATMEFct.C_Line2D_create(nil, nil, _triangle.points[_i], _triangle.points[_i + 1])
		end
		sx = sx + _triangle.points[#_triangle.points].x
		sy = sy + _triangle.points[#_triangle.points].z
			
		_triangle.sides[#_triangle.points] = ATMEFct.C_Line2D_create(nil, nil, _triangle.points[#_triangle.points], _triangle.points[1])
		
		_triangle.barycentre = ATME.convertToPoint3D({
								x = sx / #_triangle.points,
								y = sy / #_triangle.points,
							})
		
		-- Mémorisation des droites rayons : lient le barycentre de chaque triangle à ses sommets. 
		-- Evaluation de l'angle
		_triangle.angleRad = {}
		for _i = 1, #_triangle.points do
			local line = ATMEFct.C_Line2D_create(nil, nil, _triangle.barycentre,  _triangle.points[_i])
			_triangle.angleRad[_i] = {
				angle = math.atan2(-line:getB(), line:getA()),
				index = _i,
			}
		end
	end


	local newPolygon = {}
	
	setmetatable(newPolygon, ATMEDatas.C_Polygon_MT.mt)
	local index = ATMEDatas.C_Polygon_MT:add(_points, triangles)
	local localMembers = ATMEDatas.C_Polygon_MT:get(index)
	
	function newPolygon.getIndex(self)
		return index
	end

	function newPolygon.getCenter(self)
		return {
				x = localMembers.center.x,
				y = localMembers.center.y,
				z = localMembers.center.z,
			}
	end
	
	function newPolygon.getBox(self)
		return {
			min = {
				x = localMembers.box.min.x,
				y = localMembers.box.min.y,
				z = localMembers.box.min.z,
			},
			max = {
				x = localMembers.box.max.x,
				y = localMembers.box.max.y,
				z = localMembers.box.max.z,
			},
		}
	end
	
	function newPolygon.isInside(self, _reference)
		local fctDefinition = ATMEFct.getErrorPrefix(newPolygon) .. "isInside(reference)"
		local isInside = false
		
		if ATMEFct.isReference(_reference) == true then		
			local point = ATMEFct.getPointFromReference(_reference)
				
			isInside = ATMEFct.C_Polygon_isInside(point, localMembers.triangles)
		else
			ATMEFct.errorOutputCore(nil, fctDefinition, "reference type must be ATME.C_AIUnit or ATME.C_Player or ATME.C_StaticObject or table (x,y) or (x,y,z)", true)
		end
		
		return isInside
	end
	
	function newPolygon.getRandomPosition(self)
		local idTriangle = math.random(1, #triangles)
		
		local sectorMin = math.random(1, #triangles[idTriangle].points)
		local sectorMax = sectorMin + 1
		
		if sectorMin == #triangles[idTriangle].points then
			sectorMax = 1
		end
		
		local angleMin
		local angleMax
		
		if triangles[idTriangle].direction == 1 then
			angleMin = triangles[idTriangle].angleRad[sectorMin].angle
			angleMax = triangles[idTriangle].angleRad[sectorMax].angle
		else
			angleMin = triangles[idTriangle].angleRad[sectorMax].angle
			angleMax = triangles[idTriangle].angleRad[sectorMin].angle
		end
		
		local angleRad = angleMin + math.random() * (angleMax - angleMin)
		
		local pt = {
			x = triangles[idTriangle].barycentre.x + 10 * math.cos(angleRad),
			y = triangles[idTriangle].barycentre.z + 10 * math.sin(angleRad),
		}
		
		local line = ATMEFct.C_Line2D_create(nil, nil, triangles[idTriangle].barycentre, pt)
		
		local intersectPoint = line:getIntersection(triangles[idTriangle].sides[sectorMin])
		
		local dx2 = (intersectPoint.x - triangles[idTriangle].barycentre.x) * (intersectPoint.x - triangles[idTriangle].barycentre.x)
		local dy2 = (intersectPoint.z - triangles[idTriangle].barycentre.z) * (intersectPoint.z - triangles[idTriangle].barycentre.z)
		local distance = math.sqrt(dx2 + dy2)
		
		local randomDistance = distance * math.random()
		
		return line:getPointFromOrigin(randomDistance)
	end
	
	return newPolygon
end


ATMEDatas.C_Polygon_MT.__call = function(t, _vertices)
	local fctDefinition = "Constructor :\nATME.C_Polygon(vertices)\nATME.C_Polygon(DCSZoneName)"
	
	if type(_vertices) == "table" or type(_vertices) == "string" then
		local pErr
		local points = {}
		if type(_vertices) == "table" then
			for _key, _value in ipairs(_vertices) do
				if pErr == nil then
					local point
					
					if ATME.isPoint(_value) ~= POINT_BAD then
						point = ATME.convertToPoint3D(_value)
					elseif type(_value) == "string" then
						local zone = ATME.getDCSZone(_value)
						
						if zone ~= nil then
							point = zone.point
						else
							pErr = "Bad zone in item key " .. _key .. " : DCS Zone " .. _value .. " doesn't exist"
						end
					else
						pErr = "Bad type for item key " .. _key
					end
					
					if pErr == nil then
						table.insert(points, point)
					end
				end
			end
		else
			for _i = 1, ATMEConst.polygonMaxVertices do
				local currentName = _vertices .. string.format("#%03d", _i)
				local zone = ATME.getDCSZone(currentName)
				
				if zone ~= nil then
					table.insert(points, zone.point)
				end
			end
		end
		
		if pErr ~= nil then
			ATMEFct.errorOutputCore(nil, fctDefinition, pErr, false)
		else
			if #points > 2 and #points <= ATMEConst.polygonMaxVertices then
			
				-- Vérification de polygone croisé
				local intersect = false
				
				for _i = 1, #points - 1 do
					for _j = _i + 1, #points - 1 do
						local nr = (points[_i].z - points[_j].z) * (points[_j + 1].x - points[_j].x) - (points[_i].x - points[_j].x) * (points[_j + 1].z - points[_j].z)
						local ns = (points[_i].z - points[_j].z) * (points[_i + 1].x - points[_i].x) - (points[_i].x - points[_j].x) * (points[_i + 1].z - points[_i].z)
						local d = (points[_i + 1].x - points[_i].x) * (points[_j + 1].z - points[_j].z) - (points[_i + 1].z - points[_i].z) * (points[_j + 1].x - points[_j].x)

						if d ~= 0 then
							local r = nr / d
							local s = ns / d
							if r > 0 and r < 1 and s > 0 and s < 1 then
								intersect = true
							end
						end
					end
				end


				if intersect == false then
					local pErr
					-- Vérification des distances entre points consécutifs
					for _i = 1, #points - 1 do
						for _j = _i + 1, #points do
							local dX2 = (points[_i].x - points[_j].x) * (points[_i].x - points[_j].x)
							local dY2 = (points[_i].z - points[_j].z) * (points[_i].z - points[_j].z)
							local dist2 = dX2 + dY2

							if dist2 < 1 then
								-- Points trop proches distance < 1
								
								pErr = {
									first = _i,
									last = _j,
								}
							end
						end
					end

					if pErr == nil then
						return ATMEFct.C_Polygon_create(points)
					else
						ATMEFct.errorOutputCore(nil, fctDefinition, "Bad polygon : Vertex " .. pErr.first .. " and " .. pErr.last .. " too near (distance < 1m)", false)
					end
				else
					ATMEFct.errorOutputCore(nil, fctDefinition, "Bad polygon : crossed vertices", false)
				end
			else
				if #points < 3 then
					ATMEFct.errorOutputCore(nil, fctDefinition, "Bad polygon : Less than 3 vertices", false)
				else
					ATMEFct.errorOutputCore(nil, fctDefinition, "Bad polygon : More than limit of " .. ATMEConst.polygonMaxVertices .. " vertices", false)
				end
			end
		end
	else
		ATMEFct.errorOutputCore(nil, fctDefinition, "vertices type must be table or DCSZoneName type must be string", false)
	end
end

setmetatable(ATME.C_Polygon, ATMEDatas.C_Polygon_MT)

ATMEDatas.C_Polygon_MT.mt.__metatable = "Private"
ATMEDatas.C_Polygon_MT.mt.__index = ATME.C_Polygon

ATMEDatas.C_Polygon_MT.mt.__newindex = function(t, k, v)
	if ATMEDatas.C_Polygon_MT.keys[k] ~= nil then 
		rawset(t, k, v)
	else
		ATMEFct.errorOutputCore(nil, "Function ATME.C_Polygon : Bad key " .. k, "table locked", false)
	end
end

ATMEFct.C_Rectangle_isInside = function(_point, _center, _angleRad, _length, _width)
	local lPoint = {
		x = (_point.x - _center.x) * math.cos(_angleRad) + (_point.z - _center.z) * math.sin(_angleRad),
		y = _point.y,
		z = -(_point.x - _center.x) * math.sin(_angleRad) + (_point.z - _center.z) * math.cos(_angleRad),
	}
	
	if lPoint.x >= -_length /2 and lPoint.x <= _length / 2 and lPoint.z >= -_width /2 and lPoint.z <= _width / 2 then
		return true
	end
	
	return false
end

ATMEDatas.C_Rectangle_MT = {
	className = "C_Rectangle",
	parentClass = ATME.C_Zone2D,
	
	mt = {},
	
	keys = {
		["isInside"] = true,
		["getRandomPosition"] = true,
		["getIndex"] = true,
		["getLength"] = true,
		["getWidth"] = true,
		["getAzimuth"] = true,
		["getCenter"] = true,
		["getBox"] = true,
	},
	
	localMembers = ATMEFct.C_IndexList_create(),
	
	add = function(self, _center, _azimuth, _length, _width)
		local lPoints = {}
		local points = {}
		
		local angleRad = math.rad(_azimuth)
	
		table.insert(lPoints, {x = _length / 2, y = _width / 2})
		table.insert(lPoints, {x = -_length / 2, y = _width / 2})
		table.insert(lPoints, {x = -_length / 2, y = -_width / 2})
		table.insert(lPoints, {x = _length / 2, y = -_width / 2})
	
		for _index, _point in ipairs(lPoints) do
			local point =  {
				x = _center.x + lPoints[_index].x * math.cos(angleRad) - lPoints[_index].y * math.sin(angleRad),
				y = _center.z + lPoints[_index].x * math.sin(angleRad) + lPoints[_index].y * math.cos(angleRad),
			}
			
			points[_index] = ATME.convertToPoint3D(point)
		end
		
		local minPoint = {
			x = points[1].x,
			y = 0,
			z = points[1].z,
		}
			
		local maxPoint = {
			x = points[1].x,
			y = 200000,
			z = points[1].z,
		}
		
		for _, _point in ipairs(points) do
			if minPoint.x > _point.x then
				minPoint.x = _point.x
			end
			if minPoint.z > _point.z then
				minPoint.z = _point.z
			end
			
			if maxPoint.x < _point.x then
				maxPoint.x = _point.x
			end
			if maxPoint.z < _point.z then
				maxPoint.z = _point.z
			end
		end
		
		local item = {
			points = _points,
			localPoints = lPoints,
			center = _center,
			azimuth = _azimuth,
			angleRad = angleRad,
			length = _length,
			width = _width,
			box = {
				min = minPoint,
				max = maxPoint,
			},
		}
		
		return self.localMembers:add(item)
	end,
	
	remove = function(self, _id)
		self.localMembers:remove(_id)
	end,
	
	get = function(self, _id)
		return self.localMembers:get(_id)
	end,
}

ATME.C_Rectangle = {
	getClassName = function(self)
		return ATMEDatas.C_Rectangle_MT.className
	end,
	
	getParentClass = function(self)
		return ATMEDatas.C_Rectangle_MT.parentClass
	end,
}

ATMEFct.C_Rectangle_create = function(_center, _heading, _length, _width)
	local newRectangle = {}
	
	setmetatable(newRectangle, ATMEDatas.C_Rectangle_MT.mt)
	local index = ATMEDatas.C_Rectangle_MT:add(_center, _heading, _length, _width)
	local localMembers = ATMEDatas.C_Rectangle_MT:get(index)
	
	function newRectangle.getIndex(self)
		return index
	end
	
	function newRectangle.getLength(self)
		return localMembers.length
	end
	
	function newRectangle.getWidth(self)
		return localMembers.width
	end
	
	function newRectangle.getAzimuth(self)
		return localMembers.azimuth
	end

	function newRectangle.getCenter(self)
		return {
				x = localMembers.center.x,
				y = localMembers.center.y,
				z = localMembers.center.z,
			}
	end
	
	function newRectangle.getBox(self)
		return {
			min = {
				x = localMembers.box.min.x,
				y = localMembers.box.min.y,
				z = localMembers.box.min.z,
			},
			max = {
				x = localMembers.box.max.x,
				y = localMembers.box.max.y,
				z = localMembers.box.max.z,
			},
		}
	end
	
	function newRectangle.isInside(self, _reference)
		local fctDefinition = ATMEFct.getErrorPrefix(newRectangle) .. "isInside(reference)"
		local isInside = false
		
		if ATMEFct.isReference(_reference) == true then		
			local point = ATMEFct.getPointFromReference(_reference)
			
			ATMEFct.C_Rectangle_isInside(point, localMembers.center, localMembers.angleRad, localMembers.length, localMembers.width)
		else
			ATMEFct.errorOutputCore(nil, fctDefinition, "reference type must be ATME.C_AIUnit or ATME.C_Player or ATME.C_StaticObject or table (x,y) or (x,y,z)", true)
		end
		
		return isInside
	end
	
	function newRectangle.getRandomPosition(self)
		local dx = math.random(-localMembers.length / 2, localMembers.length / 2)
		local dy = math.random(-localMembers.width / 2, localMemberswidth / 2)
		local point = {
				x = localMembers.center.x + dx * math.cos(localMembers.angleRad) - dy * math.sin(localMembers.angleRad),
				y = localMembers.center.z + dx * math.sin(localMembersangleRad) + dy * math.cos(localMembers.angleRad),
		}
		
		return ATME.convertToPoint3D(point)
	end
	
	return newRectangle
end

ATMEDatas.C_Rectangle_MT.__call = function(t, _reference, _azimuth, _length, _width)
	local fctDefinition = "Constructor :\nATME.C_Rectangle(reference, azimuth, length, width)"

	if ATMEFct.isReference(_reference) == true and type(_azimuth) == "number" and type(_length) == "number" and type(_width) == "number" then
		local center = ATMEFct.getPointFromReference(_reference)
		if _length > 0 then
			if _width > 0 then
				local azimuth = math.fmod(_azimuth, 360)
				
				if azimuth < 0 then 
					azimuth = azimuth + 360
				end
				
				return ATMEFct.C_Rectangle_create(center, azimuth, _length, _width)
			else
				ATMEFct.errorOutputCore(nil, fctDefinition, "width must be > 0", false)
			end
		else
			ATMEFct.errorOutputCore(nil, fctDefinition, "length must be > 0", false)
		end
	else
		if ATMEFct.isReference(_reference) == false then
			ATMEFct.errorOutputCore(nil, fctDefinition, "reference type must be ATME.C_AIUnit, ATME.C_Player, ATME.C_StaticObject or table (x,y) or (x,y,z)", false)
		elseif type(_azimuth) ~= "number" then
			ATMEFct.errorOutputCore(nil, fctDefinition, "azimuth type must be number", false)
		elseif type(_length) ~= "number" then
			ATMEFct.errorOutputCore(nil, fctDefinition, "length type must be number", false)
		elseif type(_width) ~= "number" then
			ATMEFct.errorOutputCore(nil, fctDefinition, "width type must be number", false)
		end
	end
end

setmetatable(ATME.C_Rectangle, ATMEDatas.C_Rectangle_MT)

ATMEDatas.C_Rectangle_MT.mt.__metatable = "Private"
ATMEDatas.C_Rectangle_MT.mt.__index = ATME.C_Rectangle

ATMEDatas.C_Rectangle_MT.mt.__newindex = function(t, k, v)
	if ATMEDatas.C_Rectangle_MT.keys[k] ~= nil then 
		rawset(t, k, v)
	else
		ATMEFct.errorOutputCore(nil, "Function ATME.C_Rectangle : Bad key " .. k, "table locked", false)
	end
end

----------------------------------------------------------------------------------------------------------
-- Classe ATME.C_Airbase : gère les bases aériennes (aéroports, bateaux ou FARP). 
--                         Pas de contructeur accessible aux modules externes.
-- 
-- Deux listes globales sont créés et initialisées :
--			-> airbasesByID pour le référencement par ID (number pour les bases de la carte, string sinon)
--			-> airbases pour le référencement par nom
----------------------------------------------------------------------------------------------------------

ATMEDatas.C_Airbase_MT = {
	className = "C_Airbase",
	mt = {},
	
	keys = {
		["getName"] = true,
		["getCategory"] = true,
		["getPosition"] = true,
		["getID"] = true,
		["getCoalitionName"] = true,
	},
}

ATME.C_Airbase = {
	getClassName = function(self)
		return ATMEDatas.C_Airbase_MT.className
	end,
	
	getParentClass = function(self)
		return ATMEDatas.C_Airbase_MT.parentClass
	end,
	
	getByName = function(_name)
		if type(_name) == "string" then
			return ATMEDatas.airbases[_name]
		else
			ATMEFct.errorOutputCore(nil, "Function ATME.C_Airbase.getByName(name)", "name type must be string", false)
		end
	end,
	
	getByID = function(_id)
		if type(_id) == "string" or type(_id) == "number" then
			local id = _id
			if type(_id) == "number" then
				id = mtha.floor(_id)
			end
			
			return ATMEDatas.airbasesByID[id]
		else
			ATMEFct.errorOutputCore(nil, "Function ATME.C_Airbase.getByID(id)", "id type must be string or number", false)
		end
	end,
}

ATMEFct.C_Airbase_create_basic = function(_category, _airbase)
	local id = _airbase:getID()
	local airbaseDCS = _airbase
	local helipadId
	local airdromeId
	local name = _airbase:getName()
	local categoryName = _category
	local newAirbase = {}
	local position
	
	setmetatable(newAirbase, ATMEDatas.C_Airbase_MT.mt)

	ATMEDatas.airbasesByID[id] = newAirbase
	ATMEDatas.airbases[name] = newAirbase
	
	if type(id) == "string" then
		helipadId = id
	else
		airdromeId = id
	end
	
	if categoryName ~= "SHIP" then
		position = _airbase:getPosition().p
	end
	
	function newAirbase.getName(self)
		return name
	end
	
	function newAirbase.getID(self)
		return id, airdromeId, helipadId
	end
	
	function newAirbase.getCoalitionName(self)
		local id = airbaseDCS:getCoalition()
		return ATMEConst.coalitionNames[id]
	end
	
	function newAirbase.getCategory(self)
		return categoryName
	end
	
	function newAirbase.getPosition(self)
		if categoryName == "SHIP" then
			if ATMEDatas.AIUnits[name] ~= nil then
				return ATMEDatas.AIUnits[name]:getPosition()
			end
		else
			return position
		end
	end
	
	
	return newAirbase
end

setmetatable(ATME.C_Airbase,ATMEDatas.C_Airbase_MT)

ATMEDatas.C_Airbase_MT.mt.__metatable = "Private"
ATMEDatas.C_Airbase_MT.mt.__index = ATME.C_Airbase
ATMEDatas.C_Airbase_MT.mt.__newindex = function(t, k, v)
	if ATMEDatas.C_Airbase_MT.keys[k] ~= nil then 
		rawset(t, k, v)
	else
		ATMEFct.errorOutputCore(nil, "Function ATME.C_Airbase : Bad key " .. k, "table locked", false)
	end
end


----------------------------------------------------------------------------------------------------------
-- Classe ATME.C_Area : Gère les ensembles de zones DCS ou zones 2D. 
-- Contructeur accessible aux modules externes.
-- Cette classe permet d'étendre la notion de zones par l'union de zones multiples.
-- Une zone ne peut être liée à un objet (possibilité pour les classes ATME.C_Circle et ATME.C_Ring)
----------------------------------------------------------------------------------------------------------

ATMEFct.C_Area_isInside = function(_area, _point)
	local localMembersArea = ATMEDatas.C_Area_MT:get(_area:getIndex())
	local isInside = false
	local zones = {}
	local charge = 0
	if _area:getCount() > 0 then
		for _, _item in pairs(localMembersArea.zonesList) do
			if ATMEFct.isObjectClass(_item.zone, ATME.C_Polygon) == true then
				local localMembers = ATMEDatas.C_Polygon_MT:get(_item.zone:getIndex())
				if ATMEFct.C_Polygon_isInside(_point, localMembers.triangles) == true then
					isInside = true
					table.insert(zones, {
							name = _item.name,
							zone = _item.zone,
					})
				end
				charge = charge + #localMembers.triangles
			elseif ATMEFct.isObjectClass(_item.zone, ATME.C_Rectangle) == true then
				local localMembers = ATMEDatas.C_Rectangle_MT:get(_item.zone:getIndex())
				if ATMEFct.C_Rectangle_isInside(_point, localMembers.center, localMembers.angleRad, localMembers.length, localMembers.width) == true then
					isInside = true
					table.insert(zones, {
							name = _item.name,
							zone = _item.zone,
					})
				end
				charge = charge + 2
			elseif ATMEFct.isObjectClass(_item.zone, ATME.C_Circle) == true then
				local localMembers = ATMEDatas.C_Circle_MT:get(_item.zone:getIndex())
				if ATMEFct.C_Circle_isInside(_point, localMembers.center, localMembersArea.linkedUnitName, 0, localMembers.radius) == true then
					isInside = true
					table.insert(zones, {
							name = _item.name,
							zone = _item.zone,
					})
				end
				charge = charge + 1
			elseif ATMEFct.isObjectClass(_item.zone, ATME.C_PickupZone) == true then
				local localMembers = ATMEDatas.C_PickupZone_MT:get(_item.zone:getIndex())
				if ATMEFct.C_Circle_isInside(_point, localMembers.center, nil, 0, localMembers.radius) == true then
					isInside = true
					table.insert(zones, {
							name = _item.name,
							zone = _item.zone,
					})
				end
				charge = charge + 1
			else
				local localMembers = ATMEDatas.C_Ring_MT:get(_item.zone:getIndex())
				if ATMEFct.C_Circle_isInside(_point, localMembers.center, localMembersArea.linkedUnitName, localMembers.radiusMin, localMembers.radiusMax) == true then
					isInside = true
					table.insert(zones, {
							name = _item.name,
							zone = _item.zone,
					})
				end
				charge = charge + 1
			end
		end
	end
	
	return isInside, zones, charge
end

ATMEDatas.C_Area_MT = {
	className = "C_Area",
	mt = {},
	
	keys = {
		["add"] = true,
		["remove"] = true,
		["removeAll"] = true,
		["isInside"] = true,
		["getIndex"] = true,
		["getLinkedUnitName"] = true,
		["getRandomPosition"] = true,
		["getCount"] = true,
		["setTracking"] = true,
		["resetTracking"] = true,
		["setGroupTracking"] = true,
		["resetGroupTracking"] = true,
		["getName"] = true,
		["tagGetByID"] = true,
		["tagCompare"] = true,
		["tagGetCount"] = true,
		["getZoneByName"] = true,
		["getInsideZones"] = true,
		["getUserPrivateDatas"] = true,
	},
	
	localMembers = ATMEFct.C_IndexList_create(),
	
	add = function(self, _linkedUnitName)
		local item = {
			zonesList = {},
			zonesListByName = ATMEFct.C_IndexList_create(),
			nb = 0,
			linkedUnitName = _linkedUnitName,
			tracking ={
				unitNames = {},
				groupNames = {},
				stack = ATMEFct.C_Stack_create(false),
			},
			userPrivateDatas = {},
		}
		
		return self.localMembers:add(item)
	end,
	
	remove = function(self, _id)
		for _, _localModuleMembers in ATMEDatas.C_Module_MT:pairs() do
			self.localMembers:get(_id).userPrivateDatas[_localModuleMembers.name] = nil
		end
		self.localMembers:get(_id).userPrivateDatas = nil
		self.localMembers:remove(_id)
	end,
	
	get = function(self, _id)
		return self.localMembers:get(_id)
	end,
}

ATME.C_Area = {
	getClassName = function(self)
		return ATMEDatas.C_Area_MT.className
	end,
	
	getParentClass = function(self)
		return ATMEDatas.C_Area_MT.parentClass
	end,
}

ATMEFct.C_Area_create = function(_name, _areas, _linkedUnit)
	local newArea = {}

	setmetatable(newArea, ATMEDatas.C_Area_MT.mt)
	
	local name
	local tagsName
	local linkedUnitName
	
	if _name ~= nil and _areas ~= nil then
		name = _name
		_areas[name] = newArea
		tagsName = ATMEFct.decompString(_name)
	end
	
	if _linkedUnit ~= nil then
		if type(_linkedUnit) == "string" then
			linkedUnitName = _linkedUnit
		else
			linkedUnitName = _linkedUnit:getName()
		end
	end
	
	ATMEDatas.stackTimer:push({
							object = newArea,
							classMT = "C_Area_MT",
							id = 2,
						})
	
	local index = ATMEDatas.C_Area_MT:add(linkedUnitName)
	
	local localMembers = ATMEDatas.C_Area_MT:get(index)
	
	function newArea.getName(self)
		return name
	end
	
	function newArea.tagGetByID(self, _position)
		local fctDefinition = ATMEFct.getErrorPrefix(newArea) .. "tagGetByID(position)"
		
		if type(_position) == "number" then
			local pos = math.floor(_position)
			if tagsName ~= nil and pos >= 1 and pos <= #tagsName then
				return tagsName[pos]
			end
		else
			ATMEFct.errorOutputCore(nil, fctDefinition, "position type must be number", true)
		end
	end
	
	function newArea.tagGetCount(self)
		if tagsName ~= nil then
			return #tagsName
		else
			return 0
		end
	end
	
	function newArea.tagCompare(self, _tagsToCompare)
		local fctDefinition = ATMEFct.getErrorPrefix(newArea) .. "tagCompare(tagsToCompare)"
		
		if type(_tagsToCompare) == "string" then
			if tagsName ~= nil then
				local ok = ATMEFct.compareTags(tagsName, _tagsToCompare)
				
				if ok ~= nil then
					return ok
				else
					ATMEFct.errorOutputCore(nil, fctDefinition, "tagsToCompare format must be 'T1|T2|..|Tn'", false)
				end
			else
				return false
			end
		else
			ATMEFct.errorOutputCore(nil, fctDefinition, "tagsToCompare type must be string", true)
		end
	end
	
	function newArea.getLinkedUnitName(self)
		return localMembers.linkedUnitName
	end
	
	function newArea.getUserPrivateDatas(self, _module)
		local fctDefinition = ATMEFct.getErrorPrefix(newArea) .. "getUserPrivateDatas(module)"
		
		if ATME.isObjectClass(_module, ATME.C_Module) == true then
			return localMembers.userPrivateDatas[_module:getName()]
		else
			ATMEFct.errorOutputCore(nil, fctDefinition, "module type must be ATME.C_Module", true)
		end
	end
	
	function newArea.add(self, _zoneName, _zone)
		local item
		local fctDefinition = ATMEFct.getErrorPrefix(newArea) .. "add(zoneName, [zone])"
	
		if _zone == nil then
			if type(_zoneName) == "string" then
				-- Si un seul paramètre, c'est forcément une zone DCS
				
				if localMembers.zonesList[_zoneName] == nil then
					if ATME.getDCSZone(_zoneName) ~= nil then
						local circle = ATME.C_Circle(_zoneName)
					
						item = {
							name = _zoneName,
							zone = circle,
						}
					else
						ATMEFct.errorOutputCore(nil, fctDefinition, "DCS zone '" .. _zoneName .. "' unknown", false)
					end
				else
					ATMEFct.errorOutputCore(nil, fctDefinition, _zoneName .. " is already used in area " .. name, false)
				end
			else
				ATMEFct.errorOutputCore(nil, fctDefinition, "zoneName type must be string", true)
			end
		else
			if type(_zoneName) == "string" then
				if localMembers.zonesList[_zoneName] == nil then
					if type(_zone) == "string" then
						if ATME.getDCSZone(_zone) ~= nil then
							local circle = ATME.C_Circle(_zone)
						
							item = {
								name = _zoneName,
								zone = circle,
							}
						else
							ATMEFct.errorOutputCore(nil, fctDefinition, "DCS zone '" .. _zone .. "' unknown", false)
						end
					elseif ATME.isObjectClass(_zone, ATME.C_Zone2D) == true then
						local localMembersZone
						if ATME.isObjectClass(_zone, ATME.C_Circle) == true then
							localMembersZone = ATMEDatas.C_Circle_MT:get(_zone:getIndex())
						elseif ATME.isObjectClass(_zone, ATME.C_Ring) == true then
							localMembersZone = ATMEDatas.C_Ring_MT:get(_zone:getIndex())
						end
						
						if localMembers.linkedUnitName ~= nil then
							if localMembersZone ~= nil then
								item = {
									name = _zoneName,
									zone = _zone,
								}
							else
								ATMEFct.errorOutputCore(nil, fctDefinition, "area is linked to unit. It must contain only ATME.C_Circle and ATME.C_Ring instances", false)
							end
						else
							item = {
								name = _zoneName,
								zone = _zone,
							}
						end
					else
						ATMEFct.errorOutputCore(nil, fctDefinition, "zone type must be string, ATME.C_Circle, ATME.C_Ring, ATME.C_PickupZone, ATME.C_Rectangle or ATME.C_Polygon", false)
					end
				else
					ATMEFct.errorOutputCore(nil, fctDefinition, _zoneName .. " is already used in area " .. name, false)
				end
			else
				ATMEFct.errorOutputCore(nil, fctDefinition, "zoneName type must be string", true)
			end
		end
		
		if item ~= nil then
			localMembers.nb = localMembers.nb + 1
			localMembers.zonesList[_zoneName] = item
			item.id = localMembers.zonesListByName:add(_zoneName)
		end
	end
	
	function newArea.getZoneByName(self, _zoneName)
		local fctDefinition = ATMEFct.getErrorPrefix(newArea) .. "getZoneByName(zoneName)"
		
		if type(_zoneName) == "string" then
			return localMembers.zonesList[_zoneName].zone
		else
			ATMEFct.errorOutputCore(nil, fctDefinition, "zoneName type must be string", true)
		end
	end

	function newArea.isInside(self, _reference)
		local fctDefinition = ATMEFct.getErrorPrefix(newArea) .. "isInside(reference)"
		local isInside = false
		
		
		if ATMEFct.isReference(_reference) == true then		

			isInside, _, _ = ATMEFct.C_Area_isInside(self, ATMEFct.getPointFromReference(_reference))


			return isInside
		else
			ATMEFct.errorOutputCore(nil, fctDefinition, "reference type must be ATME.C_AIUnit or ATME.C_Player or ATME.C_StaticObject or table (x,y) or (x,y,z)", true)
		end
	end
	
	function newArea.getInsideZones(self, _reference)
		local fctDefinition = ATMEFct.getErrorPrefix(newArea) .. "getInsideZones(reference)"
		local zones
		
		if ATMEFct.isReference(_reference) == true then
			_, zones, _ = ATMEFct.C_Area_isInside(self, ATMEFct.getPointFromReference(_reference))
		else
			ATMEFct.errorOutputCore(nil, fctDefinition, "reference type must be ATME.C_AIUnit or ATME.C_Player or ATME.C_StaticObject or table (x,y) or (x,y,z)", true)
		end
		
		return zones
	end
	
	function newArea.getCount(self)
		return localMembers.nb
	end
	
	function newArea.remove(self, _name)
		local fctDefinition = ATMEFct.getErrorPrefix(newArea) .. "remove(zoneName)"
		local found = 0
		
		if type(_name) == "string" then
			local ok = false
			if localMembers.zonesList[_name] ~= nil then
				ok =  true
				localMembers.zonesListByName:remove(localMembers.zonesList[_name].id)
				localMembers.zonesList[_name] = nil
				localMembers.nb = localMembers.nb - 1
			end
			
			return ok
		else
			ATMEFct.errorOutputCore(nil, fctDefinition, "zoneName type must be string", true)
		end
	end
	
	function newArea.removeAll(self)
		localMembers.zonesList = {}
		localMembers.zonesListByName:removeAll()
		localMembers.nb = 0
	end
	
	function newArea.getIndex(self)
		return index
	end
	
	function newArea.getRandomPosition(self, _surfaceFilter, _isFlat, _altMin)
		local fctDefinition = ATMEFct.getErrorPrefix(newArea) .. "getRandomPosition(surfaceFilter, [flat], [altMin])"
	
		if type(_surfaceFilter) == "string" and (_surfaceFilter == "ALL" or _surfaceFilter == "WATER" or _surfaceFilter == "EARTH") and
					(_isFlat == nil or type(_isFlat) =="boolean") and (_altMin == nil or type(_altMin) =="number") then
			
			if self:getCount() > 0 then
				local nbTries = 0
				local point
				local isInWater
				
				local isFlat = _isFlat
				
				if _isFlat == nil then
					isFlat = false
				end
				
				local found = false
				
				repeat

					zoneName = localMembers.zonesListByName:getRandom()
					point = localMembers.zonesList[zoneName].zone:getRandomPosition()
					
					nbTries = nbTries + 1
					isInWater = ATME.isSurfaceWater(point)
					
					if _surfaceFilter == "ALL" or (isInWater == true and _surfaceFilter == "WATER") or 
							(isInWater == false and _surfaceFilter == "EARTH") then
						if isFlat == true and _surfaceFilter == "EARTH" then
							if point.y > _altMin then
								local ok = true
								for _i = -1, 1 do
									for _j = -1, 1 do
										if _i ~= 0 or _j ~= 0 then
											local deltaX = _i * 10
											local deltaZ = _j * 10
											local d2 = deltaX * deltaX + deltaZ * deltaZ
											local h = ATMEFct.getSurfaceAltitude({x = point.x + deltaX, y = point.z + deltaZ}) - point.y
											
											-- Pente de 10% max soit h > d*10/100 -> h > d/10
											if h * h > d2 / 100 then 
												ok = false
											end
										end
									end
								end
								
								found = ok
							end
						else
							found = true
						end
					end
				until found == true or nbTries >= 100
				
				if found == true then
					return point
				end
			end
		else
			if type(_surfaceFilter) ~= "string" then 
				ATMEFct.errorOutputCore(nil, fctDefinition, "surfaceFilter type must be string ('ALL', 'WATER' or 'EARTH')", true)
			elseif _isFlat ~= nil and type(_isFlat) ~= "boolean" then
				ATMEFct.errorOutputCore(nil, fctDefinition, "flat type must be nil or boolean", false)
			elseif _altMin ~= nil and type(_altMin) ~= "number" then
				ATMEFct.errorOutputCore(nil, fctDefinition, "altMin type must be nil or number", false)
			end
		end
	end
	
	function newArea.setTracking(self, _unit)
		local fctDefinition = ATMEFct.getErrorPrefix(newArea) .. "setTracking(unit)"
		
		if ATME.isObjectClass(_unit, ATME.C_Unit) == true or type(_unit) == "string" then
			local unit
			local name
			if type(_unit) == "string" then
				unit = ATMEDatas.allAIUnitsAndPlayers[_unit]
				name = _unit
			else
				unit = _unit
				name = unit:getName()
			end
			
			if unit ~= nil then
				localMembers.tracking.stack:push({unitName = name, flag = false})
			else
				ATMEFct.errorOutputCore(nil, fctDefinition, "Unit name " .. name .. " doesn't exist", false)
			end
		else
			ATMEFct.errorOutputCore(nil, fctDefinition, "unit type must be ATME.C_AIUnit or ATME.C_Player or string", true)
		end
	end
	
	function newArea.resetTracking(self, _unit)
		local fctDefinition = ATMEFct.getErrorPrefix(newArea) .. "resetTracking(unit)"
		
		if ATME.isObjectClass(_unit, ATME.C_Unit) == true or type(_unit) == "string" then
			
			local unit
			local name
			if type(_unit) == "string" then
				unit = ATMEDatas.allAIUnitsAndPlayers[_unit]
				name = _unit
			else
				unit = _unit
				name = unit:getName()
			end
			
			if unit ~= nil then
				localMembers.tracking.unitNames[name] = true
			end
		else
			ATMEFct.errorOutputCore(nil, fctDefinition, "unit type must be ATME.C_AIUnit or ATME.C_Player or string", true)
		end
	end
	
	function newArea.setGroupTracking(self, _group)
		local fctDefinition = ATMEFct.getErrorPrefix(newArea) .. "setGroupTracking(group)"
		
		if ATME.isObjectClass(_group, ATME.C_Group) == true or type(_group) == "string" then
			local group
			local name
			
			if type(_group) == "string" then
				group = ATMEDatas.groups[_group]
				name = _group
			else
				group = _group
				name = group:getName()
			end
			
			if group ~= nil then
				localMembers.tracking.stack:push({groupName = name, flag = false})
			else
				ATMEFct.errorOutputCore(nil, fctDefinition, "Group name " .. name .. " doesn't exist", false)
			end
		else
			ATMEFct.errorOutputCore(nil, fctDefinition, "group type must be ATME.C_Group or string", true)
		end
	end
	
	function newArea.resetGroupTracking(self, _group)
		local fctDefinition = ATMEFct.getErrorPrefix(newArea) .. "resetGroupTracking(group)"
		
		if ATME.isObjectClass(_group, ATME.C_Group) == true or type(_group) == "string" then
			local group
			local name
			
			if type(_group) == "string" then
				group = ATMEDatas.groups[_group]
				name = _group
			else
				group = _group
				name = group:getName()
			end
			
			if group ~= nil then
				localMembers.tracking.groupNames[name] = true
			else
				ATMEFct.errorOutputCore(nil, fctDefinition, "Group name " .. name .. " doesn't exist", false)
			end
		else
			ATMEFct.errorOutputCore(nil, fctDefinition, "group type must be ATME.C_Group or string", true)
		end
	end
	
	for _, _localModuleMembers in ATMEDatas.C_Module_MT:pairs() do
		localMembers.userPrivateDatas[_localModuleMembers.name] = {}
	end
	
	return newArea
end

setmetatable(ATME.C_Area,ATMEDatas.C_Area_MT)

ATMEDatas.C_Area_MT.__call = function(t, _linkedUnit)
	local fctDefinition = "Constructor ATME.C_Area([linkedUnit])"
	
	if _linkedUnit == nil or type(_linkedUnit) == "string" or ATME.isObjectClass(_linkedUnit, ATME.C_Unit) == true then
		return ATMEFct.C_Area_create(nil, nil, _linkedUnit)
	else
		ATMEFct.errorOutputCore(nil, fctDefinition, "linkedUnit type must be nil, string, ATME.C_AIUnit or ATME.C_Player", false)
	end
end

ATMEDatas.C_Area_MT.mt.__metatable = "Private"
ATMEDatas.C_Area_MT.mt.__index = ATME.C_Area
ATMEDatas.C_Area_MT.mt.__newindex = function(t, k, v)
	if ATMEDatas.C_Area_MT.keys[k] ~= nil then 
		rawset(t, k, v)
	else
		ATMEFct.errorOutputCore(nil, "Function ATME.C_Area : Bad key " .. k, "table locked", false)
	end
end


-----------------------------------------------------------------------------------------------------------
-- Classe ATME.C_Sound : gère les fichiers son définis dans la mission
--
-----------------------------------------------------------------------------------------------------------

ATMEFct.C_Sound_getPlaylist = function(_text, _random, _special)
	local tokens = ATMEFct.decompString(_text)

	if tokens ~= nil then
		local playlist = {}

		for _, _token in ipairs(tokens) do
			local _, _, temp = _token:find("([%d%a_]+)")
			if temp == _token then
				local idToken = _token:upper()
				if ATMEDatas.sounds[idToken] ~= nil then
					local localMembers = ATMEDatas.C_Sound_MT:get(ATMEDatas.sounds[idToken]:getIndex())
					table.insert(playlist, {
												fileName = ATMEDatas.sounds[idToken]:getFileName(),
												tips10 =  localMembers.tips10,
												tips = localMembers.tips,
												pause = false,
												spell = false,
												subtitle = {
													text = localMembers.subtitle.text,
													duration = localMembers.subtitle.duration,
												},
											})
				else
					return true, "Token " .. _token .. " - Sound doesn't exist"
				end
			elseif _special == nil then
				_, _, temp = _token:find("(%([%d]+.?[%d]*%))")

				if temp == _token then  -- Cas de la pause
					table.insert(playlist, {
												fileName = "",
												pause = true,
												spell = false,
												tips10 =  math.floor(tonumber(_token:sub(2, -2)) * 10),
												tips =  math.floor(tonumber(_token:sub(2, -2))),
												subtitle = {
													text = "",
													duration = 0,
												},
											})
				else
					_, _, temp = _token:find("({[%d]+.?[%d]+})")
					local ok = false
					
					if temp == _token then -- Cas nombre à épeler
						ok = true
					else
						_, _, temp = _token:find("({[%a%d]+})")
						
						if temp == _token then -- Cas lettres et chiffres à épeler 
							temp = _token:upper()
							ok = true
						end
					end
					
					if ok == true then
						local lg = temp:len() - 1
						for i = 2, lg do
							local id = temp:sub(i,i)
							
							if id == "." then
								id = "DECIMAL"
							end
							
							if ATMEDatas.sounds[id] ~= nil then
								local localMembers = ATMEDatas.C_Sound_MT:get(ATMEDatas.sounds[id]:getIndex())
								table.insert(playlist, {
															fileName = ATMEDatas.sounds[id]:getFileName(),
															tips10 =  localMembers.tips10,
															tips = localMembers.tips,
															pause = false,
															spell = true,
															subtitle = {
																text = localMembers.subtitle.text,
																duration = localMembers.subtitle.duration,
															},
														})
							else
								return true, "Token " .. _token .. " spelling '" .. temp:sub(i,i) .. "' - Sound " .. id .. " is missing"
							end
						end
					else
						local _, _, cardinal, d, m, cent = _token:find("%[(%a)(%d%d%d?).?(%d%d).?(%d%d)%]")
						
						if cardinal ~= nil then
							local cardinalUpper = cardinal:upper()
							if ATMEConst.cardinal[cardinalUpper] ~= nil then
								local values = {
									tonumber(d),
									tonumber(m),
									tonumber(cent),
								}
								
								local maxdeg = 90
								
								if cardinalUpper == "E" or cardinalUpper == "W" then
									maxdeg = 180
									d = string.format("%03d", values[1])
								end
								
								if values[1] <= maxdeg and values[2] < 60 then
									if ATMEDatas.sounds[ATMEConst.cardinal[cardinalUpper]] ~= nil then
										local localMembers = ATMEDatas.C_Sound_MT:get(ATMEDatas.sounds[ATMEConst.cardinal[cardinalUpper]]:getIndex())
										table.insert(playlist, {
																	fileName = ATMEDatas.sounds[ATMEConst.cardinal[cardinalUpper]]:getFileName(),
																	tips10 =  localMembers.tips10,
																	tips = localMembers.tips,
																	pause = false,
																	spell = true,
																	subtitle = {
																		text = localMembers.subtitle.text,
																		duration = localMembers.subtitle.duration,
																	},
																})
										
										local coord = d .. "." .. m .. "." .. cent									
										local lg = coord:len()
										local extCar = ""
										
										for i = 1, lg do
											local id = coord:sub(i,i)
											
											if id == "." and ATMEDatas.sounds["POINT"] ~= nil then
												id = "POINT"
											end
											
											if id ~= "." then
												if ATMEDatas.sounds[id] ~= nil then
													local localMembers = ATMEDatas.C_Sound_MT:get(ATMEDatas.sounds[id]:getIndex())
													table.insert(playlist, {
																				fileName = ATMEDatas.sounds[id]:getFileName(),
																				tips10 =  localMembers.tips10,
																				tips = localMembers.tips,
																				pause = false,
																				spell = true,
																				subtitle = {
																					text = extCar .. localMembers.subtitle.text,
																					duration = localMembers.subtitle.duration,
																				},
																			})
													extCar = ""
												else
													return true, "Token '" .. _token .. "' spelling '" .. _token:sub(i,i) .. "' - Sound " .. id .. " is missing"
												end
											else
												extCar = "."
											end
										end
									else
										return true, "Token '" .. _token .. "' spelling '" .. cardinal .. "' - Sound " .. ATMEConst.cardinal[cardinalUpper] .. " is missing"
									end
								else
									return true, "Token '" .. _token .. "' - bad coordinates"
								end
							else
								return true, "Token '" .. _token .. "' - cardinal value must be N, S, E or W"
							end
						else
							return true, "Token '" .. _token .. "' - bad format"
						end
					end
				end
			else
				return true, "Token '" .. _token .. "' - bad format"
			end
		end
						
		if #playlist > 1 and _random == false then
			-- Si playlist > 1 alors les sous titres sont regroupés dans le premier item
			local spelling = playlist[1].spell
			for i = 2, #playlist do
				if (spelling == true and playlist[i].spell == true) or playlist[1].subtitle.text:sub(-1, -1) == "\n" or playlist[i].subtitle.text:sub(1, 1) == "\n" or
					playlist[1].subtitle.text:sub(-1, -1) == " " or playlist[i].subtitle.text:sub(1, 1) == " " then
					playlist[1].subtitle.text = playlist[1].subtitle.text .. playlist[i].subtitle.text
				elseif playlist[i].subtitle.text ~= "" then
					playlist[1].subtitle.text = playlist[1].subtitle.text .. " " .. playlist[i].subtitle.text
				end
				
				playlist[i].subtitle.text = ""
				playlist[1].subtitle.duration = playlist[1].subtitle.duration + playlist[i].subtitle.duration
				playlist[i].subtitle.duration = 0
				
				spelling = playlist[i].spell
			end
		end
		
		return false, playlist
	end
	
	return false
end

ATMEDatas.C_Sound_MT = {
	className = "C_Sound",
	mt = {},
	
	keys = {
		["getIndex"] = true,
		["getID"] = true,
		["getDuration"] = true,
		["getRoundDuration"] = true,
		["getFileName"] = true,
		["getSubtitle"] = true,
	},
	
	localMembers = ATMEFct.C_IndexList_create(),
	
	add = function(self, _tips, _tips10)
		local item = {
			tips10 = _tips10,
			tips = _tips,
			subtitle = {
				text = "",
				duration = 0,
			},
		}
		
		return self.localMembers:add(item)
	end,
	
	remove = function(self, _id)
		self.localMembers:remove(_id)
	end,
	
	get = function(self, _id)
		return self.localMembers:get(_id)
	end,
	
	pairs = function(self)
		return self.localMembers:pairs()
	end,
}

ATME.C_Sound = {
	getClassName = function(self)
		return ATMEDatas.C_Sound_MT.className
	end,
	
	getParentClass = function(self)
		return ATMEDatas.C_Sound_MT.parentClass
	end,
	
	getByID = function(_id)
		if type(_id) == "string" then
			return ATMEDatas.sounds[_id]
		else
			ATMEFct.errorOutputCore(nil, "Function ATME.C_Sound.getByID(id)", "ID type must be string", false)
		end
	end,
}

ATMEFct.C_Sound_create = function(_id, _tips, _tips10, _fileName, _subtitle)	
	local newSound = {}
	local id = _id
	local fileName = _fileName
	local idFrequency
	
	local index = ATMEDatas.C_Sound_MT:add(_tips, _tips10)
	local localMembers = ATMEDatas.C_Sound_MT:get(index)

	local durationSec = _tips
	local roundDurationSec = math.floor(durationSec) + 1
	
	setmetatable(newSound, ATMEDatas.C_Sound_MT.mt)
	
	function newSound.getIndex(self)
		return index
	end
	
	function newSound.getID(self)
		return id
	end
	
	function newSound.getDuration(self)
		return durationSec
	end
	
	function newSound.getRoundDuration(self)
		return roundDurationSec
	end
	
	function newSound.getFileName(self)
		return fileName
	end
	
	function newSound.getSubtitle(self)
		return localMembers.subtitle.text, localMembers.subtitle.duration
	end
	
	localMembers.subtitle.text = _subtitle.text
	localMembers.subtitle.duration = _subtitle.duration
	
	ATMEDatas.sounds[id] = newSound
	
	return newSound
end

setmetatable(ATME.C_Sound,ATMEDatas.C_Sound_MT)

ATMEDatas.C_Sound_MT.__call = function(t, _id, ...)
	local fctDefinition = "Constructor ATME.C_Sound(ID, fileName, duration)\nATME.C_Sound(ID, fileName, duration, subtitle, subtitleDuration)"
	local args = {...}
	
	if type(_id) == "string" then
		local tokens = ATMEFct.decompString(_id)
			
		if tokens ~= nil then
			local d, f, temp = tokens[1]:find("([%d%a_]+)")
			
			if temp == tokens[1] then
				if #tokens > 1 then
					ATMEFct.errorOutputCore(nil, fctDefinition, "ID consist of letters, numbers and '_' char", false)
				else
					local tokenName = string.upper(tokens[1])
					if ATMEDatas.sounds[tokenName] ~= nil then
						ATMEFct.errorOutputCore(nil, fctDefinition, "ID " .. tokens[1] .. " already exists", false)
					else
						local tips10
						local tips
						local fileName
						local subtitle
						
						if #args >= 2 then
							if type(args[1]) == "string" and type(args[2]) == "number" then
								fileName = args[1]
								tips10 = math.floor(args[2] * 10)
								tips = math.floor(args[2])
								
								if tips ~= args[2] then
									tips = tips + 1
								end
								
								if #args == 4 then
									if type(args[3]) == "string" and type(args[4]) == "number" then
										local subtitleDuration = math.floor(args[4])
										
										if subtitleDuration >= 1 then
											subtitle = {
												text = args[3],
												duration = args[4],
											}
										else
											ATMEFct.errorOutputCore(nil, fctDefinition, "durationSubtitle must be >= 1", false)
											return
										end
									else
										if type(args[3]) ~= "string" then
											ATMEFct.errorOutputCore(nil, fctDefinition, "subtitle type must be string", true)
											return
										elseif type(args[4]) ~= "number" then
											ATMEFct.errorOutputCore(nil, fctDefinition, "durationSubtitle type must be number", false)
											return
										end
									end
								elseif #args == 2 then
									subtitle = {
										text = "",
										duration = 0,
									}
								else
									ATMEFct.errorOutputCore(nil, fctDefinition, "bad parameters", true)
									return
								end
							else
								if type(args[1]) ~= "string" then
									ATMEFct.errorOutputCore(nil, fctDefinition, "fileName type must be string", true)
									return
								elseif type(args[2]) ~= "number" then
									ATMEFct.errorOutputCore(nil, fctDefinition, "duration type must be number", false)
									return
								end
							end
						else
							ATMEFct.errorOutputCore(nil, fctDefinition, "bad parameters", true)
							return
						end

						if tips10 > 0 then
							return ATMEFct.C_Sound_create(tokenName, tips, tips10, fileName, subtitle)
						else
							ATMEFct.errorOutputCore(nil, fctDefinition, "duration must be >= 0.1", false)
						end
					end
				end
			else
				ATMEFct.errorOutputCore(nil, fctDefinition, "ID " .. token[1] .. " - bad format", false)
			end
		else
			ATMEFct.errorOutputCore(nil, fctDefinition, "no ID defined", false)
		end
	else
		if type(_id) ~= "string" then
			ATMEFct.errorOutputCore(nil, fctDefinition, "ID type must be string", false)
		elseif type(_duration) ~= "number" then
			ATMEFct.errorOutputCore(nil, fctDefinition, "duration type must be number", false)
		elseif _fileName ~= nil and type(_fileName) ~= "string" then
			ATMEFct.errorOutputCore(nil, fctDefinition, "fileName type must be nil or string", false)
		end
	end
end

ATMEDatas.C_Sound_MT.mt.__metatable = "Private"
ATMEDatas.C_Sound_MT.mt.__index = ATME.C_Sound
ATMEDatas.C_Sound_MT.mt.__newindex = function(t, k, v)
	if ATMEDatas.C_Sound_MT.keys[k] ~= nil then 
		rawset(t, k, v)
	else
		ATMEFct.errorOutputCore(nil, "Function ATME.C_Sound : Bad key " .. k, "table locked", false)
	end
end



----------------------------------------------------------------------------------------------------------
-- Classe ATME.C_F10Menu : gère les menus accessibles par F10. Constructeur accessible aux modules externes 
-- Cette classe est complexe et gère :
--			- Les entrées d'un menu (menu de base root ou sous menu). Un entrée engendre une action par l'appel
--			  d'une fonction.
--			- Les sous-menus rattachés :
--					-> au menu de base root (accessible directement par F10)
--					-> à un menu, lui même sous-menu du menu de base rout ou d'un autre menu.
--			- L'affichage dans l'ordre choisi (alpha par défaut) des sous-menus du menu courant et de ses entrées
--					-> sous menus d'abord
--					-> entrées ensuite
--			- La gestion des entrées par une identification de type groupId pour une gestion en groupe :
--					-> lors de l'affichage dans l'ordre par groupId puis alpha si groupId identique
--					-> pour la suppression de plusieurs entrées  simultanément.
--					-> le groupId d'une entrée s'applique à toutes les entrées d'un menu donné, y compris 
--					   pour les entrées de ses sous-menus
--			- Un menu vide n'est plus affiché. Un menu est vide si lui-même et ses sous-menus ne contiennent
--			  aucune entrée
----------------------------------------------------------------------------------------------------------

ATMEDatas.C_F10Menu_MT = {
	className = "C_F10Menu",
	mt = {},
	
	keys = {
		["getParent"] = true,
		["isRoot"] = true,
		["getGroupId"] = true,
		["getLabel"] = true,
		["getIndex"] = true,
		["append"] = true,
		["removeAll"] = true,
		["remove"] = true,
		["getNbEntries"] = true,
	},
		
	localMembers = ATMEFct.C_IndexList_create(),
	
	add = function(self)
		local item = {
			itemCommandsList = {},
			itemSubMenusList = {},
			isActive = false,
			path = nil,
			nbSubmenus = 0,
			erased = false,									-- Utilisé pour les données privées. Passe à true si le menu n'est pas affiché
			handlers = ATMEFct.C_IndexList_create(),	-- Table des handlers définis (proxyHandler d'appel)
		}
		
		return self.localMembers:add(item)
	end,
	
	remove = function(self, _id)
		self.localMembers:remove(_id)
	end,
	
	get = function(self, _id)
		return self.localMembers:get(_id)
	end,
}


ATME.C_F10Menu = {
	getClassName = function(self)
		return ATMEDatas.C_F10Menu_MT.className
	end,
	
	getParentClass = function(self)
		return ATMEDatas.C_F10Menu_MT.parentClass
	end,
}

ATMEFct.C_F10Menu_handler = function(_args)
	local localMembers = ATMEDatas.C_F10Menu_MT:get(_args.indexMenu) 
	local fct = localMembers.handlers:get(_args.idHandler)
	
	ATMEFct.outputCore(nil,"Appel handler du menu '" .. _args.labelMenu .. "'", 2)
	xpcall(function() fct(_args.args) end, function() ATMEFct.errUserHandler(_args.labelMenu, true) end)
end

ATMEFct.C_F10Menu_create = function(_player, _label, _parent, _moduleName)
	local found = false
	local nbEntries = 0
	local localMembersPlayer = ATMEDatas.C_Player_MT:get(_player:getIndex())

	if _parent ~= nil then
		local localMembers = ATMEDatas.C_F10Menu_MT:get(_parent:getIndex())
		
		if _parent:isRoot() == true then -- Root menu direct avec _moduleName défini
			for _, _localModuleMembers in ATMEDatas.C_Module_MT:pairs() do
				for _k, _itemSubMenu in pairs(localMembers.itemSubMenusList) do
					if _itemSubMenu:getLabel() == _label then
						found = true
					end
				end
			end
		else -- Sous menu
			for _k, _itemSubMenu in pairs(localMembers.itemSubMenusList) do
				if _itemSubMenu:getLabel() == _label then
					found = true
				end
			end
		end
		
		nbEntries = _parent:getNbEntries()
	end
	
	if nbEntries == 10 then
		found = false
	elseif found == false then
		local parent = _parent
		local isRoot = false
		local label = _label
		local player = _player
		
		local newF10SubMenu = {}
		
		setmetatable(newF10SubMenu, ATMEDatas.C_F10Menu_MT.mt)
			
		local groupId = player:getGroupId()
		
		local index = ATMEDatas.C_F10Menu_MT:add()
		
		-- Si _moduleName ~= nil -> Menu root, à mémoriser pour le joueur
		-- Plusieurs arborescences root peuvent être créées pour un joueur donné
		if _moduleName ~= nil then
			isRoot = true
			label = "Root"
		end
		
		function newF10SubMenu.getParent(self)
			return parent
		end
		
		function newF10SubMenu.isRoot(self)
			return isRoot
		end
		
		function newF10SubMenu.getGroupId(self)
			return groupId
		end
		
		function newF10SubMenu.getLabel(self)
			return label
		end
		
		function newF10SubMenu.getIndex(self)
			return index
		end
		
		function newF10SubMenu.getNbEntries(self)
			local nbEntries = 0
			
			if self:isRoot() == true then
				local localMembersPlayer = ATMEDatas.C_Player_MT:get(player:getIndex())
				
				for _, _localModuleMembers in ATMEDatas.C_Module_MT:pairs() do
					local menu = localMembersPlayer.itemsF10MenuCommandRoot[_localModuleMembers.name]
					local localMembers = ATMEDatas.C_F10Menu_MT:get(menu:getIndex())
					nbEntries = nbEntries + localMembers.nbSubmenus + #localMembers.itemCommandsList
					for _k, _itemSubMenu in pairs(localMembers.itemSubMenusList) do
						if _itemSubMenu:getLabel() == _label then
							found = true
						end
					end
				end
			else
				local localMembers = ATMEDatas.C_F10Menu_MT:get(index)
				nbEntries = localMembers.nbSubmenus + #localMembers.itemCommandsList
			end
			
			return nbEntries
		end
		
		local function C_F10Menu_deleteAllCommands(_itemF10Menu, _deleteSubMenu)
			ATMEFct.outputCore(nil, "Start Suppression -> " .. _itemF10Menu:getLabel(), 3)
			
			local localMembers = ATMEDatas.C_F10Menu_MT:get(_itemF10Menu:getIndex())
			while #localMembers.itemCommandsList > 0 do
				local toRemove= table.remove(localMembers.itemCommandsList)
				missionCommands.removeItemForGroup(_itemF10Menu:getGroupId(), toRemove.itemF10MenuCommandId)
				localMembers.handlers:remove(toRemove.idHandler)
			end
			
			for _k, _itemSubMenu in pairs(localMembers.itemSubMenusList) do
				C_F10Menu_deleteAllCommands(_itemSubMenu, true)
				localMembers.itemSubMenusList[_k] = nil
				localMembers.nbSubmenus = localMembers.nbSubmenus - 1
			end
		  
			if _deleteSubMenu == true and _itemF10Menu:isRoot() == false then
				missionCommands.removeItemForGroup(_itemF10Menu:getGroupId(), localMembers.path)
				localMembers.erased = true
			end

			ATMEFct.outputCore(nil, "End Suppression -> " .. _itemF10Menu:getLabel(), 3)
		end

		local function C_F10Menu_deleteCommands(_itemF10Menu, _groupId, _deleteSubMenu)
			local function deleteCommands(_itemF10Menu, _groupId, _deleteSubMenu)
				local erase = false

				ATMEFct.outputCore(nil, "Start Suppression -> " .. _itemF10Menu:getLabel(), 3)
			  
				local localMembers = ATMEDatas.C_F10Menu_MT:get(_itemF10Menu:getIndex())
				local i = 1
				while i <= #localMembers.itemCommandsList do
					if localMembers.itemCommandsList[i].groupId == _groupId then    
						missionCommands.removeItemForGroup(_itemF10Menu:getGroupId(), localMembers.itemCommandsList[i].itemF10MenuCommandId)
						localMembers.handlers:remove(localMembers.itemCommandsList[i].idHandler)
						table.remove(localMembers.itemCommandsList, i)
					else
						i = i + 1
					end
				end
				
				for _k, _itemSubMenu in pairs(localMembers.itemSubMenusList) do
					if deleteCommands(_itemSubMenu, _groupId, true) == true then
						localMembers.itemSubMenusList[_k] = nil
						localMembers.nbSubmenus = localMembers.nbSubmenus - 1
					end
				end
				
				if #localMembers.itemCommandsList == 0 then
					if _deleteSubMenu == true and _itemF10Menu:isRoot() == false then
						missionCommands.removeItemForGroup(_itemF10Menu:getGroupId(), localMembers.path)
						localMembers.erased = true
					end
					
					erase = true
				end
				
				ATMEFct.outputCore(nil, "End Suppression -> " .. _itemF10Menu:getLabel(), 3)
					
				return erase
			end
			
			deleteCommands(_itemF10Menu, _groupId, _deleteSubMenu)
		end
		
		function newF10SubMenu.append(self, _groupId, _label, _handler, _args)
			local fctDefinition = ATMEFct.getErrorPrefix(newF10SubMenu) .. "append(groupId, label, handler, args)"
			
			if type(_groupId) == "number" and type(_label) == "string" and type(_handler) == "function" then
				if self:getNbEntries() < 10 then
					if _groupId >= 1 then
						ATMEFct.outputCore(nil, "Start append -> " .. _label, 3)
						
						local localMembers = ATMEDatas.C_F10Menu_MT:get(index)
						local id = localMembers.handlers:add(_handler)
						local args = {
							idHandler = id,
							indexMenu = index,
							labelMenu = _label,
							args = _args,
						}
						
						local itemRadio = {
								groupId = math.floor(_groupId),
								label = _label,
								idHandler = id,
								itemF10MenuCommandId = missionCommands.addCommandForGroup(self:getGroupId(), _label, localMembers.path, ATMEFct.C_F10Menu_handler , args)
						}
						
						table.insert(localMembers.itemCommandsList,itemRadio)
					else
						ATMEFct.errorOutputCore(nil, fctDefinition, "groupId must be >= 1", false)
					end
				else
					ATMEFct.errorOutputCore(nil, fctDefinition, "Max of entries per menu is 10. Can't add new menu item", false)
				end
			else
				if type(_groupId) ~= "number" then
					ATMEFct.errorOutputCore(nil, fctDefinition, "groupId type must be number", true)
				elseif type(_label) ~= "string" then
					ATMEFct.errorOutputCore(nil, fctDefinition, "label type must be string", false)
				elseif type(_handler) ~= "function" then
					ATMEFct.errorOutputCore(nil, fctDefinition, "handler type must be function", false)
				end
			end
		end
		
		function newF10SubMenu.removeAll(self, _deleteSubMenu)
			local fctDefinition = ATMEFct.getErrorPrefix(newF10SubMenu) .. "removeAll([deleteSubMenu])"
			
			if  _deleteSubMenu == nil or type(_deleteSubMenu) == "boolean" then
				local flag = false
				if _deleteSubMenu ~= nil then
					flag = _deleteSubMenu
				end

				C_F10Menu_deleteAllCommands(self, flag)
				if flag == true and parent ~= nil then
					local localParentMembers = ATMEDatas.C_F10Menu_MT:get(parent:getIndex())
					
					localParentMembers.itemSubMenusList[label] = nil
					localParentMembers.nbSubmenus = localParentMembers.nbSubmenus - 1
				end
			else
				ATMEFct.errorOutputCore(nil, fctDefinition, "deleteSubMenu type must be nil or boolean", true)
			end
		end
		
		function newF10SubMenu.remove(self, _groupId, _deleteSubMenu)
			local fctDefinition = ATMEFct.getErrorPrefix(newF10SubMenu) .. "remove(groupId, [deleteSubMenu])"
			
			if type(_groupId) == "number" and (_deleteSubMenu == nil or type(_deleteSubMenu) == "boolean") then
				local flag = false
				if _deleteSubMenu ~= nil then
					flag = _deleteSubMenu
				end
				
				if _groupId >= 1 then
					C_F10Menu_deleteCommands(self, math.floor(_groupId), flag) 
				else
					ATMEFct.errorOutputCore(nil, fctDefinition, "groupId must be >= 1", false)
				end
			else
				if type(_groupId) ~= "number" then
					ATMEFct.errorOutputCore(nil, fctDefinition, "groupId type must be number", true)
				elseif _deleteSubMenu ~= nil and type(_deleteSubMenu) ~= "boolean" then
					ATMEFct.errorOutputCore(nil, fctDefinition, "deleteSubMenu type must be nil or boolean", false)
				end
			end
		end
		

		if isRoot == false then
			local localMembersParent = ATMEDatas.C_F10Menu_MT:get(parent:getIndex())
			localMembersParent.itemSubMenusList[label] = newF10SubMenu
			
			localMembersParent.nbSubmenus = localMembersParent.nbSubmenus + 1
			
			ATMEFct.outputCore(nil, "Création subMenu " .. label .. " à partir de " .. parent:getLabel(), 3)
		end
		
		return nbEntries, newF10SubMenu
	end
	
	return nbEntries
end


ATMEDatas.C_F10Menu_MT.__call = function(t, _player, _label, _parent)
	local fctDefinition = "Constructor ATME.C_F10Menu(player, label, parent)"
	
	if ATME.isObjectClass(_player, ATME.C_Player) == true  and type(_label) == "string" and 
			(ATME.isObjectClass(_parent, ATME.C_F10Menu) == true or ATME.isObjectClass(_parent, ATME.C_Module) == true)then
		
		local parent
		if ATMEFct.isObjectClass(_parent, ATME.C_Module) == true then
			parent = _player:getF10MenuRoot(_parent)
		else
			parent = _parent
		end
		
		local nbEntries, menu = ATMEFct.C_F10Menu_create(_player, _label, parent, nil)
		
		if menu ~= nil then
			local parentPath = nil
			if parent:isRoot() == false then
				local localParentMembers = ATMEDatas.C_F10Menu_MT:get(parent:getIndex())
				parentPath = localParentMembers.path
			end
			
			local localMembers = ATMEDatas.C_F10Menu_MT:get(menu:getIndex())
			localMembers.path = missionCommands.addSubMenuForGroup(menu:getGroupId(), menu:getLabel(), parentPath)
			
			return menu
		else
			if nbEntries == 10 then
				ATMEFct.errorOutputCore(nil, fctDefinition, "Max of entries per menu is 10. Can't add new submenu", false)
			else
				ATMEFct.errorOutputCore(nil, fctDefinition, "Label '" .. _label .. "' already exist in parent or root menu", false)
			end
		end
	else
		if ATME.isObjectClass(_player, ATME.C_Player) == false then
			ATMEFct.errorOutputCore(nil, fctDefinition, "player type must be ATME.C_Player", false)
		elseif type(_label) ~= "string" then
			ATMEFct.errorOutputCore(nil, fctDefinition, "label type must be string", false)
		elseif ATME.isObjectClass(_parent, ATME.C_F10Menu) == false and ATME.isObjectClass(_parent, ATME.C_Module) == false then
			ATMEFct.errorOutputCore(nil, fctDefinition, "parent type must be ATME.C_Module or ATME.C_F10Menu", false)
		end
	end
end

setmetatable(ATME.C_F10Menu,ATMEDatas.C_F10Menu_MT)

ATMEDatas.C_F10Menu_MT.mt.__metatable = "Private"
ATMEDatas.C_F10Menu_MT.mt.__index = ATME.C_F10Menu
ATMEDatas.C_F10Menu_MT.mt.__newindex = function(t, k, v)
	if ATMEDatas.C_F10Menu_MT.keys[k] ~= nil then 
		rawset(t, k, v)
	else
		ATMEFct.errorOutputCore(nil, "Function ATME.C_F10Menu : Bad key " .. k, "table locked", false)
	end
end

----------------------------------------------------------------------------------------------------------
-- Classe ATME.C_Alarm : gère les alarmes définies par l'utilisateur.
-- Pas de contructeur accessible aux modules externes.
-- En effet, la création d'une alarme passe par deux méthodes de la classe ATME.C_Module.
-- Il existe deux types d'alarme :
--		- Les alarmes absolues se déclenchant au moment programmé.
--		- Les alarmes relative à un flag et donc associée à l'activation de ce flag pour se déclencher.
-- La condition de temps est donné par un string au format particulier :
--		- "X..X" pour un temps en secondes depuis le début de mission (ex : "10" ou "100" pour 10s ou 100s)
--		- "+X..X" pour un temps en seconde depuis la création de l'alarme (ex : "+10" pour 10s après la création)
--		- "HH:MM" ou "HH:MM:SS" pour remplacer une expression en secondes par une expression en m/s ou h/m/s
----------------------------------------------------------------------------------------------------------

ATMEDatas.C_Alarm_MT = {
	className = "C_Alarm",
	mt = {},
	
	keys = {
		["getFlag"] = true,
		["getName"] = true,
		["tagGetByID"] = true,
		["tagCompare"] = true,
		["tagGetCount"] = true,
		["getModuleName"] = true,
		["isArmed"] = true,
		["getIndex"] = true,
		["getUserPrivateDatas"] = true, 
		["reschedule"] = true,
		["addTriggeringsLimit"] = true,
		["removeTriggeringsLimit"] = true,
	},
	
	localMembers = ATMEFct.C_IndexList_create(),
	
	add = function(self, _armed, _timeStart, _isRelative, _nbCountTips, _moduleName)
		local timeStartValue = _timeStart
		
		if _armed == true and _isRelative == true then 
			timeStartValue = timeStartValue + _nbCountTips
		end
		
		local item = {
			armed = _armed,
			timeStart = timeStartValue,
			initialTimeStart = _timeStart,
			restarted = false,
			isRelative = _isRelative,
			eventCallback = nil,
			moduleName = _moduleName,
			maxTriggerings = -1,
			maxTriggeringsCallback = nil,
			userPrivateDatas = {},
		}
		
		return self.localMembers:add(item)
	end,
	
	remove = function(self, _id)
		for _, _localModuleMembers in ATMEDatas.C_Module_MT:pairs() do
			self.localMembers:get(_id).userPrivateDatas[_localModuleMembers.name] = nil
		end
		self.localMembers:get(_id).userPrivateDatas = nil
		self.localMembers:remove(_id)
	end,
	
	get = function(self, _id)
		return self.localMembers:get(_id)
	end,
}

ATME.C_Alarm = {
	getClassName = function(self)
		return ATMEDatas.C_Alarm_MT.className
	end,
	
	getParentClass = function(self)
		return ATMEDatas.C_Alarm_MT.parentClass
	end,
}

ATMEFct.C_Alarm_create = function(_name, _moduleName, _flagID, _rules)
	local name = _name
	local tagsName
	local moduleName = _moduleName
	local flag
	
	local isArmed = true
	if _flagID ~= nil then
		flag = _flagID
		if ATME.getFlag(flag) == 0 then
			isArmed = false
		end
	end
	
	if _name ~= nil then
		tagsName = ATMEFct.decompString(_name)
	end
	
	local index
	local localMembers
	local err, timeStart, isRelative = ATMEFct.getTimeValue(_rules)
	local nbCountTips = math.floor(timer.getTime())	
	
	if err == false and ((nbCountTips < timeStart and isRelative == false) or isRelative == true) then
		local newAlarm = {}

		setmetatable(newAlarm, ATMEDatas.C_Alarm_MT.mt)
		
		index = ATMEDatas.C_Alarm_MT:add(isArmed, timeStart, isRelative, nbCountTips, _moduleName)
		localMembers = ATMEDatas.C_Alarm_MT:get(index)
		
		function newAlarm.getFlag(self)
			if flag ~= nil then
				return ATME.getFlag(flag)
			end
		end
		
		function newAlarm.getName(self)
			return name
		end
		
		function newAlarm.tagGetByID(self, _position)
			local fctDefinition = ATMEFct.getErrorPrefix(newAlarm) .. "tagGetByID(position)"
			
			if type(_position) == "number" then
				local pos = math.floor(_position)
				if tagsName ~= nil and pos >= 1 and pos <= #tagsName then
					return tagsName[pos]
				end
			else
				ATMEFct.errorOutputCore(nil, fctDefinition, "position type must be number", true)
			end
		end
		
		function newAlarm.tagGetCount(self)
			if tagsName ~= nil then
				return #tagsName
			else
				return 0
			end
		end
		
		function newAlarm.tagCompare(self, _tagsToCompare)
			local fctDefinition = ATMEFct.getErrorPrefix(newAlarm) .. "tagCompare(tagsToCompare)"
			
			if type(_tagsToCompare) == "string" then
				if tagsName ~= nil then
					local ok = ATMEFct.compareTags(tagsName, _tagsToCompare)
					
					if ok ~= nil then
						return ok
					else
						ATMEFct.errorOutputCore(nil, fctDefinition, "tagsToCompare format must be 'T1|T2|..|Tn'", false)
					end
				else
					return false
				end
			else
				ATMEFct.errorOutputCore(nil, fctDefinition, "tagsToCompare type must be string", true)
			end
		end
		
		function newAlarm.getUserPrivateDatas(self, _module)
			local fctDefinition = ATMEFct.getErrorPrefix(newAlarm) .. "getUserPrivateDatas(module)"
			
			if ATME.isObjectClass(_module, ATME.C_Module) == true then
				return localMembers.userPrivateDatas[_module:getName()]
			else
				ATMEFct.errorOutputCore(nil, fctDefinition, "module type must be ATME.C_Module", true)
			end
		end
		
		function newAlarm.isArmed(self)
			return localMembers.armed
		end
		
		function newAlarm.getModuleName(self)
			return moduleName
		end
		
		function newAlarm.addTriggeringsLimit(self, _value, _callback)
			local fctDefinition = ATMEFct.getErrorPrefix(newAlarm) .. "setReschedulingLimit(value, [callback])"
			
			if type(_value) == "number" and (_callback == nil or type(_callback) == "function") then
				local value = math.floor(_value)
				
				if value > 0 then
					localMembers.maxTriggerings = value
					localMembers.maxTriggeringsCallback = _callback
				else
					ATMEFct.errorOutputCore(nil, fctDefinition, "value must be > 0", true)
				end
			else
				if type(_value) ~= "number" then
					ATMEFct.errorOutputCore(nil, fctDefinition, "value type must be number", true)
				elseif _callback ~= nil and type(_callback) ~= "function" then
					ATMEFct.errorOutputCore(nil, fctDefinition, "callback type must be nil or function", false)
				end
			end
			
		end
		
		function newAlarm.removeTriggeringsLimit(self)
			localMembers.maxTriggerings = -1
			localMembers.maxTriggeringsCallback = nil
		end
		
		function newAlarm.reschedule(self, _rules)
			local fctDefinition = ATMEFct.getErrorPrefix(newAlarm) .. "reschedule([rules])"
			
			if _rules == nil or type(_rules) == "number" or type(_rules) == "string" then
				local err, timeStart, isRelative = ATMEFct.getTimeValue(_rules)
				local nbCountTips = math.floor(timer.getTime())

				if err == false and ((nbCountTips < timeStart and isRelative == false) or isRelative == true) then
					if flag == nil or ATME.getFlag(flag) > 0 then
						localMembers.armed = true
					else
						localMembers.armed = false
					end
					
					if isRelative == false then
						localMembers.timeStart = timeStart
					else
						localMembers.timeStart = timeStart + nbCountTips
					end
					
					localMembers.isRelative = isRelative
					localMembers.initialTimeStart = timeStart
					localMembers.restarted = true
					
					if localMembers.armed == false then
						ATMEFct.outputCore(nil, "Module " .. localMembers.moduleName .. " - reschedule alarme " .. name .. " -> alarme reprogrammée et non armée" , 2)
					else
						ATMEFct.outputCore(nil, "Module " .. localMembers.moduleName .. " - reschedule alarme " .. name .. " -> alarme reprogrammée et armée (timeStart = ".. timeStart .. ")" , 2)
					end
				else
					if err == true then
						ATMEFct.errorOutputCore(nil, fctDefinition, timeStart, false)
					else
						ATMEFct.outputCore(nil, "Module " .. localMembers.moduleName .. " - reschedule alarme " .. name .. " -> startTime < current time : alarme à supprimer", 2)
						return false
					end
				end
				
				return localMembers.restarted
			else
				ATMEFct.errorOutputCore(nil, fctDefinition, "rules type must be nil or number or string", true)
			end
		end
		
		function newAlarm.getIndex(self)
			return index
		end
		
		if localMembers.armed == false then
			ATMEFct.outputCore(nil, "Module " .. localMembers.moduleName .. " - Alarme " .. name .. " créée et non armée" , 2)
		else
			ATMEFct.outputCore(nil, "Module " .. localMembers.moduleName .. " - Alarme " .. name .. " créée et armée (timeStart = ".. timeStart .. ")" , 2)
		end
		
		for _, _localModuleMembers in ATMEDatas.C_Module_MT:pairs() do
			localMembers.userPrivateDatas[_localModuleMembers.name] = {}
		end
		
		return false, newAlarm
	else
		if err == true then
			return true, timeStart
		else
			ATMEFct.outputCore(nil, "Module " .. moduleName .. " - Alarme " .. _name .. " startTime < current time : non crée", 2)
			return false
		end
	end
end

function C_Alarm_delete(_alarms, _name)
	ATMEDatas.C_Alarm_MT:remove(_alarms[_name]:getIndex())
	_alarms[_name] = nil
end


setmetatable(ATME.C_Alarm,ATMEDatas.C_Alarm_MT)

ATMEDatas.C_Alarm_MT.mt.__metatable = "Private"
ATMEDatas.C_Alarm_MT.mt.__index = ATME.C_Alarm
ATMEDatas.C_Alarm_MT.mt.__newindex = function(t, k, v)
	if ATMEDatas.C_Alarm_MT.keys[k] ~= nil then 
		rawset(t, k, v)
	else
		ATMEFct.errorOutputCore(nil, "Function ATME.C_Alarm : Bad key " .. k, "table locked", false)
	end
end


----------------------------------------------------------------------------------------------------------
-- Classe ATME.C_CoreEvent : La classe ATME.C_CoreEvent permet la création d'instance events Core.
-- Pas de contructeur accessible aux modules externes. instances entièrement gérées par ATME.
---------------------------------------------------------------------------------------------------------- 

ATMEDatas.C_CoreEvent_MT = {
	className = "C_CoreEvent",
	mt = {},
	
	keys = {
		["getIndex"] = true,
		["getType"] = true,
		["getDatas"] = true,
	},
	
	localMembers = ATMEFct.C_IndexList_create(),
	
	add = function(self, _item, _delay)
		local item = {
			type = _item.type,
			datas = _item.datas,
			delay = _delay,
		}
		
		return self.localMembers:add(item)
	end,
	
	remove = function(self, _id)
		self.localMembers:remove(_id)
	end,
	
	get = function(self, _id)
		return self.localMembers:get(_id)
	end,
}

ATME.C_CoreEvent = {
	getClassName = function(self)
		return ATMEDatas.C_CoreEvent_MT.className
	end,
	
	getParentClass = function(self)
		return ATMEDatas.C_CoreEvent_MT.parentClass
	end,
}

setmetatable(ATME.C_CoreEvent, ATMEDatas.C_CoreEvent_MT)

ATMEDatas.C_CoreEvent_MT.mt.__metatable = "Private"
ATMEDatas.C_CoreEvent_MT.mt.__index = ATME.C_CoreEvent
ATMEDatas.C_CoreEvent_MT.mt.__newindex = function(t, k, v)
	if ATMEDatas.C_CoreEvent_MT.keys[k] ~= nil then 
		rawset(t, k, v)
	else
		ATMEFct.errorOutputCore(nil, "Function ATME.C_CoreEvent : Bad key " .. k, "table locked", false)
	end
end

ATMEFct.C_CoreEvent_create = function(_item, _delay)
	local newCoreEvent = {}
	
	setmetatable(newCoreEvent, ATMEDatas.C_CoreEvent_MT.mt)
	local index = ATMEDatas.C_CoreEvent_MT:add(_item, _delay)
	
	local localMembers = ATMEDatas.C_CoreEvent_MT:get(index)
	
	function newCoreEvent.getIndex()
		return index
	end
	
	function newCoreEvent.getType(self)
		return localMembers.type
	end
	
	function newCoreEvent.getDatas(self)
		local datas = {}
		if localMembers.type == "RACE_PLAYER_TOO_HIGH" then
			datas.race = localMembers.datas.race
			datas.unit = localMembers.datas.unit
			datas.penalty = localMembers.datas.penalty
		elseif localMembers.type == "RACE_START" then
			datas.race = localMembers.datas.race
			datas.unit = localMembers.datas.unit
		elseif localMembers.type == "RACE_TURN_TIME" then
			datas.race = localMembers.datas.race
			datas.unit = localMembers.datas.unit
			datas.playTime = localMembers.datas.playTime
			datas.totalPlayTime = localMembers.datas.totalPlayTime
			datas.penalty = localMembers.datas.penalty
			datas.turnNumber = localMembers.datas.turnNumber
		elseif localMembers.type == "RACE_PLAYER_BEST_TURN_TIME" then
			datas.race = localMembers.datas.race
			datas.unit = localMembers.datas.unit
			datas.playTime = localMembers.datas.playTime
			datas.turnNumber = localMembers.datas.turnNumber
		elseif localMembers.type == "RACE_BEST_TURN_TIME" then
			datas.race = localMembers.datas.race
			datas.unit = localMembers.datas.unit
			datas.playTime = localMembers.datas.playTime
			datas.turnNumber = localMembers.datas.turnNumber
		elseif localMembers.type == "RACE_LAP_TIME" then
			datas.race = localMembers.datas.race
			datas.unit = localMembers.datas.unit
			datas.playTime = localMembers.datas.playTime
			datas.totalPlayTime = localMembers.datas.totalPlayTime
			datas.penalty = localMembers.datas.penalty
			datas.turnNumber = localMembers.datas.turnNumber
			datas.doorNumber = localMembers.datas.doorNumber
		elseif localMembers.type == "RACE_BEST_LAP_TIME" then
			datas.race = localMembers.datas.race
			datas.unit = localMembers.datas.unit
			datas.playTime = localMembers.datas.playTime
			datas.turnNumber = localMembers.datas.turnNumber
			datas.doorNumber = localMembers.datas.doorNumber
		elseif localMembers.type == "RACE_PLAYER_BEST_FINAL_TIME" then
			datas.race = localMembers.datas.race
			datas.unit = localMembers.datas.unit
			datas.totalPlayTime = localMembers.datas.totalPlayTime
		elseif localMembers.type == "RACE_BEST_FINAL_TIME" then
			datas.race = localMembers.datas.race
			datas.unit = localMembers.datas.unit
			datas.totalPlayTime = localMembers.datas.totalPlayTime
		elseif localMembers.type == "RACE_FINAL_TIME" then
			datas.race = localMembers.datas.race
			datas.unit = localMembers.datas.unit
			datas.totalPlayTime = localMembers.datas.totalPlayTime
			datas.penalty = localMembers.datas.penalty
		elseif localMembers.type == "TRANSPORT_END_OF_BOARDING" then
			datas.unit = localMembers.datas.unit
			datas.index = localMembers.datas.index
			datas.onBoardGroupName = localMembers.datas.onBoardGroupName
			datas.nbOnBoardUnits = localMembers.datas.nbOnBoardUnits
			datas.nbDeadUnits = localMembers.datas.nbDeadUnits
		elseif localMembers.type == "TRANSPORT_END_OF_DISEMBARK" then
			datas.unit = localMembers.datas.unit
			datas.index = localMembers.datas.index
			datas.linkedGroup = localMembers.datas.linkedGroup
			datas.nbOnBoardUnits = localMembers.datas.nbOnBoardUnits
			datas.nbDeadUnits = localMembers.datas.nbDeadUnits
		elseif localMembers.type == "SIGNAL_UNIT_IN_ZONE" then
			datas.unit = localMembers.datas.unit
			datas.linkedGroup = localMembers.datas.linkedGroup
			datas.pickupZone = localMembers.datas.pickupZone
		elseif localMembers.type == "SIGNAL_UNIT_OUT_OF_ZONE" then
			datas.unit = localMembers.datas.unit
			datas.linkedGroup = localMembers.datas.linkedGroup
			datas.pickupZone = localMembers.datas.pickupZone
		elseif localMembers.type == "TRACKING_WAYPOINT" then
			datas.group = localMembers.datas.group
			datas.idWaypoint = localMembers.datas.idWaypoint
			datas.point = {
				x = localMembers.datas.point.x,
				y = localMembers.datas.point.y,
				z = localMembers.datas.point.z,
			}
		elseif localMembers.type == "TRACKING_LAST_WAYPOINT" then
			datas.group = localMembers.datas.group
			datas.point = {
				x = localMembers.datas.point.x,
				y = localMembers.datas.point.y,
				z = localMembers.datas.point.z,
			}
		elseif localMembers.type == "TASK_ZONE_CLEANED" then
			datas.group = localMembers.datas.group
			datas.zone = localMembers.datas.zone
		elseif localMembers.type == "CROSSED_SEGMENTS" then
			datas.unit = localMembers.datas.unit
			datas.multiSegment2D = localMembers.datas.multiSegment2D
			datas.infos = localMembers.datas.infos
		elseif localMembers.type == "AREA_ENTERS" then
			datas.unit = localMembers.datas.unit
			datas.area = localMembers.datas.area
		elseif localMembers.type == "AREA_LEAVES" then
			datas.unit = localMembers.datas.unit
			datas.area = localMembers.datas.area
		elseif localMembers.type == "AREA_GROUP_ENTERS" then
			datas.group = localMembers.datas.group
			datas.area = localMembers.datas.area
		elseif localMembers.type == "AREA_GROUP_LEAVES" then
			datas.group = localMembers.datas.group
			datas.area = localMembers.datas.area
		elseif localMembers.type == "SPOT_TARGET_OUT_OF_ZONE" then
			datas.unit = localMembers.datas.unit
			datas.target = localMembers.datas.target
		elseif localMembers.type == "SPOT_TARGET_NO_LOS" then
			datas.unit = localMembers.datas.unit
			datas.target = localMembers.datas.target
		elseif localMembers.type == "SPOT_NEW_TARGET" then
			datas.unit = localMembers.datas.unit
			datas.target = localMembers.datas.target
		elseif localMembers.type == "SPOT_STOP_UNIT_MOVE" then
			datas.unit = localMembers.datas.unit
		elseif localMembers.type == "SPOT_STOP" then
			datas.unit = localMembers.datas.unit
		elseif localMembers.type == "TARGET_NEW_TRACK" then
			datas.unit = localMembers.datas.unit
			datas.target = localMembers.datas.target
		elseif localMembers.type == "TARGET_END_TRACK" then
			datas.unit = localMembers.datas.unit
			datas.target = localMembers.datas.target
		elseif localMembers.type == "WEAPON_SHOOT" then
			datas.unit = localMembers.datas.unit
		elseif localMembers.type == "SHOOTING_START" then
			datas.unit = localMembers.datas.unit
			datas.target = localMembers.datas.target
		elseif localMembers.type == "SHOOTING_END" then
			datas.unit = localMembers.datas.unit
		elseif localMembers.type == "HIT_TARGET" then
			datas.unit = localMembers.datas.unit
			datas.target = localMembers.datas.target
		elseif localMembers.type == "REFUELING" then
			datas.unit = localMembers.datas.unit
		elseif localMembers.type == "REFUELING_STOP" then
			datas.unit = localMembers.datas.unit
		end
		
		return datas
	end
	
	return newCoreEvent
end

-- Définition du deux events mgr : la bascule se fait dans la fonction main timer
-- Ceci permet si des événements sont créés dans cette fonction, de les traiter
-- au coup suivant. Dans main timer, activeEvents passe de 1 à 0 et vice versa.

local events = {
	[0] = ATMEFct.C_IndexList_create(),
	[1] = ATMEFct.C_IndexList_create(),
}

local activeEvents = 0

ATMEFct.C_CoreEvent_add = function(_item, _delay)	-- Déjà prédéclarée
	local delay = 0
	if _delay ~= nil and _delay > 0 then
		delay = _delay
	end
	
	local newEvent = ATMEFct.C_CoreEvent_create(_item, delay)
	
	events[activeEvents]:add(newEvent)
end

ATMEFct.C_CoreEvent_removeAll = function(_id)
	events[_id]:removeAll()
end



----------------------------------------------------------------------------------------------------------
-- Classe ATME.C_EventsMgr : La classe ATME.C_EventsMgr permet la création d'instance gestionnaires d'events.
-- Pas de constructeur externe.
-- Gestionnaire des événements core et des alarmes
-- 		- Permet de savoir s'il s'agit d'un event core ou d'un event lié à une alarme
-- 		- Ajoute les méthodes de récupération des données des événements core
-- 		  et les méthodes pour les événements associés aux alarmes.
---------------------------------------------------------------------------------------------------------- 

ATMEDatas.C_EventsMgr_MT = {
	className = "C_EventsMgr",
	mt = {},
	
	keys = {
		["getIndex"] = true,
		["pairs"] = true,
		["isCoreEvent"] = true,
		["isAlarm"] = true,
		["getCoreEventType"] = true, 
		["getCoreEventDatas"] = true,
		["getAlarm"] = true,
		["getCoreEvent"] = true,
	},
	
	localMembers = ATMEFct.C_IndexList_create(),
	
	add = function(self)
		local item = {
			list = {},
			alarms = {}
		}
		
		
		return self.localMembers:add(item)
	end,
	
	remove = function(self, _id)
		self.localMembers:get(_id).list = nil
		self.localMembers:get(_id).alarms = nil
		self.localMembers:remove(_id)
	end,
	
	get = function(self, _id)
		return self.localMembers:get(_id)
	end,
}

ATME.C_EventsMgr = {
	getClassName = function(self)
		return ATMEDatas.C_EventsMgr_MT.className
	end,
	
	getParentClass = function(self)
		return ATMEDatas.C_EventsMgr_MT.parentClass
	end,
}

setmetatable(ATME.C_EventsMgr, ATMEDatas.C_EventsMgr_MT)

ATMEDatas.C_EventsMgr_MT.mt.__metatable = "Private"
ATMEDatas.C_EventsMgr_MT.mt.__index = ATME.C_EventsMgr
ATMEDatas.C_EventsMgr_MT.mt.__newindex = function(t, k, v)
	if ATMEDatas.C_EventsMgr_MT.keys[k] ~= nil then 
		rawset(t, k, v)
	else
		ATMEFct.errorOutputCore(nil, "Function ATME.C_EventsMgr : Bad key " .. k, "table locked", false)
	end
end

ATMEFct.C_EventsMgr_Create = function()
	local newEventsMgr = {}
	
	setmetatable(newEventsMgr, ATMEDatas.C_EventsMgr_MT.mt)
	local index = ATMEDatas.C_EventsMgr_MT:add()
	
	local localMembers = ATMEDatas.C_EventsMgr_MT:get(index)
	
	function newEventsMgr.getIndex()
		return index
	end
	
	function newEventsMgr.pairs(self)
		return ipairs(localMembers.list)
	end
	
	function newEventsMgr.isCoreEvent(self, _id)
		local fctDefinition = ATMEFct.getErrorPrefix(newEventsMgr) .. "isCoreEvent(id)"
		
		if type(_id) == "number" then
			local id = math.floor(_id)
			if id > 0 then
				return ATMEFct.isObjectClass(localMembers.list[id], ATME.C_CoreEvent)
			else
				ATMEFct.errorOutputCore(nil, fctDefinition, "id must be > 0", true)
			end
		else
			ATMEFct.errorOutputCore(nil, fctDefinition, "id type must be number", true)
		end
	end
	
	function newEventsMgr.isAlarm(self, _id)
		local fctDefinition = ATMEFct.getErrorPrefix(newEventsMgr) .. "isAlarmEvent(id)"
		
		if type(_id) == "number" or type(_id) == "string" then
			if type(_id) == "number" then
				local id = math.floor(_id)
				if id > 0 then
					return ATMEFct.isObjectClass(localMembers.list[id], ATME.C_Alarm)
				else
					ATMEFct.errorOutputCore(nil, fctDefinition, "id must be > 0", true)
				end
			else
				return ATMEFct.isObjectClass(localMembers.alarms[_id], ATME.C_Alarm)
			end
		else
			ATMEFct.errorOutputCore(nil, fctDefinition, "id type must be number or string", true)
		end
	end
	
	function newEventsMgr.getAlarm(self, _id)
		local fctDefinition = ATMEFct.getErrorPrefix(newEventsMgr) .. "getAlarm(id)"
		
		if type(_id) == "number" or type(_id) == "string" then
			if type(_id) == "number" then
				local id = math.floor(_id)
				if id > 0 then
					if ATMEFct.isObjectClass(localMembers.list[id], ATME.C_Alarm) == true then
						return localMembers.list[id]
					end
				else
					ATMEFct.errorOutputCore(nil, fctDefinition, "id must be > 0", true)
				end
			else
				if ATMEFct.isObjectClass(localMembers.alarms[_id], ATME.C_Alarm) == true then
					return localMembers.alarms[_id]
				end
			end
		else
			ATMEFct.errorOutputCore(nil, fctDefinition, "id type must be number or string", true)
		end
	end
	
	function newEventsMgr.getCoreEventType(self, _id)
		local fctDefinition = ATMEFct.getErrorPrefix(newEventsMgr) .. "getCoreEventType(id)"
		
		if type(_id) == "number" then
			local id = math.floor(_id)
			if id > 0 then
				if ATMEFct.isObjectClass(localMembers.list[id], ATME.C_CoreEvent) then
					return localMembers.list[id]:getType()
				end
			else
				ATMEFct.errorOutputCore(nil, fctDefinition, "id must be > 0", true)
			end
		else
			ATMEFct.errorOutputCore(nil, fctDefinition, "id type must be number", true)
		end
	end
	
	function newEventsMgr.getCoreEventDatas(self, _id)
		local fctDefinition = ATMEFct.getErrorPrefix(newEventsMgr) .. "getCoreEventDatas(id)"
		
		if type(_id) == "number" then
			local id = math.floor(_id)
			if id > 0 then
				if ATMEFct.isObjectClass(localMembers.list[id], ATME.C_CoreEvent) then
					return localMembers.list[id]:getDatas()
				end
			else
				ATMEFct.errorOutputCore(nil, fctDefinition, "id must be > 0", true)
			end
		else
			ATMEFct.errorOutputCore(nil, fctDefinition, "id type must be number", true)
		end
	end
	
	function newEventsMgr.getCoreEvent(self, _id)
		local fctDefinition = ATMEFct.getErrorPrefix(newEventsMgr) .. "getCoreEvent(id)"
		
		if type(_id) == "number" then
			local id = math.floor(_id)
			if id > 0 then
				if ATMEFct.isObjectClass(localMembers.list[id], ATME.C_CoreEvent) then
					return localMembers.list[id]
				end
			else
				ATMEFct.errorOutputCore(nil, fctDefinition, "id must be > 0", true)
			end
		else
			ATMEFct.errorOutputCore(nil, fctDefinition, "id type must be number", true)
		end
	end
	
	return newEventsMgr
end

ATMEFct.C_EventsMgr_addCoreEvent = function(_eventsMgr, _coreEvent)
	local localMembers = ATMEDatas.C_EventsMgr_MT:get(_eventsMgr:getIndex())
	table.insert(localMembers.list,_coreEvent)
end

ATMEFct.C_EventsMgr_addAlarmEvent = function(_eventsMgr, _alarmEvent)
	local localMembers = ATMEDatas.C_EventsMgr_MT:get(_eventsMgr:getIndex())
	table.insert(localMembers.list,_alarmEvent)
	localMembers.alarms[_alarmEvent:getName()] = _alarmEvent
end



----------------------------------------------------------------------------------------------------------
-- Classe ATME.C_Module : gère les modules externes. Contructeur accessible aux modules externes.
-- Tout module externe doit créer une instance de cette classe afin de pouvoir activer les handlers définis
-- dans le module externe. Un handler à nil, donc non défini, ne sera pas activé par ATME_Core.
-- Cette classe offre des fonction liées au event ATME et à leurs données, permet la création des triggers
-- utilisateurs dont les identifiants sont spécifiques à un module et ajoute des fonction de debug.
--
-- Il est à noter que tous les appels xpcall au travers de localMembers (Instance de ATME.C_IndexList) se font
-- toujours dans l'ordre de création des instance de cette classe. Ainsi, un module ayant besoin d'un autre
-- module devra être défini dans les triggers après le module qu'il utilise pour que le bon ordre d'appel
-- soit respecté.
----------------------------------------------------------------------------------------------------------

ATMEDatas.C_Module_MT = {
	className = "C_Module",
	mt = {},
	
	keys = {
		["errorOutput"] = true,
		["output"] = true,
		["outputVar"] = true,
		["createAbsoluteAlarm"] = true,
		["createFlagRelativeAlarm"] = true,
		["getAlarmByName"] = true, 
		["removeAlarm"] = true,
		["getName"] = true,
		["getIndex"] = true,
		["isDebugOn"] = true,
		["createNamedArea"] = true,
		["getAreaByName"] = true,
		["createNamedTask"] = true,
		["getTaskByName"] = true,
		["createNamedLine2D"] = true,
		["getLine2DByName"] = true,
		["createNamedVector3D"] = true,
		["getVector3DByName"] = true,
		["createNamedMultiSegment2D"] = true,
		["getMultiSegment2DByName"] = true,
		["createNamedCloningContext"] = true,
		["getCloningContextByName"] = true,
		["addCoreEventCallback"] = true,
		["removeCoreEventCallback"] = true,
		["addAlarmCallback"] = true,
		["removeAlarmCallback"] = true,
	},
	
	localMembers = ATMEFct.C_IndexList_create(),
	
	add = function(self, _name, _newHandlers)
		local item = {
			alarms = {},
			areas = {},
			tasks = {},
			lines2D = {},
			vectors3D = {},
			multiSegment2D = {},
			cloningContexts = {},
			name = _name,
			handlers = _newHandlers,
			userGroupsCallbacks = {},
			userAIUnitsAndPlayersCallbacks = {},
		}
		
		return self.localMembers:add(item)
	end,
	
	remove = function(self, _id)
		self.localMembers:get(_id).alarms = nil
		self.localMembers:get(_id).handlers = nil
		self.localMembers:get(_id).areas = nil
		self.localMembers:get(_id).tasks = nil
		self.localMembers:get(_id).lines2D = nil
		self.localMembers:get(_id).vectors3D = nil
		self.localMembers:get(_id).multiSegment2D = nil
		self.localMembers:get(_id).cloningContexts = nil
		self.localMembers:get(_id).userGroupsCallbacks = nil
		self.localMembers:get(_id).userAIUnitsAndPlayersCallbacks = nil
		self.localMembers:remove(_id)
	end,
	
	get = function(self, _id)
		return self.localMembers:get(_id)
	end,
	
	pairs = function(self)
		return self.localMembers:pairs()
	end,
}

ATME.C_Module = {
	getClassName = function(self)
		return ATMEDatas.C_Module_MT.className
	end,
	
	getParentClass = function(self)
		return ATMEDatas.C_Module_MT.parentClass
	end,
	
	isLoaded = function(_name)
		local found = false
		for _, _localModuleMembers in ATMEDatas.C_Module_MT:pairs() do
			if _localModuleMembers.name == _name then
				found = true
			end
		end
		
		return found
	end
}

ATMEFct.C_Module_create = function(_name, _handlers, _debugSwitch)		   
   local newHandlers = {
		onCreatePlayerHandler = _handlers.onCreatePlayerHandler,
		onDeletePlayerHandler = _handlers.onDeletePlayerHandler,
		onUpdatePlayerHandler = _handlers.onUpdatePlayerHandler,
		onTakeoffPlayerHandler = _handlers.onTakeoffPlayerHandler,
		onLandingPlayerHandler = _handlers.onLandingPlayerHandler,
		onStartEnginePlayerHandler = _handlers.onStartEnginePlayerHandler,
		onStopEnginePlayerHandler = _handlers.onStopEnginePlayerHandler,
		onBaseCapturedPlayerHandler = _handlers.onBaseCapturedPlayerHandler,
		
		onCreateAIUnitHandler = _handlers.onCreateAIUnitHandler,
		onDeleteAIUnitHandler = _handlers.onDeleteAIUnitHandler,
		onTakeoffAIUnitHandler = _handlers.onTakeoffAIUnitHandler,
		onLandingAIUnitHandler = _handlers.onLandingAIUnitHandler,
		onStartEngineAIUnitHandler = _handlers.onStartEngineAIUnitHandler,
		onStopEngineAIUnitHandler = _handlers.onStopEngineAIUnitHandler,
		onBaseCapturedAIUnitHandler = _handlers.onBaseCapturedAIUnitHandler,
		
		onCreateGroupHandler = _handlers.onCreateGroupHandler,
		onSpawnGroupHandler = _handlers.onSpawnGroupHandler,
		onDeleteGroupHandler = _handlers.onDeleteGroupHandler,
		
		onCreateStaticObjectHandler = _handlers.onCreateStaticObjectHandler,
		onDeleteStaticObjectHandler = _handlers.onDeleteStaticObjectHandler,
		
		onEndMissionHandler = _handlers.onEndMissionHandler,
		
		onTimerHandler = _handlers.onTimerHandler,
		onModuleStartHandler = _handlers.onModuleStartHandler,
	}
	
	local newModule = {}
	setmetatable(newModule, ATMEDatas.C_Module_MT.mt)
	
	local debugSwitch = _debugSwitch
	local index = ATMEDatas.C_Module_MT:add(_name, newHandlers)
	local localMembers = ATMEDatas.C_Module_MT:get(index)
	
	local err = debug.traceback()
	local referenceFile = ATMEFct.searchMainChunk(err)
	
	ATMEDatas.refModules[referenceFile] = _name
	ATMEDatas.modules[_name] = newModule
	
	if ATME.modules[_name] == nil then
		ATME.modules[_name] = {}
	end
	
	
		
	function newModule.getName(self)	
		return localMembers.name
	end
	
	function newModule.getIndex(self)
		return index
	end
	
	function newModule.isDebugOn(self)
		return debugSwitch
	end
	
	function newModule.output(self, _text, _level)
		local fctDefinition = ATMEFct.getErrorPrefix(newModule) .. "output(text, level)"
		
		if type(_text) == "string" and type(_level) == "number" then
			if _level >= 0 then
				ATMEFct.outputCore(self, _text, _level)
			else
				ATMEFct.errorOutputCore(nil, fctDefinition, "level must be >= 0", false)
			end
		else
			if type(_text) ~= "string" then
				ATMEFct.errorOutputCore(nil, fctDefinition, "text type must be string", true)
			elseif type(_level) ~= "number" then
				ATMEFct.errorOutputCore(nil, fctDefinition, "level type must be number", false)
			end
		end
	end
	
	function newModule.outputVar(self, _title, _var, _level)
		local fctDefinition = ATMEFct.getErrorPrefix(newModule) .. "outputVar(text, var, level)"
		
		if type(_title) == "string" and type(_level) == "number" then
			if _level >= 0 then
				ATMEFct.outputVarCore(self, _title, _var, _level)
			else
				ATMEFct.errorOutputCore(nil, fctDefinition, "level must be >= 0", false)
			end
		else
			if type(_title) ~= "string" then
				ATMEFct.errorOutputCore(nil, fctDefinition, "_title type must be string", true)
			elseif type(_level) ~= "number" then
				ATMEFct.errorOutputCore(nil, fctDefinition, "level type must be number", false)
			end
		end
	end
	
	function newModule.errorOutput(self, _text)
		local fctDefinition = ATMEFct.getErrorPrefix(newModule) .. "errorOutput(text)"
		
		if type(_text) == "string" then
			ATMEFct.errorOutputCore(self, "test", _text, false)
		else
			ATMEFct.errorOutputCore(nil, fctDefinition, "text type must be string", true)
		end
	end
	
	function newModule.addCoreEventCallback(self, _object, _fct)
		local fctDefinition = ATMEFct.getErrorPrefix(newModule) .. "addCoreEventCallback(object, fct)"
		
		if ATME.isObjectClass(_object, ATME.C_DynamicObject) == true and type(_fct) == "function" then
			
			if ATMEFct.isObjectClass(_object, ATME.C_Group) == true then
				localMembers.userGroupsCallbacks[_object:getName()] = _fct
			else
				localMembers.userAIUnitsAndPlayersCallbacks[_object:getName()] = _fct
			end
		else
			if ATME.isObjectClass(_object, ATME.C_DynamicObject) == false then
				ATMEFct.errorOutputCore(nil, fctDefinition, "object type must be ATME.C_Group or ATME.C_AIUnit or ATME.C_Player", true)
			elseif type(_fct) ~= "function" then
				ATMEFct.errorOutputCore(nil, fctDefinition, "fct type must be function", false)
			end
		end
	end
	
	function newModule.removeCoreEventCallback(self, _object)
		local fctDefinition = ATMEFct.getErrorPrefix(newModule) .. "removeCoreEventCallback(object)"
		if ATME.isObjectClass(_object, ATME.C_DynamicObject) == true then
			
			if ATMEFct.isObjectClass(_object, ATME.C_Group) == true then
				localMembers.userGroupsCallbacks[_object:getName()] = nil
			else
				localMembers.userAIUnitsAndPlayersCallbacks[_object:getName()] = nil
			end
		else
			ATMEFct.errorOutputCore(nil, fctDefinition, "object type must be ATME.C_Group or ATME.C_AIUnit or ATME.C_Player", true)
		end
	end
	
	function newModule.addAlarmCallback(self, _alarm, _fct)
		local fctDefinition = ATMEFct.getErrorPrefix(newModule) .. "addAlarmCallback(alarm, fct)"
		if ATME.isObjectClass(_alarm, ATME.C_Alarm) == true and type(_fct) == "function" then
			local localMembers = ATMEDatas.C_Alarm_MT:get(_alarm:getIndex())
			
			localMembers.eventCallback = _fct
		else
			if ATME.isObjectClass(_alarm, ATME.C_Alarm) == false then
				ATMEFct.errorOutputCore(nil, fctDefinition, "alarm type must be ATME.C_Alarm", true)
			elseif type(_fct) ~= "function" then
				ATMEFct.errorOutputCore(nil, fctDefinition, "fct type must be function", false)
			end
		end
	end
	
	function newModule.removeAlarmCallback(self, _alarm)
		local fctDefinition = ATMEFct.getErrorPrefix(newModule) .. "removeAlarmCallback(alarm)"
		if ATME.isObjectClass(_alarm, ATME.C_Alarm) == true then
			local localMembers = ATMEDatas.C_Alarm_MT:get(_alarm:getIndex())
			
			localMembers.eventCallback = nil
		else
			ATMEFct.errorOutputCore(nil, fctDefinition, "alarm type must be ATME.C_Alarm", true)
		end
	end
	
	function newModule.createAbsoluteAlarm(self, _name, _rules)
		local fctDefinition = ATMEFct.getErrorPrefix(newModule) .. "createAbsoluteAlarm(name, [rules])"
		
		if type(_name) == "string" and (_rules == nil or type(_rules) == "number" or type(_rules) == "string") then
			local d,f = string.find(_name, "|", 1)
			if d == nil then
				local alarms = localMembers.alarms
				if alarms[_name] == nil then
					local err, alarm = ATMEFct.C_Alarm_create(_name, localMembers.name, nil, _rules)
					
					if err == false then
						alarms[_name] = alarm
						return alarm
					else
						ATMEFct.errorOutputCore(nil, fctDefinition, alarm, false)
					end
				else
					ATMEFct.setError("ALREADY_CREATED")
				end
			else
				ATMEFct.errorOutputCore(nil, fctDefinition, "name can't contain '|' character", false)
			end
		else
			if type(_name) ~= "string" then
				ATMEFct.errorOutputCore(nil, fctDefinition, "name type must be string", true)
			elseif type(_rules) ~= "string" then
				ATMEFct.errorOutputCore(nil, fctDefinition, "rules type must be nil or number or string", false)
			end
		end
	end
		
	function newModule.createFlagRelativeAlarm(self, _name, _flagID, _rules)
		local fctDefinition = ATMEFct.getErrorPrefix(newModule) .. "createFlagRelativeAlarm(name, flagID, [rules])"
		
		if type(_name) == "string" and (_rules == nil or type(_rules) == "number" or type(_rules) == "string") and 
				(type(_flagID) == "number" or type(_flagID) == "string") then
			local d,f = string.find(_name, "|", 1)
			if d == nil then
				if localMembers.alarms[_name] == nil then
					local flag
					
					if type(_flagID) == "number" then
						flag = math.floor(_flagID)
					else
						flag = _flagID
					end
					
					if type(flag) == "string" or flag > 0 then
						local err, alarm = ATMEFct.C_Alarm_create(_name, localMembers.name, flag, _rules)
					
						if err == false then
							localMembers.alarms[_name] = alarm
							return alarm
						else
							ATMEFct.errorOutputCore(nil, fctDefinition, alarm, false)
						end
					else
						ATMEFct.errorOutputCore(nil, fctDefinition, "flagID must be > 0", false)
					end
				else
					ATMEFct.setError("ALREADY_CREATED")
				end
			else
				ATMEFct.errorOutputCore(nil, fctDefinition, "name can't contain '|' character", false)
			end
		else
			if type(_name) ~= "string" then
				ATMEFct.errorOutputCore(nil, fctDefinition, "name type must be string", true)
			elseif type(_flagID) ~= "number" then
				ATMEFct.errorOutputCore(nil, fctDefinition, "flagID type must be number or string", false)
			elseif type(_rules) ~= "string" then
				ATMEFct.errorOutputCore(nil, fctDefinition, "rules type must be nil or number or string", false)
			end
		end
	end
	
	function newModule.getAlarmByName(self, _name)
		local fctDefinition = ATMEFct.getErrorPrefix(newModule) .. "getAlarmByName(name)"
		
		if type(_name) == "string" then
			return localMembers.alarms[_name]
		else
			ATMEFct.errorOutputCore(nil, fctDefinition, "name type must be string", true)
		end
	end
	
	function newModule.removeAlarm(self, _name)
		local fctDefinition = ATMEFct.getErrorPrefix(newModule) .. "removeAlarm(name)"
		
		if type(_name) == "string" then
			C_Alarm_delete(localMembers.alarms, _name)
		else
			ATMEFct.errorOutputCore(nil, fctDefinition, "name type must be string", true)
		end
	end
	
	function newModule.createNamedArea(self, _name, _linkedUnit)
		local fctDefinition = ATMEFct.getErrorPrefix(newModule) .. "createNamedArea(name, [linkedUnit])"
		
		if type(_name) == "string" and (_linkedUnit == nil or type(_linkedUnit) == "string" or ATME.isObjectClass(_linkedUnit, ATME.C_Unit) == true) then
			if localMembers.areas[_name] ~= nil then
				ATMEFct.setError("ALREADY_CREATED")
				return
			else
				local d,f = string.find(_name, "|", 1)
				if d == nil then

					return ATMEFct.C_Area_create(_name, localMembers.areas, _linkedUnit)
				else
					ATMEFct.errorOutputCore(nil, fctDefinition, "name can't contain '|' character", false)
				end
			end
		else
			if type(_name) ~= "string" then
				ATMEFct.errorOutputCore(nil, fctDefinition, "name type must be string", true)
			elseif _linkedUnit ~= nil and type(_linkedUnit) ~= "string"  and  ATME.isObjectClass(_linkedUnit, ATME.C_Unit) == false then
				ATMEFct.errorOutputCore(nil, fctDefinition, "linkedUnit type must be nil, string, ATME.C_AIUnit or ATME.C_Player", false)
			end
		end
	end
	
	function newModule.getAreaByName(self, _name)
		local fctDefinition = ATMEFct.getErrorPrefix(newModule) .. "getAreaByName(name)"
		
		if type(_name) == "string" then
			return localMembers.areas[_name]
		else
			ATMEFct.errorOutputCore(nil, fctDefinition, "name type must be string", true)
		end
	end
	
	function newModule.createNamedTask(self, _name, _task, ...)
		local fctDefinition = ATMEFct.getErrorPrefix(newModule) .. "createNamedTask(name, task, ...)"
		
		if type(_name) == "string" and type(_task) == "string" then
			if localMembers.tasks[_name] ~= nil then
				ATMEFct.setError("ALREADY_CREATED")
				return
			else
				local d,f = string.find(_name, "|", 1)
				if d == nil then
					local taskDatas = {}
					local err, usedOnZoneOnly, filters = ATMEFct.C_Task_setParams(_task, taskDatas, 1, ...)
					
					if err == nil then
						return ATMEFct.C_Task_create(_name, localMembers.tasks, _task, usedOnZoneOnly, taskDatas, filters)
					else
						ATMEFct.errorOutputCore(nil, fctDefinition, err, false)
					end
				else
					ATMEFct.errorOutputCore(nil, fctDefinition, "name can't contain '|' character", false)
				end
			end
		else
			if type(_name) ~= "string" then
				ATMEFct.errorOutputCore(nil, fctDefinition, "name type must be string", true)
			elseif type(_task) ~= "string" then
				ATMEFct.errorOutputCore(nil, fctDefinition, "task type must be string", false)
			end
		end
	end
	
	function newModule.getTaskByName(self, _name)
		local fctDefinition = ATMEFct.getErrorPrefix(newModule) .. "getTaskByName(name)"
		
		if type(_name) == "string" then
			return localMembers.tasks[_name]
		else
			ATMEFct.errorOutputCore(nil, fctDefinition, "name type must be string", true)
		end
	end
	
	function newModule.createNamedLine2D(self, _name, ...)
		local fctDefinition = ATMEFct.getErrorPrefix(newModule) .. "createNamedLine2D(name)"
		
		if type(_name) == "string" then
			if localMembers.lines2D[_name] ~= nil then
				ATMEFct.setError("ALREADY_CREATED")
				return
			else
				local d,f = string.find(_name, "|", 1)
				if d == nil then
					local args = {...}
					
					if (#args == 1 and ATME.isObjectClass(args[1], ATME.C_Line2D) == true)  or
							(#args == 2 and ATME.isPoint(args[1]) ~= POINT_BAD and ATME.isPoint(args[2]) ~= POINT_BAD) or
							(#args == 2 and ATME.isObjectClass(args[1], ATME.C_Vector3D) == true and ATME.isPoint(args[2]) ~= POINT_BAD) then
						return ATMEFct.C_Line2D_create(_name, localMembers.lines2D, ...)
					else
						if #args == 2 then
							if ATME.isPoint(args[1]) == POINT_BAD and ATME.isObjectClass(args[1], ATME.C_Vector3D) == false then
								ATMEFct.errorOutputCore(nil, fctDefinition, "vector or pA type must be table (x,y) or (x,y,z) or ATME.C_Vector3D", false)
							elseif ATME.isPoint(args[2]) == POINT_BAD then
								ATMEFct.errorOutputCore(nil, fctDefinition, "pB or point type must be table (x,y) or (x,y,z)", false)
							end
						elseif #args == 1 and ATME.isObjectClass(args[1], ATME.C_Line2D) == false then
							ATMEFct.errorOutputCore(nil, fctDefinition, "line type must be ATME.C_Line2D", false)
						else
							ATMEFct.errorOutputCore(nil, fctDefinition, "must have 1 or 2 parameters", false)
						end
					end
				else
					ATMEFct.errorOutputCore(nil, fctDefinition, "name can't contain '|' character", false)
				end
			end
		else
			ATMEFct.errorOutputCore(nil, fctDefinition, "name type must be string", true)
		end
	end
	
	function newModule.getLine2DByName(self, _name)
		local fctDefinition = ATMEFct.getErrorPrefix(newModule) .. "getLine2DByName(name)"
		
		if type(_name) == "string" then
			return localMembers.lines2D[_name]
		else
			ATMEFct.errorOutputCore(nil, fctDefinition, "name type must be string", true)
		end
	end
	
	function newModule.createNamedMultiSegment2D(self, _name, _points)
		local fctDefinition = ATMEFct.getErrorPrefix(newModule) .. "createNamedMultiSegment2D(name, points)\ncreateNamedMultiSegment2D(name, dcsZoneName)"
		
		if type(_name) == "string" and (type(_points) == "table" or type(_points) == "string") then
			if localMembers.multiSegment2D[_name] ~= nil then
				ATMEFct.setError("ALREADY_CREATED")
				return
			else
				local d,f = string.find(_name, "|", 1)
				if d == nil then
					local pErr
					local points = {}
					if type(_points) == "table" then
						for _key, _value in ipairs(_points) do
							if pErr == nil then
								local point
								
								if ATME.isPoint(_value) ~= POINT_BAD then
									point = ATME.convertToPoint3D(_value)
								elseif type(_value) == "string" then
									local zone = ATME.getDCSZone(_value)
									
									if zone ~= nil then
										point = zone.point
									else
										pErr = "Bad zone in item key " .. _key .. " : DCS Zone " .. _value .. " doesn't exist"
									end
								else
									pErr = "Bad type for item key " .. _key
								end
								
								if pErr == nil then
									table.insert(points, point)
								end
							end
						end
					else
						for _i = 1, ATMEConst.multiSegmentMaxPoints do
							local currentName = _points .. string.format("#%03d", _i)
							local zone = ATME.getDCSZone(currentName)
							
							if zone ~= nil then
								table.insert(points, zone.point)
							end
						end
					end
					
					if pErr ~= nil then
						ATMEFct.errorOutputCore(nil, fctDefinition, pErr, false)
					else
						if #points >= 2 and #points <= ATMEConst.multiSegmentMaxPoints then
							return ATMEFct.C_MultiSegment2D_create(_name, localMembers.multiSegment2D, points)
						else
							ATMEFct.errorOutputCore(nil, fctDefinition, "#points must be >= 2 and <= " .. ATMEConst.multiSegmentMaxPoints, false)
						end
					end
				else
					ATMEFct.errorOutputCore(nil, fctDefinition, "name can't contain '|' character", false)
				end
			end
		else
			if type(_name) ~= "string" then
				ATMEFct.errorOutputCore(nil, fctDefinition, "name type must be string", true)
			elseif type(_points) ~= "table" and type(_points) ~= "string" then
				ATMEFct.errorOutputCore(nil, fctDefinition, "points type must be table or string", false)
			end
		end
	end
	
	function newModule.getMultiSegment2DByName(self, _name)
		local fctDefinition = ATMEFct.getErrorPrefix(newModule) .. "getMultiSegment2DByName(name)"
		
		if type(_name) == "string" then
			return localMembers.multiSegment2D[_name]
		else
			ATMEFct.errorOutputCore(nil, fctDefinition, "name type must be string", true)
		end
	end
	
	function newModule.createNamedVector3D(self, _name, ...)
		local fctDefinition = ATMEFct.getErrorPrefix(newModule) .. "createNamedVector3D(name)"
		
		if type(_name) == "string" then
			if localMembers.vectors3D[_name] ~= nil then
				ATMEFct.setError("ALREADY_CREATED")
				return
			else
				local d,f = string.find(_name, "|", 1)
				if d == nil then
					local args = {...}
					
					if  #args == 0 or (#args == 3 and type(args[1]) == "number" and type(args[2]) == "number" and type(args[3]) == "number") or
							(#args == 1 and ATME.isObjectClass(args[1], ATME.C_Vector3D) == true and type(args[1]:getX()) == "number" and type(args[1]:getY()) == "number" and type(args[1]:getZ()) == "number") or
							(#args == 1 and type(args[1]) == "table" and type(args[1].x) == "number" and type(args[1].y) == "number" and type(args[1].z) == "number") or
							(#args == 2 and ATME.isPoint(args[1]) ~= POINT_BAD and ATME.isPoint(args[2]) ~= POINT_BAD) then
		
						return ATMEFct.C_Vector3D_create(_name, localMembers.vectors3D, ...)
					else
						if #args == 3 then
							if type(args[1]) ~= "number" then
								ATMEFct.errorOutputCore(nil, fctDefinition, "x type must be number", false)
							elseif type(args[2]) ~= "number" then
								ATMEFct.errorOutputCore(nil, fctDefinition, "y type must be number", false)
							elseif type(args[3]) ~= "number" then
								ATMEFct.errorOutputCore(nil, fctDefinition, "z type must be number", false)
							end
						elseif #args == 2 then
							if ATME.isPoint(args[1]) == POINT_BAD then
								ATMEFct.errorOutputCore(nil, fctDefinition, "pA type must be table (x,y) or (x,y,z)", false)
							elseif ATME.isPoint(args[2]) == POINT_BAD then
								ATMEFct.errorOutputCore(nil, fctDefinition, "pB type must be table (x,y) or (x,y,z)", false)
							end
						elseif #args == 1 and ATME.isObjectClass(args[1], ATME.C_Vector3D) == false then
							ATMEFct.errorOutputCore(nil, fctDefinition, "vector type must be ATME.C_Vector3D", false)
						else
							ATMEFct.errorOutputCore(nil, fctDefinition, "must have 0 to 3 parameters", false)
						end
					end
				else
					ATMEFct.errorOutputCore(nil, fctDefinition, "name can't contain '|' character", false)
				end
			end
		else
			ATMEFct.errorOutputCore(nil, fctDefinition, "name type must be string", true)
		end
	end
	
	function newModule.getVector3DByName(self, _name)
		local fctDefinition = ATMEFct.getErrorPrefix(newModule) .. "getVector3DByName(name)"
		
		if type(_name) == "string" then
			return localMembers.vectors3D[_name]
		else
			ATMEFct.errorOutputCore(nil, fctDefinition, "name type must be string", true)
		end
	end
	
	function newModule.createNamedCloningContext(self, _name, _origin, _newGroupName)
		local fctDefinition = ATMEFct.getErrorPrefix(newModule) .. "createNamedCloningContext(name, origin, [newGroupName])"
		
		if type(_name) == "string" and 
			(type(_origin) == "string" or type(_origin) == "table") and (type(_newGroupName) == "string" or _newGroupName == nil) then
			if localMembers.cloningContexts[_name] ~= nil then
				ATMEFct.setError("ALREADY_CREATED")
				return
			else
				if type(_origin) == "table" then
					if ATMEFct.C_CloningContext_controlTable(_origin, _newGroupName) == false then
						ATMEFct.errorOutputCore(nil, fctDefinition, "Bad cloning table format", false)
						return
					end
					
					if _newGroupName ~= nil then
						_origin.datas.name = _newGroupName
					end
				end
				
				local newGroupName = _newGroupName
				if _newGroupName == nil then
					if type(_origin) == "string" then
						newGroupName = _origin
					else
						newGroupName = _origin.datas.name 
					end
				else
					local d,f = string.find(newGroupName, "|", 1)
					if d ~= nil then
						ATMEFct.errorOutputCore(nil, fctDefinition, "Name of group " .. newGroupName .. " can't contain '|' character", false)
						return
					end
					
					d,f = string.find(newGroupName:upper(), "%s+SPAWNED%s+", 1)
					if d ~= nil then
						ATMEFct.errorOutputCore(nil, fctDefinition, "Name of group " .. newGroupName .. " can't contain 'Spawned' word", false)
						return
					end
				end
				
				local err, initialNames = ATMEFct.C_CloningContext_getInitialNames(_origin)
				
				if err == nil then
					local foundPlayer = false
					for _, _unitDatas in pairs(ATMEDatas.allGroupsInMission[initialNames.groupName].units) do
						if _unitDatas.skill == "Player" or _unitDatas.skill == "Client" then
							foundPlayer = true
						end
					end
					
					if foundPlayer == false then
						-- Le nom du nouveau groupe (_newGroupName) ne doit pas correspondre à un groupe existant,
						-- à un groupe embarqué ou à un groupe en cours de spawn.

						return ATMEFct.C_CloningContext_create(_name, localMembers.cloningContexts, initialNames, newGroupName)
					else
						ATMEFct.errorOutputCore(nil, fctDefinition, "name can't contain '|' character", false)
					end
				end
			end
		else
			if type(_name) ~= "string" then
				ATMEFct.errorOutputCore(nil, fctDefinition, "name type must be string", true)
			elseif _linkedUnit ~= nil and type(_linkedUnit) ~= "string"  and  ATME.isObjectClass(_linkedUnit, ATME.C_Unit) == false then
				ATMEFct.errorOutputCore(nil, fctDefinition, "linkedUnit type must be nil, string, ATME.C_AIUnit or ATME.C_Player", false)
			end
		end
	end
	
	function newModule.getCloningContextByName(self, _name)
		local fctDefinition = ATMEFct.getErrorPrefix(newModule) .. "getCloningContextByName(name)"
		
		if type(_name) == "string" then
			return localMembers.cloningContexts[_name]
		else
			ATMEFct.errorOutputCore(nil, fctDefinition, "name type must be string", true)
		end
	end
	
	return newModule			
end

ATMEDatas.C_Module_MT.__call = function(t, _name, _handlers, _debugSwitch)
	local fctDefinition = "Constructor ATME.C_Module(name, handlers, debugSwitch)"
	
	if type(_name) == "string" and type(_handlers) == "table" and type(_debugSwitch) == "boolean" then
		if ATMEDatas.isRunning == false then
			local found = false
			for _, _localModuleMembers in ATMEDatas.C_Module_MT:pairs() do
				if _localModuleMembers.name == _name then
					found = true
				end
			end
			if found == false then
				if (type(_handlers.onCreatePlayerHandler) == "function" or _handlers.onCreatePlayerHandler == nil) and
				   (type(_handlers.onDeletePlayerHandler) == "function" or _handlers.onDeletePlayerHandler == nil) and
				   (type(_handlers.onUpdatePlayerHandler) == "function" or _handlers.onUpdatePlayerHandler == nil) and
				   (type(_handlers.onTakeoffPlayerHandler) == "function" or _handlers.onTakeoffPlayerHandler == nil) and
				   (type(_handlers.onLandingPlayerHandler) == "function" or _handlers.onLandingPlayerHandler == nil) and
				   (type(_handlers.onStartEnginePlayerHandler) == "function" or _handlers.onStartEnginePlayerHandler == nil) and
				   (type(_handlers.onStopEnginePlayerHandler) == "function" or _handlers.onStopEnginePlayerHandler == nil) and
				   (type(_handlers.onBaseCapturedPlayerHandler) == "function" or _handlers.onBaseCapturedPlayerHandler == nil) and
				   (type(_handlers.onCreateAIUnitHandler) == "function" or _handlers.onCreateAIUnitHandler == nil) and
				   (type(_handlers.onDeleteAIUnitHandler) == "function" or _handlers.onDeleteAIUnitHandler == nil) and			   
				   (type(_handlers.onTakeoffAIUnitHandler) == "function" or _handlers.onTakeoffAIUnitHandler == nil) and
				   (type(_handlers.onLandingAIUnitHandler) == "function" or _handlers.onLandingAIUnitHandler == nil) and
				   (type(_handlers.onStartEngineAIUnitHandler) == "function" or _handlers.onStartEngineAIUnitHandler == nil) and
				   (type(_handlers.onStopEngineAIUnitHandler) == "function" or _handlers.onStopEngineAIUnitHandler == nil) and
				   (type(_handlers.onBaseCapturedAIUnitHandler) == "function" or _handlers.onBaseCapturedAIUnitHandler == nil) and
				   (type(_handlers.onCreateGroupHandler) == "function" or _handlers.onCreateGroupHandler == nil) and
				   (type(_handlers.onSpawnGroupHandler) == "function" or _handlers.onSpawnGroupHandler == nil) and
				   (type(_handlers.onDeleteGroupHandler) == "function" or _handlers.onDeleteGroupHandler == nil) and
				   (type(_handlers.onCreateStaticObjectHandler) == "function" or _handlers.onCreateStaticObjectHandler == nil) and
				   (type(_handlers.onDeleteStaticObjectHandler) == "function" or _handlers.onDeleteStaticObjectHandler == nil) and
				   (type(_handlers.onEndMissionHandler) == "function" or _handlers.onEndMissionHandler == nil) and
				   (type(_handlers.onTimerHandler) == "function" or _handlers.onTimerHandler == nil) and
				   (type(_handlers.onModuleStartHandler) == "function" or _handlers.onModuleStartHandler == nil) then
				   
					return ATMEFct.C_Module_create(_name, _handlers, _debugSwitch)
				else
					ATMEFct.errorOutputCore(nil, fctDefinition, "Module " .. _name .. " - each handler must be nil or function", false)
				end
			else
				ATMEFct.errorOutputCore(nil, fctDefinition, "Module " .. _name .. " already loaded", false)
			end
		else
			ATMEFct.errorOutputCore(nil, fctDefinition, "Module " .. _name .. " is not created - ATME is running", false)
		end
	else
		if type(_name) ~= "string" then
			ATMEFct.errorOutputCore(nil, fctDefinition, "name type must be string", false)
		elseif type(_handlers) ~= "table" then
			ATMEFct.errorOutputCore(nil, fctDefinition, "handlers type must be table of functions", false)
		elseif type(_debugSwitch) ~= "boolean" then
			ATMEFct.errorOutputCore(nil, fctDefinition, "debugSwitch type must be boolean", false)
		end
	end
end

setmetatable(ATME.C_Module,ATMEDatas.C_Module_MT)

ATMEDatas.C_Module_MT.mt.__metatable = "Private"
ATMEDatas.C_Module_MT.mt.__index = ATME.C_Module
ATMEDatas.C_Module_MT.mt.__newindex = function(t, k, v)
	if ATMEDatas.C_Module_MT.keys[k] ~= nil then 
		rawset(t, k, v)
	else
		ATMEFct.errorOutputCore(nil, "Function ATME.C_Module : Bad key " .. k, "table locked", false)
	end
end


----------------------------------------------------------------------------------------------------------
-- Classe ATME.C_Smoke : gère les fumées. Contructeur accessible aux modules externes.
-- Une fumée peut être déclenché simplement. DCS l'arrêtera au bout de 300s (5 minutes). Elle peut être également
-- redéclenchée au bout de cette durée jusqu'à un arrêt volontaire. 
-- La couleur est définie par une string dans ATME.
-- On notera qu'il est aussi possible de déclencher une fumée à partir d'un unité joueur, AI, ou d'un objet statique.
----------------------------------------------------------------------------------------------------------

ATMEDatas.C_Smoke_MT = {
	className = "C_Smoke",
	mt = {},
	
	keys = {
		["activate"] = true,
		["stop"] = true,
		["getPoint"] = true,
		["getColor"] = true,
		["getIndex"] = true,
	},
	
	localMembers = ATMEFct.C_IndexList_create(),
	
	add = function(self, _timeStart)
		local item = {
			timeStart = _timeStart,
		}
		
		return self.localMembers:add(item)
	end,
	
	remove = function(self, _id)
		self.localMembers:remove(_id)
	end,
	
	get = function(self, _id)
		return self.localMembers:get(_id)
	end,
}

ATME.C_Smoke = {
	getClassName = function(self)
		return ATMEDatas.C_Smoke_MT.className
	end,
	
	getParentClass = function(self)
		return ATMEDatas.C_Smoke_MT.parentClass
	end,
}

ATMEFct.C_Smoke_create = function(_color, _point)
	local newSmoke = {}
	local color

	setmetatable(newSmoke, ATMEDatas.C_Smoke_MT.mt)

	if ATMEConst.smokeColors[string.upper(_color)] == -1 then
		color = ATMEConst.smokeColors[ATMEConst.smokeColorsIndex[math.random(1,#ATMEConst.smokeColorsIndex)]]
	else
		color = ATMEConst.smokeColors[string.upper(_color)]
	end
	
	local point = ATME.convertToPoint3D(_point)

	local entry = 0
	local activated = false
	
	local index = ATMEDatas.C_Smoke_MT:add(timer.getTime())
	
	function newSmoke.activate(self, _always)
		local fctDefinition = ATMEFct.getErrorPrefix(newSmoke) .. "activate([always])"
		
		if _always == nil or type(_always) == "boolean" then
			local always = _always
			if _always == nil then
				always = false
			end
			
			if activated == false then
				trigger.action.smoke(point, color)
				activated = true
				
				if always == true then
					entry = ATMEDatas.activatedSmokes:add(self)
				end
			end
		else
			ATMEFct.errorOutputCore(nil, fctDefinition, "always type must be nil or boolean", true)
		end
	end

	function newSmoke.stop(self)
		if entry > 0 then
			ATMEDatas.activatedSmokes:remove(entry)
			entry = 0
		end
	end
	
	function newSmoke.getPoint(self)
		return point
	end
	
	function newSmoke.getColor(self)
		if color == trigger.smokeColor.Green then
			return ATMEConst.smokeColorsIndex[1]
		elseif color == trigger.smokeColor.Red then
			return ATMEConst.smokeColorsIndex[2]
		elseif color == trigger.smokeColor.White then
			return ATMEConst.smokeColorsIndex[3]
		elseif color == trigger.smokeColor.Orange then
			return ATMEConst.smokeColorsIndex[4]
		else
			return ATMEConst.smokeColorsIndex[5]
		end
	end
	
	function newSmoke.getIndex(self)
		return index
	end
	
	return newSmoke
end

setmetatable(ATME.C_Smoke,ATMEDatas.C_Smoke_MT)

ATMEDatas.C_Smoke_MT.__call = function(t, _color, _point)
	local fctDefinition = "Constructor ATME.C_Smoke(color, point)"
	
	if type(_color) == "string" and ATME.isPoint(_point) ~= POINT_BAD then
		if ATMEConst.smokeColors[string.upper(_color)]~= nil then
			return ATMEFct.C_Smoke_create(_color, _point)
		else
			ATMEFct.errorOutputCore(nil, fctDefinition, "color must be a smoke color", false)
		end
	else
		if type(_color) ~= "string" then
			ATMEFct.errorOutputCore(nil, fctDefinition, "color type must be string", false)
		elseif ATME.isPoint(_point) == POINT_BAD then
			ATMEFct.errorOutputCore(nil, fctDefinition, "point type must be table (x,y) or (x,y,z)", false)
		end
	end
end

ATMEDatas.C_Smoke_MT.mt.__metatable = "Private"
ATMEDatas.C_Smoke_MT.mt.__index = ATME.C_Smoke
ATMEDatas.C_Smoke_MT.mt.__newindex = function(t, k, v)
	if ATMEDatas.C_Smoke_MT.keys[k] ~= nil then 
		rawset(t, k, v)
	else
		ATMEFct.errorOutputCore(nil, "Function ATME.C_Smoke : Bad key " .. k, "table locked", false)
	end
end


----------------------------------------------------------------------------------------------------------
-- Classe ATME.C_Flare : gère les flares de couleur. Contructeur accessible aux modules externes.
-- Un tir de flare peut être déclenché unitairement. Il peut être aussi redéclenché automatiquement et aléatoirement
-- sur une durée souhaitée ou jusqu'à un arrêt volontaire.
-- La couleur est définie par une string dans ATME. Il existe une couleur "RANDOM" pour un choix aléatoire.
-- On notera qu'il est aussi possible de déclencher un flare à partir d'un unité joueur, AI, ou d'un objet statique.
----------------------------------------------------------------------------------------------------------

ATMEDatas.C_Flare_MT = {
	className = "C_Flare",
	mt = {},
	
	keys = {
		["fireOnce"] = true,
		["fire"] = true,
		["stop"] = true,
		["getColor"] = true,
		["getPoint"] = true,
		["getDuration"] = true,
		["getTimeStart"] = true,
	},
}

ATME.C_Flare = {
	getClassName = function(self)
		return ATMEDatas.C_Flare_MT.className
	end,
	
	getParentClass = function(self)
		return ATMEDatas.C_Flare_MT.parentClass
	end,
}

ATMEFct.C_Flare_create = function(_color, _point)	
	local newFlare = {}
	local color
	local randomFireColor = false
	local timeStart = 0
	local entry = 0
	local seconds = 0
	
	setmetatable(newFlare, ATMEDatas.C_Flare_MT.mt)
	
	if ATMEConst.flareColors[string.upper(_color)] == -1 then
		randomFireColor = true
	else
		color = ATMEConst.flareColors[string.upper(_color)]
	end

	
	local point = ATME.convertToPoint3D(_point)
	
	function newFlare.fireOnce(self)
		if randomFireColor == true then
			color = ATMEConst.flareColors[ATMEConst.flareColorsIndex[math.random(1,#ATMEConst.flareColorsIndex)]]
		end
		
		self:stop()
		
		seconds = 0
		timeStart = timer.getTime()
		
		trigger.action.signalFlare(point, color, math.random() * 2 * math.pi)
	end
	
	function newFlare.fire(self, _seconds)
		entry = ATMEDatas.activatedFlares:add(self)
		
		seconds = _seconds
		timeStart = timer.getTime()
	end
	
	function newFlare.stop(self)
		if entry > 0 then
			ATMEDatas.activatedFlares:remove(entry)
			entry = 0
		end
	end
	
	function newFlare.getPoint(self)
		return point
	end
	
	function newFlare.getColor(self)
		if color == trigger.flareColor.Green then
			return ATMEConst.flareColorsIndex[1]
		elseif color == trigger.flareColor.Red then
			return ATMEConst.flareColorsIndex[2]
		elseif color == trigger.flareColor.White then
			return ATMEConst.flareColorsIndex[3]
		else
			return ATMEConst.flareColorsIndex[4]
		end
	end
	
	function newFlare.getDuration(self)
		return seconds
	end
	
	function newFlare.getTimeStart(self)
		return timeStart
	end
	
	return newFlare
end

setmetatable(ATME.C_Flare,ATMEDatas.C_Flare_MT)

ATMEDatas.C_Flare_MT.__call = function(t, _color, _point)
	local fctDefinition = "Constructor ATME.C_Flare(color, point)"
		
	if type(_color) == "string" and ATME.isPoint(_point) ~= POINT_BAD then
		if ATMEConst.flareColors[string.upper(_color)]~= nil then
			return ATMEFct.C_Flare_create(_color, _point)
		else
			ATMEFct.errorOutputCore(nil, fctDefinition, "color must be a flare color or RANDOM", false)
		end
	else
		if type(_color) ~= "string" then
			ATMEFct.errorOutputCore(nil, fctDefinition, "color type must be string", false)
		elseif ATME.isPoint(_point) == POINT_BAD then
			ATMEFct.errorOutputCore(nil, fctDefinition, "point type must be table (x,y) or (x,y,z)", false)
		end
	end
end


ATMEDatas.C_Flare_MT.mt.__metatable = "Private"
ATMEDatas.C_Flare_MT.mt.__index = ATME.C_Flare
ATMEDatas.C_Flare_MT.mt.__newindex = function(t, k, v)
	if ATMEDatas.C_Flare_MT.keys[k] ~= nil then 
		rawset(t, k, v)
	else
		ATMEFct.errorOutputCore(nil, "Function ATME.C_Flare : Bad key " .. k, "table locked", false)
	end
end


-----------------------------------------------------------------------------------------------------------
-- Définition des fonctions indirectes ATMEAIIndFct liées aux tâches et définies dans la table 
-- ATMEConst.taskAI. Ces fonctions retournent toujours une table, qui comporte un ou plusieurs éléments 
-- indexés. Si plusieurs éléments sont retournées, les paramètres associés à linkedParams, définis dans
-- la table ATMEConst.taskAI seront initialisés.
-----------------------------------------------------------------------------------------------------------

ATMEAIIndFct.C_testFormation = function(_arg)	
	if ATMEConst.badOptionAIFormationValues[_arg] == nil then
		return {args}
	end
end

ATMEAIIndFct.C_getNumberWithFlag = function(_arg)
	return {_arg, true}
end

ATMEAIIndFct.C_Circle_getCenterRadius = function(_arg)
	local point = _arg:getCenter()
	
	return {{x = point.x, y = point.z}, _arg:getRadius()}
end

ATMEAIIndFct.C_Group_getID = function(_arg)
	localMembers = ATMEDatas.C_Group_MT:get(_arg:getIndex())
	
	return {localMembers.spawnDatas.datas.groupId}
end

ATMEAIIndFct.C_Unit_getID = function(_arg)
	return {_arg:getDCSUnit():getID()}
end

ATMEAIIndFct.C_getWeaponFlag = function(_arg)	
	return {ATMEConst.weaponFlags[string.upper(_arg)]}
end

ATMEAIIndFct.C_getExpend = function(_arg)	
	return {ATMEConst.weaponExpend[string.upper(_arg)]}
end

ATMEAIIndFct.C_getDesignation = function(_arg)	
	return {ATMEConst.designationAI[string.upper(_arg)]}
end

ATMEAIIndFct.C_getTargetsType = function(_arg)
	local values = {}
	
	for _i, _item in ipairs(_arg) do
		values[_i] = ATMEConst.TargetsType[string.upper(_item)]
	end
	
	return values
end

ATMEAIIndFct.C_getModulation = function(_arg)
	local value = string.upper(_arg)
	
	if value == "FM" then
		return {radio.modulation.FM}
	elseif value == "AM" then
		return {radio.modulation.AM}
	end
end

ATMEAIIndFct.C_getCallname = function(_arg)
	local tokens = ATMEFct.analyzeString(string.upper(_arg))
	
	if #tokens == 2 and tokens[1].type == "TOKEN_JTAC_CALLSIGN_NAME" and tokens[2].type == "TOKEN_INTEGER" then
		return {ATMEConst.blueCallsigns.jtacs[tokens[1].value].id, tokens[2].value}
	end
end

ATMEAIIndFct.C_getPoint2D = function(_arg)
	if ATME.isObjectClass(_arg, ATME.C_Unit) or ATME.isObjectClass(_arg, ATME.C_Group) then
		local pos = _arg:getPosition()
		return {{x = pos.x, y = pos.z}}
	elseif _arg.x ~= nil and _arg.y ~= nil then
		local point = ATME.convertToPoint3D(_arg)
		return {{x = point.x, y = point.z}}
	end
end

ATMEAIIndFct.C_getOrbitPattern = function(_arg)
	return {ATMEConst.orbitPattern[string.upper(_arg)]}
end	

ATMEAIIndFct.C_getAirbase = function(_arg)
	if ATMEDatas.airbases[_arg] ~= nil then
		return {ATMEDatas.airbases[_arg]:getID()}
	end
end

ATMEAIIndFct.C_Vector_getPos = function(_arg)
	return {{x = _arg:getX(), y = _arg:getY(), z = _arg:getZ()}}
end

ATMEFct.testDatas = function(_data, _param)
	if _data ~= nil then
		if _param.enum ~= nil then
			local data = _data
			if type(data) == "string" then
				data = string.upper(_data)
			end
			if _param.enum[data] ~= nil then
				return _param.enum[data]
			end
		elseif type(_data) == "number" then
			if _param.max ~= nil and type(_data) == "number" then
				if _data > _param.max then
					return
				end
			end
			
			if _param.min ~= nil and type(_data) == "number" then
				if _data < _param.min then
					return
				end
			end
			
			return _data
		else
			return _data
		end
	end
end

-----------------------------------------------------------------------------------------------------------
-- Classe ATME.C_Task : gère la création dynamique des taches associées ensuite à des WP ou à des groupes
-- d'unités.
-----------------------------------------------------------------------------------------------------------

-- Analyse des paramètres pour une tache :
-- _id = 1 pour les paramètres obligatoires (voir déclaration de taskAI)
-- _id = 2 pour les paramètres optionnels (voir déclaration de taskAI)
--
-- Cette analyse se fait argument par argument lié à {...}
-- Le type des arguments est testé.
-- Un argument peut représenter plusieurs paramètres de la tâche (exemple argument cercle qui renseigne
-- un centre et un rayon. Chaque paramètre peut faire appel à une fonction indirecte spécifique ou pas.
-- Un argument peut également lié plusieurs paramètres de la tâche, dans ce cas, la fonction indirecte
-- doit exister et retourner une table avec plusieurs valeurs, une par paramètre.
-- Enfin, chaque paramètre est testé en terme de valeur sur une plage min/max ou énumération.

ATMEFct.C_Task_setParams = function(_task, _taskDatas, _id, ...)
	local taskID = string.upper(_task)
	local args = {...}
	local filters
	local usedOnZoneOnly = false
	
	if ATMEConst.taskAI[taskID] ~= nil then
		local index = 1
		
		if _id == 1 then
			_taskDatas["id"] = ATMEConst.taskAI[taskID].id
			_taskDatas["params"] = {}
			
			if ATMEConst.taskAI[taskID].const ~= nil then
				for _name, _value in pairs(ATMEConst.taskAI[taskID].const) do
					_taskDatas["params"][_name] = _value
				end
			end
		end
		
		for _i, _arg in ipairs(ATMEConst.taskAI[taskID].args[_id]) do
			for _name, _param in pairs(_arg.params) do
				if type(args[_i]) == "table" and _arg.multi == true then
					local datas = {}
					
					for _, _item in ipairs(args[_i]) do
						if _arg.type == type(_item) or ATMEFct.isObjectClass(_item, _arg.type) == true then
							if _param.fct ~= nil then
								local values = ATMEAIIndFct[_param.fct](args[_i])
								local items = {}
								for _valueId, _value in ipairs(values) do
									local value = ATMEFct.testDatas(_value, _arg)
									if value ~= nil then
										items[_valueId] = value
									else
										return "Parameter #".. _i .. " - Bad value"
									end
								end
								
								if #values == 1 then
									table.insert(datas, items[1])
								else
									table.insert(datas, items)
								end
							else
								local value = ATMEFct.testDatas(_item, _arg)
								if  value ~= nil then
									table.insert(datas, value)
								else
									return "Parameter #".. _i .. " - Bad value"
								end
							end
						else
							return "Parameter #".. _i .. " - Bad type"
						end
					end
						
					_taskDatas["params"][_name] = datas
				elseif _arg.multi == false and (type(args[_i]) == _arg.type or ATMEFct.isObjectClass(args[_i], _arg.type) == true) then
					if _param.fct ~= nil then
						local values = ATMEAIIndFct[_param.fct](args[_i])

						for _valueId, _value in ipairs(values) do
							local value = ATMEFct.testDatas(_value, _arg)
							if value ~= nil then
								if _valueId == 1 then
									_taskDatas["params"][_name] = value
								else
									_taskDatas["params"][_param.linkedParams[_valueId - 1]] = value
								end
							else
								return "Parameter #".. _i .. " - Bad value"
							end
						end
					elseif ATMEFct.isObjectClass(args[_i], _arg.type) == false then
						local value = ATMEFct.testDatas(args[_i], _arg)
						if value ~= nil then
							_taskDatas["params"][_name] = value
						else
							return "Parameter #".. _i .. " - Bad value"
						end
					else
						return "Parameter #".. _i .. " - Bad value"
					end
				elseif args[_i] == nil then
					if _id == 2 then
						_taskDatas["params"][_name] = nil
						if _param.linkedParams ~= nil then
							for _valueId, _ in ipairs(_param.linkedParams) do
								_taskDatas["params"][_param.linkedParams[_valueId]] = nil
							end
						end
					else
						if _arg.onZone ~= nil then
							usedOnZoneOnly = true
						else
							return "Parameter #".. _i .. " - Bad type"
						end
					end
				else
					return "Parameter #".. _i .. " - Bad type"
				end
			end
		end
		
		return nil, usedOnZoneOnly, ATMEConst.taskAI[taskID].filters
	else
		return "Task '" .. _task .. "' doesn't exist"
	end
end

ATMEFct.C_Task_getTaskDatas = function(_task, _type, _start)
	local localMembers = ATMEDatas.C_Task_MT:get(_task:getIndex())

	local ok = false
	for _id, _ in pairs(localMembers.filters.type) do
		if _id == _type then
			ok = true
		end
	end
	
	local taskDatas = ATMEFct.copyTable(localMembers.datas)
	
	if ok == true then
		if localMembers.stopCondition ~= nil or (localMembers.startCondition ~= nil and _start == true) then
			temp = taskDatas
			taskDatas = { 
				["id"] = "ControlledTask", 
				["params"] = { 
					task = temp,
				} 
			}
			
			if localMembers.stopCondition ~= nil then
				taskDatas.params.stopCondition = ATMEFct.copyTable(localMembers.stopCondition) 
			end
			
			if localMembers.startCondition ~= nil then
				taskDatas.params.condition = ATMEFct.copyTable(localMembers.startCondition)
			end
		end
	else
		
	end
	
	return ok, localMembers.usedOnZoneOnly, taskDatas
end

ATMEDatas.C_Task_MT = {
	className = "C_Task",
	mt = {},
	
	keys = {
		["getIndex"] = true,
		["getName"] = true,
		["tagGetByID"] = true,
		["tagCompare"] = true,
		["tagGetCount"] = true,
		["addStopCondition"] = true,
		["removeStopCondition"] = true,
		["addStartCondition"] = true,
		["removeStartCondition"] = true,
		["setOptionalParameters"] = true,
	},
	
	localMembers = ATMEFct.C_IndexList_create(),
	
	add = function(self, _taskID, _usedOnZoneOnly, _taskDatas, _filters)
		local item = {
			taskID = _taskID,
			datas = _taskDatas,
			filters = _filters,
			usedOnZoneOnly = _usedOnZoneOnly,
		}
		
		return self.localMembers:add(item)
	end,
	
	remove = function(self, _id)
		self.localMembers:remove(_id)
	end,
	
	get = function(self, _id)
		return self.localMembers:get(_id)
	end,
}

ATME.C_Task = {
	getClassName = function(self)
		return ATMEDatas.C_Task_MT.className
	end,
	
	getParentClass = function(self)
		return ATMEDatas.C_Task_MT.parentClass
	end,
}

ATMEFct.C_Task_create = function(_name, _tasks, _taskID, _usedOnZoneOnly, _taskDatas, _filters)
	local newTask = {}

	setmetatable(newTask, ATMEDatas.C_Task_MT.mt)
	
	local name
	local tagsName
	
	if _name ~= nil and _tasks ~= nil then
		name = _name
		_tasks[name] = newTask
		tagsName = ATMEFct.decompString(_name)
	end
	
	local index = ATMEDatas.C_Task_MT:add(_taskID, _usedOnZoneOnly, _taskDatas, _filters)
	
	local localMembers = ATMEDatas.C_Task_MT:get(index)
	
	function newTask.getName(self)
		return name
	end
	
	function newTask.getIndex(self)
		return index
	end
	
	function newTask.setOptionalParameters(self, ...)
		local fctDefinition = ATMEFct.getErrorPrefix(newTask) .. "setOptionalParameters(...)"
		local err, usedOnZoneOnly, filters = ATMEFct.C_Task_setParams(localMembers.taskID, localMembers.datas, 2, ...)

		if err ~= nil then
			ATMEFct.errorOutputCore(nil, fctDefinition, err, false)
		end
	end
	
	function newTask.addStopCondition(self, _condition)
		local fctDefinition = ATMEFct.getErrorPrefix(newTask) .. "addStopCondition(condition)"
		
		if type(_condition) == "string" then
			local stopCondition = {}
			local tokens = ATMEFct.analyzeString(_condition)

			if #tokens == 2 then
				if tokens[1].type == "TOKEN_TYPE_TIME" then
					if (tokens[2].type == "TOKEN_INTEGER" or tokens[2].type == "TOKEN_TIME") and tokens[2].value > 0 then
						if tokens[2].status == "RELATIVE" then
							stopCondition.duration = tokens[2].value
						else
							stopCondition.time = tokens[2].value
						end
					else
						ATMEFct.errorOutputCore(nil, fctDefinition, "Parameter #2 must be integer or time value in string format condition", false)
						return
					end
				elseif tokens[1].type == "TOKEN_TYPE_WAYPOINT" then
					if tokens[2].type == "TOKEN_INTEGER" and tokens[2].value >= 0 then
						stopCondition.userFlag = tokens[2].value
					else
						ATMEFct.errorOutputCore(nil, fctDefinition, "Parameter #2 must be integer >= 0 in string format condition", false)
						return
					end
				else
					ATMEFct.errorOutputCore(nil, fctDefinition, "Bad string format condition", false)
					return
				end
			elseif #tokens == 3 then
				if tokens[1].type == "TOKEN_TYPE_FLAG" then
					stopCondition.userFlagValue = false
					if tokens[3].type == "TOKEN_INTEGER" and tokens[3].value >= 0 then
						if tokens[3].value > 0 then
							stopCondition.userFlagValue = true
						end
						
						if tokens[2].type == "TOKEN_INTEGER" and tokens[2].value > 0 then
							stopCondition.userFlag = string.format("%d", tokens[2].value)
						elseif tokens[2].type == "TOKEN_STRING" then
							stopCondition.userFlag = tokens[2].value
						else
							ATMEFct.errorOutputCore(nil, fctDefinition, "Parameter #2 must be integer > 0 in string format condition", false)
							return
						end
					else
						ATMEFct.errorOutputCore(nil, fctDefinition, "Parameter #3 must be integer > 0 or boolean in string format condition", false)
						return
					end
				else
					ATMEFct.errorOutputCore(nil, fctDefinition, "Bad string format condition", false)
					return
				end
			else
				ATMEFct.errorOutputCore(nil, fctDefinition, "Bad string format condition", false)
				return
			end
			
			localMembers.stopCondition = stopCondition
		else
			ATMEFct.errorOutputCore(nil, fctDefinition, "condition type must be string", true)
		end
	end
	
	function newTask.removeStopCondition(self)
		localMembers.stopCondition = nil
	end
	
	function newTask.addStartCondition(self,_condition)
		local fctDefinition = ATMEFct.getErrorPrefix(newTask) .. "addStartCondition(condition)"
		
		if type(_condition) == "string" then
			local startCondition = {}
			local tokens = ATMEFct.analyzeString(_condition)

			if #tokens == 2 then
				if tokens[1].type == "TOKEN_TYPE_TIME" then
					if (tokens[2].type == "TOKEN_INTEGER" or tokens[2].type == "TOKEN_TIME") and tokens[2].value > 0 then
						if tokens[2].status == "RELATIVE" then
							ATMEFct.errorOutputCore(nil, fctDefinition, "Parameter #2 must be an absolute time value", false)
							return
						else
							startCondition.time = tokens[2].value
						end
					else
						ATMEFct.errorOutputCore(nil, fctDefinition, "Parameter #2 must be integer or time value in string format condition", false)
						return
					end
				else
					ATMEFct.errorOutputCore(nil, fctDefinition, "Bad string format condition", false)
					return
				end
			elseif #tokens == 3 then
				if tokens[1].type == "TOKEN_TYPE_FLAG" then
					startCondition.userFlagValue = false
					if tokens[3].type == "TOKEN_INTEGER" and tokens[3].value >= 0 then
						if tokens[3].value > 0 then
							startCondition.userFlagValue = true
						end
						
						if tokens[2].type == "TOKEN_INTEGER" and tokens[2].value > 0 then
							startCondition.userFlag = string.format("%d", tokens[2].value)
						elseif tokens[2].type == "TOKEN_STRING" then
							startCondition.userFlag = tokens[2].value
						else
							ATMEFct.errorOutputCore(nil, fctDefinition, "Parameter #2 must be integer > 0 in string format condition", false)
							return
						end
					else
						ATMEFct.errorOutputCore(nil, fctDefinition, "Parameter #3 must be integer > 0 or boolean in string format condition", false)
						return
					end
				else
					ATMEFct.errorOutputCore(nil, fctDefinition, "Bad string format condition", false)
					return
				end
			else
				ATMEFct.errorOutputCore(nil, fctDefinition, "Bad string format condition", false)
				return
			end
			
			localMembers.startCondition = startCondition
		else
			ATMEFct.errorOutputCore(nil, fctDefinition, "condition type must be string", true)
		end
	end
	
	function newTask.removeStartCondition(self)
		localMembers.startCondition = nil
	end
	
	function newTask.tagGetByID(self, _position)
		local fctDefinition = ATMEFct.getErrorPrefix(newTask) .. "tagGetByID(position)"
		
		if type(_position) == "number" then
			local pos = math.floor(_position)
			if tagsName ~= nil and pos >= 1 and pos <= #tagsName then
				return tagsName[pos]
			end
		else
			ATMEFct.errorOutputCore(nil, fctDefinition, "position type must be number", true)
		end
	end
	
	function newTask.tagGetCount(self)
		if tagsName ~= nil then
			return #tagsName
		else
			return 0
		end
	end
	
	function newTask.tagCompare(self, _tagsToCompare)
		local fctDefinition = ATMEFct.getErrorPrefix(newTask) .. "tagCompare(tagsToCompare)"
		
		if type(_tagsToCompare) == "string" then
			if tagsName ~= nil then
				local ok = ATMEFct.compareTags(tagsName, _tagsToCompare)
				
				if ok ~= nil then
					return ok
				else
					ATMEFct.errorOutputCore(nil, fctDefinition, "tagsToCompare format must be 'T1|T2|..|Tn'", false)
				end
			else
				return false
			end
		else
			ATMEFct.errorOutputCore(nil, fctDefinition, "tagsToCompare type must be string", true)
		end
	end
	
	
	return newTask
end

setmetatable(ATME.C_Task,ATMEDatas.C_Task_MT)

ATMEDatas.C_Task_MT.__call = function(t, _task, ...)
	local fctDefinition = "Constructor ATME.C_Task(task, ...)"
	
	if type(_task) == "string" then
		local taskDatas = {}
		
		local err, usedOnZoneOnly, filters = ATMEFct.C_Task_setParams(_task, taskDatas, 1, ...)
		
		if err == nil then
			return ATMEFct.C_Task_create(nil, nil, _task, usedOnZoneOnly, taskDatas, filters)
		else
			ATMEFct.errorOutputCore(nil, fctDefinition, err, false)
		end
	else
		if type(_task) ~= "string" then
			ATMEFct.errorOutputCore(nil, fctDefinition, "task type must be string", false)
		end
	end
end

ATMEDatas.C_Task_MT.mt.__metatable = "Private"
ATMEDatas.C_Task_MT.mt.__index = ATME.C_Task
ATMEDatas.C_Task_MT.mt.__newindex = function(t, k, v)
	if ATMEDatas.C_Task_MT.keys[k] ~= nil then 
		rawset(t, k, v)
	else
		ATMEFct.errorOutputCore(nil, "Function ATME.C_Task : Bad key " .. k, "table locked", false)
	end
end

-----------------------------------------------------------------------------------------------------------
-- Classe ATME.C_Route : gère la création dynamique de route composée de WP
--
-- ATTENTION : WP 0 dans l'éditeur de mission est waypoints[1] de cette classe avec les coordonnées de la
-- première unité du groupe.
-----------------------------------------------------------------------------------------------------------
-- Set option des AI
ATMEFct.C_setOption = function(_type, _option, _param)
	local optionName = string.upper(_option)

	if ATMEConst.optionAI[_type][optionName] ~= nil then
		local optionValue 
		local tokens
		local values = {}
		
		if type(_param) == "string" then
			tokens = ATMEFct.decompString(_param)
			optionValue = 0
			
			if #tokens ~= #ATMEConst.optionAI[_type][optionName].values.args then
				if #ATMEConst.optionAI[_type][optionName].values > 1 then
					return true, "Option '" .. _option .. "' : string value must have " .. #ATMEConst.optionAI[_type][optionName].values .. " tokens"
				else
					return true, "Option '" .. _option .. "' : string value must have 1 token"
				end
			end
		end
		
		for _i, _item in ipairs(ATMEConst.optionAI[_type][optionName].values.args) do
			if tokens ~= nil then -- Si ok string
				if _item.fct ~= nil then
					local values = ATMEAIIndFct[_item.fct](tokens[_i])
					local value = ATMEFct.testDatas(values[1], _item)
					
					if value ~= nil then
						optionValue = optionValue + value
					else
						return true, "Option '" .. _option .. " : string value token '" .. tokens[_i] .. "' - Bad value"
					end
				else
					local value = ATMEFct.testDatas(tokens[_i], _item)
					if value ~= nil then
						optionValue = optionValue + value
					else
						return true, "Option '" .. _option .. " : string value token '" .. tokens[_i] .. "' - Bad value"
					end
				end
			elseif type(_param) == _item.type then  -- Number ou Boolean uniquement
				if _item.fct ~= nil then
					local values = ATMEAIIndFct[_item.fct](_param)
					local value = ATMEFct.testDatas(values[1], _item)
					
					if value ~= nil then
						optionValue =  value
					else
						if type(_param) == "number" then
							return true, "Option '" .. _option .. " : number value " .. _param .. " - Bad value"
						end
					end
				else
					local value = ATMEFct.testDatas(_param, _item)
					if value ~= nil then
						optionValue = value
					else
						if type(_param) == "number" then
							return true, "Option '" .. _option .. " : number value " .. _param .. " - Bad value"
						end
					end
				end
			else
				return true, "Value : Bad type"
			end
		end
		
		if ATMEConst.optionAI[_type][optionName].values.validFct ~= nil then
			local values = ATMEAIIndFct[ATMEConst.optionAI[_type][optionName].values.validFct](optionValue)
			
			if values[1] ~= nil then
				return true, "Option '" .. _option .. " : string value '" .. _param .. "' not allowed"
			end
		end	
		
		return false, optionName, optionValue
	else
		return true, "Option '" .. _option .. "' doesn't exist"
	end
end

ATMEFct.C_Route_getWaypointPosition = function(_route, _position)
	local localMembers = ATMEDatas.C_Route_MT:get(_route:getIndex())
	local surfaceFilter = "EARTH"
	local inWater = false
	local position
	
	if localMembers.type == "ship" then
		surfaceFilter = "WATER"
		inWater = true
	elseif localMembers.type == "plane" or  localMembers.type == "helicopter" then
		surfaceFilter = "ALL"
	end
	
	if ATME.isPoint(_position) ~= POINT_BAD then
		position = ATME.convertToPoint3D(_position)
		
		if surfaceFilter ~= "ALL" and ATME.isSurfaceWater(position) ~= inWater then
			return true, "Bad surface for position"
		end
	elseif type(_position) == "string" then
		local zone = ATME.getDCSZone(_position)
		
		if zone ~= nil then
			local tempArea = ATME.C_Area()
			
			tempArea:add(_position)
			position = tempArea
		else
			return true, "DCS zone " .. _position .. " unknown"
		end
	else
		if _position:getCount() > 0 then
			position = _position
		else
			return true, "Area without zones"
		end
	end
	
	return false, position, surfaceFilter
end								

ATMEFct.C_Route_createWaypoints = function(_route)
	local localMembers = ATMEDatas.C_Route_MT:get(_route:getIndex())

	if localMembers.waypoints == nil or localMembers.forced == true then
		localMembers.waypoints = {}
		if #localMembers.initWP > 0 then
			
			for _index, _initWP in ipairs(localMembers.initWP) do
				local absPoint
				
				if _initWP.type ~= "WAYPOINT" then
					if _initWP.position ~= nil then
						local position = _initWP.position:getRandomPosition(_initWP.surfaceFilter)

						absPoint = {
							x = position.x,
							y = _initWP.alt,
							z = position.z,
						}
					else
						local point = {
							x = _initWP.x,
							y = _initWP.alt,
							z = _initWP.y,
						}
						
						if _initWP.isRelative == true then
							if _initWP.unitName ~= nil and ATMEDatas.allAIUnitsAndPlayers[_initWP.unitName] ~= nil then
								-- Evaluation des positions relatives
								absPoint = ATME.coordLocalToDCS(point, ATMEDatas.allAIUnitsAndPlayers[_initWP.unitName], ATMEDatas.allAIUnitsAndPlayers[_initWP.unitName]:getAzimuth())
							end
						else
							absPoint = point
						end
					end
					
					local minAlt = absPoint.y
					if absPoint.y ~= nil then
						minAlt = ATME.getSurfaceAltitude({x = absPoint.x, y = absPoint.z}) + 500
					
						if absPoint.y > minAlt then
							minAlt = absPoint.y
						end
					end

					local speedLocked = false
					if _index == 1 then
						speedLocked = true
					end

					table.insert(localMembers.waypoints, {
												x = absPoint.x,
												y = absPoint.z,
												alt = minAlt,
												name = _initWP.name,
												speed = _initWP.speed,
												speed_locked = speedLocked,
												alt_type = "BARO",
												ETA = 0,
												ETA_locked = false,
												type = _initWP.typeWP,
												action = _initWP.action,
												helipadId = _initWP.helipadId,
												airdromeId = _initWP.airdromeId,
												task = {
													["id"] = "ComboTask",
													["params"] = 
													{
														["tasks"] = 
														{
														},
													},
												},
												properties = {
													["vnav"] = 1,
													["scale"] = 0,
													["angle"] = 0,
													["vangle"] = 0,
													["steer"] = 2,
												},
												formation_template = "",
												})
				else
					table.insert(localMembers.waypoints, ATMEFct.copyTable(_initWP.datas))
				end
				
				for _, _task in ipairs(_initWP.tasks) do
					table.insert(localMembers.waypoints[#localMembers.waypoints].task.params.tasks, _task)
				end
			end
			
			if #localMembers.waypoints == 0 then
				return true
			end
		else
			return true
		end
	end

	local waypoints = {}
	
	for _i, _waypoint in ipairs(localMembers.waypoints) do
		table.insert(waypoints, _waypoint)
	end
	
	return false, waypoints
end

ATMEFct.C_Route_addCurrentPositionWaypoint = function(_waypoints, _actualWaypoint, _ATMEGroup)
	local waypoint = ATMEFct.copyTable(_actualWaypoint)
	
	local units = _ATMEGroup:getUnits()
	local minHDistance = -1
	local name
	local altitude
	
	for _id, _unit in pairs(units) do
		local pos = _unit:getPosition()
		local v = ATMEFct.C_Vector3D_create(nil, nil, _waypoints[1], pos)
		
		if minHDistance < 0 or minHDistance > v:getHModule() then
			minHDistance = v:getHModule()
			name = _id
			altitude = pos.y
		end
	end
	
	local line = ATMEFct.C_Line2D_create(nil, nil, units[name]:getPosition(), _waypoints[1])

	if line ~= nil then
		local pt = line:getPointFromOrigin(20)
		
		waypoint.x = pt.x
		waypoint.y = pt.z
	end
	
	waypoint.alt = altitude

	table.insert(_waypoints, 1, waypoint)
end


ATMEDatas.C_Route_MT = {
	className = "C_Route",
	mt = {},
	
	keys = {
		["addRampHotWaypoint"] = true,
		["addRampWaypoint"] = true,
		["addUnitRelativePolarWaypoint"] = true,
		["addAbsoluteWaypoint"] = true,
		["addLandingWaypoint"] = true,
		["addTaskToWaypoint"] = true,
		["addOptionToWaypoint"] = true,
		["setNameToWaypoint"] = true,
		["getIndex"] = true,
		["addWaypointsFrom"] = true,
		["addInitialWaypointsFrom"] = true,
		["removeAllWaypoints"] = true,
		["getNbWaypoints"] = true,
	},
	
	localMembers = ATMEFct.C_IndexList_create(),
	
	add = function(self, _type, _forced)
		local item = {
			initWP = {},
			waypoints = nil,
			type = _type,
			forced = _forced,
		}
		
		return self.localMembers:add(item)
	end,
	
	remove = function(self, _id)
		self.localMembers:get(_id).initWP = nil
		self.localMembers:get(_id).waypoints = nil
		self.localMembers:remove(_id)
	end,
	
	get = function(self, _id)
		return self.localMembers:get(_id)
	end,
	
	pairs = function(self)
		return self.localMembers:pairs()
	end,
}

ATME.C_Route = {
	getClassName = function(self)
		return ATMEDatas.C_Route_MT.className
	end,
	
	getParentClass = function(self)
		return ATMEDatas.C_Route_MT.parentClass
	end,
}

ATMEFct.C_Route_create = function(_type, _forced)	
	local newRoute = {}
	
	setmetatable(newRoute, ATMEDatas.C_Route_MT.mt)
	
	
	local index = ATMEDatas.C_Route_MT:add(_type, _forced)
	local localMembers = ATMEDatas.C_Route_MT:get(index)
	local landingWaypointExist = false
	
	local function addInitWP(_fctDefinition, _unit, _datas, _copy)
		local newPoint

		if _copy == false then
			if _unit == nil then
				newPoint = {
					type = "POINT",
					isRelative = false,
					x = _datas.x,
					y = _datas.y,
					speed = _datas.speed,
					alt = _datas.altitude,
					typeWP = _datas.typeWP,
					position = _datas.position,
					surfaceFilter = _datas.surfaceFilter,
				}
			else			
				newPoint = {
					type = "POINT",
					isRelative = true,
					x = _datas.x,
					y = _datas.y,
					alt = _datas.altitude,
					speed = _datas.speed,
					typeWP = _datas.typeWP,
					unitName = _unit:getName(),
				}
			end

			if _datas.typeWP == "Turning Point" then
				if _datas.action == nil then
					newPoint.action = "Turning Point"
					if localMembers.type == "vehicle" then
						newPoint.action = "Off Road"
					elseif localMembers.type == "ship" then
						newPoint.action = "Turning Point"
					end
				else
					newPoint.action = _datas.action
				end
			elseif _datas.typeWP == "Land" or _datas.typeWP == "TakeOffHotParking" or _datas.typeWP == "TakeOffParking" then
				if _datas.typeWP == "Land" then
					newPoint.action = "Landing"
				else
					newPoint.action = "From Parking Area"
				end
				
				local _, airdromeId, helipadId = _datas.airbase:getID()
				newPoint.airdromeId = airdromeId
				newPoint.helipadId = helipadId
			end
			
			newPoint.name = ""
			newPoint.tasks = {}
		else
			newPoint = {
				type = "WAYPOINT",
				datas = _datas,
				tasks = {},
			}
		end
		
		-- On retourne le numéro du waypoint qui débute à 0
		table.insert(localMembers.initWP, newPoint)
		return #localMembers.initWP - 1
	end		

	local function addWPFrom(_groupName, _originalWP, _reference, _withTask)
		local waypoints, typeRoute = ATMEFct.C_CloningContext_getInitialWaypointsAndType(_groupName, _originalWP)

		if waypoints ~= nil then		
			if localMembers.type == typeRoute then
				ATMEFct.C_CloningContext_startRouteAt(waypoints, _reference, 0)
				
				if #waypoints > 0 then
					if waypoints[1].type == "TakeOffParking" or waypoints[1].type == "TakeOffParkingHot" or waypoints[1].type == "TakeOff" then
						if #localMembers.initWP ~= 0 then
							return true, "can't add a takeoff waypoint after existing waypoints"
						end
					elseif waypoints[#waypoints].type == "Land" then
						if landingWaypointExist == true then
							return true, "can't add a new waypoint after a landing waypoint"
						end
					end
					
					local first
					local last
					for _, _waypoint in ipairs(waypoints) do
						if _withTask == false then
							_waypoint.task = {
								["id"] = "ComboTask",
								["params"] = {
									["tasks"] = {
									},
								},
							}
						end
						if first == nil then
							first = addInitWP(fctDefinition, nil, _waypoint, true)
							last = first
						else
							last = addInitWP(fctDefinition, nil, _waypoint, true)
						end
					end
					
					return false, first, last
				else
					ATMEFct.setError("NO_COPY")
					return false
				end
			else
				return true, _groupName .. " type and route type are different"
			end
		else
			return true, _groupName .. " doesn't exist"
		end
	end
	
	local function analyzeAltitudeAction(_typeRoute, ...)
		local args = {...}
		local altitude = 0
		local action
		local err
		
		if type(args[1]) == "number" then
			altitude = math.floor(args[1])
			if type(args[2]) == "string" then
				if ATMEConst.WPActions[_typeRoute][args[2]] ~= nil then
					action = ATMEConst.WPActions[_typeRoute][args[2]]
				else
					err = "action must be a correct value. See doc for further informations"
				end
			elseif args[2] ~= nil then
				err = "action type must be nil or string"
			end
		elseif type(args[1]) == "string" then
			if ATMEConst.WPActions[_typeRoute][args[1]] ~= nil then
				action = ATMEConst.WPActions[_typeRoute][args[1]]
			else
				err = "action must be a correct value. See doc for further informations"
			end
		elseif args[1] ~= nil then
			err = "altitude type must be nil or number"
		end

		return err, altitude, action
	end
	
	function newRoute.getIndex(self)
		return index
	end
	
	function newRoute.removeAllWaypoints(self)
		localMembers.initWP = {}
		localMembers.waypoints = nil
		landingWaypointExist = false
	end
	
	function newRoute.addUnitRelativePolarWaypoint(self, _unit, _azimuth, _distance, _speed, ...)
		local fctDefinition = ATMEFct.getErrorPrefix(newRoute) .. "addUnitRelativePolarWaypoint(unit, azimuth, distance, speed)\nddUnitRelativePolarWaypoint(unit, azimuth, distance, speed, altitude)\nddUnitRelativePolarWaypoint(unit, azimuth, distance, speed, action)\nddUnitRelativePolarWaypoint(unit, azimuth, distance, speed, altitude, action)"
		
		if landingWaypointExist == false then
			if ATME.isObjectClass(_unit, ATME.C_Unit) == true and type(_azimuth) == "number" and type(_distance) == "number" and 
					type(_speed) == "number" then
				
				local err, altitude, action = analyzeAltitudeAction(localMembers.type, ...)

				if err == nil then
					local speed = math.floor(_speed)
					if speed > 0 then
						if altitude == nil or altitude >= 0 then
							local azimuth = math.fmod(_azimuth, 360)
					
							if azimuth < 0 then 
								azimuth = azimuth + 360
							end
							
							local azimuthRad =  math.rad(azimuth)
							
							local point = {
								x = _distance * math.cos(azimuthRad),
								y = _distance * math.sin(azimuthRad),
							}
							
							local datas = {
								x = point.x,
								y = point.y,
								speed = speed,
								altitude = altitude,
								typeWP = "Turning Point",
								action = action,
							}
							
							return addInitWP(fctDefinition, _unit, datas, false)
						else
							ATMEFct.errorOutputCore(nil, fctDefinition, "altitude must be >= 0", false)
						end
					else
						ATMEFct.errorOutputCore(nil, fctDefinition, "speed must be > 0", false)
					end
				else
					ATMEFct.errorOutputCore(nil, fctDefinition, err, false)
				end
			else
				if ATME.isObjectClass(_unit, ATME.C_Unit) == false then
					ATMEFct.errorOutputCore(nil, fctDefinition, "unit type must be ATME.C_AIUnit or ATME.C_Player", true)
				elseif type(_azimuth) ~= "number" then 
					ATMEFct.errorOutputCore(nil, fctDefinition, "azimuth type must be number", false)
				elseif type(_distance) ~= "number" then
					ATMEFct.errorOutputCore(nil, fctDefinition, "distance type must be number", false)
				elseif type(_speed) ~= "number" then
					ATMEFct.errorOutputCore(nil, fctDefinition, "speed type must be number", false)
				end
			end
		else
			ATMEFct.errorOutputCore(nil, fctDefinition, "can't add a new waypoint after a landing waypoint", false)
		end
	end
	
	function newRoute.addAbsoluteWaypoint(self, _position, _speed, ...)
		local fctDefinition = ATMEFct.getErrorPrefix(newRoute) .. "addAbsoluteWaypoint(position, speed)\naddAbsoluteWaypoint(position, speed, altitude)\naddAbsoluteWaypoint(position, speed, action)\naddAbsoluteWaypoint(position, speed, altitude, action)"
		
		if landingWaypointExist == false then
			if (ATME.isPoint(_position) ~= POINT_BAD or type(_position) == "string" or ATME.isObjectClass(_position, ATME.C_Area) == true) and 
					type(_speed) == "number" then
					
				local err, altitude, action = analyzeAltitudeAction(localMembers.type, ...)
				
				if err == nil then
					local err1, position, surfaceFilter = ATMEFct.C_Route_getWaypointPosition(self, _position)
					
					if err1 == false then
						local speed = math.floor(_speed)
						if speed >= 0 then
							if altitude == nil or altitude >= 0 then
								local datas
								
								if ATME.isPoint(position) ~= POINT_BAD then
									datas = {
										x = position.x,
										y = position.z,
										speed = speed,
										altitude = altitude,
										typeWP = "Turning Point",
										action = action,
									}
								else
									datas = {
										speed = speed,
										altitude = altitude,
										typeWP = "Turning Point",
										position = position,
										surfaceFilter = surfaceFilter,
										action = action,
									}
								end
								
								return addInitWP(fctDefinition, nil, datas, false)
							else
								ATMEFct.errorOutputCore(nil, fctDefinition, "altitude must be >= 0", false)
							end
						else
							ATMEFct.errorOutputCore(nil, fctDefinition, "speed must be >= 0", false)
						end
					else
						ATMEFct.errorOutputCore(nil, fctDefinition, position, false)
					end
				else
					ATMEFct.errorOutputCore(nil, fctDefinition, err, false)
				end
			else
				if ATME.isPoint(_position) == POINT_BAD and type(_position) ~= "string" and ATME.isObjectClass(_position, ATME.C_Area) == false then
					ATMEFct.errorOutputCore(nil, fctDefinition, "position type must be string or table (x,y) or (x,y,z) or ATME.C_Area", true)
				elseif type(_speed) ~= "number" then
					ATMEFct.errorOutputCore(nil, fctDefinition, "speed type must be number", false)
				end
			end
		else
			ATMEFct.errorOutputCore(nil, fctDefinition, "can't add a new waypoint after a landing waypoint", false)
		end
	end
	
	function newRoute.addRampWaypoint(self, _name)
		local fctDefinition = ATMEFct.getErrorPrefix(newRoute) .. "addRampWaypoint(name)"
		
		if #localMembers.initWP == 0 then
			if localMembers.type == "plane" or localMembers.type == "helicopter" then
				if type(_name) == "string" then
					if ATMEDatas.airbases[_name] ~= nil then
						local point = ATMEDatas.airbases[_name]:getPosition()
						
						local datas = {
							x = point.x,
							y = point.z,
							altitude = point.y,
							typeWP = "TakeOffParking",
							airbase = ATMEDatas.airbases[_name],
						}
							
						return addInitWP(fctDefinition, nil, datas, false)
					else
						ATMEFct.errorOutputCore(nil, fctDefinition, "Airbase " .. _name .. " doesn't exist", false)
					end
				else
					ATMEFct.errorOutputCore(nil, fctDefinition, "name type must be string", true)
				end
			else
				ATMEFct.errorOutputCore(nil, fctDefinition, "reserved to 'AIRPLANE' or 'HELICOPTER' route", false)
			end
		else
			ATMEFct.errorOutputCore(nil, fctDefinition, "can't add a takeoff waypoint after existing waypoints", false)
		end
	end
	
	function newRoute.addRampHotWaypoint(self, _name)
		local fctDefinition = ATMEFct.getErrorPrefix(newRoute) .. "addRampHotWaypoint(name)"
		
		if #localMembers.initWP == 0 then
			if localMembers.type == "plane" or localMembers.type == "helicopter" then
				if type(_name) == "string" then
					if ATMEDatas.airbases[_name] ~= nil then
						local point = ATMEDatas.airbases[_name]:getPosition()
						
						local datas = {
							x = point.x,
							y = point.z,
							altitude = point.y,
							typeWP = "TakeOffParkingHot",
							airbase = ATMEDatas.airbases[_name],
						}
							
						return addInitWP(fctDefinition, nil, datas, false)
					else
						ATMEFct.errorOutputCore(nil, fctDefinition, "Airbase " .. _name .. " doesn't exist", false)
					end
				else
					ATMEFct.errorOutputCore(nil, fctDefinition, "name type must be string", true)
				end
			else
				ATMEFct.errorOutputCore(nil, fctDefinition, "reserved to 'AIRPLANE' or 'HELICOPTER' route", false)
			end
		else
			ATMEFct.errorOutputCore(nil, fctDefinition, "can't add a takeoff waypoint after existing waypoints", false)
		end
	end
	
	function newRoute.addLandingWaypoint(self, _name)
		local fctDefinition = ATMEFct.getErrorPrefix(newRoute) .. "addLandingWaypoint(name)"
		
		if landingWaypointExist == false then
			if localMembers.type == "plane" or localMembers.type == "helicopter" then
				if type(_name) == "string" then
					if ATMEDatas.airbases[_name] ~= nil then
						local point = ATMEDatas.airbases[_name]:getPosition()
						
						local datas = {
							x = point.x,
							y = point.z,
							altitude = point.y,
							typeWP = "Land",
							airbase = ATMEDatas.airbases[_name],
						}
						
						landingWaypointExist = true
							
						return addInitWP(fctDefinition, nil, datas, false)
					else
						ATMEFct.errorOutputCore(nil, fctDefinition, "Airbase " .. _name .. " doesn't exist", false)
					end
				else
					ATMEFct.errorOutputCore(nil, fctDefinition, "name type must be string", true)
				end
			else
				ATMEFct.errorOutputCore(nil, fctDefinition, "reserved to 'AIRPLANE' or 'HELICOPTER' route", false)
			end
		else
			ATMEFct.errorOutputCore(nil, fctDefinition, "can't add a new waypoint after a landing waypoint", false)
		end
	end
	
	function newRoute.addWaypointsFrom(self, _groupName, ...)
		local fctDefinition = ATMEFct.getErrorPrefix(newRoute) .. "addWaypointsFrom(groupName, [reference])\naddWaypointsFrom(groupName, withTask, [reference])"
		local args = {...}
		
		if type(_groupName) == "string" then
			local withTask = false
			local reference = 0
			
			
			if #args > 0 then
				local index = 1
				if type(args[1]) == "boolean" then
					withTask = args[1]
					index = index + 1
				end
				
				if args[index] == nil or ATME.isObjectClass(args[index], ATME.C_Unit) == true or ATME.isObjectClass(args[index], ATME.C_StaticObject) == true or
					ATME.isPoint(args[index]) ~= POINT_BAD or type(args[index]) == "string" or type(args[index]) == "number" then
				
					if args[index] ~= nil then
						reference = args[index]
						if type(args[index]) == "number" then
							reference = math.floor(args[index])
							
							if reference < 0 then
								ATMEFct.errorOutputCore(nil, fctDefinition, "reference must be >= 0 if number", false)
								return
							end
						end
					end
				else
					ATMEFct.errorOutputCore(nil, fctDefinition, "reference type must be nil or string or number or table (x,y) or (x,y,z) or ATME.C_AIUnit or ATME.C_Player or ATME.C_StaticObject", false)
					return
				end
			end
			
			local err, first, last = addWPFrom(_groupName, false, reference, withTask)

			if err == false then
				return first, last
			else
				ATMEFct.errorOutputCore(nil, fctDefinition, first, false)
			end
		else
			ATMEFct.errorOutputCore(nil, fctDefinition, "groupName type must be string", true)
		end
	end
	
	function newRoute.addInitialWaypointsFrom(self, _groupName, ...)
		local fctDefinition = ATMEFct.getErrorPrefix(newRoute) .. "addInitialWaypointsFrom(groupName, [reference])\naddInitialWaypointsFrom(groupName, withTask, [reference])"
		local args = {...}
		
		if type(_groupName) == "string" then
			local withTask = false
			local reference = 0
			
			
			if #args > 0 then
				local index = 1
				if type(args[1]) == "boolean" then
					withTask = args[1]
					index = index + 1
				end
				
				if args[index] == nil or ATME.isObjectClass(args[index], ATME.C_Unit) == true or ATME.isObjectClass(args[index], ATME.C_StaticObject) == true or
					ATME.isPoint(args[index]) ~= POINT_BAD or type(args[index]) == "string" or type(args[index]) == "number" then
				
					if args[index] ~= nil then
						reference = args[index]
						if type(args[index]) == "number" then
							reference = math.floor(args[index])
							
							if reference < 0 then
								ATMEFct.errorOutputCore(nil, fctDefinition, "reference must be >= 0 if number", false)
								return
							end
						end
					end
				else
					ATMEFct.errorOutputCore(nil, fctDefinition, "reference type must be nil or string or number or table (x,y) or (x,y,z) or ATME.C_AIUnit or ATME.C_Player or ATME.C_StaticObject", false)
					return
				end
			end

			local err, first, last = addWPFrom(_groupName, true, reference, withTask)

			if err == false then
				return first, last
			else
				ATMEFct.errorOutputCore(nil, fctDefinition, first, false)
			end
		else
			ATMEFct.errorOutputCore(nil, fctDefinition, "groupName type must be string", true)
		end
	end
	
	function newRoute.setNameToWaypoint(self, _numWaypoint, _name)
		local fctDefinition = ATMEFct.getErrorPrefix(newRoute) .. "setNameToWaypoint(numWaypoint, name)"
		
		if type(_numWaypoint) == "number" and type(_name) == "string" then
			local numWaypoint = math.floor(_numWaypoint) + 1
			if numWaypoint > 0 and numWaypoint <= #localMembers.initWP then
				localMembers.initWP[numWaypoint].name = _name
			end
		else
			if type(_numWaypoint) ~= "number" then
				ATMEFct.errorOutputCore(nil, fctDefinition, "numWaypoint type must be number", true)
			elseif type(_name) ~= "string" then
				ATMEFct.errorOutputCore(nil, fctDefinition, "name type must be string", false)
			end
		end
	end
	
	function newRoute.getNbWaypoints(self)
		return #localMembers.initWP
	end
	
	function newRoute.addTaskToWaypoint(self, _numWaypoint, _task)
		local fctDefinition = ATMEFct.getErrorPrefix(newRoute) .. "addTaskToWaypoint(numWaypoint, task)"
		
		if type(_numWaypoint) == "number" and ATME.isObjectClass(_task, ATME.C_Task) == true then
			local numWaypoint = math.floor(_numWaypoint) + 1
			if numWaypoint > 0 and numWaypoint <= #localMembers.initWP then
				local ok, usedOnZoneOnly, taskDatas = ATMEFct.C_Task_getTaskDatas(_task, localMembers.type, true)
				if ok == true then
					if usedOnZoneOnly == false then
						table.insert(localMembers.initWP[numWaypoint].tasks, taskDatas)
					else
						ATMEFct.errorOutputCore(nil, fctDefinition, "Task '" .. taskDatas.id .. "' is initialized to be set on zone", false)
					end
				else
					ATMEFct.errorOutputCore(nil, fctDefinition, "Task '" .. taskDatas.id .. "' is not allow for this route type", false)
				end	
			else
				ATMEFct.errorOutputCore(nil, fctDefinition, "Bad waypoint number", false)
			end
		else
			if type(_numWaypoint) ~= "number" then
				ATMEFct.errorOutputCore(nil, fctDefinition, "numWaypoint type must be number", true)
			elseif ATME.isObjectClass(_task, ATME.C_Task) == false then
				ATMEFct.errorOutputCore(nil, fctDefinition, "task type must be ATME.C_Task", false)
			end
		end
	end
	
	function newRoute.addOptionToWaypoint(self, _numWaypoint, _option, _value)
		local fctDefinition = ATMEFct.getErrorPrefix(newRoute) .. "addOptionToWaypoint(numWaypoint, option, value)"
		
		if type(_numWaypoint) == "number" and type(_option) == "string" and _value ~= nil then
			local numWaypoint = math.floor(_numWaypoint) + 1
			if numWaypoint > 0 and numWaypoint <= #localMembers.initWP then
				local err, option, optionValue = ATMEFct.C_setOption(localMembers.type, _option, _value) 

				if err == false then
					ATMEFct.outputCore(nil, "id = " .. option .." - optionValue = ".. optionValue,2)
					local taskDatas = {
						["id"] = "WrappedAction",		   
						["params"] = {
							["action"] = 
							{
								["id"] = "Option",
								["params"] = 
								{
									["value"] = optionValue,
									["name"] = option,
								},
							},
						},
					}
					table.insert(localMembers.initWP[numWaypoint].tasks, taskDatas)
				else
					ATMEFct.errorOutputCore(nil, fctDefinition, option, false)
				end
			else
				ATMEFct.errorOutputCore(nil, fctDefinition, "Bad waypoint number", false)
			end
		else
			if type(_numWaypoint) ~= "number" then
				ATMEFct.errorOutputCore(nil, fctDefinition, "numWaypoint type must be number", true)
			elseif type(_option) ~= "string" then
				ATMEFct.errorOutputCore(nil, fctDefinition, "option type must be string", false)
			elseif _value == nil then
				ATMEFct.errorOutputCore(nil, fctDefinition, "value type can't be nil", false)
			end
		end
	end
	
	return newRoute
end

setmetatable(ATME.C_Route,ATMEDatas.C_Route_MT)

ATMEDatas.C_Route_MT.__call = function(t, _typeRoute, _rebuild)
	local fctDefinition = "Constructor ATME.C_Route(typeRoute, [rebuild])"
		
	if type(_typeRoute) == "string" and (_rebuild == nil or type(_rebuild) == "boolean") then
		if ATMEConst.categoryNameFilters[_typeRoute] ~= nil then
			local rebuild = _rebuild
			if rebuild == nil then
				rebuild = false
			end
			return ATMEFct.C_Route_create(ATMEConst.categoryNameFilters[_typeRoute], _rebuild)
		else
			ATMEFct.errorOutputCore(nil, fctDefinition, "type must be 'AIRPLANE', 'HELICOPTER', 'GROUND' or 'SHIP'", false)
		end
	else
		if type(_typeRoute) ~= "string" then
			ATMEFct.errorOutputCore(nil, fctDefinition, "typeRoute type must be string", false)
		elseif _rebuild ~= nil and type(_rebuild) ~= "boolean" then
			ATMEFct.errorOutputCore(nil, fctDefinition, "rebuild type must be il or boolean", false)
		end
	end
end


ATMEDatas.C_Route_MT.mt.__metatable = "Private"
ATMEDatas.C_Route_MT.mt.__index = ATME.C_Route
ATMEDatas.C_Route_MT.mt.__newindex = function(t, k, v)
	if ATMEDatas.C_Route_MT.keys[k] ~= nil then 
		rawset(t, k, v)
	else
		ATMEFct.errorOutputCore(nil, "Function ATME.C_Route : Bad key " .. k, "table locked", false)
	end
end

----------------------------------------------------------------------------------------------------------
-- Classe ATME.C_CloningContext : gère les données de clonage nécessaire à la duplication de groupes
--
-- Cette classe permet de gérer les chargements/déchargements d'unités d'un véhicule (voir load/unload)
-- des classes C_Player et C_AIUnit. Cette fonctionnalité n'est pas accessible aux autres modules
--
-- Cette classe offre également le spawn d'unités définie à partir d'un groupe existant.
-- Le spawn sera en échec si le groupe existe. 
-- Pour l'attribution des noms :
-- 		* Pour le nom des groupes : Si le nom n'existe pas dans la mission de base (donnée initiale) ni 
--		  dans les groupes existants (actifs), le nom est celui donnée à la construction du contexte de 
--		  de clonage. Sinon, le num sera postfixé avec " - Spawned #XXX". La valeur XXX est incrémentée 
--        automatiquement un nom de groupe particulier. Elle est comprise en 001 et 999. Si le groupe
--		  est détruit, cette valeur sera réutilisée par le prochain spawn.
--		* Pour les noms d'unités : Le nom d'unité dépend du groupe initial (défini dans la mission ou créé
--	      directement "from scratch"). En conséquence, le nom de l'unité existe dès le clonage, aussi tous
--        tous les noms d'unités clonées sont postfixée avec " - Spawned #XXX". La valeur XXX est incrémentée 
--        automatiquement un nom de l'unité particulière. Elle est comprise en 001 et 999. Si l'unité
--		  est détruite, cette valeur sera réutilisée par le prochain spawn.
--
-- Il est possible de construire un contexte de clonage à partir d'un groupe existants (actifs) ou défini initialement
-- dans la mission. Le nom du groupe à cloner sera alors une entrée pour le contexte de clonage.  Il est également
-- possible de construire un groupe "from scratch", l'entrée du contexte de clonage sera alors la table datas de 
-- DCS correctement renseignée.
--
-- Pour les waypoints : La modification d'une route initiale par la fonction setRoute de ATME.C_Group n'a aucun incidence
-- sur la route du nouveau groupe cloné. Le groupe cloné peut avoir :
--			- Par défaut : les WP définis initialement pour le groupe source du clonage.
--			- Une route spécifique définie par une instance de ATME.C_Route
----------------------------------------------------------------------------------------------------------
ATMEFct.C_CloningContext_controlTable = function(_WPGroup, _newGroupName)
	if ATMEConst.countries[_WPGroup.countryName] == nil or
		ATMEConst.categoryNameFilters[_WPGroup.typeName] == nil or
		_WPGroup.datas == nil or
		_WPGroup.datas.task == nil or _WPGroup.datas.tasks == nil then
		
		return false
	end
	
	if _WPGroup.datas.units == nil or type(_WPGroup.datas.units) ~= "table"  then
		_WPGroup.datas.units = {}
	end
	
	if (type(_WPGroup.datas.name) ~= "string" and type(_newGroupName) ~= "string") or type(_WPGroup.datas.tasks) ~= "table" then
		return false
	end
	
	for _, _unit in ipairs(_WPGroup.datas.units) do
		if type(_unit.name) ~= "string" then
			return false
		end
	end
	
	return true
end

ATMEFct.C_CloningContext_addUnit = function(_allGroupsInMissionItem, _unit, _newName, _initialNames, _initialType)
	local newName = _newName
	
	if newName == nil then
		newName = _unit.name
		
		if newName == nil then
			return true, "Group " .. _allGroupsInMissionItem.name .. " - New unit name is nil"
		end
	end
	
	if ATMEDatas.allAIUnitsInMission[newName] ~= nil then
		return true, "Unit " .. newName .. " exists in mission"
	end
	
	if _unit.skill ~= "Client" and _unit.skill ~= "Player" then
		local payload = _unit.payload
		
		if payload == nil and (_initialType == "plane" or _initialType == "helicopter") then
			payload = {
				["pylons"] = {},
			}
		end
		
		_allGroupsInMissionItem.units[newName] = {
			name = newName,
			row = #_initialNames.unitsName + 1,
			type = _unit.type,
			livery_id = _unit.livery_id,
			speed = _unit.speed,
			psi = _unit.psi,
			payload = payload,
			skill = _unit.skill,
			x = _unit.x,
			y = _unit.y,
			playerCanDrive = _unit.playerCanDrive,
			heading = _unit.heading,
			alt = _unit.alt,
			alt_type = _unit.alt_type,
			callsign = _unit.callsign,
			onboard_num = _unit.onboard_num,
			parking = _unit.parking,
			parking_id = _unit.parking_id,
		}
		
		table.insert(_initialNames.unitsName, newName)
		
		ATMEDatas.allAIUnitsInMission[newName] = {
			group = _allGroupsInMissionItem,
			unit = _allGroupsInMissionItem.units[newName],
		}
		
		return false
	else
		return true, "Group " .. _allGroupsInMissionItem.name .. " has one or more player units"
	end
end

ATMEFct.C_CloningContext_getInitialNames = function(_WPGroup)
	if type(_WPGroup) == "string" then
		if ATMEDatas.allGroupsInMission[_WPGroup] ~= nil then
			return nil, ATMEDatas.allInitialGroupNames[_WPGroup]
		elseif ATMEDatas.groups[_WPGroup] ~= nil then
			local localMembersGroup = ATMEDatas.C_Group_MT:get(ATMEDatas.groups[_WPGroup]:getIndex())
			
			return nil, localMembersGroup.spawnDatas.initialNames
		elseif ATMEDatas.groupsOnBoard[_WPGroup] ~= nil then
			return nil, ATMEDatas.groupsOnBoard[_WPGroup].spawnDatas.initialNames
		elseif ATMEDatas.groupsReadyToBirth[_WPGroup] ~= nil then
			return nil, ATMEDatas.groupsReadyToBirth[_WPGroup].spawnDatas.initialNames
		end
		
		return "Group " .. _WPGroup .. " not in mission"
	else
		if ATMEDatas.allGroupsInMission[_WPGroup.datas.name] == nil then
			if ATMEConst.categoryNameFilters[_WPGroup.typeName] ~= nil then
				local initialNames = {
					groupName = _WPGroup.datas.name,
					unitsName = {},
				}
				
				-- Pour ces groupes qui servent au spawn, le group ID n'est pas initialisé.
				-- Il le sera lors du spawn par la fonction addGroup.
				local allGroupsInMissionItem = {
					name = _WPGroup.datas.name,
					country = ATMEConst.countries[_WPGroup.countryName],
					coalition = coalition.getCountryCoalition(ATMEConst.countries[_WPGroup.countryName]),
					category = ATMEConst.groupCategories[ATMEConst.categoryNameFilters[_WPGroup.typeName]],
					type = ATMEConst.categoryNameFilters[_WPGroup.typeName],
					units = {},
					taskSelected = true,
					hidden = _WPGroup.datas.hidden,
					start_time = 0,
					task = _WPGroup.datas.task,
					tasks = _WPGroup.datas.tasks,
					radioSet = _WPGroup.datas.radioSet,
					modulation = _WPGroup.datas.modulation,
					frequency = _WPGroup.datas.frequency,
					communication = _WPGroup.datas.communication,
					waypoints = {},
				}

				for _, _unit in ipairs(_WPGroup.datas.units) do
					local err, value = ATMEFct.C_CloningContext_addUnit(allGroupsInMissionItem, _unit, nil, initialNames, ATMEConst.categoryNameFilters[_WPGroup.typeName])

					if err == true then
						return err, value
					end
				end
				
				if _WPGroup.datas.route ~= nil and _WPGroup.datas.route.points ~= nil and #_WPGroup.datas.route.points > 0 then
					for _pointNum, _point in ipairs(_WPGroup.datas.route.points) do
						allGroupsInMissionItem.waypoints[#allGroupsInMissionItem.waypoints + 1] = {
							name = _point.name,
							x = _point.x,
							y = _point.y,
							speed = _point.speed,
							speed_locked = _point.speed_locked,
							alt = _point.alt,
							alt_type = _point.alt_type,
							ETA = _point.ETA,
							ETA_locked = _point.ETA_locked,
							airdromeId = _point.airdromeId,
							helipadId = _point.helipadId,
							type = _point.type,
							action = _point.action,
							properties = _point.properties,
							formation_template = _point.formation_template,
						}
						
						if _point.task == nil then
							ATMEFct.C_CloningContext_setWaypointComboTask(allGroupsInMissionItem.waypoints[#allGroupsInMissionItem.waypoints])
						else
							allGroupsInMissionItem.waypoints[#allGroupsInMissionItem.waypoints].task = ATMEFct.copyTable(_point.task)
						end
					end
				end

				-- Préparation des données globales si tout est ok
				
				ATMEDatas.allGroupsInMission[_WPGroup.datas.name] = allGroupsInMissionItem
				ATMEDatas.allInitialGroupNames[_WPGroup.datas.name] = initialNames
				
				return nil, initialNames
			else
				return "Group " .. _WPGroup.datas.name .. " bad type name"
			end
		else
			return "Group " .. _WPGroup.datas.name .. " exists in mission"
		end
	end
end

ATMEFct.C_CloningContext_getInitialWaypointsAndType = function(_WPGroupName, _onlyInMission)
	local initialWaypoints
	local initialType
	
	if ATMEDatas.groups[_WPGroupName] ~= nil and _onlyInMission == false then
		local localMembersGroup = ATMEDatas.C_Group_MT:get(ATMEDatas.groups[_WPGroupName]:getIndex())
		initialWaypoints = localMembersGroup.spawnDatas.datas.route.points
		initialType = localMembersGroup.spawnDatas.type
	elseif ATMEDatas.allGroupsInMission[_WPGroupName] ~= nil then
		initialWaypoints = ATMEDatas.allGroupsInMission[_WPGroupName].waypoints
		initialType = ATMEDatas.allGroupsInMission[_WPGroupName].type
	end
	
	if initialWaypoints ~= nil then
		local waypoints = ATMEFct.C_CloningContext_copyAllWaypoints(initialWaypoints)

		return waypoints, initialType
	end
end

ATMEFct.C_CloningContext_getInitialWaypointFromID = function(_WPGroupName, _id)
	local initialWaypoints
	
	if ATMEDatas.groups[_WPGroupName] ~= nil then
		local localMembersGroup = ATMEDatas.C_Group_MT:get(ATMEDatas.groups[_WPGroupName]:getIndex())
		initialWaypoints = localMembersGroup.spawnDatas.datas.route.points
	elseif ATMEDatas.allGroupsInMission[_WPGroupName] ~= nil then
		initialWaypoints = ATMEDatas.allGroupsInMission[_WPGroupName].waypoints
	end
	
	if initialWaypoints ~= nil then
		local waypoint = initialWaypoints[_id]

		return waypoint
	end
end

ATMEFct.C_CloningContext_copyAllWaypoints = function(_waypoints)
	local newWaypoints = {}

	for _, _waypoint in ipairs(_waypoints) do
		table.insert(newWaypoints, ATMEFct.copyTable(_waypoint))
	end

	return newWaypoints
end

ATMEFct.C_CloningContext_setWaypointComboTask = function(_waypoint)
	if _waypoint.task == nil then
		_waypoint.task = {
			["id"] = "ComboTask",
			["params"] = {
				["tasks"] = {
				},
			},
		}
	end
end

ATMEFct.C_CloningContext_setTaskWaypointsTracking = function(_name, _waypoints)
	local offsetTaskWaypointTracking = {}
	
	for _i = 2, #_waypoints do
		ATMEFct.C_CloningContext_setWaypointComboTask(_waypoints[_i])
		local index = #_waypoints[_i].task.params.tasks + 1
		_waypoints[_i].task.params.tasks[index] = {
			["enabled"] = true,
			["auto"] = false,
			["id"] = "WrappedAction",
			["number"] = 1,
			["params"] = 
			{
				["action"] = 
				{
					["id"] = "Script",
					["params"] = 
					{
						["command"] = "ATME.onTrackWaypoints('" .. _name .. "'," .. _i - 1 .. ")",
					},
				},
			},
		}
		
		table.insert(offsetTaskWaypointTracking, index)
	end 
	
	return offsetTaskWaypointTracking
end

ATMEFct.C_CloningContext_deleteTaskWaypointsTracking = function(_offsetTaskWaypointTracking, _waypoints)
	while #_offsetTaskWaypointTracking > 0 do
		table.remove(_waypoints[#_offsetTaskWaypointTracking + 1].task.params.tasks, _offsetTaskWaypointTracking[#_offsetTaskWaypointTracking])
		table.remove(_offsetTaskWaypointTracking)
	end 
end


ATMEFct.C_CloningContext_setMission = function(_ATMEGroup, _waypoints, _trackingOk, _delayed)
	if _delayed == false and _ATMEGroup:isControlled() == true then
		local offsetTaskWaypointTracking
		if _trackingOk == true then
			offsetTaskWaypointTracking = ATMEFct.C_CloningContext_setTaskWaypointsTracking(_ATMEGroup:getName(), _waypoints)
		end
		
		local _task = { 
			id = 'Mission', 
			params = { 
				route = {
					points = _waypoints,
				}
			} 
		}
	
		local controller = _ATMEGroup:getDCSGroup():getController()

		controller:setTask(_task)
		
		if _trackingOk == true then
			ATMEFct.C_CloningContext_deleteTaskWaypointsTracking(offsetTaskWaypointTracking, _waypoints)
		end
	else
		local item = {
			name = _ATMEGroup:getName(),
			waypoints = _waypoints,
			delay = 2,
			trackingOk = _trackingOk,
			controlled = _ATMEGroup:isControlled(),
		}
		
		table.insert(ATMEDatas.missionsDelayed, item)
	end
end

ATMEFct.C_CloningContext_setWaypoints = function(_ATMEGroup, _waypoints, _isOnRoad, _trackingOk)
	local firstUnit = _ATMEGroup:getFirstUnit()
	
	if firstUnit ~= nil then
		-- On ajoute la position courante à la nouvelle route

		local newWP = ATMEFct.copyTable(_waypoints[1])
		newWP.x = firstUnit:getPosition().x
		newWP.y = firstUnit:getPosition().z
		
		if _waypoints[1].action == "On Road" and _isOnRoad == false then
			newWP.action = "Off Road"
		end
		
		table.insert(_waypoints, 1, newWP)
		
		ATMEFct.C_CloningContext_setMission(_ATMEGroup, _waypoints, _trackingOk, false)
	end
end

ATMEFct.C_CloningContext_getWaypointFromName = function(_waypoints, _name)
	local index = 0
	local name = string.upper(_name)
	
	for _i, _wp in ipairs(_waypoints) do
		if name == string.upper(_wp.name) then
			index = _i
		end
	end
	
	if index > 0 then
		return index - 1
	else
		return nil
	end
end

ATMEFct.C_CloningContext_startRouteAt = function(_waypoints, _reference, _radius)
	-- _radius défini la zone d'exclusion par rapport à la référence de type objet. Non pris en compte sinon.
	-- Dans ce cas, la route débutera au waypoint le plus proche de la référence, mais en excluant un cercle de rayon 
	-- _radius autour de la référence.
	-- Pour les autres cas, l'offset ou le nom du waypoint est recherché. S'il n'est pas trouvé, la route reste la 
	-- route par défaut

	local nbWaypointsInit = #_waypoints

	if type(_reference) == "string" then -- Relatif au nom du waypoint
		-- Si le nom n'est pas trouvé, il s'agira du premier waypoint (0 dans l'éditeur)
		local found = false
		local name = string.upper(_reference)
		local index = #_waypoints + 1
		while index > 1 and found == false do
			index = index - 1

			if name == string.upper(_waypoints[index].name) then
				found = true
			end
		end
		
		if found == true then
			for _i = 1, index - 1 do
				table.remove(_waypoints, 1)
			end
		end
	elseif type(_reference) == "number" then -- relatif au numéro de waypoint (début à 0 pour rappel)
		-- Si le numéro est plus grand que le dernier waypoint, il s'agira du dernier waypoint.
		if _reference >= 0 and _reference <= #_waypoints then
			local nb = _reference
			while nb > 0 do 
				table.remove(_waypoints, 1)
				nb = nb - 1
			end
		end
	else -- Relatif à un objet : uniquement pour le débarquement d'unités
		local point = ATMEFct.getPointFromReference(_reference)

		local index = -1
		local minDistance = -1
		
		for _index, _waypoint in ipairs(_waypoints) do
			local v = ATMEFct.C_Vector3D_create(nil, nil, point, _waypoint)
			if v:getHModule() > _radius and (minDistance < 0 or minDistance > v:getHModule())  then
				minDistance = v:getHModule()
				index = _index
			end
		end

		if index == -1 then
			index = #_waypoints
		end

		for _i = 1, index - 1 do
			table.remove(_waypoints, 1)
		end	
	end

	-- Retourne l'offset du premier point au regard des waypoints initiaux
	return nbWaypointsInit - #_waypoints
end
								

-- Fonction spawn des objets DCS avec gestion ATME
ATMEFct.C_CloningContext_spawn = function(_spawnDatas, _idStart)
	-- ATTENTION deux cas :
	--	*	Pour les groupes d'unités au sol ou les bateaux, les unités sont créées (event S_EVENT_BIRTH) 
	--		pendant le addgroup mais parfois leur groupe associé ne l'est pas encore ... 
	--		Donc on mémorise lors de l'événement DCS et on traite ci après
	--	*	Pour les groupes aircraft, l'event S_EVENT_BIRTH est appelé bien après. On mémorise ici pour un
	--		traitement lors de l'événement DCS.
	
	ATMEDatas.spawnedGroupsWaypoints[_spawnDatas.datas.name] = {
		waypoints = ATMEFct.C_CloningContext_copyAllWaypoints(_spawnDatas.datas.route.points),
	}
	
	local offsetTaskWaypointTracking = ATMEFct.C_CloningContext_setTaskWaypointsTracking(_spawnDatas.datas.name, _spawnDatas.datas.route.points)
	
	coalition.addGroup(_spawnDatas.country, _spawnDatas.category, _spawnDatas.datas)

	ATMEFct.C_CloningContext_deleteTaskWaypointsTracking(offsetTaskWaypointTracking, _spawnDatas.datas.route.points)

	if #ATMEDatas.unitsReadyToCreate > 0 then
		while #ATMEDatas.unitsReadyToCreate > 0 do
			local newUnit = table.remove(ATMEDatas.unitsReadyToCreate)
			
			local datas = {
				idStart = _idStart,
				uncontrolled = false,
				visible = true,
				spawnDatas = _spawnDatas,
			}
			
			ATMEFct.C_AIUnit_create(newUnit, datas)
		end
		
		ATMEDatas.newCreatedGroups[_spawnDatas.datas.name].isSpawned = true
	else
		local item = {
			name = _spawnDatas.datas.name,
			units = {},
			idStart = _idStart,
			nbUnits = 0,
			uncontrolled = false,
			visible = true,
			spawnDatas = _spawnDatas,
		}
		
		for _i, _unit in ipairs(_spawnDatas.datas.units) do
			item.units[_unit.name] = true
			item.nbUnits = item.nbUnits + 1
		end
		
		ATMEDatas.groupsReadyToBirth[_spawnDatas.datas.name] = item
	end

	return _spawnDatas.datas.name
end

-- Spawn sur débarquement des troupes embarquées dans un transport
ATMEFct.C_CloningContext_spawnFromTransportUnit = function(_transportUnit, _currentOnBoardGroupDatas)
	if ATMEDatas.exitATME == false then -- Test nécessaire car sinon problème sur l'événement du spawn (S_EVENT_BIRTH) désactivé par ATMEDatas.exitATME à true
		local spawnDatas = _currentOnBoardGroupDatas.spawnDatas
		local lastPassedWaypoint = _currentOnBoardGroupDatas.lastPassedWaypoint
		local unitsOnBoard = _currentOnBoardGroupDatas.unitsOnBoard
		local waypoints = _currentOnBoardGroupDatas.waypoints
		
		local nb = _transportUnit:getNbUnitsOnBoard()
		
		-- Min une unité par 3° soit 118 unités au maximum
		-- Calcul : pour 180° -> 180/3 - 1 unités, soit pour 360°, 2 x (180/3 - 1) = 118
		-- Max units par groupe terrestre = 99 < 118 donc pas de soucis actuellement
		-- sachant que la charge d'un hélico est bien inférieure à 99 unités.

		local point = _transportUnit:getPosition()
		local azimuth = _transportUnit:getAzimuth()

		-- Vérification d'absence d'eau côté droit/gauche 
		
		local sides = {}
		local startAngle = 0
		local nbPointsWater = {0,0}
		local index = 1
		local distance = ATMEConst.personnelCarrierAttributes[_transportUnit:getTypeName()].minDistance
		local deltaRad = math.pi / 4
		for _side = 1,-1,-2 do
			for _angle = deltaRad / 4 * _side, 3 * deltaRad * _side, deltaRad * _side do
				local result = ATME.coordLocalToDCS({x = distance * math.cos(_angle), y = distance * math.sin(_angle)}, point, azimuth)
				if ATME.isSurfaceWater(result) == true then
					nbPointsWater[index] = nbPointsWater[index] + 1
				end
			end
			
			if nbPointsWater[index] < 2 then
				table.insert(sides, startAngle)
			end
			startAngle = startAngle + 180
			index = index + 1
		end
		
		if #sides > 0 then
			if #sides == 2 then
				if nbPointsWater[1] > nbPointsWater[2] then -- On permute les côtés pour privilégier le côté sans eau (1 unité de plus si impair)
					sides[1] = 180
					sides[2] = 0
				end
			end
			-- Ajustements en fonction du nombre d'unités et du nombre
			-- de côtés possibles.
			
			-- Si moins de 2 unités par côté pas de symétrie
			if nb/#sides <= 2 and #sides > 1 then
				table.remove(sides)
			end
			
			-- Si symétrie (2 côtés) et nombre impair d'unités -> On ajuste pour rendre pairs
			if nb/#sides ~= math.floor(nb/#sides) then
				-- Si le nombre d'unités est impair quand 2 côtés ok, on ajoute 1
				nb = nb + 1
			end

			-- Calcul de l'angle entre chaque unité
			
			local deltaAngle = math.floor(180 / (nb + 1))
			local unitAngle = startAngle
			local id = 1
			local currentSide = 1
			local nbDeadUnits = 0

			while id <= #spawnDatas.datas.units do
				if unitsOnBoard[spawnDatas.datas.units[id].name] ~= nil then
					local unit = spawnDatas.datas.units[id]
					unitAngle = unitAngle + deltaAngle


					local unitAngleRad = math.rad(unitAngle + sides[currentSide])
					currentSide = currentSide + 1
					if currentSide > #sides then
						currentSide = 1
					end
					
					local result = ATME.coordLocalToDCS(
												{
													x = distance * math.cos(unitAngleRad), 
													y = distance  * math.sin(unitAngleRad),
												}, 
												point, 
												azimuth)
					
					-- Si l'unité est bien sur terre, alors ok
					if ATME.isSurfaceWater(result) == false then
					
						unit.x = result.x
						unit.y = result.z

						unit.heading = unitAngleRad + math.rad(azimuth)
						id = id + 1
					else -- si elle est dans l'eau alors elle meure (elle ne sera pas réactivée).
						table.remove(spawnDatas.datas.units, id)
						nbDeadUnits = nbDeadUnits + 1
					end
				else
					table.remove(spawnDatas.datas.units, id)
				end
			end

			if #spawnDatas.datas.units > 0 then
				local offsetStart
				local startWP = ATMEFct.copyTable(waypoints[1])
				
				local nextWaypoint
				if _currentOnBoardGroupDatas.nextWaypoint ~= nil then
					if type(_currentOnBoardGroupDatas.nextWaypoint) == "number" then
						if _currentOnBoardGroupDatas.nextWaypoint > lastPassedWaypoint and _currentOnBoardGroupDatas.nextWaypoint < #waypoints - 2 then
							nextWaypoint = _currentOnBoardGroupDatas.nextWaypoint
						elseif _currentOnBoardGroupDatas.nextWaypoint <= lastPassedWaypoint then
							nextWaypoint = lastPassedWaypoint + 1
						end
					else
						for _, _waypoint in ipairs(waypoints) do
							if _waypoint.name == _currentOnBoardGroupDatas.nextWaypoint then
								nextWaypoint = _currentOnBoardGroupDatas.nextWaypoint
							end
						end
					end
				end
				
				if nextWaypoint == nil then
					-- Dans ce cas, les unités débarquées suivent une route qui débute
					-- au waypoint le plus proche du transport (exclusion de 200m)
					-- sans prendre en compte les waypoints déjà passés.
					
					local idStart = lastPassedWaypoint

					while idStart >= 0 do
						table.remove(waypoints, 1)
						idStart = idStart - 1
					end
					
					offsetStart = ATMEFct.C_CloningContext_startRouteAt(waypoints, _transportUnit, 200)
					lastPassedWaypoint = lastPassedWaypoint + offsetStart
				else
					-- Dans ce cas soit le nom soit le numéro du waypoint est connu.
					-- Dans ce cas, les unités débarquées suivent une route qui débute au waypoint désigné.
					
					offsetStart = ATMEFct.C_CloningContext_startRouteAt(waypoints, nextWaypoint, 0)
					lastPassedWaypoint = offsetStart - 1
				end

				table.insert(waypoints, 1, startWP)

				-- Mémorisation de la route initiale du spawnDatas pour après le spawn
				local initialRoute = spawnDatas.datas.route
				
				-- Pour le spawn, création de la bonne route
				spawnDatas.datas.route = {}
				spawnDatas.datas.route.points = waypoints	

				-- Mise à jour de la position du premier WP (WP0 dans l'éditeur) avec
				-- les nouvelles coordonnées de la première unité du groupe qui débarque.
				-- Si le groupe est en maintenir position (task = Hold), cette tache est supprimée
				
				spawnDatas.datas.route.points[1].x = spawnDatas.datas.units[1].x
				spawnDatas.datas.route.points[1].y = spawnDatas.datas.units[1].y
				spawnDatas.datas.route.points[1].action = "Off Road"

				local index = 0
				for _i, _task in ipairs(spawnDatas.datas.route.points[1].task.params.tasks) do
					if _task.id == "Hold" then -- Maintenir position activé
						index = _i
					end
				end

				if index ~= 0 then
					table.remove(spawnDatas.datas.route.points[1].task.params.tasks, index)
				end
				
				local rollAxis = ATMEFct.C_Line2D_create(nil, nil, _transportUnit:getRollAxisVector(), _transportUnit:getPosition())
				
				local pAxis
				local newWP = ATMEFct.copyTable(spawnDatas.datas.route.points[1])
				
				if #spawnDatas.datas.route.points > 1 then
					-- Les unités ont tendance à détruire le transport si elles le percutent (bug DCS)
					-- Aussi, un WP est ajouté dans l'axe du transport à 100m, au plus près du
					-- deuxième WP (WP1 dans l'éditeur de mission ou créé s'il n'existe pas) si
					-- le groupe dispose d'une route de plus d'un WP.

					pAxis = {}
					pAxis[1] = rollAxis:getPointFromOrigin(100)
					pAxis[2] = rollAxis:getPointFromOrigin(-100)
					
					local indexPAxis = 1
					local vAxis1 = ATMEFct.C_Vector3D_create(nil, nil, pAxis[1], spawnDatas.datas.route.points[2])
					local vAxis2 = ATMEFct.C_Vector3D_create(nil, nil, pAxis[2], spawnDatas.datas.route.points[2])
					
					if vAxis2:getHModule() < vAxis1:getHModule() then
						indexPAxis = 2
					end
					
					newWP.x = pAxis[indexPAxis].x
					newWP.y = pAxis[indexPAxis].z
					table.insert(spawnDatas.datas.route.points, 2, newWP)
				else
					-- Si le groupe ne dispose pas de route de plus d'un WP, on en crée un à 300m devant
					-- l'unité de transport. Ainsi le déplacement du groupe est maitrisé par l'azimuth du 
					-- transport.
					
					pAxis = rollAxis:getPointFromOrigin(300)
					newWP.x = pAxis.x
					newWP.y = pAxis.z
					table.insert(spawnDatas.datas.route.points, newWP)
				end
				
				-- Mémorisation du groupe spawné pour traitement à la création
				-- du groupe ATME.C_Group
	
				ATMEDatas.spawnedGroupsWaypoints[spawnDatas.datas.name] = {
					waypoints = spawnDatas.datas.route.points,
				}
				
				local offsetTaskWaypointTracking = ATMEFct.C_CloningContext_setTaskWaypointsTracking(spawnDatas.datas.name, spawnDatas.datas.route.points)

				coalition.addGroup(spawnDatas.country, spawnDatas.category, spawnDatas.datas)
				
				ATMEFct.C_CloningContext_deleteTaskWaypointsTracking(offsetTaskWaypointTracking, spawnDatas.datas.route.points)
				
				-- Les unités sont créées (event S_EVENT_BIRTH) pendant le addgroup mais parfois
				-- leur groupe associé ne l'est pas encore ... Dans ce cas on mémorise et on traite ci après.
				
				-- On remet le spawnDatas.datas.route sur la route initiale
				spawnDatas.datas.route = initialRoute
				
				while #ATMEDatas.unitsReadyToCreate > 0 do
					local newUnit = table.remove(ATMEDatas.unitsReadyToCreate)
					
					local datas = {
						idStart = _currentOnBoardGroupDatas.offsetIdWaypoint + lastPassedWaypoint - 1,
						uncontrolled = false,
						visible = true,
						spawnDatas = spawnDatas,
					}
					
					ATMEFct.C_AIUnit_create(newUnit, datas)
				end
				
				local localGroupMembers = ATMEDatas.C_Group_MT:get(ATMEDatas.groups[spawnDatas.datas.name]:getIndex())
				
				-- Offset lié à l'ajout d'un waypoint devant ou derrière le véhicule de débarquement pour
				-- minimiser les collisions (bug DCS des unités spawnées) et rattrage sur la route originale.
				-- Le point ajouté ne doit pas être connus par les autres modules.
				
				localGroupMembers.lastPassedWaypoint = lastPassedWaypoint
				localGroupMembers.disembark = true

				if _currentOnBoardGroupDatas.isWaypointsTracking == true then
					ATMEDatas.groups[spawnDatas.datas.name]:setWaypointsTracking(_currentOnBoardGroupDatas.isFullWaypointsTracking)
				end
				
				return ATMEDatas.groups[spawnDatas.datas.name], nbDeadUnits
			else
				ATMEFct.setError("PLAYER_UNLOAD_ALL_GROUP_DEAD", 0)
				return
			end
		else
			ATMEFct.setError("PLAYER_UNLOAD_ONLY_WATER", 0)
			return
		end
	end
end

-- Fonction de création des données de base nécessaire au spawn simple ou multiple.
--   Le groupe _groupeName s'il existe peut lui même être un groupe spawné.
--   Dans ce cas, il faudra utiliser les noms originaux du groupe et unités associés 
--   tels que définis dans la mission. D'où la variable originalMissionNames
--   Si ce groupe n'existe pas alors on se base sur les données de missions.
--
-- 	 _toSpawnUnitNames est nécessaire à la gestion des troupes embarqués, sinon il vaut nil.

ATMEFct.C_CloningContext_create = function(_name, _cloningContexts, _initialNames, _newGroupName)
	local groupNameToCopy = _initialNames.groupName
	local newGroupName = _newGroupName
	local initialCoalition
	local initialType
	local initialNames = _initialNames
	
	
	initialType = ATMEDatas.allGroupsInMission[groupNameToCopy].type
	initialCoalition = ATMEDatas.allGroupsInMission[groupNameToCopy].coalition
	
	local newSpawnContext = {}
	
	local name
	local tagsName
	local transportUnitName
	
	if _name ~= nil and _cloningContexts ~= nil then
		name = _name
		_cloningContexts[name] = newSpawnContext
		tagsName = ATMEFct.decompString(_name)
	end
	
	setmetatable(newSpawnContext, ATMEDatas.C_CloningContext_MT.mt)
	
	local index = ATMEDatas.C_CloningContext_MT:add(_toSpawnUnitNames)
	local localMembers = ATMEDatas.C_CloningContext_MT:get(index)
	
	function newSpawnContext.getIndex(self)
		return index
	end
	
	function newSpawnContext.setAircraftsCallsign(self, _callsign)
		local fctDefinition = ATMEFct.getErrorPrefix(newSpawnContext) .. "setAircraftsCallsign(callsign)"
		if type(_callsign) == "string" or type(_callsign) == "number" then
			if initialType == "plane" or initialType == "helicopter" then
				if initialCoalition == "BLUE" then -- Coalition BLUE
					if type(_callsign) == "string" then
						local tokens = ATMEFct.analyzeString(_callsign)
						
						if #tokens >= 1 and tokens[1].type == "TOKEN_AIRCRAFT_CALLSIGN_NAME" then
							local value
							if #tokens == 2 and tokens[2].type == "TOKEN_INTEGER" and tokens[2].status == "ABSOLUTE" and tokens[2].value <= 9 then
								value = tokens[2].value
							else
								value = 1
							end
							
							localMembers.callsign = {
								[1] = ATMEConst.blueCallsigns.aircrafts[tokens[1].value].id,
								[2] = value,
								name = ATMEConst.blueCallsigns.aircrafts[tokens[1].value].name .. tokens[2].value,
							}
						else
							ATMEFct.errorOutputCore(nil, fctDefinition, "For BLUE coalition, callsign format must be 'Callsign' or 'Callsign X' x < 9", false)
						end
					else
						ATMEFct.errorOutputCore(nil, fctDefinition, "For BLUE coalition, callsign type must be string only", false)
					end
				else --Coalition RED
					local callsignId = 0
					if type(_callsign) == "string" then
						local tokens = ATMEFct.analyzeString(_callsign)
						if #tokens == 1 and tokens[1].type == "TOKEN_INTEGER" and tokens[1].status == "ABSOLUTE" then
							callsignId = math.floor(tonumber(tokens[1].value))
						end
					else
						callsignId = math.floor(_callsign)
					end
					
					if callsignId > 0 and callsignId <= 999 then
						localMembers.callsign[i] = callsignId
					else
						ATMEFct.errorOutputCore(nil, fctDefinition, "For RED coalition, callsign format must be 'XXX' or XXX (XXX > 0 and <= 999)", false)
					end
				end
			else
				ATMEFct.errorOutputCore(nil, fctDefinition, "groupDatas must refer to planes or helicopters group", false)
			end
		else
			ATMEFct.errorOutputCore(nil, fctDefinition, "callsign type must be string or number ('CALLSIGN X' or 'XXX'/XXX)", true)
		end
	end
	
	function newSpawnContext.setAutoRepeatSpawn(self, _quantity, _repeatPeriod)
		local fctDefinition = ATMEFct.getErrorPrefix(newSpawnContext) .. "setAutoRepeatSpawn(quantity, repeatPeriod)"
		
		if (type(_quantity) == "number" or type(_quantity) == "string") and (type(_repeatPeriod) == "number" or type(_repeatPeriod) == "string") then
			local maxQuantity = 0

			local err, qtyRandom, qtyMin, qtyMax = ATMEFct.getRandomDatas(_quantity)
			if err ~= nil then
				ATMEFct.errorOutputCore(nil, fctDefinition, err .. "quantity", false)
				return
			else
				if qtyRandom == true then
					if qtyMin >= 1 then
						if qtyMax ~= nil then 
							if qtyMax <= 20 then
								maxQuantity = math.random(qtyMin, qtyMax)
							else
								ATMEFct.errorOutputCore(nil, fctDefinition, "Parameter #3 must be <= 20 in string format quantity", false)
								return
							end
						else
							maxQuantity = qtyMin
							if maxQuantity < 1 then
								ATMEFct.errorOutputCore(nil, fctDefinition, "quantity must be >= 1", false)
								return
							end
						end
						
					else
						ATMEFct.errorOutputCore(nil, fctDefinition, "Parameter #2 must be >= 1 in string format quantity", false)
						return
					end
				else
					maxQuantity = qtyMin
					if maxQuantity < 1 then
						ATMEFct.errorOutputCore(nil, fctDefinition, "quantity must be >= 1", false)
						return
					end
				end
			end
			
			local err, repeatRandom, repeatPeriodMin, repeatPeriodMax = ATMEFct.getRandomDatas(_repeatPeriod)
			if err ~= nil then
				ATMEFct.errorOutputCore(nil, fctDefinition, err .. "repeatPeriod", false)
				return
			else
				if repeatRandom == true then
					if repeatPeriodMin < 1 then
						ATMEFct.errorOutputCore(nil, fctDefinition, "Parameter #2 must be >= 1 in string format repeatPeriod", false)
						return
					end
				else
					if repeatPeriodMin < 1 then
						ATMEFct.errorOutputCore(nil, fctDefinition, "repeatPeriod must be >= 1", false)
						return
					end
				end
			end

			ATMEDatas.spawnGroupDatasRepeat[groupNameToCopy] = {
				groupDatas = self,
				repeatPeriodMin = repeatPeriodMin,
				repeatPeriodMax = repeatPeriodMax,
				repeatRandom = repeatRandom,
				maxQuantity = maxQuantity,
				nbSpawn = 1,
			}
				
		else
			if type(_maxQuantity) ~= "number" then
				ATMEFct.errorOutputCore(nil, fctDefinition, "quantity type must be number or string", true)
			elseif type(_repeatPeriod) ~= "number" then
				ATMEFct.errorOutputCore(nil, fctDefinition, "repeatPeriod type must be number or string", false)
			end
		end
	end
	
	function newSpawnContext.resetAutoRepeatSpawn(self)
		ATMEDatas.spawnGroupDatasRepeat[spawnDatas.datas.name] = nil
	end
	
	function newSpawnContext.addUnit(self, _unitDatas, _newUnitName)
		local fctDefinition = ATMEFct.getErrorPrefix(newSpawnContext) .. "addUnit(unitDatas, [newUnitName])"
		
		if type(_unitDatas) == "table" and (_newUnitName == nil or type(_newUnitName) == "string") then
			local err, value = ATMEFct.C_CloningContext_addUnit(ATMEDatas.allGroupsInMission[groupNameToCopy], _unitDatas, _newUnitName, initialNames, initialType)
			
			if err == true then
				ATMEFct.errorOutputCore(nil, fctDefinition, value, false)
			end
		else
			if type(_unitDatas) ~= "table" then
				ATMEFct.errorOutputCore(nil, fctDefinition, "unitDatas type must be table", true)
			elseif _newUnitName ~= nil and type(_newUnitName) ~= "string" then
				ATMEFct.errorOutputCore(nil, fctDefinition, "newUnitName type must be nil or string", true)
			end
		end
	end
	
	function newSpawnContext.getName(self)
		return name
	end
	
	function newSpawnContext.setWeaponToUnit(self, _unitName, _pylonID, _weapon)
		local fctDefinition = ATMEFct.getErrorPrefix(newSpawnContext) .. "addWeaponsToUnit(unitName, pylonID, weapon)"
		
		if type(_unitName) == "string" and type(_pylonID) == "number" and (_weapon == nil or type(_weapon) == "table") then
			if initialType == "plane" or initialType == "helicopter" then
				local unitDatas = ATMEDatas.allGroupsInMission[groupNameToCopy].units[_unitName]
				
				if unitDatas ~= nil then
					if _pylonID > 0 then
						if type(_weapon) == "table" then
							unitDatas.payload.pylons[_pylonID] = ATMEFct.copyTable(_weapon)
						else
							unitDatas.payload.pylons[_pylonID] = nil
						end
					else
						ATMEFct.errorOutputCore(nil, fctDefinition, "pylonID must be > 0", false)
					end
				else
					ATMEFct.errorOutputCore(nil, fctDefinition, "unit " .. _unitName .. " doesn't exist", false)
				end
			else
				ATMEFct.errorOutputCore(nil, fctDefinition, "unit " .. _unitName .. " must be an aircraft unit", false)
			end
		else
			if type(_unitName) ~= "string" then
				ATMEFct.errorOutputCore(nil, fctDefinition, "unitName type must be string", true)
			elseif type(_pylonID) ~= "number" then
				ATMEFct.errorOutputCore(nil, fctDefinition, "pylonID type must be number", false)
			elseif _weapon ~= nil and type(_weapon) ~= "table" then
				ATMEFct.errorOutputCore(nil, fctDefinition, "weapon type must be nil or table", true)
			end
		end
	end
	
	function newSpawnContext.getGroupName(self)
		return groupNameToCopy
	end
	
	function newSpawnContext.tagGetByID(self, _position)
		local fctDefinition = ATMEFct.getErrorPrefix(newSpawnContext) .. "tagGetByID(position)"
		
		if type(_position) == "number" then
			local pos = math.floor(_position)
			if tagsName ~= nil and pos >= 1 and pos <= #tagsName then
				return tagsName[pos]
			end
		else
			ATMEFct.errorOutputCore(nil, fctDefinition, "position type must be number", true)
		end
	end
	
	function newSpawnContext.tagGetCount(self)
		if tagsName ~= nil then
			return #tagsName
		else
			return 0
		end
	end
	
	function newSpawnContext.tagCompare(self, _tagsToCompare)
		local fctDefinition = ATMEFct.getErrorPrefix(newSpawnContext) .. "tagCompare(tagsToCompare)"
		
		if type(_tagsToCompare) == "string" then
			if tagsName ~= nil then
				local ok = ATMEFct.compareTags(tagsName, _tagsToCompare)
				
				if ok ~= nil then
					return ok
				else
					ATMEFct.errorOutputCore(nil, fctDefinition, "tagsToCompare format must be 'T1|T2|..|Tn'", false)
				end
			else
				return false
			end
		else
			ATMEFct.errorOutputCore(nil, fctDefinition, "tagsToCompare type must be string", true)
		end
	end
	
	function newSpawnContext.spawn(self, _route)
		if ATMEDatas.exitATME == false then -- Test nécessaire car sinon problème sur l'événement du spawn (S_EVENT_BIRTH) 
											-- désactivé par ATMEDatas.exitATME à true
			local route
			local fctDefinition = ATMEFct.getErrorPrefix(newSpawnContext) .. "spawn([route])"

			if _route ~= nil then
				if ATME.isObjectClass(_route, ATME.C_Route) == true then
					route = _route
				else
					ATMEFct.errorOutputCore(nil, fctDefinition, "route type must be nil or ATME.C_Route", false)
					return
				end
			else
				route = ATMEFct.C_Route_create(initialType)
				route:addWaypointsFrom(groupNameToCopy)
			end

			local localMembersRoute = ATMEDatas.C_Route_MT:get(route:getIndex())

			if initialType == localMembersRoute.type then
				-- Mémorisation du groupe spawné pour traitement à la création
				-- du groupe (C_Group)

				local err, waypoints = ATMEFct.C_Route_createWaypoints(route)
				if err == false then
					local spawnDatas
					local newInitialNames

					
					-- Si le groupe à créer existe, il faudra toujours postfixer son nom d'origine
					-- avec " - Spawned #XXX" où XXX est une valeur incrémentale. Néanmoins,
					-- si un groupe avec le même nom ainsi posfixé a déjà été créé puis détruit,
					-- la valeur XXX associée pourra être réutilisée (entrée freeIds).
					-- Idem pour les unités. Attention, même si le nouveau groupe a un nom différent,
					-- les unités elles conservent leur nom d'origine donc l'incrément s'applique 
					-- plus souvent.
					
					local idSpawnedList = {
						units = {},
					}

					if ATMEDatas.groups[newGroupName] ~= nil or ATMEDatas.groupsOnBoard[newGroupName] ~= nil or
																	ATMEDatas.groupsReadyToBirth[newGroupName] ~= nil then

						_, newInitialNames = ATMEFct.C_CloningContext_getInitialNames(newGroupName)

						local newId
						if ATMEDatas.spawnedGroups[newInitialNames.groupName] == nil then
							ATMEDatas.spawnedGroups[newInitialNames.groupName] = {
								max = 1,
								freeIds = {},
							}
							newId = ATMEDatas.spawnedGroups[newInitialNames.groupName].max
						else
							if #ATMEDatas.spawnedGroups[newInitialNames.groupName].freeIds == 0 then
								ATMEDatas.spawnedGroups[newInitialNames.groupName].max = ATMEDatas.spawnedGroups[newInitialNames.groupName].max + 1
								newId = ATMEDatas.spawnedGroups[newInitialNames.groupName].max
								
								if newId > 999 then
									ATMEFct.errorOutputCore(nil, fctDefinition, "Too much group with the same name (#XXX > 999)", false)
									return
								end
							else
								newId = table.remove(ATMEDatas.spawnedGroups[newInitialNames.groupName].freeIds)
							end
						end
						
						newGroupName = string.format("%s - Spawned #%03d", newInitialNames.groupName, newId)
						idSpawnedList.groupSpawnedId = newId
					else
						-- Le nom du groupe est nouveau mais le nom des unités sont bien la duplication d'unités existantes
						newInitialNames = {
							groupName = newGroupName,
							unitsName = ATMEDatas.allInitialGroupNames[groupNameToCopy].unitsName,
						}
					end

					spawnDatas = {
						initialNames = newInitialNames,
						idSpawnedList = idSpawnedList,
						country = ATMEDatas.allGroupsInMission[groupNameToCopy].country,
						category = ATMEDatas.allGroupsInMission[groupNameToCopy].category,
						type = initialType,
						datas = {
							name = newGroupName,
							hidden = ATMEDatas.allGroupsInMission[groupNameToCopy].hidden,
							start_time = 0,
							task = ATMEDatas.allGroupsInMission[groupNameToCopy].task,
							visible = false,
							taskSelected = true,
							lateActivation = false,
							tasks = {},
							units = {},
							route = {},
						},
					}
					
					local first = true
					local position0 = {}

					for _i, _unitName in ipairs(newInitialNames.unitsName) do
						local unitName = _unitName

						if ATMEDatas.AIUnits[_unitName] ~= nil then
							local newId
							if ATMEDatas.spawnedUnits[_unitName] == nil then
								ATMEDatas.spawnedUnits[_unitName] = {
									max = 1,
									freeIds = {},
								}
								newId = ATMEDatas.spawnedUnits[_unitName].max
							else
								if #ATMEDatas.spawnedUnits[_unitName].freeIds == 0 then
									ATMEDatas.spawnedUnits[_unitName].max = ATMEDatas.spawnedUnits[_unitName].max + 1
									newId = ATMEDatas.spawnedUnits[_unitName].max
									if newId > 999 then
										ATMEFct.errorOutputCore(nil, fctDefinition, "Too much units with the same name (#XXX > 999)", false)
										return
									end
								else
									newId = table.remove(ATMEDatas.spawnedUnits[_unitName].freeIds)
								end
							end

							unitName = string.format("%s - Spawned #%03d", _unitName, newId)
							idSpawnedList.units[_unitName] = newId
						end
						
						local initialUnit = ATMEDatas.allAIUnitsInMission[_unitName].unit
						
						if initialUnit.x == nil then
							initialUnit.x = 0
						end
						
						if initialUnit.y == nil then
							initialUnit.y = 0
						end
						
						if first == true then
							position0.x = initialUnit.x
							position0.y = initialUnit.y
							first = false
						end
						
						initialUnit.x = waypoints[1].x + initialUnit.x - position0.x
						initialUnit.y = waypoints[1].y + initialUnit.y - position0.y
						
						if #waypoints > 1 then
							local dx = waypoints[2].x - initialUnit.x
							local dy = waypoints[2].y - initialUnit.y
							
							if dx == 0 and dy == 0 then
								initialUnit.heading = math.rad(math.random(-179, 180))
							else
								initialUnit.heading = math.atan2(dy, dx)
							end
						else
							if initialUnit.heading == nil then
								initialUnit.heading = math.rad(math.random(-179, 180))
							end
						end
						
						spawnDatas.datas.units[_i] = {
							type = initialUnit.type,
							name = unitName,
							skill = initialUnit.skill,
							alt = waypoints[1].alt,
							x = initialUnit.x,
							y = initialUnit.y,
							alt_type = initialUnit.alt_type,
							playerCanDrive = initialUnit.playerCanDrive,
							heading = initialUnit.heading,
							payload = initialUnit.payload,
							speed = initialUnit.speed,
							callsign = initialUnit.callsign,
							onboard_num = initialUnit.onboard_num,
							psi = initialUnit.psi,
							livery_id = initialUnit.livery_id,
						}
					end
					
					if initialType == "plane" or initialType == "helicopter" then
						if localMembers.callsigns ~= nil then
							if initialCoalition == "BLUE" then
								for _i, _unit in ipairs(spawnDatas.datas.units) do
									_unit.callsign = {
										[1] = localMembers.callsign[1],
										[2] = localMembers.callsign[2],
										[3] = _i,
										name = localMembers.callsign.name .. _i,
									}
								end
								
								localMembers.callsign[2] = localMembers.callsign[2] + 1
								if localMembers.callsign[2] > 9 then
									localMembers.callsign[2] = 1
								end
							else -- RED
								for _i, _unit in ipairs(spawnDatas.datas.units) do
									_unit.callsign = string.format("%03d", localMembers.callsign + _i - 1)
								end
								
								localMembers.callsign = localMembers.callsign + 10
							end
						end
					end

					spawnDatas.datas.route.points = waypoints
					
					-- Mémorisation des GroupDatas pour un éventuel respawn automatique
					if ATMEDatas.groups[spawnDatas.datas.name] == nil and ATMEDatas.groupsOnBoard[spawnDatas.datas.name] == nil then
						if ATMEDatas.spawnGroupDatasRepeat[groupNameToCopy] ~= nil then
							ATMEDatas.spawnGroupDatasRepeat[groupNameToCopy].arg = route
							if ATMEDatas.spawnGroupDatasRepeat[groupNameToCopy].repeatRandom == true then
								ATMEDatas.spawnGroupDatasRepeat[groupNameToCopy].currentTime = math.random(ATMEDatas.spawnGroupDatasRepeat[groupNameToCopy].repeatPeriodMax, ATMEDatas.spawnGroupDatasRepeat[groupNameToCopy].repeatPeriodMax)
							else
								ATMEDatas.spawnGroupDatasRepeat[groupNameToCopy].currentTime = ATMEDatas.spawnGroupDatasRepeat[groupNameToCopy].repeatPeriodMin
							end
						end
						
						return ATMEFct.C_CloningContext_spawn(spawnDatas, 0)
					else
						ATMEFct.errorOutputCore(nil, fctDefinition, "Group " .. localMembers.datas.name .. " already exists or on board", false)
						return
					end
				else
					ATMEFct.setError("SPAWN_NO_WAYPOINTS")
					return
				end
			else
				ATMEFct.errorOutputCore(nil, fctDefinition, "Route must have same type as " .. localMembers.datas.name, false)
				return
			end
		end
	end
	
	return newSpawnContext
end

ATMEDatas.C_CloningContext_MT = {
	className = "C_CloningContext",
	mt = {},
	
	keys = {
		["getIndex"] = true,
		["spawn"] = true,
		["setAutoRepeatSpawn"] = true,
		["resetAutoRepeatSpawn"] = true,
		["setAircraftsCallsign"] = true,
		["addUnit"] = true,
		["setWeaponToUnit"] = true,
		["getName"] = true,
		["getGroupName"] = true,
		["tagGetByID"] = true,
		["tagCompare"] = true,
		["tagGetCount"] = true,
	},
	
	localMembers = ATMEFct.C_IndexList_create(),
	
	add = function(self)
		local item = {
			callsigns = nil,
		}
		
		return self.localMembers:add(item)
	end,
	
	remove = function(self, _id)
		self.localMembers:remove(_id)
	end,
	
	get = function(self, _id)
		return self.localMembers:get(_id)
	end,
}

ATME.C_CloningContext = {
	getClassName = function(self)
		return ATMEDatas.C_CloningContext_MT.className
	end,
	
	getParentClass = function(self)
		return ATMEDatas.C_CloningContext_MT.parentClass
	end,
}

setmetatable(ATME.C_CloningContext,ATMEDatas.C_CloningContext_MT)

ATMEDatas.C_CloningContext_MT.__call = function(t, _origin, _newGroupName)
	local fctDefinition = "Constructor ATME.C_CloningContext(origin, [newGroupName])"

	if (type(_origin) == "string" or type(_origin) == "table") and (type(_newGroupName) == "string" or _newGroupName == nil) then
		if type(_origin) == "table" then
			if ATMEFct.C_CloningContext_controlTable(_origin, _newGroupName) == false then
				ATMEFct.errorOutputCore(nil, fctDefinition, "Bad cloning table format", false)
				return
			end
			
			if _newGroupName ~= nil then
				_origin.datas.name = _newGroupName
			end
		end
		
		local newGroupName = _newGroupName
		if _newGroupName == nil then
			if type(_origin) == "string" then
				newGroupName = _origin
			else
				newGroupName = _origin.datas.name 
			end
		else
			local d,f = string.find(newGroupName, "|", 1)
			if d ~= nil then
				ATMEFct.errorOutputCore(nil, fctDefinition, "Name of group " .. newGroupName .. " can't contain '|' character", false)
				return
			end
			
			d,f = string.find(newGroupName:upper(), "%s+SPAWNED%s+", 1)
			if d ~= nil then
				ATMEFct.errorOutputCore(nil, fctDefinition, "Name of group " .. newGroupName .. " can't contain 'Spawned' word", false)
				return
			end
		end
		
		local err, initialNames = ATMEFct.C_CloningContext_getInitialNames(_origin)
		
		if err == nil then
			local foundPlayer = false
			for _, _unitDatas in pairs(ATMEDatas.allGroupsInMission[initialNames.groupName].units) do
				if _unitDatas.skill == "Player" or _unitDatas.skill == "Client" then
					foundPlayer = true
				end
			end
			
			if foundPlayer == false then
				-- Le nom du nouveau groupe (_newGroupName) ne doit pas correspondre à un groupe existant,
				-- à un groupe embarqué ou à un groupe en cours de spawn.

				return ATMEFct.C_CloningContext_create(nil, nil, initialNames, newGroupName)
			else
				ATMEFct.errorOutputCore(nil, fctDefinition, "Group " .. _origin .. " has one or more player units", false)
			end
		else
			ATMEFct.errorOutputCore(nil, fctDefinition, err, false)
		end
	else
		if type(_origin) ~= "string" and type(_origin) ~= "table" then
			ATMEFct.errorOutputCore(nil, fctDefinition, "origin type must be string or table (DCS fromat)", false)
		elseif _newGroupName ~= nil and type(_newGroupName) ~= "string" then
			ATMEFct.errorOutputCore(nil, fctDefinition, "newGroupName type must be nil or string", false)
		end
	end
end

ATMEDatas.C_CloningContext_MT.mt.__metatable = "Private"
ATMEDatas.C_CloningContext_MT.mt.__index = ATME.C_CloningContext
ATMEDatas.C_CloningContext_MT.mt.__newindex = function(t, k, v)
	if ATMEDatas.C_CloningContext_MT.keys[k] ~= nil then 
		rawset(t, k, v)
	else
		ATMEFct.errorOutputCore(nil, "Function ATME.C_CloningContext : Bad key " .. k, "table locked", false)
	end
end

----------------------------------------------------------------------------------------------------------
-- Classe ATME.C_Group : gère les groupes d'unités (AI ou joueur) au format ATME. Pas de contructeur accessible
-- pour les modules externes.
-- Les instances de cette classe sont intégralement gérées par le module ATME_Core. La création et la destruction
-- dépendent du contexte de début de mission et des événements qui se produisent dans DCS en cours de mission.
-- Les modules externes accèdent à cette gestion indirectement par les handlers définis dans ceux-ci et les méthodes
-- accessibles de cette classe. Ceci permet de garantir une cohérence sur les listes internes ATME.
-- ATME crée des instances de cette classe à partir de la création d'instance d'unité joueur ou AI.
-- Chaque unité AI ou joueur dispose d'une variable représentant le groupe ATME qui lui est associé.
-- En cas de destruction (suppression) d'une unité (AI ou joueur), le groupe ne sera détruit qu'après la destruction
-- de la dernière unité (AI ou joueur) du groupe.
----------------------------------------------------------------------------------------------------------

ATMEDatas.C_Group_MT = {
	className = "C_Group",
	parentClass = ATME.C_DynamicObject,
	
	mtModules = {},
	mt = {},
	
	keys = {
		["disable"] = true,
		["setSignal"] = true,
		["resetSignal"] = true,
		["isSignalSet"] = true,
		["getFirstUnit"] = true,
		["getNextUnit"] = true,
		["getPreviousUnit"] = true,
		["getLastUnit"] = true,
		["getUnitByName"] = true,
		["getUnits"] = true,
		["getNbUnits"] = true,
		["getCoalitionName"] = true,
		["getCountryName"] = true,
		["isOnlyInfantry"] = true,
		["isOnlyAI"] = true,
		["isInArea"] = true,
		["isInDCSZone"] = true,
		["isInZone2D"] = true,
		["isInSphere"] = true,
		["isNear"] = true,
		["getCategoryName"] = true,
		["setPickupZone"] = true,
		["resetPickupZone"] = true,
		["hasPickupZone"] = true,
		["getPickupZone"] = true, 
		["isReadyToBoard"] = true,
		["setReadyToBoard"] = true,
		["resetReadyToBoard"]= true,
		["isBoarding"] = true,
		["move"] = true,
		["stop"] = true,
		["freeze"] = true,
		["getDCSGroup"] = true,
		["hasAutoRespawn"] = true,
		["setAutoRespawn"] = true,
		["resetAutoRespawn"] = true,
		["getName"] = true,
		["tagGetByID"] = true,
		["tagCompare"] = true,
		["tagGetCount"] = true,
		["getIndex"] = true,
		["activate"] = true,
		["isActivated"] = true,
		["isAlwaysVisible"] = true,
		["setRoute"] = true,
		["setTask"] = true,
		["resetTask"] = true,
		["pushTask"] = true,
		["popTask"] = true,
		["getMinDistance"] = true,
		["getMaxDistance"] = true, 
		["getMinHDistance"] = true,
		["getMaxHDistance"] = true,
		["getPosition"] = true,
		["getRandomUnitPosition"] = true,
		["modules"] = true,
		["isWaypointsTracking"] = true,
		["isFullWaypointsTracking"] = true,
		["setWaypointsTracking"] = true, 
		["resetWaypointsTracking"] = true,
		["setPatrol"] = true,
		["resetPatrol"] = true,
		["start"] = true,
		["isControlled"] = true,
		["canFly"] = true,
		["getUserPrivateDatas"] = true,
		["setInvisible"] = true,
		["setImmortal"] = true,
		["setOption"] = true,
	},
	
	localMembers = ATMEFct.C_IndexList_create(),
	
	add = function(self, _hasPlayers, _name, _datas)
		local item = {
			originMissionDatasGroupName = _name,
			waypoints = nil,						-- localMembers.waypoints contient la route courante éventuellement
													-- ajustée par spawn de débarquement (unload). Cette variable est aussi
													-- modifiée par setRoute.
			maxWaypoints = 0, 						-- Nombre de waypoints tenant compte de l'ajustement si le dernier WP
													-- n'est pas de type "Land" pour les aéronefs.
			offsetIdWaypoint = _datas.idStart,
			disembark = false,
			waypointsTracking = false,
			endOfRoute = false, 						-- Fin de la route, le dernier WP a été passé
			fullWaypointsTracking = false,
			lastPassedWaypoint = 0,						-- Indique le dernier WP passé
			hasPlayers = _hasPlayers,
			onBoard = false,
			autoRespawn = {
				activated = false,
				time = 0,
				random = false,
				minTime = 0,
				maxTime = 0,
			},
			patrolWP = {
				last = -1,
				restart = -1,
				nbTurns = 0,
				maxTurns = -1,
				maxTime = -1,
				fuelRatio = -1,
				maxRandom = -1,
				isArmed = false,
				id = 0,
			},
			onlyInfantry = true,
			boardingStarted = false,
			signalIndex = 0,
			pickupZone = nil,
			nextWaypoint = nil,
			isEnabled = true,
			nbUnitsToEnable = 0,
			isStopped = false,
			nextUnit = 0,
			previousUnit = 0,
			ATMEUnits = {},
			ATMEUnitNames = {},
			userPrivateDatas = {},						-- Point d'entrée des données privées : un par module
			tagsName = ATMEFct.decompString(_name),
			spawnDatas = _datas.spawnDatas,
			onZoneTask = nil,							-- Tâche pilotée par ATME, sur zone donnée
		}
		
		return self.localMembers:add(item)
	end,
	
	remove = function(self, _id)
		self.localMembers:get(_id).ATMEUnits = nil
		self.localMembers:get(_id).ATMEUnitNames = nil
		self.localMembers:remove(_id)
	end,
	
	get = function(self, _id)
		return self.localMembers:get(_id)
	end,
}

ATMEFct.C_Group_Unit_isInZone2D = function(_unit, _zone)
	local point = _unit:getPosition()
	if ATMEFct.isObjectClass(_zone, ATME.C_Polygon) == true then
		local localMembers = ATMEDatas.C_Polygon_MT:get(_zone:getIndex())
		return ATMEFct.C_Polygon_isInside(point, localMembers.triangles)
	elseif ATMEFct.isObjectClass(_zone, ATME.C_Circle) == true then
		local localMembers = ATMEDatas.C_Circle_MT:get(_zone:getIndex())
		return ATMEFct.C_Circle_isInside(point, localMembers.center, nil, 0, localMembers.radius)
	elseif ATMEFct.isObjectClass(_zone, ATME.C_PickupZone) == true then
		local localMembers = ATMEDatas.C_PickupZone_MT:get(_zone:getIndex())
		return ATMEFct.C_Circle_isInside(point, localMembers.center, nil, 0, localMembers.radius)
	else
		local localMembers = ATMEDatas.C_Ring_MT:get(_zone:getIndex())
		return ATMEFct.C_Circle_isInside(point, localMembers.center, nil, localMembers.radiusMin, localMembers.radiusMax)
	end
end

ATMEFct.C_Group_isUnitOk = function(_ATMEUnit)
	local group = _ATMEUnit:getGroup()
	local active = _ATMEUnit:getDCSUnit():isActive()

	return active == true or (active == false and group:isAlwaysVisible() == true)
end


ATMEFct.C_Group_searchInBox = function(_unit, _datas)
	local unitName = _unit:getName()
	local ATMEUnit = ATMEDatas.allAIUnitsAndPlayers[unitName]
	local group = ATMEUnit:getGroup()
	local groupName = group:getName()

	if group:getCategoryName() == _datas.filter or _datas.filter == "ALL" then
		if _datas.coalition == nil or group:getCoalitionName() == _datas.coalition then
			if ATMEFct.C_Group_isUnitOk(ATMEUnit) == true and ATMEFct.C_Group_Unit_isInZone2D(ATMEUnit, _datas.zone) == true then
				if _datas.nbUnitsGroup[groupName] == nil then
					if _datas.allGroup == false then
						_datas.groups[groupName] = group
						_datas.nbGroups = _datas.nbGroups + 1
					end
					
					_datas.nbUnitsGroup[groupName] = 0
				end
				
				_datas.nbUnitsGroup[groupName] = _datas.nbUnitsGroup[groupName] + 1
				
				_datas.units[unitName] = ATMEUnit
				_datas.nbUnits = _datas.nbUnits + 1
				
				if _datas.groups[groupName] == nil then
					if _datas.nbUnitsGroup[groupName] == group:getNbUnits() then
						_datas.groups[groupName] = group
						_datas.nbGroups = _datas.nbGroups + 1
					end
				end
			end
		end
	end
end

ATMEFct.C_Group_isTargetOk = function(_ATMEUnit)
	local group = _ATMEUnit:getGroup()
	local active = _ATMEUnit:isActivated()

	return (group:getCategoryName() == "GROUND" or 
			((group:getCategoryName() == "AIRPLANE" or group:getCategoryName() == "HELICOPTER") and _ATMEUnit:inAir() == false)) and 
			(active == true or (active == false and group:isAlwaysVisible() == true))
end

ATMEFct.C_Group_loopAttributes = function(_unit, _datas)
	for _attribute, _priority in pairs(ATMEConst.targetAttributePriority.vehicle) do
		if type(_attribute) == "table" then
			ATMEFct.C_Group_loopAttributes(_unit, _datas)	
		elseif _unit:hasAttribute(_attribute) then
			if _datas.currentPriority < _priority then
				_datas.currentPriority = _priority
				_datas.targetGroupName = _unit:getGroup():getName()
			end
		end
	end
end

ATMEFct.C_Group_searchTargetsInBox = function(_unit, _datas)
	local ATMEUnit = ATMEDatas.allAIUnitsAndPlayers[_unit:getName()]
	
	if ATMEFct.C_Group_isTargetOk(ATMEUnit) == true and ATMEUnit:getCoalitionName() == _datas.targetsCoalition then
		if ATMEFct.C_Group_Unit_isInZone2D(ATMEUnit, _datas.zone) == true then	
			ATMEFct.C_Group_loopAttributes(_unit, _datas)
			
			if _datas.targetGroupName == nil then
				_datas.targetGroupName = ATMEUnit:getGroup():getName()
			end
		end
	end
end

ATMEFct.C_Group_findTargetInZone2D = function(_zone, _targetsCoalition)
	local box = _zone:getBox()				
	local volume = {
		id = world.VolumeType.BOX,
		params = box,
	}
	
	local datas = {
		currentPriority = 0,
		zone = _zone,
		targetsCoalition = _targetsCoalition,
	}

	world.searchObjects(Object.Category.UNIT, volume, ATMEFct.C_Group_searchTargetsInBox, datas)
	
	return datas.targetGroupName
end

ATME.C_Group = {
	getClassName = function(self)
		return ATMEDatas.C_Group_MT.className
	end,
	
	getParentClass = function(self)
		return ATMEDatas.C_Group_MT.parentClass
	end,
	
	getByName = function(_groupName)
		if type(_groupName) == "string" then
			return ATMEDatas.groups[_groupName]
		else
			ATMEFct.errorOutputCore(nil, "Function ATME.C_Group.getByName(name)", "name type must be string", false)
		end
	end,
	
	getGroupsInAreaForAll = function(_area, _allGroup, _filter)
		local fctDefinition = "Function ATME.C_Group.getGroupsInAreaForAll(area, allGroup, [filter])"
		
		if ATME.isObjectClass(_area, ATME.C_Area) == true and type(_allGroup) == "boolean" and (_filter == nil or type(_filter) == "string") then
			local filterValue
			if _filter == nil then
				filterValue = "ALL"
			else
				filterValue = string.upper(_filter)
			end
			
			if filterValue == "ALL" or ATMEConst.categoryNameFilters[filterValue] ~= nil then
				local datas = {
					groups = {}, 
					nbGroups = 0, 
					nbUnitsGroup = {},
					units = {},
					nbUnits = 0,
					allGroup = _allGroup,
					filter = filterValue,
				}
				
				local localMembersArea = ATMEDatas.C_Area_MT:get(_area:getIndex())
				
				for _, _zoneItem in pairs(localMembersArea.zonesList) do
					local box = _zoneItem.zone:getBox()
				
					local volume = {
						id = world.VolumeType.BOX,
						params = box,
					}
					
					datas.zone = _zoneItem.zone
					world.searchObjects(Object.Category.UNIT, volume, ATMEFct.C_Group_searchInBox, datas)
				end
				
				return datas.groups, datas.nbGroups, datas.units, datas.nbUnits
			else
				ATMEFct.errorOutputCore(nil, fctDefinition, "filter must be 'ALL', 'AIRPLANE', 'HELICOPTER', 'GROUND' or 'SHIP'", false)
			end
		else
			if ATME.isObjectClass(_area, ATME.C_Area) == false then
				ATMEFct.errorOutputCore(nil, fctDefinition, "area type must be ATME.C_Area", false)
			elseif type(_allGroup) ~= "boolean" then
				ATMEFct.errorOutputCore(nil, fctDefinition, "allGroup type must be boolean", false)
			elseif _filter ~= nil and type(_filter) ~= "string" then
				ATMEFct.errorOutputCore(nil, fctDefinition, "filter type must be nil or string", false)
			end
		end
	end,
	
	getGroupsInAreaForCoalition = function(_coalitionName, _area, _allGroup, _filter)
		local fctDefinition = "Function ATME.C_Group.getGroupsInAreaForCoalition(coalitionName, area, allGroup, [filter])"
		
		if type(_coalitionName) == "string" and ATME.isObjectClass(_area, ATME.C_Area) == true and type(_allGroup) == "boolean" and
				(_filter == nil or type(_filter) == "string") then
			
			local coalitionName = string.upper(_coalitionName)
			if ATMEConst.coalitionIds[coalitionName] ~= nil then
				local filterValue
				if _filter == nil then
					filterValue = "ALL"
				else
					filterValue = string.upper(_filter)
				end
				
				if filterValue == "ALL" or ATMEConst.categoryNameFilters[filterValue] ~= nil then
					local datas = {
						groups = {}, 
						nbGroups = 0, 
						nbUnitsGroup = {},
						units = {},
						nbUnits = 0,
						allGroup = _allGroup,
						filter = filterValue,
						coalition = coalitionName,
					}
					
					local localMembersArea = ATMEDatas.C_Area_MT:get(_area:getIndex())
					
					for _name, _zoneItem in pairs(localMembersArea.zonesList) do
						local box = _zoneItem.zone:getBox()

						local volume = {
							id = world.VolumeType.BOX,
							params = box,
						}
						
						datas.zone = _zoneItem.zone
						world.searchObjects(Object.Category.UNIT, volume, ATMEFct.C_Group_searchInBox, datas)
					end
					
					return datas.groups, datas.nbGroups, datas.units, datas.nbUnits
				else
					ATMEFct.errorOutputCore(nil, fctDefinition, "filter must be 'ALL', 'AIRPLANE', 'HELICOPTER', 'GROUND' or 'SHIP'", false)
				end
			else
				ATMEFct.errorOutputCore(nil, fctDefinition, "coalitionName must be 'RED' or 'BLUE'", false)
			end
		else
			if type(_coalitionName) ~= "string" then
				ATMEFct.errorOutputCore(nil, fctDefinition, "coalitionName type must be string", false)
			elseif ATME.isObjectClass(_area,ATME.C_Area) == false then
				ATMEFct.errorOutputCore(nil, fctDefinition, "area type must be ATME.C_Area", false)
			elseif type(_allGroup) ~= "boolean" then
				ATMEFct.errorOutputCore(nil, fctDefinition, "allGroup type must be boolean", false)
			elseif _filter ~= nil and type(_filter) ~= "string" then
				ATMEFct.errorOutputCore(nil, fctDefinition, "filter type must be nil or string", false)
			end
		end
	end,
	
	getGroupsInDCSZoneForAll = function(_zoneName, _allGroup, _filter)
		local fctDefinition = "Function ATME.C_Group.getGroupsInDCSZoneForAll(zoneName, allGroup, [filter])"
		
		if type(_zoneName) == "string" and type(_allGroup) == "boolean" and (_filter == nil or type(_filter) == "string") then
			local filterValue
			if _filter == nil then
				filterValue = "ALL"
			else
				filterValue = string.upper(_filter)
			end
			
			if filterValue == "ALL" or ATMEConst.categoryNameFilters[filterValue] ~= nil then
				local zone = ATME.getDCSZone(_zoneName)
				if zone ~= nil then
					local volume = {
						id = world.VolumeType.BOX,
						params = {
							min = {
								x = zone.point.x - zone.radius,
								y = 0,
								z = zone.point.z - zone.radius
							},
							max = {
								x = zone.point.x + zone.radius,
								y = 200000,
								z = zone.point.z + zone.radius,
							},
						},
					}
					
					local datas = {
						groups = {}, 
						nbGroups = 0, 
						nbUnitsGroup = {},
						units = {},
						nbUnits = 0,
						zone = ATMEFct.C_Circle_create(zone.point, zone.radius),
						allGroup = _allGroup,
						filter = filterValue,
					}
					
					world.searchObjects(Object.Category.UNIT, volume, ATMEFct.C_Group_searchInBox, datas)
					
					return datas.groups, datas.nbGroups, datas.units, datas.nbUnits
				else
					ATMEFct.errorOutputCore(nil, fctDefinition, "Zone " .. _name .. " unknown", false)
				end
			else
				ATMEFct.errorOutputCore(nil, fctDefinition, "filter must be 'ALL', 'AIRPLANE', 'HELICOPTER', 'GROUND' or 'SHIP'", false)
			end
		else
			if type(_zoneName) ~= "string" then
				ATMEFct.errorOutputCore(nil, fctDefinition, "zoneName type must be string", false)
			elseif type(_allGroup) ~= "boolean" then
				ATMEFct.errorOutputCore(nil, fctDefinition, "allGroup type must be boolean", false)
			elseif _filter ~= nil and type(_filter) ~= "string" then
				ATMEFct.errorOutputCore(nil, fctDefinition, "filter type must be nil or string", false)
			end
		end
	end,
	
	getGroupsInDCSZoneForCoalition = function(_coalitionName, _zoneName, _allGroup, _filter)
		local fctDefinition = "Function ATME.C_Group.getGroupsInDCSZoneForCoalition(coalitionName, zoneName, allGroup, [filter])"
		
		if type(_coalitionName) == "string" and type(_zoneName) == "string" and type(_allGroup) == "boolean" and 
					(_filter == nil or type(_filter) == "string")then
			local coalitionName = string.upper(_coalitionName)
			if ATMEConst.coalitionIds[coalitionName] ~= nil then
				local filterValue
				if _filter == nil then
					filterValue = "ALL"
				else
					filterValue = string.upper(_filter)
				end
				
				if filterValue == "ALL" or ATMEConst.categoryNameFilters[filterValue] ~= nil then
					local zone = ATME.getDCSZone(_zoneName)
					if zone ~= nil then
						local volume = {
							id = world.VolumeType.BOX,
							params = {
								min = {
									x = zone.point.x - zone.radius,
									y = 0,
									z = zone.point.z - zone.radius
								},
								max = {
									x = zone.point.x + zone.radius,
									y = 200000,
									z = zone.point.z + zone.radius,
								},
							},
						}
						
						local datas = {
							groups = {}, 
							nbGroups = 0, 
							nbUnitsGroup = {},
							units = {},
							nbUnits = 0,
							zone = ATMEFct.C_Circle_create(zone.point, zone.radius),
							allGroup = _allGroup,
							filter = filterValue,
							coalition = coalitionName,
						}

						world.searchObjects(Object.Category.UNIT, volume, ATMEFct.C_Group_searchInBox, datas)

						return datas.groups, datas.nbGroups, datas.units, datas.nbUnits
					else
						ATMEFct.errorOutputCore(nil, fctDefinition, "DCS zone " .. _zoneName .. " unknown", false)
					end
				else
					ATMEFct.errorOutputCore(nil, fctDefinition, "filter must be 'ALL', 'AIRPLANE', 'HELICOPTER', 'GROUND' or 'SHIP'", false)
				end
			else
				ATMEFct.errorOutputCore(nil, fctDefinition, "coalitionName must be 'RED' or 'BLUE'", false)
			end
		else
			if type(_coalitionName) ~= "string" then
				ATMEFct.errorOutputCore(nil, fctDefinition, "coalitionName type must be string", false)
			elseif type(_zoneName) ~= "string" then
				ATMEFct.errorOutputCore(nil, fctDefinition, "zoneName type must be string", false)
			elseif type(_allGroup) ~= "boolean" then
				ATMEFct.errorOutputCore(nil, fctDefinition, "allGroup type must be boolean", false)
			elseif _filter ~= nil and type(_filter) ~= "string" then
				ATMEFct.errorOutputCore(nil, fctDefinition, "filter type must be nil or string", false)
			end
		end
	end,

	getGroupsInZone2DForAll = function(_zone, _allGroup, _filter)
		local fctDefinition = "Function ATME.C_Group.getGroupsInZone2DForAll(zone, allGroup, [filter])"
		
		if ATME.isObjectClass(_zone, ATME.C_Zone2D) == true and type(_allGroup) == "boolean" and 
				(_filter == nil or type(_filter) == "string") then
			local filterValue
			if _filter == nil then
				filterValue = "ALL"
			else
				filterValue = string.upper(_filter)
			end
			
			if filterValue == "ALL" or ATMEConst.categoryNameFilters[filterValue] ~= nil then
				local box = _zone:getBox()
				
				local volume = {
					id = world.VolumeType.BOX,
					params = box,
				}
				
				local datas = {
					groups = {}, 
					nbGroups = 0, 
					nbUnitsGroup = {},
					units = {},
					nbUnits = 0,
					zone = _zone,
					allGroup = _allGroup,
					filter = filterValue,
				}

				world.searchObjects(Object.Category.UNIT, volume, ATMEFct.C_Group_searchInBox, datas)

				return datas.groups, datas.nbGroups, datas.units, datas.nbUnits
			else
				ATMEFct.errorOutputCore(nil, fctDefinition, "filter must be 'ALL', 'AIRPLANE', 'HELICOPTER', 'GROUND' or 'SHIP'", false)
			end
		else
			if ATME.isObjectClass(_zone, ATME.C_Zone2D) == false then
				ATMEFct.errorOutputCore(nil, fctDefinition, "zone type must be ATME.C_Circle, ATME.C_Ring, ATME.C_PickupZone, ATME.C_Rectangle or ATME.C_Polygon", false)
			elseif type(_allGroup) ~= "boolean" then
				ATMEFct.errorOutputCore(nil, fctDefinition, "allGroup type must be boolean", false)
			elseif _filter ~= nil and type(_filter) ~= "string" then
				ATMEFct.errorOutputCore(nil, fctDefinition, "filter type must be nil or string", false)
			end
		end
	end,
	
	getGroupsInZone2DForCoalition = function(_coalitionName, _zone, _allGroup, _filter)
		local fctDefinition = "Function ATME.C_Group.getGroupsInZone2DForCoalition(coalitionName, zone, allGroup, [filter])"
		
		if type(_coalitionName) == "string" and ATME.isObjectClass(_zone, ATME.C_Zone2D) == true and type(_allGroup) == "boolean" and 
				(_filter == nil or type(_filter) == "string") then
			local coalitionName = string.upper(_coalitionName)
			if ATMEConst.coalitionIds[coalitionName] ~= nil then
				local filterValue
				if _filter == nil then
					filterValue = "ALL"
				else
					filterValue = string.upper(_filter)
				end
			
				if filterValue == "ALL" or ATMEConst.categoryNameFilters[filterValue] ~= nil then
					local box = _zone:getBox()
					
					local volume = {
						id = world.VolumeType.BOX,
						params = box,
					}
					
					local datas = {
						groups = {}, 
						nbGroups = 0, 
						nbUnitsGroup = {},
						units = {},
						nbUnits = 0,
						zone = _zone,
						allGroup = _allGroup,
						filter = filterValue,
						coalition = coalitionName,
					}
					
					world.searchObjects(Object.Category.UNIT, volume, ATMEFct.C_Group_searchInBox, datas)
					
					return datas.groups, datas.nbGroups, datas.units, datas.nbUnits
				else
					ATMEFct.errorOutputCore(nil, fctDefinition, "filter must be 'ALL', 'AIRPLANE', 'HELICOPTER', 'GROUND' or 'SHIP'", false)
				end
			else
				ATMEFct.errorOutputCore(nil, fctDefinition, "coalitionName must be 'RED' or 'BLUE'", false)
			end
		else
			if type(_coalitionName) ~= "string" then
				ATMEFct.errorOutputCore(nil, fctDefinition, "coalitionName type must be string", false)
			elseif ATME.isObjectClass(_zone, ATME.C_Zone2D) == false then
				ATMEFct.errorOutputCore(nil, fctDefinition, "zone type must be ATME.C_Circle, ATME.C_Ring, ATME.C_PickupZone, ATME.C_Rectangle or ATME.C_Polygon", false)
			elseif type(_allGroup) ~= "boolean" then
				ATMEFct.errorOutputCore(nil, fctDefinition, "allGroup type must be boolean", false)
			elseif _filter ~= nil and type(_filter) ~= "string" then
				ATMEFct.errorOutputCore(nil, fctDefinition, "filter type must be nil or string", false)
			end
		end
	end,
	
	getReadyToBoardGroupsForAll = function()
		local groupsReady = {}
		local nbGroups = 0
		for _, _group in pairs(ATMEDatas.readyToBoardGroups) do
			groupsReady[_group:getName()] = _group
			nbGroups = nbGroups + 1
		end
		
		return groupsReady, nbGroups
	end,
	
	getReadyToBoardGroupsForCoalition = function(_coalitionName)
		local fctDefinition = "Function ATME.C_Group.getReadyToBoardGroupsForCoalition(coalitionName)"
		
		if type(_coalitionName) == "string" then
			local coalitionName = string.upper(_coalitionName)
			if ATMEConst.coalitionIds[coalitionName] ~= nil then
				local groupsReady = {}
				local nbGroups = 0
				for _, _group in pairs(ATMEDatas.readyToBoardGroups) do
					if _group:getCoalitionName() == coalitionName then
						groupsReady[_group:getName()] = _group
						nbGroups = nbGroups + 1
					end
				end
				
				return groupsReady, nbGroups
			else
				ATMEFct.errorOutputCore(nil, fctDefinition, "coalitionName must be 'RED' or 'BLUE'", false)
			end
		else
			ATMEFct.errorOutputCore(nil, fctDefinition, "coalitionName type must be string", false)
		end
	end,
}


ATMEFct.C_Group_addUnit = function(_ATMEGroup, _unit)
	local unitName = _unit:getName()

	local localMembers = ATMEDatas.C_Group_MT:get(_ATMEGroup:getIndex())
	
	if ATMEFct.isObjectClass(_unit, ATME.C_Player) == true then
		localMembers.hasPlayers = true
	end
	
	table.insert(localMembers.ATMEUnitNames, unitName)
	localMembers.ATMEUnits[unitName] = _unit
	
	ATMEFct.outputCore(nil,"Function C_Group_addUnit : ajout unité " .. unitName, 2)
	
	if ATMEFct.isObjectClass(_unit, ATME.C_Player) == true or 
		(ATMEFct.isObjectClass(_unit, ATME.C_AIUnit) == true and localMembers.onlyInfantry == true and _unit:isInfantry() == false) then
		localMembers.onlyInfantry = false
	end
end


ATMEFct.C_Group_deleteUnit = function(_ATMEGroup, _unitName)
	local localMembers = ATMEDatas.C_Group_MT:get(_ATMEGroup:getIndex())
	localMembers.ATMEUnits[_unitName] = nil
	
	for _i, _name in ipairs(localMembers.ATMEUnitNames) do
		if _name == _unitName then
			table.remove(localMembers.ATMEUnitNames, _i)
		end
	end
	
	if #localMembers.ATMEUnitNames == 0 then
		ATMEFct.outputCore(nil,"Function C_Group_deleteUnit : appel C_group_delete", 2)
		ATMEFct.C_Group_delete(_ATMEGroup)
	end
end

ATMEFct.C_Group_evalDistances = function(_ATMEGroup, _point)
	local minDistance = -1
	local maxDistance = -1
	local minHDistance = -1
	local maxHDistance = -1
	local minDeltaAltitude = -1
	local maxDeltaAltitude = -1
	local units = _ATMEGroup:getUnits()
	
	for _, _unit in pairs(units) do
		local v = ATMEFct.C_Vector3D_create(nil, nil, _point, _unit:getPosition())
		if minDistance < 0 or minDistance > v:getModule() then
			minDistance = v:getModule()
		end
		
		if maxDistance < v:getModule() then
				maxDistance = v:getModule()
		end
		
		if minHDistance < 0 or minHDistance > v:getHModule() then
			minHDistance = v:getHModule()
		end
		
		if maxHDistance < v:getHModule() then
				maxHDistance = v:getHModule()
		end
		
		if minDeltaAltitude < 0 or minDeltaAltitude > v:getY() then
			minDeltaAltitude = v:getY()
		end
		
		if maxDeltaAltitude < v:getY() then
			maxDeltaAltitude = v:getY()
		end
	end
	
	return minDistance, maxDistance, minHDistance, maxHDistance, minDeltaAltitude, maxDeltaAltitude
end


ATMEFct.C_Group_changeReadyToBoard = function(_group, _value, _nextWaypoint)
	local localMembers = ATMEDatas.C_Group_MT:get(_group:getIndex())
	
	if _value == true and ATMEDatas.readyToBoardGroups[_group:getName()] == nil then
		localMembers.nextWaypoint = _nextWaypoint
		
		ATMEDatas.readyToBoardGroups[_group:getName()] = _group
		_group:resetPatrol()
		_group:stop()
	elseif _value == false and _group:isBoarding() == false and ATMEDatas.readyToBoardGroups[_group:getName()] ~= nil then
		_group:move()
		ATMEDatas.readyToBoardGroups[_group:getName()] = nil
		localMembers.nextWaypoint = nil
	end	
end



ATMEFct.C_Group_create = function(_ATMEUnit, _datas)
	local group = _ATMEUnit:getDCSUnit():getGroup()
	local name = group:getName()
	
	-- Récupération des données d'état initial pour le groupe
	
	local uncontrolled = _datas.uncontrolled
	local alwaysVisible = _datas.visible
		
	local newGroup = {}
	setmetatable(newGroup, ATMEDatas.C_Group_MT.mt)
	
	local index
	
	if ATMEFct.isObjectClass(_ATMEUnit, ATME.C_Player) == true then
		index = ATMEDatas.C_Group_MT:add(true, name, _datas)
	else
		index = ATMEDatas.C_Group_MT:add(false, name, _datas)
	end
	
	local localMembers = ATMEDatas.C_Group_MT:get(index)
	
	
	function newGroup.getName(self)
		return name
	end
	
	function newGroup.tagGetByID(self, _position)
		local fctDefinition = ATMEFct.getErrorPrefix(newGroup) .. "tagGetByID(position)"
		
		if type(_position) == "number" then
			local pos = math.floor(_position)
			if localMembers.tagsName ~= nil and pos >= 1 and pos <= #localMembers.tagsName then
				return localMembers.tagsName[pos]
			end
		else
			ATMEFct.errorOutputCore(nil, fctDefinition, "position type must be number", true)
		end
	end
	
	function newGroup.tagGetCount(self)
		if tagsName ~= nil then
			return #tagsName
		else
			return 0
		end
	end
	
	function newGroup.tagCompare(self, _tagsToCompare)
		local fctDefinition = ATMEFct.getErrorPrefix(newGroup) .. "tagCompare(tagsToCompare)"
		
		if type(_tagsToCompare) == "string" then
			if localMembers.tagsName ~= nil then
				local ok = ATMEFct.compareTags(localMembers.tagsName, _tagsToCompare)
				
				if ok ~= nil then
					return ok
				else
					ATMEFct.errorOutputCore(nil, fctDefinition, "tagsToCompare format must be 'T1|T2|..|Tn'", false)
				end
			else
				return false
			end
		else
			ATMEFct.errorOutputCore(nil, fctDefinition, "tagsToCompare type must be string", true)
		end
	end
	
	function newGroup.isAlwaysVisible(self)
		return alwaysVisible
	end
	
	function newGroup.getCategoryName(self)
		local id = group:getCategory()
		return ATMEConst.categoryNames[id]
	end
	
	function newGroup.getCoalitionName(self)
		local id = group:getCoalition()
		return ATMEConst.coalitionNames[id]
	end
	
	function newGroup.getDCSGroup(self)
		return group
	end
	
	function newGroup.getIndex(self)
		return index
	end
		
	function newGroup.activate(self)
		group:activate()
	end
	
	function newGroup.isActivated(self)
		-- ATTENTION fonction DCS sur l'unité et non sur le groupe
		-- Risque de BUG DCS car pas homogène
		
		local unit = self:getFirstUnit()

		if unit ~= nil then
			return unit:getDCSUnit():isActive()
		else
			return false
		end
	end
	
	function newGroup.getUserPrivateDatas(self, _module)
		local fctDefinition = ATMEFct.getErrorPrefix(newGroup) .. "getUserPrivateDatas(module)"
		
		if ATME.isObjectClass(_module, ATME.C_Module) == true then
			return localMembers.userPrivateDatas[_module:getName()]
		else
			ATMEFct.errorOutputCore(nil, fctDefinition, "module type must be ATME.C_Module", true)
		end
	end
	
	function newGroup.setInvisible(self, _invisible)
		local fctDefinition = ATMEFct.getErrorPrefix(newGroup) .. "setInvisible(invisible)"
		
		if type(_invisible) == "boolean" then
			local controller = self:getDCSGroup():getController()
			local command = {
				id = "SetInvisible", 
				params = { 
					value = _invisible, 
				} 
			}
			
			controller:setCommand(command)
		else
			ATMEFct.errorOutputCore(nil, fctDefinition, "invisible type must be boolean", true)
		end
	end
	
	function newGroup.setImmortal(self, _immortal)
		local fctDefinition = ATMEFct.getErrorPrefix(newGroup) .. "setInvisible(immortal)"
		
		if type(_immortal) == "boolean" then
			local controller = self:getDCSGroup():getController()
			local command = {
				id = "SetImmortal", 
				params = { 
					value = _immortal, 
				} 
			}
			
			controller:setCommand(command)
		else
			ATMEFct.errorOutputCore(nil, fctDefinition, "immortal type must be boolean", true)
		end
	end
	
	function newGroup.setRoute(self, _route)
		local localMembersRoute
		
		local fctDefinition = ATMEFct.getErrorPrefix(newGroup) .. "setRoute(route)"
		
		if ATME.isObjectClass(_route, ATME.C_Route) == true then
			localMembersRoute = ATMEDatas.C_Route_MT:get(_route:getIndex())
			
			if localMembers.spawnDatas.type == localMembersRoute.type then
				if uncontrolled == false then
					self:resetPatrol()
					localMembers.disembark = false

					local err, waypoints = ATMEFct.C_Route_createWaypoints(_route)
					if err == false then
						ATMEFct.C_Route_addCurrentPositionWaypoint(waypoints, localMembers.spawnDatas.datas.route.points[localMembers.lastPassedWaypoint + 1], self)
						localMembers.waypoints = waypoints
						localMembers.spawnDatas.datas.route.points = waypoints
						localMembers.lastPassedWaypoint = 0
						localMembers.offsetIdWaypoint = 0
						
						ATMEFct.C_CloningContext_setMission(self, localMembers.waypoints, true, false)
						
						-- Ajustement du nombre de waypoints si pour un aéronef le dernier waypoint
						-- n'est pas un waypoint d'atterrissage.
						
						localMembers.maxWaypoints = #localMembers.waypoints
						if self:canFly() == true then
							if 	localMembers.waypoints[#localMembers.waypoints].type ~= "Land" then
								localMembers.maxWaypoints = localMembers.maxWaypoints + 1
							end
						end
						
						
					else
						ATMEFct.setError("SPAWN_NO_WAYPOINTS")
					end
				else
					ATMEFct.errorOutputCore(nil, fctDefinition, name .. " is an uncontrolled group.", false)
				end
			else
				ATMEFct.errorOutputCore(nil, fctDefinition, "Route must have same type as " .. name, false)
			end
		else
			ATMEFct.errorOutputCore(nil, fctDefinition, "route type must be ATME.C_Route", true)
		end
	end
	
	function newGroup.setTask(self, _task, _zone2D)
		local fctDefinition = ATMEFct.getErrorPrefix(newGroup) .. "setTask(task, [zone])"
		
		if ATME.isObjectClass(_task, ATME.C_Task) == true and
				(_zone2D == nil or ATME.isObjectClass(_zone2D, ATME.C_Zone2D) == true or type(_zone2D) == "string") then
			
			local ok, usedOnZoneOnly, taskDatas = ATMEFct.C_Task_getTaskDatas(_task, localMembers.spawnDatas.type, false)
			
			if ok == true then
				if _zone2D ~= nil then
					local targetGroupName
					local zone2D
					
					local targetsCoalition = "RED"
					if self:getCoalitionName() == "RED" then
						targetsCoalition = "BLUE"
					end
					
					if type(_zone2D) == "string" then
						local zone = ATME.getDCSZone(_zone2D)
						if zone ~= nil then
							zone2D = ATMEFct.C_Circle_create(zone.point, zone.radius)
							targetGroupName = ATMEFct.C_Group_findTargetInZone2D(zone2D, targetsCoalition)
							
							if targetGroupName == nil then
								-- Aucune unité trouvée. Pas d'activation

								return false
							end
						else
							ATMEFct.errorOutputCore(nil, fctDefinition, "DCS zone " .. _zone2D .. " unknown", false)
							return
						end
					else
						targetGroupName = ATMEFct.C_Group_findTargetInZone2D(_zone2D, targetsCoalition)
						zone2D = _zone2D
						
						if targetGroupName == nil then
							-- Aucune unité trouvée. Pas d'activation
							
							return false
						end
					end

					-- Préparation
					ATMEDatas.onZoneTaskReady[name] = {
						isActive = false,
						zone = zone2D,
						targetGroupName = targetGroupName,
						delay = 1,
					}
					
					if ATMEFct.onZoneTasks[taskDatas.id] ~= nil then
						localMembers.onZoneTask = taskDatas
						
						return true
					else
						return false
					end
				else
					if usedOnZoneOnly == false then
						ATMEDatas.onZoneTaskReady[name] = nil
						localMembers.onZoneTask = nil
		
						local controller = self:getDCSGroup():getController()

						controller:setTask(taskDatas)
						
						return true
					else
						ATMEFct.errorOutputCore(nil, fctDefinition, "Task '" .. taskDatas.id .. "' is initialized to be set on zone", false)
					end
				end
			else
				ATMEFct.errorOutputCore(nil, fctDefinition, "Task '".. taskDatas.id .. "' is not allowed for group '" .. name .. "'", false)
			end	
		else
			if ATME.isObjectClass(_task, ATME.C_Task) == false then
				ATMEFct.errorOutputCore(nil, fctDefinition, "task type must be ATME.C_Task", true)
			elseif _zone2D ~= nil and ATME.isObjectClass(_zone2D, ATME.C_Zone2D) == false and type(_zone2D) ~= "string" then
				ATMEFct.errorOutputCore(nil, fctDefinition, "reference type must be nil or string or ATME.C_Zone2D or ATME.C_Group", false)
			end
		end
	end
	
	function newGroup.resetTask(self)
		local controller = self:getDCSGroup():getController()

		controller:resetTask()
		
		ATMEDatas.onZoneTaskReady[name] = nil
		localMembers.onZoneTask = nil
	end
	
	function newGroup.pushTask(self, _task)
		local fctDefinition = ATMEFct.getErrorPrefix(newGroup) .. "pushTask(task)"
		
		if ATME.isObjectClass(_task, ATME.C_Task) == true then
			local ok, usedOnZoneOnly, taskDatas = ATMEFct.C_Task_getTaskDatas(_task, localMembers.spawnDatas.type, false)
			
			if ok == true then
				if usedOnZoneOnly == false then
					local controller = self:getDCSGroup():getController()

					controller:pushTask(taskDatas)
				else
					ATMEFct.errorOutputCore(nil, fctDefinition, "Task '" .. taskDatas.id .. "' is initialized to be set on zone", false)
				end
			else
				ATMEFct.errorOutputCore(nil, fctDefinition, "Task '".. taskDatas.id .. "' is not allowed for group '" .. name .. "'", false)
			end	
		else
			if ATME.isObjectClass(_task, ATME.C_Task) == false then
				ATMEFct.errorOutputCore(nil, fctDefinition, "task type must be ATME.C_Task", true)
			end
		end
	end
	
	function newGroup.popTask(self)
		local controller = self:getDCSGroup():getController()

		controller:popTask()
	end
	
	function newGroup.canFly(self)
		local categoryName = self:getCategoryName()

		return categoryName == "AIRPLANE" or categoryName == "HELICOPTER"
	end
	
	function newGroup.getMinDistance(self, _reference)
		local fctDefinition = ATMEFct.getErrorPrefix(newGroup) .. "getMinDistance(reference)"
		
		if ATMEFct.isReference(_reference) == true then
			local point = ATMEFct.getPointFromReference(_reference)
			local minDistance, maxDistance, minHDistance, maxHDistance, minDeltaAltitude, maxDeltaAltitude = ATMEFct.C_Group_evalDistances(self, point)
			
			return minDistance
		else
			ATMEFct.errorOutputCore(nil, fctDefinition, "reference type must be ATME.C_AIUnit or ATME.C_Player or ATME.C_StaticObject or table (x,y) or (x,y,z)", true)
		end
	end
	
	function newGroup.getMaxDistance(self, _reference)
		local fctDefinition = ATMEFct.getErrorPrefix(newGroup) .. "getMaxDistance(reference)"
		if ATMEFct.isReference(_reference) == true then
			local point = ATMEFct.getPointFromReference(_reference)
			local minDistance, maxDistance, minHDistance, maxHDistance, minDeltaAltitude, maxDeltaAltitude = ATMEFct.C_Group_evalDistances(self, point)
			
			return maxDistance
		else
			ATMEFct.errorOutputCore(nil, fctDefinition, "reference type must be ATME.C_AIUnit or ATME.C_Player or ATME.C_StaticObject or table (x,y) or (x,y,z)", true)
		end
	end
	
	function newGroup.getMinHDistance(self, _reference)
		local fctDefinition = ATMEFct.getErrorPrefix(newGroup) .. "getMinHDistance(reference)"
		
		if ATMEFct.isReference(_reference) == true then
			local point = ATMEFct.getPointFromReference(_reference)
			local minDistance, maxDistance, minHDistance, maxHDistance, minDeltaAltitude, maxDeltaAltitude = ATMEFct.C_Group_evalDistances(self, point)
			return minHDistance
		else
			ATMEFct.errorOutputCore(nil, fctDefinition, "reference type must be ATME.C_AIUnit or ATME.C_Player or ATME.C_StaticObject or table (x,y) or (x,y,z)", true)
		end
	end
		
	function newGroup.getMaxHDistance(self, _reference)
		local fctDefinition = ATMEFct.getErrorPrefix(newGroup) .. "getMaxHDistance(reference)"
		
		if ATMEFct.isReference(_reference) == true then
			local point = ATMEFct.getPointFromReference(_reference)
			local minDistance, maxDistance, minHDistance, maxHDistance, minDeltaAltitude, maxDeltaAltitude = ATMEFct.C_Group_evalDistances(self, point)
			
			return maxHDistance
		else
			ATMEFct.errorOutputCore(nil, fctDefinition, "reference type must be ATME.C_AIUnit or ATME.C_Player or ATME.C_StaticObject or table (x,y) or (x,y,z)", true)
		end
	end
	
	function newGroup.getPosition(self)
		local unit = self:getFirstUnit()	
		
		if unit ~= nil then
			return unit:getPosition()
		end
	end
	
	function newGroup.getRandomUnitPosition(self)
		local unit = ATMEDatas.allAIUnitsAndPlayers[localmember.ATMEUnitNames[math.random(1, #localmember.ATMEUnitNames)]]
		
		if unit ~= nil then
			return unit:getPosition()
		end
	end
	
	function newGroup.disable(self)
		if localMembers.hasPlayers == false then
			localMembers.isEnabled = false
			
			local units = self:getUnits()
			for _, _unit in pairs(units) do
				_unit:disable()
			end
		end
	end
	
	function newGroup.setWaypointsTracking(self, _fullTracking)
		local fctDefinition = ATMEFct.getErrorPrefix(newGroup) .. "setWaypointsTracking(fullTracking)"
		
		if type(_fullTracking) == "boolean" then
			if localMembers.hasPlayers == false then
				localMembers.waypointsTracking = true
				localMembers.fullWaypointsTracking = _fullTracking
			else
				ATMEFct.errorOutputCore(nil, fctDefinition, "Group " .. name .. " has player units - Do not use setWaypointsTracking", false)
			end
		else
			ATMEFct.errorOutputCore(nil, fctDefinition, "fullTracking type must be boolean", true)
		end
	end
	
	function newGroup.resetWaypointsTracking(self)	
		localMembers.waypointsTracking = false
		localMembers.fullWaypointsTracking = false
	end
	
	function newGroup.isWaypointsTracking(self)
		return localMembers.waypointsTracking
	end

	function newGroup.isFullWaypointsTracking(self)
		return localMembers.fullWaypointsTracking
	end
	
	function newGroup.setSignal(self, _radius, _signalType)
		local fctDefinition = ATMEFct.getErrorPrefix(newGroup) .. "setSignal(radius, signalType)"
		
		if type(_radius) == "number" and type(_signalType) == "string" then
			if self:getCategoryName() == "GROUND" then
				if _radius > 0 then
					local tokens = ATMEFct.analyzeString(_signalType)
					local ok = false
					
					if #tokens == 2 and tokens[1].type == "TOKEN_SIGNAL_TYPE" and (tokens[2].type == "TOKEN_COLOR" or tokens[2].type == "TOKEN_TYPE_RANDOM") then
						if (tokens[1].value == "SMOKE" and ATMEConst.smokeColors[tokens[2].value] ~= nil) or
								(tokens[1].value == "FLARE" and ATMEConst.flareColors[tokens[2].value] ~= nil) then
							
							if localMembers.pickupZone == nil then
								local item = {
									unitName = "",
									groupName = self:getName(),
									radius = _radius,
									type = tokens[1].value,
									color = tokens[2].value,
									timeStart = -1,
									offsetTime = 0,
									coalitionUnitsInZone = {},
								}
								
								localMembers.signalIndex = ATMEDatas.signals:add(item)
								return true
							end
							
							ok = true
						end
					end
					
					if ok == false then
						ATMEFct.errorOutputCore(nil, fctDefinition, "signalType string bad format", false)
					end
				else
					ATMEFct.errorOutputCore(nil, fctDefinition, "radius must be > 0", false)
				end
			else
				ATMEFct.errorOutputCore(nil, fctDefinition, name .. " isn't a ground group", false)
			end
		else
			if type(_radius) ~= "number" then
				ATMEFct.errorOutputCore(nil, fctDefinition, "radius type must be number", false)
			elseif type(_signalType) ~= "string" then
				ATMEFct.errorOutputCore(nil, fctDefinition, "signalType type must be string", false)
			end
		end
		
		return false
	end
	
	function newGroup.resetSignal(self)
		if localMembers.signalIndex > 0 then
			ATMEFct.resetSignalUnits(localMembers.signalIndex)
			ATMEDatas.signals:remove(localMembers.signalIndex)
			localMembers.signalIndex = 0
		end
	end
	
	function newGroup.isSignalSet(self)
		return localMembers.signalIndex ~= 0
	end
	
	function newGroup.setAutoRespawn(self, _rules)
		local fctDefinition = ATMEFct.getErrorPrefix(newGroup) .. "setAutoRespawn([rules])"
		
		if (_rules == nil or type(_rules) == "string" or type(_rules) == "number") then
			if localMembers.hasPlayers == false then
				if _rules == nil then
					localMembers.autoRespawn = {
						activated = true,
						time = 0,
						random = false,
						minTime = 0,
						maxTime = 0,
					}
				elseif type(_rules) == "number" then
					if _rules >= 0 then
						local value = math.floor(_rules)
						localMembers.autoRespawn = {
							activated = true,
							time = value,
							random = false,
							minTime = 0,
							maxTime = 0,
						}
					else
						ATMEFct.errorOutputCore(nil, fctDefinition, "rules must be >= 0 when number", false)
					end
				else
					local tokens = ATMEFct.analyzeString(_rules)
					
					if #tokens >= 1 and #tokens <= 3 then
						local ok = false
						local minRandom = 0
						local maxRandom = 0
						local value = 0
						local randomFlag = false
						
						if #tokens >= 2 and tokens[1].type == "TOKEN_TYPE_RANDOM" then
							randomFlag = true
							
							if tokens[2].type == "TOKEN_INTEGER" or tokens[2].type == "TOKEN_TIME" then
								if tokens[2].value >= 0 then
									maxRandom = tokens[2].value
									
									if #tokens == 3 then
										minRandom = tokens[2].value
										
										if tokens[3].type == "TOKEN_INTEGER" or tokens[3].type == "TOKEN_TIME" then
											if tokens[3].value >= 0 then
												maxRandom = tokens[3].value
												ok = true
											else
												ATMEFct.errorOutputCore(nil, fctDefinition, "Parameter #3 must be >= 0 in string format rules", false)
											end
										else
											ATMEFct.errorOutputCore(nil, fctDefinition, "Parameter #3 must be number or time value in string format rules", false)
										end
									else
										maxRandom = tokens[2].value
										ok = true
									end
								else
									ATMEFct.errorOutputCore(nil, fctDefinition, "Parameter #2 must be >= 0 in string format rules", false)
								end
							else
								ATMEFct.errorOutputCore(nil, fctDefinition, "Parameter #2 must be number or time value in string format rules", false)
							end
						else
							if tokens[1].type == "TOKEN_INTEGER" or tokens[1].type == "TOKEN_TIME" then
								if tokens[1].value >= 0 then
									value = tokens[1].value
									ok = true
								else
									ATMEFct.errorOutputCore(nil, fctDefinition, "Parameter #1 must be >= 0 in string format rules", false)
								end
							else
								ATMEFct.errorOutputCore(nil, fctDefinition, "Parameter #1 must be number or time value or 'RANDOM' in string format rules", false)
							end
						end
						
						if ok == true then
							if randomFlag == true then
								if maxRandom > minRandom then
									localMembers.autoRespawn = {
										activated = true,
										time = 0,
										random = true,
										minTime = minRandom,
										maxTime = maxRandom,
									}
								else
									ATMEFct.errorOutputCore(nil, fctDefinition, "Parameter #2 must be < parameter #3 in string format rules", false)
								end
							else
								localMembers.autoRespawn = {
									activated = true,
									time = value,
									random = false,
									minTime = 0,
									maxTime = 0,
								}
							end
						end
					else
						ATMEFct.errorOutputCore(nil, fctDefinition, "Bad string format rules", false)
					end
				end
			else
				ATMEFct.errorOutputCore(nil, fctDefinition, "Group " .. name .. " has player units - Do not use setAutoRespawn", false)
			end
		else
			if _rules ~= nil and type(_rules) ~= "string" and type(_rules) ~= "number" then
				ATMEFct.errorOutputCore(nil, fctDefinition, "rules type must be nil, string or number", true)
			end
		end
	end
	
	function newGroup.resetAutoRespawn(self)
		localMembers.autoRespawn = {
			activated = false,
			time = 0,
			random = false,
			minTime = 0,
			maxTime = 0,
		}
		return 
	end
	
	function newGroup.hasAutoRespawn(self)
		return localMembers.autoRespawn.activated
	end
	
	function newGroup.setPatrol(self, _restartWaypoint, _lastWaypoint, _stopCondition)
		local fctDefinition = ATMEFct.getErrorPrefix(newGroup) .. "setPatrol(lastWaypoint, restartWaypoint, [stopCondition])"
		
		if type(_lastWaypoint) == "number" or type(_lastWaypoint) == "string" or 
				type(_restartWaypoint) == "number" or type(_restartWaypoint) == "string" or
				_stopCondition == nil or type(_stopCondition) == "string" then
				
			if localMembers.hasPlayers == false then
				local lastWaypoint
				local restartWaypoint
				local randomValue = -1
				local maxTurnsValue = -1
				local maxTimeValue = -1
				
				if type(_lastWaypoint) == "number" then
					lastWaypoint = _lastWaypoint
				else
					lastWaypoint = ATMEFct.C_CloningContext_getWaypointFromName(localMembers.waypoints, _lastWaypoint)
					if lastWaypoint == nil then
						ATMEFct.errorOutputCore(nil, fctDefinition, "Waypoint " .. _lastWaypoint .. " not found in current route - Group " .. name, false)
						return
					end
				end
				
				if type(_restartWaypoint) == "number" then
					restartWaypoint = _restartWaypoint
				else
					restartWaypoint = ATMEFct.C_CloningContext_getWaypointFromName(localMembers.waypoints, _restartWaypoint)
					if restartWaypoint == nil then
						ATMEFct.errorOutputCore(nil, fctDefinition, "Waypoint " .. _restartWaypoint .. " not found in current route - Group " .. name, false)
						return
					end
				end
				
				if lastWaypoint <= restartWaypoint then
					ATMEFct.errorOutputCore(nil, fctDefinition, "LastWaypoint must be > at restartWaypoint - Group " .. name, false)
					return
				end
				
				if _stopCondition ~= nil then
					local tokens = ATMEFct.analyzeString(_stopCondition)
						
					if #tokens == 2 then
						if tokens[1].type == "TOKEN_TYPE_RANDOM" then
							if tokens[2].type == "TOKEN_INTEGER" and tokens[2].value > 0 and tokens[2].value < 1 then
								randomValue = tokens[2].value
							else
								ATMEFct.errorOutputCore(nil, fctDefinition, "Parameter #2 must be integer > 0 and < 1 in string format stopCondition", false)
							end
						elseif tokens[1].type == "TOKEN_TYPE_TIME" then
							if (tokens[2].type == "TOKEN_INTEGER" or tokens[2].type == "TOKEN_TIME") and tokens[2].value > 0 then
								maxTimeValue = tokens[2].value + timer.getTime()
							else
								ATMEFct.errorOutputCore(nil, fctDefinition, "Parameter #2 must be integer or time value in string format stopCondition", false)
							end
						elseif tokens[1].type == "TOKEN_TYPE_MAX_TURNS" then
							if tokens[2].type == "TOKEN_INTEGER" and tokens[2].value > 0 then
								maxTurnsValue = tokens[2].value
							else
								ATMEFct.errorOutputCore(nil, fctDefinition, "Parameter #2 must be integer > 0 in string format stopCondition", false)
							end
						end
					else
						ATMEFct.errorOutputCore(nil, fctDefinition, "Bad string format stopCondition", false)
					end
				end
				
				-- La patrouille ne peut se faire que du deuxième jusqu'à l'avant dernier waypoint de la route pour un aéronef
				if localMembers.waypoints[lastWaypoint + 1].type == "Turning Point" and 
							localMembers.waypoints[restartWaypoint + 1].type == "Turning Point"  then
					
					localMembers.patrolWP = {
						last = lastWaypoint + 1,
						restart = restartWaypoint + 1,
						nbTurns = 0,
						maxTurns = maxTurnsValue,
						maxTime = maxTimeValue,
						maxRandom = randomValue,
						isArmed = false,
					}
					
					local item = {
						name = name,	
					}
					
					localMembers.patrolWP.id = ATMEDatas.patrolsToUpdate:add(item)
				else
					if localMembers.waypoints[lastWaypoint + 1].type ~= "Turning Point" then
						ATMEFct.errorOutputCore(nil, fctDefinition, "LastWaypoint must be 'Turning Point' type - Group " .. name, false)
						return
					else
						ATMEFct.errorOutputCore(nil, fctDefinition, "RestartWaypoint must be 'Turning Point' type - Group " .. name, false)
						return
					end
				end
			else
				ATMEFct.errorOutputCore(nil, fctDefinition, "Group " .. name .. " has player units - Do not use setPatrol", false)
			end
		else
			if type(_lastWaypoint) ~= "string" and type(_lastWaypoint) ~= "number" then
					ATMEFct.errorOutputCore(nil, fctDefinition, "lastWaypoint type must be string or number", true)
			elseif type(_restartWaypoint) ~= "string" and type(_restartWaypoint) ~= "number" then
					ATMEFct.errorOutputCore(nil, fctDefinition, "restartWaypoint type must be string or number", true)
			elseif _stopCondition ~= nil and type(_stopCondition) ~= "string" then
				ATMEFct.errorOutputCore(nil, fctDefinition, "stopCondition type must be nil or string", false)
			end
		end
	end
	
	function newGroup.resetPatrol(self)
		if localMembers.patrolWP.id > 0 then
			ATMEDatas.patrolsToUpdate:remove(localMembers.patrolWP.id)
		end
		
		localMembers.patrolWP = {
			last = -1,
			restart = -1,
			nbTurns = 0,
			maxTurns = -1,
			maxTime = -1,
			maxRandom = -1,
			isArmed = false,
			id = 0,
		}
	end
	
	function newGroup.start(self)
		local fctDefinition = ATMEFct.getErrorPrefix(newGroup) .. "start()"
		
		if localMembers.hasPlayers == false then
			if self:canFly() == true then
				if uncontrolled == true then
					uncontrolled = false
					
					local controller = self:getDCSGroup():getController()

					controller:setCommand({ 
											id = 'Start', 
											params = {},
										})
				end
			else
				self:freeze(false)
			end
		else
			ATMEFct.errorOutputCore(nil, fctDefinition, "Group " .. name .. " can't have player units", false)
		end
	end
	
	function newGroup.isControlled(self)
		return uncontrolled == false
	end
	
	function newGroup.getFirstUnit(self)
		localMembers.nextUnit = 2
		localMembers.previousUnit = 0
		
		if #localMembers.ATMEUnitNames > 0 then
			return self:getUnitByName(localMembers.ATMEUnitNames[1])
		end
	end

	function newGroup.getNextUnit(self)
		if localMembers.nextUnit <= #localMembers.ATMEUnitNames then
			localMembers.previousUnit = localMembers.nextUnit - 1
			localMembers.nextUnit = localMembers.nextUnit + 1

			return self:getUnitByName(localMembers.ATMEUnitNames[localMembers.nextUnit - 1])
		end
	end

	function newGroup.getPreviousUnit(self)
		if localMembers.previousUnit > 0 then
			localMembers.nextUnit = localMembers.previousUnit + 1
			localMembers.previousUnit = localMembers.previousUnit - 1

			return self:getUnitByName(localMembers.ATMEUnitNames[localMembers.previousUnit + 1])
		end
	end

	function newGroup.getLastUnit(self)
		localMembers.nextUnit = #localMembers.ATMEUnitNames + 1
		localMembers.previousUnit = #localMembers.ATMEUnitNames - 1
		
		if #localMembers.ATMEUnitNames > 0 then
			return self:getUnitByName(localMembers.ATMEUnitNames[#localMembers.ATMEUnitNames])
		end
	end


	function newGroup.getUnitByName(self, _name)
		local fctDefinition = ATMEFct.getErrorPrefix(newGroup) .. "getUnitByName(name)"
		
		if type(_name) == "string" then
			return localMembers.ATMEUnits[_name]
		else
			ATMEFct.errorOutputCore(nil, fctDefinition, "name type must be string", true)
		end	
	end

	function newGroup.getUnits(self)
		return localMembers.ATMEUnits
	end

	function newGroup.getNbUnits(self)
		return #localMembers.ATMEUnitNames
	end

	function newGroup.isOnlyInfantry(self)
		return localMembers.onlyInfantry
	end

	function newGroup.isOnlyAI(self)
		return localMembers.hasPlayers == false
	end

	function newGroup.isInArea(self, _area, _allGroup)
		local fctDefinition = ATMEFct.getErrorPrefix(newGroup) .. "isInArea(area, allGroup)"
		
		if ATME.isObjectClass(_area, ATME.C_Area) == true and type(_allGroup) == "boolean" then
			local allUnitInArea = true
			local found = false
			local units = self:getUnits()
			for _, _unit in pairs(units) do
				local point = _unit:getPosition()
				local isInside, _, _ = ATMEFct.C_Area_isInside(_area, point)
				if  isInside == false then
					allUnitInArea = false
				else 
					found = true
				end
			end
			
			return(_allGroup == false and found == true) or (_allGroup == true and allUnitInArea == true)
		else
			if ATME.isObjectClass(_area, ATME.C_Area) == false then
				ATMEFct.errorOutputCore(nil, fctDefinition, "area type must be ATME.C_Area", true)
			elseif type(_allGroup) ~= "boolean" then
				ATMEFct.errorOutputCore(nil, fctDefinition, "allGroup type must be boolean", false)
			end
		end
	end				
	
	function newGroup.isInDCSZone(self, _zoneName, _allGroup)
		local fctDefinition = ATMEFct.getErrorPrefix(newGroup) .. "isInDCSZone(zoneName, allGroup)"
		
		if type(_zoneName) == "string" and type(_allGroup) == "boolean" then
			local zone = ATME.getDCSZone(_zoneName)
			if zone ~= nil then
				if _allGroup == false then
					return self:getMinHDistance(zone.point) <= zone.radius
				else
					return self:getMaxHDistance(zone.point) <= zone.radius
				end
			else
				ATMEFct.errorOutputCore(nil, fctDefinition, "DCS zone " .. _zoneName .. " unknown", false)
			end
		else
			if type(_zoneName) ~= "string" then
				ATMEFct.errorOutputCore(nil, fctDefinition, "zoneName type must be string", true)
			elseif type(_allGroup) ~= "boolean" then
				ATMEFct.errorOutputCore(nil, fctDefinition, "allGroup type must be boolean", false)
			end
		end
	end

	function newGroup.isInZone2D(self, _zone, _allGroup)
		local fctDefinition = ATMEFct.getErrorPrefix(newGroup) .. "isInZone2D(zone, allGroup)"
		
		if ATME.isObjectClass(_zone, ATME.C_Zone2D) == true and type(_allGroup) == "boolean" then
			local units = self:getUnits()
			local allGroupInZone = true
			local found = false
			
			for _, _unit in pairs(units) do
				local point = _unit:getPosition()
				if ATMEFct.isObjectClass(_zone, ATME.C_Polygon) == true then
					local localMembersZone = ATMEDatas.C_Polygon_MT:get(_zone:getIndex())
					if ATMEFct.C_Polygon_isInside(point, localMembersZone.triangles) == false then
						allGroupInZone = false
					else
						found = true
					end
				elseif ATMEFct.isObjectClass(_zone, ATME.C_Circle) == true then
					local localMembersZone = ATMEDatas.C_Circle_MT:get(_zone:getIndex())
					if ATMEFct.C_Circle_isInside(point, localMembersZone.center, nil, 0, localMembersZone.radius) == false then
						allGroupInZone = false
					else
						found = true
					end
				elseif ATMEFct.isObjectClass(_zone, ATME.C_PickupZone) == true then
					local localMembersZone = ATMEDatas.C_PickupZone_MT:get(_zone:getIndex())
					if ATMEFct.C_Circle_isInside(point, localMembersZone.center, nil, 0, localMembersZone.radius) == false then
						allGroupInZone = false
					else
						found = true
					end
				else
					local localMembersZone = ATMEDatas.C_Ring_MT:get(_zone:getIndex())
					if ATMEFct.C_Circle_isInside(point, localMembersZone.center, nil, localMembersZone.radiusMin, localMembersZone.radiusMax) == false then
						allGroupInZone = false
					else
						found = true
					end
				end
			end
			
			return (_allGroup == true and allGroupInZone == true) or (_allGroup == false and found == true) 
		else
			if ATME.isObjectClass(_zone, ATME.C_Zone2D) == false then
				ATMEFct.errorOutputCore(nil, fctDefinition, "zone type must be ATME.C_Circle, ATME.C_Ring, ATME.C_PickupZone, ATME.C_Rectangle or ATME.C_Polygon", true)
			elseif type(_radius) ~= "number" then
				ATMEFct.errorOutputCore(nil, fctDefinition, "radius type must be number", false)
			elseif type(_allGroup) ~= "boolean" then
				ATMEFct.errorOutputCore(nil, fctDefinition, "allGroup type must be boolean", false)
			end
		end
	end	
			
	function newGroup.isInSphere(self, _reference, _radius, _allGroup)
		local fctDefinition = ATMEFct.getErrorPrefix(newGroup) .. "isInZone3D(reference, radius, allGroup)"
		
		if ATMEFct.isReference(_reference) == true and type(_radius) == "number" then
			if _radius > 0 then
				if _allGroup == false then
					return self:getMinDistance(_reference) <= _radius
				else
					return self:getMaxDistance(_reference) <= _radius
				end
			else
				ATMEFct.errorOutputCore(nil, fctDefinition, "radius must be > 0", false)
			end
		else
			if ATMEFct.isReference(_reference) == false then
				ATMEFct.errorOutputCore(nil, fctDefinition, "reference type must be ATME.C_AIUnit or ATME.C_Player or ATME.C_StaticObject or table (x,y) or (x,y,z)", true)
			elseif type(_radius) ~= "number" then
				ATMEFct.errorOutputCore(nil, fctDefinition, "radius type must be number", false)
			elseif type(_allGroup) ~= "boolean" then
				ATMEFct.errorOutputCore(nil, fctDefinition, "allGroup type must be boolean", false)
			end
		end
	end
	
	function newGroup.isNear(self, _reference, _radius, _deltaAltitude, _allGroup)
		local fctDefinition = ATMEFct.getErrorPrefix(newGroup) .. "isNear(reference, radius, deltaAltitude, allGroup)"
		
		if ATMEFct.isReference(_reference) == true and type(_radius) == "number" and type(_deltaAltitude) == "number" then	
			if _radius > 0 then
				if _deltaAltitude > 0 then
					local point = ATMEFct.getPointFromReference(_reference)
					local minDistance, maxDistance, minHDistance, maxHDistance, minDeltaAltitude, maxDeltaAltitude = ATMEFct.C_Group_evalDistances(self, point)
					
					if _allGroup == false then
						return minHDistance <= _radius and minDeltaAltitude <= _deltaAltitude
					else
						return maxHDistance <= _radius and maxDeltaAltitude <= _deltaAltitude
					end
				else
					ATMEFct.errorOutputCore(nil, fctDefinition, "deltaAltitude must be > 0", false)
				end
			else
				ATMEFct.errorOutputCore(nil, fctDefinition, "radius must be > 0", false)
			end
		else
			if ATMEFct.isReference(_reference) == false then
				ATMEFct.errorOutputCore(nil, fctDefinition, "reference type must be ATME.C_AIUnit or ATME.C_Player or ATME.C_StaticObject or table (x,y) or (x,y,z)", true)
			elseif type(_radius) ~= "number" then
				ATMEFct.errorOutputCore(nil, fctDefinition, "radius type must be number", false)
			elseif type(_deltaAltitude) ~= "number" then
				ATMEFct.errorOutputCore(nil, fctDefinition, "deltaAltitude type must be number", false)
			elseif type(_allGroup) ~= "boolean" then
				ATMEFct.errorOutputCore(nil, fctDefinition, "allGroup type must be boolean", false)
			end
		end
	end

	function newGroup.setPickupZone(self, _pickupZone, _nextWaypoint)
		local fctDefinition = ATMEFct.getErrorPrefix(newGroup) .. "setPickupZone(pickupZone, [nextWaypoint])"
		
		if ATME.isObjectClass(_pickupZone, ATME.C_PickupZone) == true and
				(_nextWaypoint == nil or type(_nextWaypoint) == "number" or type(_nextWaypoint) == "string") then
			if self:isOnlyInfantry() == true then
				local localMembersPickupZone = ATMEDatas.C_PickupZone_MT:get(_pickupZone:getIndex())
				
				if localMembersPickupZone.coalitionName == self:getCoalitionName() then
					local item = {
						randomMax = 0.25 + math.random() / 2,
						groupName = name,
						start = timer.getTime(),
						isInZone = false,
						zone = ATME.getDCSZone(_pickupZone:getName())
					}
					
					if type(_nextWaypoint) == "number" and _nextWaypoint >= 0 then
						item.nextWaypoint = math.floor(_nextWaypoint)
					else
						item.nextWaypoint = _nextWaypoint
					end
					
					localMembersPickupZone.tracking.stack:push(item)
					localMembers.pickupZone = _pickupZone

					-- Si le groupe a un zone signalée, elle est supprimée
					self:resetSignal()
					
					return true
				else
					return false
				end
			else
				ATMEFct.errorOutputCore(nil, fctDefinition, name .. " isn't only infantry group", false)
			end
		else
			if ATME.isObjectClass(_pickupZone, ATME.C_PickupZone) == false then
				ATMEFct.errorOutputCore(nil, fctDefinition, "pickupZone type must be ATME.C_PickupZone", true)
			elseif _nextWaypoint ~= nil and type(_nextWaypoint) ~= "number" and type(_nextWaypoint) ~= "string" then
				ATMEFct.errorOutputCore(nil, fctDefinition, "nextWaypoint type must be nil, number or string", false)
			end
		end
	end

	function newGroup.resetPickupZone(self)
		if localMembers.pickupZone ~= nil then
			local localMembersPickupZone = ATMEDatas.C_PickupZone_MT:get(localMembers.pickupZone:getIndex())
			localMembersPickupZone.tracking.groupNames[name] = true
		end
		
		localMembers.pickupZone = nil
	end

	function newGroup.hasPickupZone(self)
		return localMembers.pickupZone ~= nil
	end

	function newGroup.getPickupZone(self)
		return localMembers.pickupZone
	end

	function newGroup.isReadyToBoard(self)
		return ATMEDatas.readyToBoardGroups[self:getName()] ~= nil
	end

	function newGroup.setReadyToBoard(self, _nextWaypoint)
		local fctDefinition = ATMEFct.getErrorPrefix(newGroup) .. "setReadyToBoard([nextWaypoint])"
		
		if _nextWaypoint == nil or type(_nextWaypoint) == "number" or type(_nextWaypoint) == "string" then
			if self:isOnlyInfantry() == true then
				if localMembers.pickupZone == nil then
					local nextWaypoint
					if type(_nextWaypoint) == "number" and _nextWaypoint >= 0 then
						nextWaypoint = math.floor(_nextWaypoint)
					else
						nextWaypoint = _nextWaypoint
					end
					
					ATMEFct.C_Group_changeReadyToBoard(self, true, nextWaypoint)
				else
					ATMEFct.setError("GROUP_WITH_PICKUPZONE")
				end
			else
				ATMEFct.errorOutputCore(nil, fctDefinition, "Group must be infantry group", true)
			end
		else
			if type(_value) ~= "boolean" then
				ATMEFct.errorOutputCore(nil, fctDefinition, "value type must be boolean", true)
			elseif _nextWaypoint ~= nil and type(_nextWaypoint) ~= "number" and type(_nextWaypoint) ~= "string" then
				ATMEFct.errorOutputCore(nil, fctDefinition, "nextWaypoint type must be nil, number or string", false)
			end
		end	
	end
	
	function newGroup.resetReadyToBoard(self)
		if self:isOnlyInfantry() == true then
			ATMEFct.C_Group_changeReadyToBoard(self, false, nil)
			if localMembers.pickupZone ~= nil then
				self:resetPickupZone()
			end
		else
			ATMEFct.errorOutputCore(nil, fctDefinition, "Group must be infantry group", true)
		end
	end

	function newGroup.isBoarding(self)
		return localMembers.boardingStarted
	end
	
	function newGroup.move(self)
		if self:canFly() == false then
			if localMembers.isStopped == true then
				local group = self:getDCSGroup()
				trigger.action.groupContinueMoving(group)
				localMembers.isStopped = false
			end
		else
			ATMEFct.errorOutputCore(nil, fctDefinition, "only ground groups can be moved", false)
		end
	end

	function newGroup.stop(self)
		if self:canFly() == false then
			if localMembers.isStopped == false then
				local group = self:getDCSGroup()
				trigger.action.groupStopMoving(group)
				localMembers.isStopped = true
			end
		else
			ATMEFct.errorOutputCore(nil, fctDefinition, "only ground groups can be stopped", false)
		end
	end

	function newGroup.freeze(self, _freezeOn)
		if self:canFly() == false then
			local fctDefinition = ATMEFct.getErrorPrefix(newGroup) .. "freeze(freezeOn)"
			
			if type(_freezeOn) == "boolean" then
				local group = self:getDCSGroup()
				if _freezeOn == true then
					trigger.action.setGroupAIOff(group)
				else
					trigger.action.setGroupAIOn(group)
				end
			else
				ATMEFct.errorOutputCore(nil, fctDefinition, "freezeOn type must be boolean", true)
			end	
		else
			ATMEFct.errorOutputCore(nil, fctDefinition, "only ground groups can be freezed", false)
		end
	end
	
	function newGroup.setOption(self, _option, _value)
		local fctDefinition = ATMEFct.getErrorPrefix(newGroup) .. "setOption(option, value)"

		if type(_option) == "string" and _value ~= nil then
			local err, option, optionValue = ATMEFct.C_setOption(localMembers.spawnDatas.type, _option, _value) 

			if err == false then
				local controller = self:getDCSGroup():getController()
				controller:setOption(ATMEConst.optionAI[localMembers.spawnDatas.type][option].id, optionValue)
			else
				ATMEFct.errorOutputCore(nil, fctDefinition, option, false)
			end
		else
			if type(_option) ~= "string" then
				ATMEFct.errorOutputCore(nil, fctDefinition, "option type must be string", true)
			elseif _value == nil then
				ATMEFct.errorOutputCore(nil, fctDefinition, "value type can't be nil", false)
			end
		end
	end
	
	
	ATMEFct.C_Group_addUnit(newGroup, _ATMEUnit)
	ATMEDatas.groups[name] = newGroup


	-- Initialisation du tracking
	-- Les waypoints sont complétés par une action permettant le suivi dans la fonction initObjectsInMission
	-- La tache mission est ajustée à la création du groupe ci-après.
	if ATMEDatas.spawnedGroupsWaypoints[name] == nil then  -- Groupe non spawné
		-- Les waypoints de la route initiale sont recopiés
		-- pour avoir la route courante.

		localMembers.waypoints = ATMEFct.C_CloningContext_copyAllWaypoints(localMembers.spawnDatas.datas.route.points)
		ATMEFct.C_CloningContext_setMission(newGroup, localMembers.waypoints, true, false)
	else -- Groupe spawné, pas de setMission car inclut dans addgroup.
		localMembers.waypoints = ATMEDatas.spawnedGroupsWaypoints[name].waypoints
		ATMEDatas.spawnedGroupsWaypoints[name] = nil
	end
	
	-- Ajustement du nombre de waypoints si pour un aéronef le dernier waypoint
	-- n'est pas un waypoint d'atterrissage.
	localMembers.maxWaypoints = #localMembers.waypoints
	if newGroup:canFly() == true then
		if localMembers.maxWaypoints > 0 then
			if 	localMembers.waypoints[#localMembers.waypoints].type ~= "Land" then
				localMembers.maxWaypoints = localMembers.maxWaypoints + 1
			end
		end
	end

	newGroup.modules = {}
	setmetatable(newGroup.modules, ATMEDatas.C_Group_MT.mtModules)
	
	local alreadyDeleted = ATMEDatas.groupsAlreadyDeleted[newGroup:getName()]
	if alreadyDeleted == nil then
		alreadyDeleted = false
	end
	
	for _, _localModuleMembers in ATMEDatas.C_Module_MT:pairs() do
		localMembers.userPrivateDatas[_localModuleMembers.name] = {}
		if newGroup.modules[_localModuleMembers.name] == nil then
			newGroup.modules[_localModuleMembers.name] = {}
		end
	end
	
	if ATMEDatas.groupsOnBoard[name] == nil then
		-- Les groupes déchargés d'un autre véhicules ne génèrent pas d'appel 
		-- à onCreateGroupHandler. Sinon on mémorise
		
		ATMEDatas.newCreatedGroups[name] = {
			timerOffset = 2,
			isSpawned = false,
		}
	end
	
	ATMEFct.outputCore(nil,"Create group = " .. name, 2)
end

ATMEFct.C_Group_delete = function(_ATMEGroup)
	local localMembers = ATMEDatas.C_Group_MT:get(_ATMEGroup:getIndex())
	local groupName = _ATMEGroup:getName()

	for _, _localModuleMembers in ATMEDatas.C_Module_MT:pairs() do
		if localMembers.onBoard == false then
			-- Les groupes chargés dans un autre véhicule ne génèrent pas d'appel 
			-- à onDeleteGroupHandler
			
			if _localModuleMembers.handlers.onDeleteGroupHandler ~= nil then
				-- Appel du module
				ATMEFct.outputCore(nil,"Appel onDeleteGroupHandler du module " .. _localModuleMembers.name, 2)
				xpcall(function() _localModuleMembers.handlers.onDeleteGroupHandler(_ATMEGroup, localMembers.isEnabled) end, function() ATMEFct.errUserHandler('onDeleteGroupHandler') end)
			end
		end
	end
	
	if localMembers.signalIndex > 0 then
		ATMEFct.resetSignalUnits(localMembers.signalIndex)
		ATMEDatas.signals:remove(localMembers.signalIndex)
		localMembers.signalIndex = 0
	end
	
	for _, _localModuleMembers in ATMEDatas.C_Module_MT:pairs() do
		_ATMEGroup.modules[_localModuleMembers.name] = nil
		localMembers.userPrivateDatas[_localModuleMembers.name] = nil
	end

	-- Si le groupe a détruit normalement (pas à bord)
	if localMembers.onBoard == false then
		ATMEDatas.groupsAlreadyDeleted[groupName] = true
		
		-- Si le groupe a un respawn automatique il est préparé
		if localMembers.autoRespawn.activated == true then
			local respawnTime = localMembers.autoRespawn.time
			if localMembers.autoRespawn.random == true then
				respawnTime = math.random(localMembers.autoRespawn.minTime, localMembers.autoRespawn.maxTime)
			end
			
			ATMEDatas.groupsToRespawn[groupName]  = {
				time = respawnTime + timer.getTime(),
				spawnDatas = localMembers.spawnDatas,
			}
		elseif localMembers.spawnDatas.idSpawnedList ~= nil then
			if localMembers.spawnDatas.idSpawnedList.groupSpawnedId ~= nil then
				table.insert(ATMEDatas.spawnedGroups[localMembers.spawnDatas.initialNames.groupName].freeIds, localMembers.spawnDatas.idSpawnedList.groupSpawnedId)
			end
			
			for _name, _id in pairs(localMembers.spawnDatas.idSpawnedList.units) do
				table.insert(ATMEDatas.spawnedUnits[_name].freeIds, _id)
			end

		end
	end

			
	ATMEDatas.C_Group_MT:remove(_ATMEGroup:getIndex())
	
	ATMEDatas.groups[groupName] = nil
	ATMEDatas.readyToBoardGroups[groupName] = nil
	ATMEDatas.onZoneTaskReady[groupName]  = nil
	
	ATMEFct.outputCore(nil,"Delete group = " .. groupName, 2)
end

setmetatable(ATME.C_Group,ATMEDatas.C_Group_MT)

ATMEDatas.C_Group_MT.mt.__metatable = "Private"
ATMEDatas.C_Group_MT.mt.__index = ATME.C_Group
ATMEDatas.C_Group_MT.mt.__newindex = function(t, k, v)
	if ATMEDatas.C_Group_MT.keys[k] ~= nil then 
		rawset(t, k, v)
	else
		ATMEFct.errorOutputCore(nil, "Function ATME.C_Group : Bad key " .. k, "table locked", false)
	end
end

ATMEDatas.C_Group_MT.mtModules.__metatable = "Private"
ATMEDatas.C_Group_MT.mtModules.__newindex = function(t, k, v)
	if ATMEDatas.modules[k] ~= nil then
		rawset(t, k, v)
	else
		ATMEFct.errorOutputCore(nil,"ATME : ATME.C_Group.modules Bad key " .. k, "table locked", false)
	end
end


-- Fonctions communes à ATME.C_Player et ATME.C_AIUnit

ATMEFct.C_Player_C_AIUnit_unload = function(_transportUnit, _id, _currentOnBoardGroupDatas, _whenStop)
	if _whenStop == false then
		local localMembers = ATMEFct.C_Player_C_AIUnit_getLocalMembers(_transportUnit)
		
		if  _transportUnit:getHSpeed() < 2 and (_transportUnit:isGroundVehicle() == true  or 
				((_transportUnit:isHelicopter() or _transportUnit:isPlane()) and _transportUnit:inAir() == false)) then
		
			local spawnedGroup, nbDeadUnits = ATMEFct.C_CloningContext_spawnFromTransportUnit(_transportUnit, _currentOnBoardGroupDatas)
			
			if spawnedGroup == nil then
				return
			end
			
			-- ATTENTION : Lors du spawn, les unités sont crées après la fonction addGroup car unités au sol.
			-- Donc, à ce stade, les infos ATME pour le groupe et les unités sont à jour.
			-- La mise à jour de ATMEDatas.groupsOnBoard se fait ici.
			
			ATMEDatas.groupsOnBoard[spawnedGroup:getName()] = nil
			
			local localSpawnGroupMembers = ATMEDatas.C_Group_MT:get(spawnedGroup:getIndex())
			localSpawnGroupMembers.autoRespawn = _currentOnBoardGroupDatas.autoRespawn
			
			localMembers.nbUnitsOnBoard = localMembers.nbUnitsOnBoard - _currentOnBoardGroupDatas.nbUnitsOnBoard
			localMembers.onBoardGroupDatas:remove(_id)
			
			local event = {
				type = "TRANSPORT_END_OF_DISEMBARK",
				datas = {
					unitName = _transportUnit:getName(),
					index = _id,
					linkedGroupName = spawnedGroup:getName(),
					nbUnitsOnBoard = localMembers.nbUnitsOnBoard,
					nbDeadUnits = nbDeadUnits,
				},
			}
				
			ATMEFct.C_CoreEvent_add(event, 1)
			
			return spawnedGroup, nbDeadUnits
		else
			if _transportUnit:isGroundVehicle() == true then
				ATMEFct.setError("UNLOAD_UNIT_BAD_SPEED")
				return
			else
				ATMEFct.setError("UNLOAD_UNIT_IN_AIR")
				return
			end
		end
	else
		local name = _transportUnit:getName()
		if ATMEDatas.autoUnloadDatas[name] == nil then
			ATMEDatas.autoUnloadDatas[name] = {}
		end

		-- On évite les doublons
		local found = false
		for _, _datas in ipairs(ATMEDatas.autoUnloadDatas[name]) do
			if _datas.id == _id then
				found = true
			end
		end
		
		if found == false then
			table.insert(ATMEDatas.autoUnloadDatas[name], {id = _id, armed = false})
		end
	end
end

ATMEFct.C_Player_C_AIUnit_whichSide = function(_transportUnit, _point)
	local rollAxis = ATMEFct.C_Line2D_create(nil, nil, _transportUnit:getRollAxisVector(), _transportUnit:getPosition())

	return ATMEFct.whichSideLine2D(rollAxis, _point)
end

ATMEFct.C_Player_C_AIUnit_load = function(_transportUnit, _groupToBoard, _radius)
	local maxUnits = ATMEConst.personnelCarrierAttributes[_transportUnit:getTypeName()].maxUnits
	local nbUnits
	local nbUnitsBoarding = 0
	
	local localMembers = ATMEFct.C_Player_C_AIUnit_getLocalMembers(_transportUnit)

	nbUnits = localMembers.nbUnitsOnBoard
								
	for _, _groupItem in ipairs(localMembers.groupsBoarding) do
		nbUnitsBoarding = nbUnitsBoarding + _groupItem.nbUnits
	end
	
	if _groupToBoard:getNbUnits() + nbUnits + nbUnitsBoarding <= maxUnits then
		if (_transportUnit:isGroundVehicle() == true and _transportUnit:getHSpeed() < 2) or 
				((_transportUnit:isHelicopter() or _transportUnit:isPlane()) and _transportUnit:inAir() == false) then
				
			local transportUnitPosition = _transportUnit:getPosition()
			if _groupToBoard:getMinHDistance(transportUnitPosition) <= _radius then	
				-- On mémorise le nb waypoints avant le changement de route pour monter
				-- dans le transport.
				local localGroupMembers = ATMEDatas.C_Group_MT:get(_groupToBoard:getIndex())
				local initialWaypoints = localGroupMembers.waypoints
				
				local pos = _groupToBoard:getPosition()
				
				local v = ATMEFct.C_Vector3D_create(nil, nil, pos, transportUnitPosition)
				local v1 = v:toUnitVector()

				local waypoints = {}
				waypoints[1] = {
					action = "Off Road",
					x = transportUnitPosition.x,
					y = transportUnitPosition.z,
					type = "Turning Point",
					speed = 5,
				}
				
				waypoints[2] = {
					action = "Off Road",
					x = transportUnitPosition.x + v1:getX() * 500,
					y = transportUnitPosition.z + v1:getZ() * 500,
					type = "Turning Point",
					speed = 5,
				}
				
				local line = ATMEFct.C_Line2D_create(nil, nil, transportUnitPosition, pos)
				local axis = line:getPerpendicular(0)
				
				-- Pas de tracking sur ces waypoints temporaire -> dernier paramètre à false
				ATMEFct.C_CloningContext_setWaypoints(_groupToBoard, waypoints, false, false)
				
				_groupToBoard:move()
				
				local item = {
					groupName = _groupToBoard:getName(),
					nbUnits = _groupToBoard:getNbUnits(),
				}
				table.insert(localMembers.groupsBoarding, item)
				
				local pA = axis:getOrigin()
				local pB = axis:getPointFromOrigin(10)
				
				localGroupMembers.boardingStarted = true

				local item = {
					activeGroupName = _groupToBoard:getName(),
					spawnDatas = localGroupMembers.spawnDatas,
					isWaypointsTracking = localGroupMembers.waypointsTracking,
					isFullWaypointsTracking = localGroupMembers.fullWaypointsTracking,
					lastPassedWaypoint = localGroupMembers.lastPassedWaypoint,
					offsetIdWaypoint = localGroupMembers.offsetIdWaypoint,
					waypoints = initialWaypoints,
					transportUnitName = _transportUnit:getName(),
					unitsOnBoard = {},
					nbUnitsOnBoard = 0,
					unitsLost = {},
					timeStart = timer.getTime(),
					initialDistance = _groupToBoard:getMaxHDistance(transportUnitPosition),
					A = pA,
					B = pB,
					sideOfWP2 = ATMEFct.C_Player_C_AIUnit_whichSide(_transportUnit, waypoints[2]),
					autoRespawn = localGroupMembers.autoRespawn,
					nextWaypoint = localGroupMembers.nextWaypoint,
				}
				
				ATMEDatas.groupsToBoard:add(item)
				
				return _groupToBoard
			else
				ATMEFct.setError("LOAD_UNIT_TOO_FAR")
				return
			end
		else
			if _transportUnit:isGroundVehicle() == true then
				ATMEFct.setError("LOAD_UNIT_BAD_SPEED")
				return
			else
				ATMEFct.setError("LOAD_UNIT_IN_AIR")
				return
			end
		end
	else
		ATMEFct.setError("LOAD_TOO_MUCH_UNITS")
		return
	end
end

ATMEFct.C_Player_C_AIUnit_getNearestReadyToBoardGroup = function(_transportUnit, _radius)
	local unitPosition = _transportUnit:getPosition()
	local radius = math.floor(_radius)
	local minDistance = -1
	local nearestGroup
	
	for _, _group in pairs(ATMEDatas.readyToBoardGroups) do
		local distance = _group:getMinHDistance(unitPosition)
		
		if distance <= radius and _group:getCoalitionName() == _transportUnit:getCoalitionName() and 
				_group:isBoarding() == false and _group:isActivated() == true then
			if ATMEConst.personnelCarrierAttributes[_transportUnit:getTypeName()].maxUnits >= _group:getNbUnits() and
						(minDistance < 0 or distance < minDistance) then
				minDistance = distance
				nearestGroup = _group
			end
		end
	end
	
	return nearestGroup
end

ATMEFct.C_Player_C_AIUnit_addOnBoardGroup = function(_transportUnit, _datas)
	local localMembers = ATMEFct.C_Player_C_AIUnit_getLocalMembers(_transportUnit)
	localMembers.onBoardGroupDatas:add(_datas)

	ATMEDatas.groupsOnBoard[_datas.name] = {
		transportUnit = _transportUnit,
		spawnDatas = _datas.spawnDatas,
	}
	
	return localMembers.onBoardGroupDatas:getCount()
end


----------------------------------------------------------------------------------------------------------
-- Classe ATME.C_Player : gère les unités joueurs au format ATME. Pas de contructeur accessible
-- pour les modules externes.
-- Les instances de cette classe sont intégralement gérées par le module ATME_Core. La création et la destruction
-- dépendent du contexte de début de mission et des événements qui se produisent dans DCS en cours de mission.
-- Les modules externes accèdent à cette gestion indirectement par les handlers définis dans ceux-ci et les méthodes
-- accessibles de cette classe. Ceci permet de garantir une cohérence sur les listes internes ATME.
----------------------------------------------------------------------------------------------------------

ATMEDatas.C_Player_MT = {
	className = "C_Player",
	parentClass = ATME.C_Unit,
	
	mtModules = {},
	mt = {},
	
	keys = {
		["isEngineStarted"] = true,
		["getIndex"] = true,
		["getDCSUnit"] = true,
		["getName"] = true,
		["tagGetByID"] = true,
		["tagCompare"] = true,
		["tagGetCount"] = true,
		["getTypeName"] = true,
		["getNbUnitsOnBoard"] = true,
		["getGroupOnBoardNames"] = true,
		["getF10MenuRoot"] = true,
		["getPseudo"] = true,
		["getGroup"] = true,
		["getGroupId"] = true,
		["display"] = true,
		["mark"] = true,
		["setVoice"] = true,
		["getVoice"] = true,
		["soundOnce"] = true,
		["soundStart"] = true,
		["load"] = true,
		["unload"] = true,
		["soundStop"] = true,
		["getFuelRatio"] = true,
		["getLife"] = true,
		["getLifeRatio"] = true,
		["getCallsign"] = true,
		["getNearestReadyToBoardGroup"] = true,
		["getPosition"] = true,
		["getVelocityVector"] = true,
		["getSpeed"] = true,
		["getHSpeed"] = true,
		["getVSpeed"] = true,
		["getRollAxisVector"] = true,
		["getSpeedAzimuth"] = true,
		["getAzimuth"] = true, 
		["getCountryName"] = true,
		["getCoalitionName"] = true,
		["isHelicopter"] = true,
		["isPersonnelCarrier"] = true,
		["isPlane"] = true,
		["inAir"] = true,
		["isGroundVehicle"] = true,
		["getMSLAltitude"] = true,
		["getAGLAltitude"] = true, 
		["explode"] = true,
		["isInArea"] = true,
		["isInDCSZone"] = true,
		["isInZone2D"] = true,
		["isInSphere"] = true,
		["isNear"] = true,
		["isPilotDead"] = true,
		["isPilotEjected"] = true,
		["whichSide"] = true,
		["setMultiSegmentTracking"] = true,
		["resetMultiSegmentTracking"] = true,
		["isRouteInDirection"] = true,
		["modules"] = true,
		["canFly"] = true,
		["getUserPrivateDatas"] = true,
	},
	
	localMembers = ATMEFct.C_IndexList_create(),
	
	add = function(self, _name)
		local item = {
			engineOn = false,
			nbUnitsOnBoard = 0,
			groupsBoarding = {},
			onBoardGroupDatas = ATMEFct.C_IndexList_create(),
			playlist = {
				readOnce = false,
			},
			currentReadIndex = 1,
			randomRead = false,
			tips10 = 0,
			interval = 0,
			entry = 0,
			soundPause = nil, 				-- Si un son est en boucle, l'emission d'un son unique suspend le son en boucle
			itemsF10MenuCommandRoot = {},	-- Table des menus root : une par module.
			multiSegment2D = {},			-- Table des axes suivis en franchissement par le joueur
			userPrivateDatas = {},			-- Point d'entrée des données privées : un par module
			signalIndex = {},				-- Table pour les zones signalées où se trouve l'unité
			tagsName = ATMEFct.decompString(_name),
			currentVoice = "",
			pilotEjected = false,
			pilotDead = false,
		}
		
		return self.localMembers:add(item)
	end,
	
	remove = function(self, _id)
		for _k, _itemF10MenuCommandRoot in pairs(self.localMembers:get(_id).itemsF10MenuCommandRoot) do
			_itemF10MenuCommandRoot:removeAll()
			ATMEDatas.C_F10Menu_MT:remove(_itemF10MenuCommandRoot:getIndex())
			self.localMembers:get(_id).itemsF10MenuCommandRoot[_k] = nil
		end
		self.localMembers:remove(_id)
	end,
	
	get = function(self, _id)
		return self.localMembers:get(_id)
	end,
}

ATME.C_Player = {
	getClassName = function(self)
		return ATMEDatas.C_Player_MT.className
	end,
	
	getParentClass = function(self)
		return ATMEDatas.C_Player_MT.parentClass
	end,
	
	getByName = function(_playerName)
		if type(_playerName) == "string" then
			return ATMEDatas.players[_playerName]
		else
			ATMEFct.errorOutputCore(nil, "Function ATME.C_Player.getByName(name)", "name must be string", false)
		end
	end,
	
	getRandomFromCoalition = function(_coalitionName)
		local fctDefinition = "Function ATME.C_Player.getRandomFromCoalition(coalitionName)"
		
		if type(_coalitionName) == "string" then
			if ATMEConst.coalitionIds[_coalitionName] ~= nil then
				return ATMEFct.getRandomPlayerFromCoalition(_coalitionName)
			else
				ATMEFct.errorOutputCore(nil, fctDefinition, "coalitionName must be 'RED' or 'BLUE'", false)
			end
		else
			ATMEFct.errorOutputCore(nil, fctDefinition, "coalitionName type must be string", false)
		end
	end,
}

ATMEFct.C_Player_create = function(_unit, _datas)
	local newPlayer = {}
	setmetatable(newPlayer, ATMEDatas.C_Player_MT.mt)
	
	local name = _unit:getName()
	
	local unit = _unit
	local typeName = _unit:getTypeName()
	local groupId = ATMEDatas.allPlayerUnitsInMission[name].group.groupId
	local waypoints = ATMEDatas.allPlayerUnitsInMission[name].group.waypoints			
	local airbase
	local oldSide
	
	local groupName = _unit:getGroup():getName()
	local ATMEGroup
	
	local index = ATMEDatas.C_Player_MT:add(name)
	local localMembers = ATMEDatas.C_Player_MT:get(index)
	
	function newPlayer.getIndex(self)
		return index
	end
	
	function newPlayer.getGroupId(self)
		return groupId
		
		-- Bug DCS getID
		--local group = ATMEGroup:getDCSGroup()
		--return group:getID()
	end
	
	function newPlayer.getDCSUnit(self)
		return unit
	end
	
	function newPlayer.getName(self)
		return name
	end
	
	function newPlayer.tagGetByID(self, _position)
		local fctDefinition = ATMEFct.getErrorPrefix(newPlayer) .. "tagGetByID(position)"
		
		if type(_position) == "number" then
			local pos = math.floor(_position)
			if localMembers.tagsName ~= nil and pos >= 1 and pos <= #localMembers.tagsName then
				return localMembers.tagsName[pos]
			end
		else
			ATMEFct.errorOutputCore(nil, fctDefinition, "position type must be number", true)
		end
	end
	
	function newPlayer.tagGetCount(self)
		if tagsName ~= nil then
			return #tagsName
		else
			return 0
		end
	end
	
	function newPlayer.tagCompare(self, _tagsToCompare)
		local fctDefinition = ATMEFct.getErrorPrefix(newPlayer) .. "tagCompare(tagsToCompare)"
		
		if type(_tagsToCompare) == "string" then
			if localMembers.tagsName ~= nil then
				local ok = ATMEFct.compareTags(localMembers.tagsName, _tagsToCompare)

				if ok ~= nil then
					return ok
				else
					ATMEFct.errorOutputCore(nil, fctDefinition, "tagsToCompare format must be 'T1|T2|..|Tn'", false)
				end
			else
				return false
			end
		else
			ATMEFct.errorOutputCore(nil, fctDefinition, "tagsToCompare type must be string", true)
		end
	end
	
	function newPlayer.getPseudo(self)
		return unit:getPlayerName()
	end
	
	function newPlayer.getTypeName(self)
		return typeName
	end
	
	function newPlayer.getGroup(self)
		return ATMEGroup
	end
	
	function newPlayer.getUserPrivateDatas(self, _module)
		local fctDefinition = ATMEFct.getErrorPrefix(newPlayer) .. "getUserPrivateDatas(module)"
		
		if ATME.isObjectClass(_module, ATME.C_Module) == true then
			return localMembers.userPrivateDatas[_module:getName()]
		else
			ATMEFct.errorOutputCore(nil, fctDefinition, "module type must be ATME.C_Module", true)
		end
	end
	
	function newPlayer.display(self, _text, _duration)
		local fctDefinition = ATMEFct.getErrorPrefix(newPlayer) .. "display(text, duration)"
		
		if type(_text) == "string" and type(_duration) == "number" then
			if _duration >= 0 then
				trigger.action.outTextForGroup(groupId, _text, _duration)
			else
				ATMEFct.errorOutputCore(nil, fctDefinition, "duration type must be >= 0", false)
			end
		else
			if type(_text) ~= "string" then
				ATMEFct.errorOutputCore(nil, fctDefinition, "text type must be string", true)
			elseif type(_duration) ~= "number" then
				ATMEFct.errorOutputCore(nil, fctDefinition, "duration type must be number", false)
			end
		end
	end
	
	function newPlayer.mark(self, _text, _reference, _readOnly, _message)
		local fctDefinition = ATMEFct.getErrorPrefix(newPlayer) .. "mark(text, reference, readOnly, [message])"
		
		if type(_text) == "string" and ATMEFct.isReference(_reference) == true and type(_readOnly) == "boolean" and
						(_message == nil or type(_message) == "string") then
			local point = ATMEFct.getPointFromReference(_reference)

			return ATMEFct.addMark(nil, groupId, _text, point, _readOnly, _message)
		else
			if type(_text) ~= "string" then
				ATMEFct.errorOutputCore(nil, fctDefinition, "text type must be string", true)
			elseif ATMEFct.isReference(_reference) == false then
				ATMEFct.errorOutputCore(nil, fctDefinition, "reference type must be ATME.C_AIUnit or ATME.C_Player or ATME.C_StaticObject or table (x,y) or (x,y,z)", false)
			elseif type(_readOnly) ~= "boolean" then
				ATMEFct.errorOutputCore(nil, fctDefinition, "readOnly type must be boolean", false)
			elseif _message ~= nil and type(_message) ~= "string" then
				ATMEFct.errorOutputCore(nil, fctDefinition, "message type must be nil or string", false)
			end
		end
	end
	
	function newPlayer.setVoice(self, _name)
		local fctDefinition = ATMEFct.getErrorPrefix(newPlayer) .. "setVoice([name])"
		
		if _name == nil or type(_name) == "string" then
			if _name ~= nil then
				local d, f, temp = _name:find("^(%a[%a%d_]*)")
				
				if temp == _name then
					localMembers.currentVoice = _name
				else
					ATMEFct.errorOutputCore(nil, fctDefinition, "name bad format", false)
				end
			else
				localMembers.currentVoice = ""
			end
		else
			ATMEFct.errorOutputCore(nil, fctDefinition, "name type must be nil or string", true)
		end
	end
	
	function newPlayer.getVoice(self)
		if localMembers.currentVoice ~= "" then
			return localMembers.currentVoice
		end
	end

	function newPlayer.soundOnce(self, _text, _randomRead)
		local fctDefinition = ATMEFct.getErrorPrefix(newPlayer) .. "soundOnce(_text, [randomRead])"
		
		if type(_text) == "string" and (_randomRead == nil or type(_randomRead) == "boolean") then
			local randomRead = false
			
			if type(_randomRead) == "boolean" then
				randomRead = _randomRead
			end
			
			local err, playlist = ATMEFct.C_Sound_getPlaylist(_text, randomRead)

			if err == true then
				ATMEFct.errorOutputCore(nil, fctDefinition, playlist, false)
				return
			end

			if playlist == nil then
				ATMEFct.errorOutputCore(nil, fctDefinition, "text string has no sound token", false)
				return
			end
		
			ATMEFct.initSoundPlaylist({
										player = self, 
										randomRead = randomRead, 
										readOnce = true, 
										playlist = playlist,
									})
		else
			if type(_text) ~= "string" then
				ATMEFct.errorOutputCore(nil, fctDefinition, "text type must be string", true)
			elseif _randomRead ~= nil and type(_randomRead) ~= "boolean" then
				ATMEFct.errorOutputCore(nil, fctDefinition, "randomRead type must be nil or boolean", false)
			end
		end
	end
	
	function newPlayer.soundStart(self, _text, _randomRead)
		local fctDefinition = ATMEFct.getErrorPrefix(newPlayer) .. "soundStart(text, [randomRead])"
		
		if type(_text) == "string" and (_randomRead == nil or type(_randomRead) == "boolean") then
			local randomRead = false
			
			if type(_randomRead) == "boolean" then
				randomRead = _randomRead
			end

			local err, playlist = ATMEFct.C_Sound_getPlaylist(_text, randomRead)

			if err == true then
				ATMEFct.errorOutputCore(nil, fctDefinition, playlist, false)
				return
			end

			if playlist == nil then
				ATMEFct.errorOutputCore(nil, fctDefinition, "text string has no sound token", false)
				return
			end
		
			ATMEFct.initSoundPlaylist({
										player = self, 
										randomRead = randomRead, 
										readOnce = false, 
										playlist = playlist,
									})
		else
			if type(_text) ~= "string" then
				ATMEFct.errorOutputCore(nil, fctDefinition, "text type must be string", true)
			elseif _randomRead ~= nil and type(_randomRead) ~= "boolean" then
				ATMEFct.errorOutputCore(nil, fctDefinition, "randomRead type must be nil or boolean", false)
			end
		end
	end
	
	function newPlayer.soundStop(self)
		if localMembers.entry ~= 0 then
			ATMEDatas.activatedSounds:remove(localMembers.entry)

			if localMembers.soundPause ~= nil then
				localMembers.entry = ATMEDatas.activatedSounds:add(localMembers.soundPause)
				localMembers.soundPause = nil
			else
				localMembers.entry = 0
			end
		end
	end
	
	function newPlayer.getFuelRatio(self)
		return unit:getFuel()
	end
	
	function newPlayer.getLife(self)
		return unit:getLife()
	end
	
	function newPlayer.getLifeRatio(self)
		return self:getLife()/unit:getLife0()
	end
	
	function newPlayer.getCallsign(self)
		local identification
		local id1
		local id2
		
		if unit:hasAttribute("Helicopters") or unit:hasAttribute("Planes") then
			local callsign = unit:getCallsign()
			if unit:getCoalition() == 2 then
				identification = string.match(callsign, "^%a*")
				id1 = string.match(callsign, "%d")
				id2 = string.match(callsign, "%d$")
			else
				identification = callsign
			end
		end
		
		return identification, id1, id2
	end
	
	function newPlayer.getPosition(self)
		return unit:getPoint()
	end

	function newPlayer.getVelocityVector(self)
		local vector = ATMEFct.C_Vector3D_create(nil, nil, unit:getVelocity())
		return vector
	end

	function newPlayer.getSpeed(self)
		local vector = self:getVelocityVector()
		return vector:getModule(vector)
	end

	function newPlayer.getHSpeed(self)
		local vector = self:getVelocityVector()
		return vector:getHModule(vector)
	end

	function newPlayer.getVSpeed(self)
		local vector = unit:getVelocity()
		return vector.y
	end

	function newPlayer.getSpeedAzimuth(self)
		local vector = self:getVelocityVector()
		
		if vector:getModule() > 1 then 
			return vector:getAzimuth()
		else
			return 0
		end
	end
	
	function newPlayer.getRollAxisVector(self)
		return ATMEFct.C_Vector3D_create(nil, nil, unit:getPosition().x)
	end

	function newPlayer.getAzimuth(self)
		local vector = self:getRollAxisVector()
		return vector:getAzimuth()
	end

	function newPlayer.getCountryName(self)
		local id = unit:getCountry()
		
		return country.name[id]
	end

	function newPlayer.getCoalitionName(self)
		local id = unit:getCoalition()
		return ATMEConst.coalitionNames[id]
	end

	function newPlayer.isHelicopter(self)
		return unit:hasAttribute("Helicopters")
	end
	
	function newPlayer.isPersonnelCarrier(self)
		return ATMEConst.personnelCarrierAttributes[self:getTypeName()] ~= nil
	end

	function newPlayer.isPlane(self)
		return unit:hasAttribute("Planes")
	end
	
	function newPlayer.canFly(self)
		return self:isPlane() == true or self:isHelicopter() == true
	end

	function newPlayer.inAir(self)
		return unit:inAir()
	end
	
	function newPlayer.isGroundVehicle(self)
		return unit:hasAttribute("Ground vehicles")
	end

	function newPlayer.getMSLAltitude(self)
		return ATME.getPointAltitude(self:getPosition())
	end

	function newPlayer.getAGLAltitude(self)
		local landHeight = ATMEFct.getSurfaceAltitude(self:getPosition())
		return ATME.getPointAltitude(self:getPosition()) - landHeight
	end

	function newPlayer.explode(self, _power)
		local fctDefinition = ATMEFct.getErrorPrefix(newPlayer) .. "explode(power)"
		
		if type(_power) == "number" then
			if _power >= 1 then
				ATME.explode(self:getPosition(), _power)
			else
				ATMEFct.errorOutputCore(nil, fctDefinition, "power must be >= 1", false)
			end
		else
			ATMEFct.errorOutputCore(nil, fctDefinition, "power type must be number", true)
		end
	end

	function newPlayer.isInArea(self, _area)
		local fctDefinition = ATMEFct.getErrorPrefix(newPlayer) .. "isInArea(area)"
		
		if ATME.isObjectClass(_area, ATME.C_Area) == true then
			return _area:isInside(self) 
		else
			ATMEFct.errorOutputCore(nil, fctDefinition, "area type must be ATME.C_Area", true)
		end
	end				
	
	function newPlayer.isInDCSZone(self, _name)
		local fctDefinition = ATMEFct.getErrorPrefix(newPlayer) .. "isInDCSZone(name)"
		
		if type(_name) == "string" then
			local zone = ATME.getDCSZone(_name)
			
			if zone ~= nil then
				local vector = ATMEFct.C_Vector3D_create(nil, nil, self:getPosition(), zone.point)
				if vector:getHModule() <= zone.radius then
					return true
				else
					return false
				end
			else
				ATMEFct.errorOutputCore(nil, fctDefinition, "DCS zone " .. _name .. " unknown", false)
			end
		else
			ATMEFct.errorOutputCore(nil, fctDefinition, "name type must be string", true)
		end
	end
	
	function newPlayer.isInZone2D(self, _zone)
		local fctDefinition = ATMEFct.getErrorPrefix(newPlayer) .. "isInZone2D(zone)"
		
		if ATME.isObjectClass(_zone, ATME.C_Zone2D) == true then
				
			local found = false
			local point = self:getPosition()
			
			if ATMEFct.isObjectClass(_zone, ATME.C_Polygon) == true then
				local localMembersZone = ATMEDatas.C_Polygon_MT:get(_zone:getIndex())
				found = ATMEFct.C_Polygon_isInside(point, localMembersZone.triangles) 
			elseif ATMEFct.isObjectClass(_zone, ATME.C_Circle) == true then
				local localMembersZone = ATMEDatas.C_Circle_MT:get(_zone:getIndex())
				found = ATMEFct.C_Circle_isInside(point, localMembersZone.center, nil, 
											0, localMembersZone.radius)
			elseif ATMEFct.isObjectClass(_zone, ATME.C_PickupZone) == true then
				local localMembersZone = ATMEDatas.C_PickupZone_MT:get(_zone:getIndex())
				found = ATMEFct.C_Circle_isInside(point, localMembersZone.center, nil, 0, localMembersZone.radius)
			else
				local localMembersZone = ATMEDatas.C_Ring_MT:get(_zone:getIndex())
				found =  ATMEFct.C_Circle_isInside(point, localMembersZone.center, nil, 
											localMembersZone.radiusMin, localMembersZone.radiusMax) 
			end
			
			return found
		else
			ATMEFct.errorOutputCore(nil, fctDefinition, "zone type must be ATME.C_Circle, ATME.C_Ring, ATME.C_PickupZone, ATME.C_Rectangle or ATME.C_Polygon", true)
		end
	end
	
	function newPlayer.isInSphere(self, _reference, _radius)
		local fctDefinition = ATMEFct.getErrorPrefix(newPlayer) .. "isInZone3D(reference, radius)"
		
		if ATMEFct.isReference(_reference) == true and type(_radius) == "number" then
			if _radius > 0 then
				local point = ATMEFct.getPointFromReference(_reference)
				local vector = ATMEFct.C_Vector3D_create(nil, nil, self:getPosition(), point)
				
				return vector:getModule() <= _radius
			else
				ATMEFct.errorOutputCore(nil, fctDefinition, "radius must be > 0", false)
			end
		else
			if ATMEFct.isReference(_reference) == false then
				ATMEFct.errorOutputCore(nil, fctDefinition, "reference type must be ATME.C_AIUnit or ATME.C_Player or ATME.C_StaticObject or table (x,y) or (x,y,z)", true)
			elseif type(_radius) ~= "number" then
				ATMEFct.errorOutputCore(nil, fctDefinition, "radius type must be number", false)
			end
		end
	end
	
	function newPlayer.isNear(self, _reference, _radius, _deltaAltitude)
		local fctDefinition = ATMEFct.getErrorPrefix(newPlayer) .. "isNear(reference, radius, deltaAltitude)"
	
		if ATMEFct.isReference(_reference) == true and type(_radius) == "number" and type(_deltaAltitude) == "number" then	
			if _radius > 0 then
				if _deltaAltitude > 0 then
					local point = ATMEFct.getPointFromReference(_reference)
					local vector = ATMEFct.C_Vector3D_create(nil, nil, self:getPosition(), point)

					return vector:getHModule() <= _radius and math.abs(vector:getY()) <= _deltaAltitude
				else
					ATMEFct.errorOutputCore(nil, fctDefinition, "deltaAltitude must be > 0", false)
				end
			else
				ATMEFct.errorOutputCore(nil, fctDefinition, "radius must be > 0", false)
			end
		else
			if ATMEFct.isReference(_reference) == false then
				ATMEFct.errorOutputCore(nil, fctDefinition, "reference type must be ATME.C_AIUnit or ATME.C_Player or ATME.C_StaticObject or table (x,y) or (x,y,z)", true)
			elseif type(_radius) ~= "number" then
				ATMEFct.errorOutputCore(nil, fctDefinition, "radius type must be number", false)
			elseif type(_deltaAltitude) ~= "number" then
				ATMEFct.errorOutputCore(nil, fctDefinition, "deltaAltitude type must be number", false)
			end
		end
	end
	
	function newPlayer.whichSide(self, _reference)
		local fctDefinition = ATMEFct.getErrorPrefix(newPlayer) .. "whichSide(reference)"
		
		if ATMEFct.isReference(_reference) == true  then
			local point = ATMEFct.getPointFromReference(_reference)

			return ATMEFct.C_Player_C_AIUnit_whichSide(self, point)
		else
			ATMEFct.errorOutputCore(nil, fctDefinition, "reference type must be ATME.C_AIUnit or ATME.C_Player or ATME.C_StaticObject or table (x,y) or (x,y,z)", true)
		end
	end
	
	function newPlayer.setMultiSegmentTracking(self, _multiSegment2D)
		local fctDefinition = ATMEFct.getErrorPrefix(newPlayer) .. "setMultiSegmentTracking(multiSegment2D)"
		
		if ATME.isObjectClass(_multiSegment2D, ATME.C_MultiSegment2D) == true then
			ATMEFct.C_MultiSegment2D_changeCrossingMultiSegmentTracking(_multiSegment2D, self, true)
			
			localMembers.multiSegment2D[_multiSegment2D] = _multiSegment2D
		else
			ATMEFct.errorOutputCore(nil, fctDefinition, "multiSegment2D type must be ATME.C_MultiSegment2D", true)
		end
	end
	
	function newPlayer.resetMultiSegmentTracking(self, _multiSegment2D)
		local fctDefinition = ATMEFct.getErrorPrefix(newPlayer) .. "resetMultiSegmentTracking(multiSegment2D)"
		
		if ATME.isObjectClass(_multiSegment2D, ATME.C_MultiSegment2D) == true then
			ATMEFct.C_MultiSegment2D_changeCrossingMultiSegmentTracking(_multiSegment2D, self, false)
			
			localMembers.multiSegment2D[_multiSegment2D] = nil
		else
			ATMEFct.errorOutputCore(nil, fctDefinition, "multiSegment2D type must be ATME.C_MultiSegment2D", true)
		end
	end
	
	
	function newPlayer.isRouteInDirection(self, _reference)
		local fctDefinition = ATMEFct.getErrorPrefix(newPlayer) .. "isRouteInDirection(reference)"
		
		if ATMEFct.isReference(_reference) == true then
			return ATMEFct.isAzimuthInLimits(self:getPosition(), self:getSpeedAzimuth(), ATMEFct.getPointFromReference(_reference))
		else
			ATMEFct.errorOutputCore(nil, fctDefinition, "reference type must be ATME.C_AIUnit or ATME.C_Player or ATME.C_StaticObject or table (x,y) or (x,y,z)", true)
		end
	end
	
	function newPlayer.isEngineStarted(self)
		return localMembers.engineOn
	end
	
	function newPlayer.getF10MenuRoot(self, _module)
		local fctDefinition = ATMEFct.getErrorPrefix(newPlayer) .. "getF10MenuRoot(module)"
		
		if ATME.isObjectClass(_module, ATME.C_Module) == true then
			return localMembers.itemsF10MenuCommandRoot[_module:getName()]
		else
			ATMEFct.errorOutputCore(nil, fctDefinition, "module type must be ATME.C_Module", true)
		end
	end

	function newPlayer.getNbUnitsOnBoard(self)
		return localMembers.nbUnitsOnBoard
	end

	function newPlayer.getGroupOnBoardNames(self)
		local temp = {}
		
		for _, _item in localMembers.onBoardGroupDatas:pairs() do
			table.insert(temp, _item.name)
		end
		
		return temp
	end

	function newPlayer.unload(self, _id, _whenStop)
		local fctDefinition = ATMEFct.getErrorPrefix(newPlayer) .. "unload(id, [whenStop])"
		
		if type(_id) == "number" then
			local id = math.floor(_id)
			
			local currentOnBoardGroupDatas = localMembers.onBoardGroupDatas:get(id)
			if currentOnBoardGroupDatas ~= nil then
				local whenStop = _whenStop
				
				if _whenStop == nil then
					whenStop = false
				end
				
				return ATMEFct.C_Player_C_AIUnit_unload(self, id, currentOnBoardGroupDatas, whenStop)
			else
				ATMEFct.setError("UNLOAD_BAD_ID")
				return
			end
		else
			if type(_id)~= "number" then
				ATMEFct.errorOutputCore(nil, fctDefinition, "id type must be number", true)
			elseif _whenStop ~= nil and type(_whenStop) ~= "boolean" then
				ATMEFct.errorOutputCore(nil, fctDefinition, "whenStop type must be nil or boolean", false)
			end
		end
	end

	function newPlayer.load(self, _radius, _groupToBoard)
		local fctDefinition = ATMEFct.getErrorPrefix(newPlayer) .. "load(radius, [groupToBoard])"
		
		if type(_radius) == "number" and (_groupToBoard == nil or ATME.isObjectClass(_groupToBoard, ATME.C_Group) == true or type(_groupToBoard) == "string") then
			local groupToBoard
			
			if _groupToBoard == nil then
				groupToBoard = ATMEFct.C_Player_C_AIUnit_getNearestReadyToBoardGroup(self, _radius)
			elseif type(_groupToBoard) == "string" then
				groupToBoard = ATME.C_Group.getByName(_groupToBoard)
			else
				groupToBoard = _groupToBoard
			end
			
			if groupToBoard ~= nil then
				if groupToBoard:isOnlyInfantry() == true then
					if _radius > 0 then
						if groupToBoard:isReadyToBoard() == true and groupToBoard:isBoarding() == false then
							if ATMEConst.personnelCarrierAttributes[self:getTypeName()] ~= nil then
								return ATMEFct.C_Player_C_AIUnit_load(self, groupToBoard, _radius)
							else
								ATMEFct.errorOutputCore(nil, fctDefinition, self:getName() .. " not a transport unit", false)
							end
						else
							ATMEFct.setError("LOAD_INFANTRY_GROUP_NOT_READY")
						end
					else
						ATMEFct.errorOutputCore(nil, fctDefinition, "radius must be > 0", false)
					end
				else
					ATMEFct.errorOutputCore(nil, fctDefinition, "Not infantry group", false)
				end
			else
				ATMEFct.setError("LOAD_NO_GROUP_FOUND")
			end
		else
			if type(_radius) ~= "number" then
				ATMEFct.errorOutputCore(nil, fctDefinition, "radius type must be number", true)
			elseif ATME.isObjectClass(_groupToBoard, ATME.C_Group) == false and _groupToBoard ~= nil then
				ATMEFct.errorOutputCore(nil, fctDefinition, "groupToBoard type must be nil or ATME.C_Group or string", false)

			end
		end
	end
	
	function newPlayer.isPilotDead(self)
		return localMembers.pilotDead
	end
	
	function newPlayer.isPilotEjected(self)
		return localMembers.pilotEjected
	end
	
	function newPlayer.getNearestReadyToBoardGroup(self, _radius)
		local fctDefinition = ATMEFct.getErrorPrefix(newPlayer) .. "getNearestReadyToBoardGroup(radius)"
		
		if type(_radius) == "number" then
			if _radius >= 0 then
				return ATMEFct.C_Player_C_AIUnit_getNearestReadyToBoardGroup(self, _radius)
			else
				ATMEFct.errorOutputCore(nil, fctDefinition, "radius must be > 0", false)
			end
		else
			ATMEFct.errorOutputCore(nil, fctDefinition, "radius must be number", true)
		end
	end
	
	local wp = waypoints[1]
	if wp.airdromeId ~= nil or wp.helipadId ~= nil then
		if wp.airdromeId ~= nil then
			airbase = ATMEDatas.airbasesByID[wp.airdromeId]:getName()
		elseif wp.helipadId ~= nil then
			airbase = ATMEDatas.airbasesByID[string.format("%d", wp.helipadId)]:getName()
		end
		
		if wp.type == "TakeOffParkingHot" then
			-- Cas d'initialisation en fonction de la position de début de mission
			-- Au parking moteur allumé
			
			localMembers.engineOn = true
		elseif wp.type == "TakeOffParking" then
			-- Cas d'initialisation en fonction de la position de début de mission
			-- Au parking moteur éteint
			
			localMembers.engineOn = false
		elseif wp.type == "TakeOff" then
			-- Cas d'initialisation en fonction de la position de début de mission
			-- Sur la piste, prêt à décoler
			
			localMembers.engineOn = true
		end
	else
		-- Cas d'initialisation en fonction de la position de début de mission
		-- En vol....
		
		localMembers.engineOn = true
	end
	
	ATMEDatas.players[name] = newPlayer
	ATMEDatas.allAIUnitsAndPlayers[name] = newPlayer
	
	newPlayer.modules = {}
	setmetatable(newPlayer.modules, ATMEDatas.C_Player_MT.mtModules)
	
	for _, _localModuleMembers in ATMEDatas.C_Module_MT:pairs() do
		local _, menu = ATMEFct.C_F10Menu_create(newPlayer, nil, nil, _localModuleMembers.name)
		localMembers.itemsF10MenuCommandRoot[_localModuleMembers.name] = menu
		localMembers.userPrivateDatas[_localModuleMembers.name] = {}
		if newPlayer.modules[_localModuleMembers.name] == nil then
			newPlayer.modules[_localModuleMembers.name] = {}
		end
	end
	
	if ATMEConst.personnelCarrierAttributes[newPlayer:getTypeName()] ~= nil and newPlayer:isHelicopter() == true then
		ATMEDatas.signalCapabilityUnits:push(name)
	end
	
	if ATMEDatas.groups[groupName] == nil then
		ATMEFct.C_Group_create(newPlayer, _datas)
	else
		ATMEFct.C_Group_addUnit(ATMEDatas.groups[groupName], newPlayer)
	end
	
	ATMEGroup = ATMEDatas.groups[groupName]
	
	for _, _localModuleMembers in ATMEDatas.C_Module_MT:pairs() do
		if _localModuleMembers.handlers.onCreatePlayerHandler ~= nil then
			-- Appel du module
			ATMEFct.outputCore(nil,"Appel onCreatePlayerHandler du module " .. _localModuleMembers.name, 2)
			xpcall(function() _localModuleMembers.handlers.onCreatePlayerHandler(newPlayer) end, function() ATMEFct.errUserHandler('onCreatePlayerHandler') end)
		end
	end
	
	ATMEDatas.nbPlayers = ATMEDatas.nbPlayers + 1
	
	ATMEFct.outputCore(nil,"Create Player = " .. name , 2)
end

ATMEFct.C_Player_delete = function(_player)
	local localMembers = ATMEDatas.C_Player_MT:get(_player:getIndex())
	local flag = "EJECTION"
	if _player:isPilotDead() == true then
		flag = "DEAD"
	end
	
	for _, _localModuleMembers in ATMEDatas.C_Module_MT:pairs() do
		if _localModuleMembers.handlers.onDeletePlayerHandler ~= nil then
			-- Appel du module
			ATMEFct.outputCore(nil,"Appel onDeletePlayerHandler du module " .. _localModuleMembers.name, 2)
			xpcall(function() _localModuleMembers.handlers.onDeletePlayerHandler(_player, flag) end, function() ATMEFct.errUserHandler('onDeletePlayerHandler') end)
		end
	end
	
	for _, _race in pairs(ATMEDatas.races) do
		_race:removePlayer(_player)
	end
	
	_player:soundStop()
	
	-- Suppression de l'unité dans les zones signalées où elle se trouve
	for _index, _ in pairs(localMembers.signalIndex) do
		local signal = ATMEDatas.signals:get(_index)
		
		signal.coalitionUnitsInZone[_player:getName()] = nil
		localMembers.signalIndex[_index] = nil
	end
	
	-- Suppression des tracking de franchissement pour cette unité joueur
	for _, _multiSegment in pairs(localMembers.multiSegment2D) do
		local localMembersMultiSegment = ATMEDatas.C_MultiSegment2D_MT:get(_multiSegment:getIndex())
		ATMEFct.C_MultiSegment2D_remove(_multiSegment, localMembersMultiSegment, _AIUnit:getName())
		localMembers.multiSegment2D[_multiSegment] = nil
	end

	
	for _, _localModuleMembers in ATMEDatas.C_Module_MT:pairs() do
		_player.modules[_localModuleMembers.name] = nil
		localMembers.userPrivateDatas[_localModuleMembers.name] = nil
	end
	
	for _, _item in localMembers.onBoardGroupDatas:pairs() do
		-- Si un des groupes embarqués a un respawn automatique il est préparé
		
		if _item.autoRespawn.activated == true then
			local respawnTime = _item.autoRespawn.time
			if _item.autoRespawn.random == true then
				respawnTime = math.random(_item.autoRespawn.minTime, _item.autoRespawn.maxTime)
			end
			
			ATMEDatas.groupsToRespawn[_item.name] = {
				time = respawnTime + timer.getTime(),
				spawnDatas = _item.spawnDatas,
			}
		end
		
		ATMEDatas.groupsOnBoard[_item.name] = nil
	end
	
	local playerName = _player:getName()
	localMembers.onBoardGroupDatas:removeAll()
	ATMEDatas.autoUnloadDatas[playerName] = nil
	
	ATMEFct.C_Group_deleteUnit(_player:getGroup(), playerName)
	ATMEDatas.C_Player_MT:remove(_player:getIndex())
	
	ATMEDatas.players[playerName] = nil
	ATMEDatas.allAIUnitsAndPlayers[playerName] = nil
	ATMEDatas.signalCapabilityUnitsToDelete[playerName] = true
	
	ATMEDatas.nbPlayers = ATMEDatas.nbPlayers - 1
	
	ATMEFct.outputCore(nil,"Delete Player : " .. playerName , 2)
end

setmetatable(ATME.C_Player,ATMEDatas.C_Player_MT)

ATMEDatas.C_Player_MT.mt.__metatable = "Private"
ATMEDatas.C_Player_MT.mt.__index = ATME.C_Player
ATMEDatas.C_Player_MT.mt.__newindex = function(t, k, v)
	if ATMEDatas.C_Player_MT.keys[k] ~= nil then 
		rawset(t, k, v)
	else
		ATMEFct.errorOutputCore(nil, "Function ATME.C_Player : Bad key " .. k, "table locked", false)
	end
end

ATMEDatas.C_Player_MT.mtModules.__metatable = "Private"
ATMEDatas.C_Player_MT.mtModules.__newindex = function(t, k, v)
	if ATMEDatas.modules[k] ~= nil then
		rawset(t, k, v)
	else
		ATMEFct.errorOutputCore(nil,"ATME : ATME.C_Player.modules Bad key " .. k, "table locked", false)
	end
end


----------------------------------------------------------------------------------------------------------
-- Classe ATME.C_AIUnit : gère les unités AI au format ATME. Pas de contructeur accessible
-- pour les modules externes.
-- Les instances de cette classe sont intégralement gérées par le module ATME_Core. La création et la destruction
-- dépendent du contexte de début de mission et des événements qui se produisent dans DCS en cours de mission.
-- Les modules externes accèdent à cette gestion indirectement par les handlers définis dans ceux-ci et les méthodes
-- accessibles de cette classe. Ceci permet de garantir une cohérence sur les listes internes ATME.
----------------------------------------------------------------------------------------------------------

ATMEDatas.C_AIUnit_MT = {
	className = "C_AIUnit",
	parentClass = ATME.C_Unit,
	mtModules = {},
	mt = {},
	
	keys = {
		["setFrequency"] = true,
		["setVoice"] = true,
		["getVoice"] = true,
		["transmissionLock"] = true,
		["transmissionOnce"] = true,
		["transmissionLoop"] = true,
		["transmissionStart"] = true,
		["transmissionStop"] = true,
		["transmissionDelayed"] = true,
		["getPosition"] = true,
		["getVelocityVector"] = true,
		["getRollAxisVector"] = true,
		["getIndex"] = true,
		["getDCSUnit"] = true,
		["getName"] = true,
		["tagGetByID"] = true,
		["tagCompare"] = true,
		["tagGetCount"] = true,
		["getTypeName"] = true,
		["getGroup"] = true,
		["disable"] = true,
		["getFuelRatio"] = true,
		["getLife"] = true,
		["getLifeRatio"] = true,
		["getCallsign"] = true,
		["getSpeed"] = true,
		["getHSpeed"] = true,
		["getVSpeed"] = true,
		["getSpeedAzimuth"] = true,
		["getAzimuth"] = true,
		["getCountryName"] = true,
		["getCoalitionName"] = true,
		["isActivated"] = true,
		["isHelicopter"] = true,
		["isPlane"] = true,
		["isPersonnelCarrier"] = true,
		["isInfantry"] = true,
		["isGroundVehicle"] = true,
		["isAirDefence"] = true, 
		["isManPad"] = true,
		["isSAMVehicle"] = true,
		["isSAMSiteLauncher"] = true,
		["isSAMSiteRadar"] = true,
		["isSAMSiteCommandCenter"] = true,
		["isAAA"] = true,
		["inAir"] = true,
		["getMSLAltitude"] = true,  
		["getAGLAltitude"] = true,
		["explode"] = true,
		["isInArea"] = true,
		["isInDCSZone"] = true,
		["isInZone2D"] = true,
		["isInSphere"] = true,
		["isNear"] = true,
		["isPilotDead"] = true,
		["isPilotEjected"] = true,
		["setMultiSegmentTracking"] = true,
		["resetMultiSegmentTracking"] = true,
		["whichSide"] = true,
		["getNbUnitsOnBoard"] = true,
		["getGroupOnBoardNames"] = true,
		["load"] = true,
		["unload"] = true,
		["getNearestReadyToBoardGroup"] = true,
		["fireFlare"] = true,
		["fireSmoke"] = true,
		["fireIlluminationBomb"] = true,
		["modules"] = true,
		["canFly"] = true,
		["getUserPrivateDatas"] = true,
		["spotActivate"] = true,
		["spotDesactivate"] = true,
		["spotWhichIsActivated"] = true,
		["spotGetDatas"] = true,
		["spotIgnoreTarget"] = true,
		["sensorStart"] = true,
		["sensorStop"] = true,
	},
	
	localMembers = ATMEFct.C_IndexList_create(),

	add = function(self, _name)
		local item = {
			nbUnitsOnBoard = 0,
			groupsBoarding = {},
			onBoardGroupDatas = ATMEFct.C_IndexList_create(),
			isEnabled = true,
			radioTransmissionID = 0,
			multiSegment2D = {},			-- Table des multisegments suivis en franchissement par l'unité
			userPrivateDatas = {},			-- Point d'entrée des données privées : un par module
			signalIndex = {},				-- Table pour les zones signalées où se trouve l'unité
			targets = {},					-- Table des cibles trackées à un instant T
			tagsName = ATMEFct.decompString(_name),
			pilotDead = false,
			pilotEjected = false,
		}
		
		return self.localMembers:add(item)
	end,
	
	remove = function(self, _id)
		self.localMembers:get(_id).targets = nil
		self.localMembers:remove(_id)
	end,
	
	get = function(self, _id)
		return self.localMembers:get(_id)
	end,
}

ATME.C_AIUnit = {
	getClassName = function(self)
		return ATMEDatas.C_AIUnit_MT.className
	end,
	
	getParentClass = function(self)
		return ATMEDatas.C_AIUnit_MT.parentClass
	end,
	
	getByName = function(_unitName)
		if type(_unitName) == "string" then
			return ATMEDatas.AIUnits[_unitName]
		else
			ATMEFct.errorOutputCore(nil, "Function ATME.C_AIUnit.getByName(name)", "name type must be string", false)
		end	
	end,
}

ATMEFct.C_AIUnit_startTransmission = function(_radioTransmission)
	if _radioTransmission.started == false and _radioTransmission.playlist[_radioTransmission.currentReadIndex].pause == false then
		local controller = ATMEDatas.AIUnits[_radioTransmission.unitName]:getDCSUnit():getController()

		local command = { 
			id = "TransmitMessage", 
			params = {
				file = "l10n/DEFAULT/" .. _radioTransmission.voice .. _radioTransmission.playlist[_radioTransmission.currentReadIndex].fileName,
				duration = _radioTransmission.playlist[_radioTransmission.currentReadIndex].subtitle.duration,
				subtitle = _radioTransmission.playlist[_radioTransmission.currentReadIndex].subtitle.text,
				loop = _radioTransmission.autoRestartDCS,
			} 
		}
		controller:setCommand(command)
		_radioTransmission.started = true
	end
end

ATMEFct.C_AIUnit_stopTransmission = function(_radioTransmission)
	if _radioTransmission.started == true then
		local controller = ATMEDatas.AIUnits[_radioTransmission.unitName]:getDCSUnit():getController()
		
		local command = { 
			id = "StopTransmission", 
			params = {},
				
		}
		
		controller:setCommand(command)
	
		_radioTransmission.started = false
	end
end

ATMEFct.C_AIUnit_isTargetOk = function(_ATMEUnit, _ignoredTargets)
	local group = _ATMEUnit:getGroup()
	local active = _ATMEUnit:isActivated()
	local ok = false
	
	if _ignoredTargets ~= nil and _ignoredTargets[_ATMEUnit:getName()] == true then
		ok = true
	end
	
	return (group:getCategoryName() == "GROUND" or 
			((group:getCategoryName() == "AIRPLANE" or group:getCategoryName() == "HELICOPTER") and _ATMEUnit:inAir() == false)) and 
			(active == true or (active == false and group:isAlwaysVisible() == true)) and ok == false
end

ATMEFct.C_AIUnit_loopAttributes = function(_unit, _datas)
	for _attribute, _priority in pairs(ATMEConst.targetAttributePriority.vehicle) do
		if type(_attribute) == "table" then
			ATMEFct.C_AIUnit_loopAttributes(_unit, _datas)	
		elseif _unit:hasAttribute(_attribute) then
			if _datas.currentPriority < _priority then
				_datas.currentPriority = _priority
				_datas.targetName = _unit:getName()
			end
		end
	end
end

ATMEFct.C_AIUnit_searchTargetsInBox = function(_unit, _datas)
	local ATMEUnit = ATMEDatas.allAIUnitsAndPlayers[_unit:getName()]
	
	if ATMEFct.C_AIUnit_isTargetOk(ATMEUnit, _datas.ignoredTargets) == true and ATMEUnit:getCoalitionName() == _datas.targetsCoalition then
		if ATMEFct.C_Group_Unit_isInZone2D(ATMEUnit, _datas.zone) == true then	
			ATMEFct.C_AIUnit_loopAttributes(_unit, _datas)
			
			if _datas.targetName == nil then
				_datas.targetName = _unit:getName()
			end
		end
	end
end

ATMEFct.C_AIUnit_findTargetInGroup = function(_group , _ignoredTargets)
	local unit = _group:getFirstUnit()
	
	if unit ~= nil then
		local datas = {
			currentPriority = 0,
		}
		
		repeat
			if ATMEFct.C_AIUnit_isTargetOk(unit, _ignoredTargets) == true then
				local found = false
				local unitName = unit:getName()

				ATMEFct.C_AIUnit_loopAttributes(unit:getDCSUnit(), datas)
				
				if datas.targetName == nil then
					datas.targetName = unitName
				end
			end
			
			unit = _group:getNextUnit()
		until unit == nil
		
		return datas.targetName
	end
end

ATMEFct.C_AIUnit_findTargetInZone2D = function(_zone, _targetsCoalition, _ignoredTargets)
	local box = _zone:getBox()				
	local volume = {
		id = world.VolumeType.BOX,
		params = box,
	}
	
	local datas = {
		currentPriority = 0,
		zone = _zone,
		targetsCoalition = _targetsCoalition,
		ignoredTargets = _ignoredTargets,
	}

	world.searchObjects(Object.Category.UNIT, volume, ATMEFct.C_AIUnit_searchTargetsInBox, datas)
		
	
	return datas.targetName
end

ATMEFct.C_AIUnit_getDetectedTargets = function(_ATMEUnit, _typeOfSensorName)
	local controller = _ATMEUnit:getDCSUnit():getController()
	local detectedTargetsList
	local localMembers = ATMEDatas.C_AIUnit_MT:get(_ATMEUnit:getIndex())

	if _typeOfSensorName ~= nil then
		detectedTargetsList = controller:getDetectedTargets(ATMEConst.typesOfSensor[_typeOfSensorName])
	else
		detectedTargetsList = controller:getDetectedTargets()
	end
	

	local nb = 0

	for _, _target in pairs(localMembers.targets) do
		_target.stillDetected = false
	end

	for _, _target in ipairs(detectedTargetsList) do
		if _target.object ~= nil then
			local targetName = _target.object:getName()
			if ATMEDatas.allAIUnitsAndPlayers[targetName] ~= nil then
				-- Test si la target est bien une unité ou un joueur
				
				if localMembers.targets[targetName] ~= nil then
					localMembers.targets[targetName].stillDetected = true
				else
					localMembers.targets[targetName] = {
						stillDetected = true,
						trackingOn = false,
						confirmed = 0,
					}
				end
	
				nb = nb + 1
			end
		end
	end
	
	return localMembers.targets, nb
end

ATMEFct.C_AIUnit_create = function(_unit, _datas)
	local name = _unit:getName()
	local newUnit = {}
	
	setmetatable(newUnit, ATMEDatas.C_AIUnit_MT.mt)
	local index = ATMEDatas.C_AIUnit_MT:add(name)
	local localMembers = ATMEDatas.C_AIUnit_MT:get(index)
	
	local unit = _unit
	local waypoints
	local typeName = _unit:getTypeName()
	local oldSide
	
	local frequency
	local modulation
	local currentVoice = ""
	local locked = false
	local waitIfFrequencyLocked = false
	
	if ATMEDatas.allAIUnitsInMission[name] ~= nil then
		waypoints = ATMEDatas.allAIUnitsInMission[name].group.waypoints
	end
		
	local groupName = _unit:getGroup():getName()
	local ATMEGroup
	
	
	function newUnit:getIndex(self)
		return index
	end
	
	function newUnit.getDCSUnit(self)
		return unit
	end
	
	function newUnit.getName(self)
		return name
	end
	
	function newUnit.isActivated(self)
		return unit:isActive()
	end
	
	function newUnit.tagGetByID(self, _position)
		local fctDefinition = ATMEFct.getErrorPrefix(newUnit) .. "tagGetByID(position)"
		
		if type(_position) == "number" then
			local pos = math.floor(_position)
			if localMembers.tagsName ~= nil and pos >= 1 and pos <= #localMembers.tagsName then
				return localMembers.tagsName[pos]
			end
		else
			ATMEFct.errorOutputCore(nil, fctDefinition, "position type must be number", true)
		end
	end
	
	function newUnit.tagGetCount(self)
		if tagsName ~= nil then
			return #tagsName
		else
			return 0
		end
	end
	
	function newUnit.tagCompare(self, _tagsToCompare)
		local fctDefinition = ATMEFct.getErrorPrefix(newUnit) .. "tagCompare(tagsToCompare)"
		
		if type(_tagsToCompare) == "string" then
			if localMembers.tagsName ~= nil then
				local ok = ATMEFct.compareTags(localMembers.tagsName, _tagsToCompare)
				
				if ok ~= nil then
					return ok
				else
					ATMEFct.errorOutputCore(nil, fctDefinition, "tagsToCompare format must be 'T1|T2|..|Tn'", false)
				end
			else
				return false
			end
		else
			ATMEFct.errorOutputCore(nil, fctDefinition, "tagsToCompare type must be string", true)
		end
	end
	
	function newUnit.getTypeName(self)
		return typeName
	end
	
	function newUnit.getGroup(self)
		return ATMEGroup
	end
	
	function newUnit.getUserPrivateDatas(self, _module)
		local fctDefinition = ATMEFct.getErrorPrefix(newUnit) .. "getUserPrivateDatas(module)"
		
		if ATME.isObjectClass(_module, ATME.C_Module) == true then
			return localMembers.userPrivateDatas[_module:getName()]
		else
			ATMEFct.errorOutputCore(nil, fctDefinition, "module type must be ATME.C_Module", true)
		end
	end
	
	function newUnit.sensorStart(self, _typeOfSensorName, _flag)
		local fctDefinition = ATMEFct.getErrorPrefix(newUnit) .. "sensorStart(typeOfSensorName, [flag])"
		
		if type(_typeOfSensorName) == "string" and (type(_flag) == "number" or type(_flag) == "string" or _flag == nil) then
			if ATMEConst.typesOfSensor[_typeOfSensorName] ~= nil then
				if ATMEDatas.targetsTracking[self:getName()] == nil then
					ATMEDatas.targetsTracking[self:getName()] = {
						flag = _flag,
					}
					if _typeOfSensorName ~= "ALL" then
						ATMEDatas.targetsTracking[self:getName()].typeOfSensorName = _typeOfSensorName
					end
				end
			else
				ATMEFct.errorOutputCore(nil, fctDefinition, "typeOfSensorName must be 'ALL', 'RADAR', 'VISUAL', 'OPTIC', 'IRST', 'RWR', 'DLINK'", false)
			end
		else
			if type(_typeOfSensorName) ~= "string" then
				ATMEFct.errorOutputCore(nil, fctDefinition, "typeOfSensorName type must be string", true)
			elseif type(_flag) ~= "number" and type(_flag) ~= "string" and _flag ~= nil then
				ATMEFct.errorOutputCore(nil, fctDefinition, "flag type must be nil or string or number", false)
			end
		end
	end
	
	function newUnit.sensorStop(self)
		ATMEDatas.targetsTracking[self:getName()] = nil
	end
	
	function newUnit.spotActivate(self, _reference, _code)
		local fctDefinition = ATMEFct.getErrorPrefix(newUnit) .. "spotActivate(reference, [code])"
		
		if (ATME.isObjectClass(_reference, ATME.C_AIUnit) == true or ATME.isObjectClass(_reference, ATME.C_StaticObject) == true or
				ATME.isObjectClass(_reference, ATME.C_Group) == true or ATME.isObjectClass(_reference, ATME.C_Zone2D) == true or 
				type(_reference) == "string" or ATME.isPoint(_reference) ~= POINT_BAD) and (_code == nil or type(_code) == "number") then
				 
			local point
			local referenceGroupName
			local dynamicSpot = ATME.isObjectClass(_reference, ATME.C_StaticObject) == false and ATME.isPoint(_reference) == POINT_BAD
			local datas
			local targetName
			local zone2D
			
			if ATME.isObjectClass(_reference, ATME.C_StaticObject) == true or ATME.isObjectClass(_reference, ATME.C_AIUnit) == true then
				if ATME.isObjectClass(_reference, ATME.C_StaticObject) == true or ATMEFct.C_AIUnit_isTargetOk(_reference) == true then
					targetName = _reference:getName()
				else
					ATMEFct.errorOutputCore(nil, fctDefinition, "reference must be ground unit or aircraft unit on floor", false)
					return
				end
			elseif ATME.isObjectClass(_reference, ATME.C_Group) == true then
				if _reference:getCategoryName() ~= "SHIP" then
					if self:getCoalitionName() ~= _reference:getCoalitionName() then
						targetName = ATMEFct.C_AIUnit_findTargetInGroup(_reference)
						referenceGroupName = _reference:getName()
						if targetName == nil then
							-- Aucune unité trouvée. Pas d'activation
							
							return false
						end
					else
						return false
					end
				else
					ATMEFct.errorOutputCore(nil, fctDefinition, "reference must be ground group or aircraft group", false)
					return
				end
			elseif type(_reference) == "string" then
				local zone = ATME.getDCSZone(_reference)
				if zone ~= nil then
					local targetsCoalition = "RED"
					if self:getCoalitionName() == "RED" then
						targetsCoalition = "BLUE"
					end
					zone2D = ATMEFct.C_Circle_create(zone.point, zone.radius)
					targetName = ATMEFct.C_AIUnit_findTargetInZone2D(zone2D, targetsCoalition)
					
					if targetName == nil then
						-- Aucune unité trouvée. Pas d'activation

						return false
					end
				else
					ATMEFct.errorOutputCore(nil, fctDefinition, "DCS zone " .. _reference .. " unknown", false)
					return
				end
			elseif ATME.isObjectClass(_reference, ATME.C_Zone2D) == true then
				local targetsCoalition = "RED"
				if self:getCoalitionName() == "RED" then
					targetsCoalition = "BLUE"
				end
				targetName = ATMEFct.C_AIUnit_findTargetInZone2D(_reference, targetsCoalition)
				zone2D = _reference
				
				if targetName == nil then
					-- Aucune unité trouvée. Pas d'activation
					
					return false
				end
			else
				point = ATME.convertToPoint3D(_reference)
			end
			
			-- Lasing à partir d'un drone en vol
			local lasingInAir = false
			if self:canFly() == true and self:inAir() == true and ATMEConst.targetAttributePriority.aircraftType[typeName] == true then
				lasingInAir = true
			end
			
			if self:getGroup():getCategoryName() == "GROUND" or lasingInAir == true then
				local code

				if _code ~= nil then
					code = math.floor(_code)
					if code < 1111 or code > 1788 then
						ATMEFct.errorOutputCore(nil, fctDefinition, "code must be >= 1111 and <= 1788", false)
						return
					end
				end
				
				if (self:getSpeed() == 0 and lasingInAir == false) or lasingInAir == true then
					if ATMEDatas.spots[name] ~= nil and ATMEDatas.spots[name].spot ~= nil then
						ATMEDatas.spots[name].spot:destroy()
					end
					
					ATMEDatas.spots[name] = {
						targetName = targetName,
						groupName = referenceGroupName,
						zone = zone2D,
						code = code,
						dynamicSpot = dynamicSpot,
						noLOS = 0,
						neverHaveLOS = true,
						ignoredTargets = {},
						ignoredTargetOn = false,
						fromAir = lasingInAir,
					}
					
					return true
				else
					return false
				end
			else
				ATMEFct.errorOutputCore(nil, fctDefinition, "current unit must be ground unit or drone unit in air", false)
			end
		else
			if ATME.isObjectClass(_reference, ATME.C_AIUnit) == false and ATME.isObjectClass(_reference, ATME.C_StaticObject) == false and
					ATME.isObjectClass(_reference, ATME.C_Group) == false and ATME.isObjectClass(_reference, ATME.C_Zone2D) == false and 
					type(_reference) ~= "string" and ATME.isPoint(_reference) == POINT_BAD then
				ATMEFct.errorOutputCore(nil, fctDefinition, "reference type must be string or ATME.C_Zone2D or ATME.C_Group or ATME.C_AIUnit or ATME.C_StaticObject or table (x,y) or (x,y,z)", true)
			elseif _code ~= nil and type(_code) ~= "number" then
				ATMEFct.errorOutputCore(nil, fctDefinition, "code type must be nil or number", false)
			end
		end
	end
	
	function newUnit.spotDesactivate(self)
		if ATMEDatas.spots[name] ~= nil then
			if ATMEDatas.spots[name].spot ~= nil then
				ATMEDatas.spots[name].spot:destroy()
			end
			
			ATMEDatas.spots[name] = nil
			ATMEDatas.spotsToReassign[name] = nil
		end
	end
	
	function newUnit.spotIgnoreTarget(self)
		if ATMEDatas.spots[name] ~= nil then
			if ATMEDatas.spots[name].targetName ~= nil then
				ATMEDatas.spots[name].ignoredTargets[ATMEDatas.spots[name].targetName] = true
				ATMEDatas.spots[name].ignoredTargetOn = true
			end
		end
	end
	
	function newUnit.spotWhichIsActivated(self)
		if ATMEDatas.spots[name] ~= nil then
			if ATMEDatas.spots[name].code ~= nil then
				return "LASER"
			else
				return  "IR"
			end
		end
	end
	
	function newUnit.spotGetDatas(self)
		if ATMEDatas.spots[name] ~= nil then
			return {
				targetName = ATMEDatas.spots[name].targetName,
				isAIUnit = ATMEDatas.spots[name].targetName ~= nil and ATMEDatas.spots[name].dynamicSpot == true,
				isStaticObject = ATMEDatas.spots[name].targetName ~= nil and ATMEDatas.spots[name].dynamicSpot == false,
				isFixedPoint = ATMEDatas.spots[name].targetName == nil,
				code = ATMEDatas.spots[name].code,
				vector = ATMEDatas.spots[name].vector,
			}
		end
	end
	
	function newUnit.disable(self)	
		localMembers.isEnabled = false
		
		unit:destroy()
		ATMEFct.C_AIUnit_delete(self)
	end
	
	function newUnit.getFuelRatio(self)
		return unit:getFuel()
	end
	
	function newUnit.getLife(self)
		return unit:getLife()
	end
	
	function newUnit.getLifeRatio(self)
		return self:getLife()/unit:getLife0()
	end
	
	function newUnit.getCallsign(self)
		local identification
		local id1
		local id2
		
		if unit:hasAttribute("Helicopters") or unit:hasAttribute("Planes") then
			local callsign = unit:getCallsign()
			if unit:getCoalition() == 2 then
				identification = string.match(callsign, "^%a*")
				id1 = string.match(callsign, "%d")
				id2 = string.match(callsign, "%d$")
			else
				identification = callsign
			end
		end
		
		return identification, id1, id2
	end
	
	function newUnit.getPosition(self)
		return unit:getPoint()
	end

	function newUnit.getVelocityVector(self)
		local vector = ATMEFct.C_Vector3D_create(nil, nil, unit:getVelocity())
		return vector
	end

	function newUnit.getSpeed(self)
		local vector = self:getVelocityVector()
		return vector:getModule(vector)
	end

	function newUnit.getHSpeed(self)
		local vector = self:getVelocityVector()
		return vector:getHModule(vector)
	end

	function newUnit.getVSpeed(self)
		local vector = unit:getVelocity()
		return vector.y
	end

	function newUnit.getSpeedAzimuth(self)
		local vector = self:getVelocityVector()
			
		if vector:getModule() > 1 then 
			return vector:getAzimuth()
		else
			return 0
		end
	end

	function newUnit.getRollAxisVector(self)
		return ATMEFct.C_Vector3D_create(nil, nil, unit:getPosition().x)
	end

	function newUnit.getAzimuth(self)
		local vector = self:getRollAxisVector()
		return vector:getAzimuth()
	end

	function newUnit.getCountryName(self)
		local id = unit:getCountry()
		return country.name[id]
	end

	function newUnit.getCoalitionName(self)
		local id = unit:getCoalition()
		return ATMEConst.coalitionNames[id]
	end

	function newUnit.isHelicopter(self)
		return unit:hasAttribute("Helicopters")
	end
	
	function newUnit.isPersonnelCarrier(self)
		return ATMEConst.personnelCarrierAttributes[self:getTypeName()] ~= nil
	end


	function newUnit.isPlane(self)
		return unit:hasAttribute("Planes")
	end
	
	function newUnit.canFly(self)
		return self:isPlane() == true or self:isHelicopter() == true
	end
	
	function newUnit.isInfantry(self)
		return unit:hasAttribute("Infantry")
	end
	
	function newUnit.isGroundVehicle(self)
		return unit:hasAttribute("Ground vehicles")
	end

	function newUnit.isAirDefence(self)
		return unit:hasAttribute("Air Defence")
	end

	function newUnit.isManPad(self)
		return unit:hasAttribute("MANPADS")
	end

	function newUnit.isSAMVehicle(self, _range)
		local fctDefinition = ATMEFct.getErrorPrefix(newUnit) .. "isSAMVehicle(range)"
		
		if type(_range) == "string" then
			if _range == "SHORT" then
				return unit:hasAttribute("SR SAM")
			elseif _range == "MEDIUM" then
				return self.unit:hasAttribute("MR SAM")
			elseif _range == "LONG" then
				return self.unit:hasAttribute("LR SAM")
			elseif _range == "ALL" then
				return unit:hasAttribute("SR SAM") or self.unit:hasAttribute("MR SAM") or self.unit:hasAttribute("LR SAM")
			else
				ATMEFct.errorOutputCore(nil, fctDefinition, "range bad value (SHORT, MEDIUM, LONG or ALL)", false)
			end
		else
			ATMEFct.errorOutputCore(nil, fctDefinition, "range type must be string", true)
		end
	end

	function newUnit.isSAMSiteLauncher(self)
		return unit:hasAttribute("SAM LL")
	end

	function newUnit.isSAMSiteRadar(self, _category)
		local fctDefinition = ATMEFct.getErrorPrefix(newUnit) .. "isSAMSiteRadar(category)"
		
		if type(_category) == "string" then
			if _category == "SURFACE" then
				return unit:hasAttribute("SAM SR")
			elseif _category == "TRACKING" then
				return self.unit:hasAttribute("SAM TR")
			elseif _category == "ALL" then
				return unit:hasAttribute("SAM SR") or unit:hasAttribute("SAM TR")
			else
				ATMEFct.errorOutputCore(nil, fctDefinition, "category bad value (SURFACE, TRACKING or ALL)", false)
			end
		else
			ATMEFct.errorOutputCore(nil, fctDefinition, "category type must be string", true)
		end
	end

	function newUnit.isSAMSiteCommandCenter(self)
		return unit:hasAttribute("SAM CC")
	end

	function newUnit.isAAA(self)
		return unit:hasAttribute("AAA")
	end	

	function newUnit.inAir(self)
		return unit:inAir()
	end

	function newUnit.getMSLAltitude(self)
		return ATME.getPointAltitude(self:getPosition())
	end

	function newUnit.getAGLAltitude(self)
		local landHeight = ATMEFct.getSurfaceAltitude(self:getPosition())
		return ATME.getPointAltitude(self:getPosition()) - landHeight
	end

	function newUnit.explode(self, _power)
		local fctDefinition = ATMEFct.getErrorPrefix(newUnit) .. "explode(power)"
		
		if type(_power) == "number" then
			if _power >= 1 then
				ATME.explode(self:getPosition(), _power)
			else
				ATMEFct.errorOutputCore(nil, fctDefinition, "power must be >= 1", false)
			end
		else
			ATMEFct.errorOutputCore(nil, fctDefinition, "power type must be number", true)
		end
	end
	
	function newUnit.isInArea(self, _area)
		local fctDefinition = ATMEFct.getErrorPrefix(newUnit) .. "isInArea(area)"
		
		if ATME.isObjectClass(_area, ATME.C_Area) == true then
			return _area:isInside(self) 
		else
			ATMEFct.errorOutputCore(nil, fctDefinition, "area type must be ATME.C_Area", true)
		end
	end				

	function newUnit.isInDCSZone(self, _name)
		local fctDefinition = ATMEFct.getErrorPrefix(newUnit) .. "isInDCSZone(name)"
		
		if type(_name) == "string" then
			local zone = ATME.getDCSZone(_name)
			
			if zone ~= nil then
				local vector = ATMEFct.C_Vector3D_create(nil, nil, self:getPosition(), zone.point)
				if vector:getHModule() <= zone.radius then
					return true
				else
					return false
				end
			else
				ATMEFct.errorOutputCore(nil, fctDefinition, "DCS zone " .. _name .. " unknown", false)
			end
		else
			ATMEFct.errorOutputCore(nil, fctDefinition, "name type must be string", true)
		end
	end
	
	function newUnit.isInZone2D(self, _zone)
		local fctDefinition = ATMEFct.getErrorPrefix(newUnit) .. "isInZone2D(zone)"
		
		if ATME.isObjectClass(_zone, ATME.C_Zone2D) == true then
			
			local found = false
			local point = self:getPosition()
			
			if ATMEFct.isObjectClass(_zone, ATME.C_Polygon) == true then
				local localMembersZone = ATMEDatas.C_Polygon_MT:get(_zone:getIndex())
				found = ATMEFct.C_Polygon_isInside(point, localMembersZone.triangles) 
			elseif ATMEFct.isObjectClass(_zone, ATME.C_Circle) == true then
				local localMembersZone = ATMEDatas.C_Circle_MT:get(_zone:getIndex())
				found = ATMEFct.C_Circle_isInside(point, localMembersZone.center, nil, 
												0, localMembersZone.radius)
			elseif ATMEFct.isObjectClass(_zone, ATME.C_PickupZone) == true then
				local localMembersZone = ATMEDatas.C_PickupZone_MT:get(_zone:getIndex())
				found = ATMEFct.C_Circle_isInside(point, localMembersZone.center, nil, 0, localMembersZone.radius)
			else
				local localMembersZone = ATMEDatas.C_Ring_MT:get(_zone:getIndex())
				found =  ATMEFct.C_Circle_isInside(point, localMembersZone.center, nil, 
												localMembersZone.radiusMin, localMembersZone.radiusMax) 
			end
			
			return found
		else
			ATMEFct.errorOutputCore(nil, fctDefinition, "zone type must be ATME.C_Circle, ATME.C_Ring, ATME.C_PickupZone, ATME.C_Rectangle or ATME.C_Polygon", true)
		end
	end
	
	function newUnit.isInSphere(self, _reference, _radius)
		local fctDefinition = ATMEFct.getErrorPrefix(newUnit) .. "isInZone3D(reference, radius)"
		
		if ATMEFct.isReference(_reference) == true and type(_radius) == "number" then
			if _radius > 0 then
				local point = ATMEFct.getPointFromReference(_reference)
				local vector = ATMEFct.C_Vector3D_create(nil, nil, self:getPosition(), point)
				
				return vector:getModule() <= _radius
			else
				ATMEFct.errorOutputCore(nil, fctDefinition, "radius must be > 0", false)
			end
		else
			if ATMEFct.isReference(_reference) == false then
				ATMEFct.errorOutputCore(nil, fctDefinition, "reference type must be ATME.C_AIUnit or ATME.C_Player or ATME.C_StaticObject or table (x,y) or (x,y,z)", true)
			elseif type(_radius) ~= "number" then
				ATMEFct.errorOutputCore(nil, fctDefinition, "radius type must be number", false)
			end
		end
	end
	
	function newUnit.isNear(self, _reference, _radius, _deltaAltitude)
		local fctDefinition = ATMEFct.getErrorPrefix(newUnit) .. "isNear(reference, radius, deltaAltitude)"
		
		if ATMEFct.isReference(_reference) == true and type(_radius) == "number" and type(_deltaAltitude) == "number" then	
			if _radius > 0 then
				if _deltaAltitude > 0 then
					local point = ATMEFct.getPointFromReference(_reference)
					local vector = ATMEFct.C_Vector3D_create(nil, nil, self:getPosition(), point)
					
					return vector:getHModule() <= _radius and math.abs(vector:getY()) <= _deltaAltitude
				else
					ATMEFct.errorOutputCore(nil, fctDefinition, "deltaAltitude must be > 0", false)
				end
			else
				ATMEFct.errorOutputCore(nil, fctDefinition, "radius must be > 0", false)
			end
		else
			if ATMEFct.isReference(_reference) == false then
				ATMEFct.errorOutputCore(nil, fctDefinition, "reference type must be ATME.C_AIUnit or ATME.C_Player or ATME.C_StaticObject or table (x,y) or (x,y,z)", true)
			elseif type(_radius) ~= "number" then
				ATMEFct.errorOutputCore(nil, fctDefinition, "radius type must be number", false)
			elseif type(_deltaAltitude) ~= "number" then
				ATMEFct.errorOutputCore(nil, fctDefinition, "deltaAltitude type must be number", false)
			end
		end
	end
	
	function newUnit.isPilotDead(self)
		return localMembers.pilotDead
	end
	
	function newUnit.isPilotEjected(self)
		return localMembers.pilotEjected
	end
	
	function newUnit.whichSide(self, _reference)
		local fctDefinition = ATMEFct.getErrorPrefix(newUnit) .. "whichSide(reference)"
		
		if ATMEFct.isReference(_reference) == true  then
			local point = ATMEFct.getPointFromReference(_reference)

			return ATMEFct.C_Player_C_AIUnit_whichSide(self, point)
		else
			ATMEFct.errorOutputCore(nil, fctDefinition, "reference type must be ATME.C_AIUnit or ATME.C_Player or ATME.C_StaticObject or table (x,y) or (x,y,z)", true)
		end
	end
	
	function newUnit.setMultiSegmentTracking(self, _multiSegment2D)
		local fctDefinition = ATMEFct.getErrorPrefix(newUnit) .. "setMultiSegmentTracking(multiSegment2D)"
		
		if ATME.isObjectClass(_multiSegment2D, ATME.C_MultiSegment2D) == true then
			ATMEFct.C_MultiSegment2D_changeCrossingMultiSegmentTracking(_multiSegment2D, self, true)
			
			localMembers.multiSegment2D[_multiSegment2D] = _multiSegment2D
		else
			ATMEFct.errorOutputCore(nil, fctDefinition, "multiSegment2D type must be ATME.C_MultiSegment2D", true)
		end
	end
	
	function newUnit.resetMultiSegmentTracking(self, _multiSegment2D)
		local fctDefinition = ATMEFct.getErrorPrefix(newUnit) .. "resetMultiSegmentTracking(multiSegment2D)"
		
		if ATME.isObjectClass(_multiSegment2D, ATME.C_MultiSegment2D) == true then
			ATMEFct.C_MultiSegment2D_changeCrossingMultiSegmentTracking(_multiSegment2D, self, false)
			
			localMembers.multiSegment2D[_multiSegment2D] = nil
		else
			ATMEFct.errorOutputCore(nil, fctDefinition, "multiSegment2D type must be ATME.C_MultiSegment2D", true)
		end
	end
	
	function newUnit.getNbUnitsOnBoard(self)
		return localMembers.nbUnitsOnBoard
	end

	function newUnit.getGroupOnBoardNames(self)
		local temp = {}
		
		for _, _item in localMembers.onBoardGroupDatas:pairs() do
			table.insert(temp, _item.name)
		end
		return temp
	end

	function newUnit.unload(self, _id, _whenStop)
		local fctDefinition = ATMEFct.getErrorPrefix(newUnit) .. "unload(id, [whenStop])"
		
		if type(_id) == "number" and (_whenStop == nil or type(_whenStop) == "boolean") then
			local id = math.floor(_id)
			
			local currentOnBoardGroupDatas = localMembers.onBoardGroupDatas:get(id)
			local whenStop = _whenStop
				
			if _whenStop == nil then
				whenStop = false
			end
				
			if (currentOnBoardGroupDatas ~= nil and whenStop == false) or whenStop == true then
				
				return ATMEFct.C_Player_C_AIUnit_unload(self, id, currentOnBoardGroupDatas, whenStop)
			else
				ATMEFct.setError("UNLOAD_BAD_ID")
			end
		else
			if type(_id)~= "number" then
				ATMEFct.errorOutputCore(nil, fctDefinition, "id type must be number", true)
			elseif _whenStop ~= nil and type(_whenStop) ~= "boolean" then
				ATMEFct.errorOutputCore(nil, fctDefinition, "whenStop type must be nil or boolean", false)
			end
		end
	end

	function newUnit.load(self, _radius, _groupToBoard)
		local fctDefinition = ATMEFct.getErrorPrefix(newPlayer) .. "load(radius, [groupToBoard])"
		
		if type(_radius) == "number" and (_groupToBoard == nil or ATME.isObjectClass(_groupToBoard, ATME.C_Group) == true or type(_groupToBoard) == "string") then
			local groupToBoard
			
			if _groupToBoard == nil then
				groupToBoard = ATMEFct.C_Player_C_AIUnit_getNearestReadyToBoardGroup(self, _radius)
			elseif type(_groupToBoard) == "string" then
				groupToBoard = ATME.C_Group.getByName(_groupToBoard)
			else
				groupToBoard = _groupToBoard
			end
			
			if groupToBoard ~= nil then
				if groupToBoard:isOnlyInfantry() == true then
					if _radius > 0 then
						if groupToBoard:isReadyToBoard() == true and groupToBoard:isBoarding() == false then
							if ATMEConst.personnelCarrierAttributes[self:getTypeName()] ~= nil then
								return ATMEFct.C_Player_C_AIUnit_load(self, groupToBoard, _radius)
							else
								ATMEFct.errorOutputCore(nil, fctDefinition, self:getName() .. " not a transport unit", false)
							end
						else
							ATMEFct.setError("LOAD_INFANTRY_GROUP_NOT_READY")
						end
					else
						ATMEFct.errorOutputCore(nil, fctDefinition, "radius must be > 0", false)
					end
				else
					ATMEFct.errorOutputCore(nil, fctDefinition, "Not infantry group", false)
				end
			else
				ATMEFct.setError("LOAD_NO_GROUP_FOUND")
			end
		else
			if type(_radius) ~= "number" then
				ATMEFct.errorOutputCore(nil, fctDefinition, "radius type must be number", true)
			elseif ATME.isObjectClass(_groupToBoard, ATME.C_Group) == false and _groupToBoard ~= nil then
				ATMEFct.errorOutputCore(nil, fctDefinition, "groupToBoard type must be nil or ATME.C_Group", false)
			end
		end
	end

	function newUnit.getNearestReadyToBoardGroup(self, _radius)
		local fctDefinition = ATMEFct.getErrorPrefix(newUnit) .. "getNearestReadyToBoardGroup(radius)"
		
		if type(_radius) == "number" then
			if _radius >= 0 then
				return ATMEFct.C_Player_C_AIUnit_getNearestReadyToBoardGroup(self, _radius)
			else
				ATMEFct.errorOutputCore(nil, fctDefinition, "radius must be > 0", false)
			end
		else
			ATMEFct.errorOutputCore(nil, fctDefinition, "radius must be number", true)
		end
	end
	
	function newUnit.fireFlare(self, _color)
		local fctDefinition = ATMEFct.getErrorPrefix(newUnit) .. "fireFlare(color)"
		
		if type(_color) == "string" then
			if ATMEConst.flareColors[string.upper(_color)]~= nil then
				if self:getGroup():getCategoryName() == "GROUND" then
					local flare = ATMEFct.C_Flare_create(_color, self:getPosition())
					flare:fireOnce()
				else
					ATMEFct.setError("AIUNIT_NOT_GROUND_UNIT")
				end
			else
				ATMEFct.errorOutputCore(nil, fctDefinition, "color must be a flare color or RANDOM", false)
			end
		else
			ATMEFct.errorOutputCore(nil, fctDefinition, "color type must be string", true)
		end
	end

	function newUnit.fireSmoke(self, _color)
		local fctDefinition = ATMEFct.getErrorPrefix(newUnit) .. "fireSmoke(color)"
		
		if type(_color) == "string" then
			if ATMEConst.smokeColors[string.upper(_color)] ~= nil then 
				if self:getGroup():getCategoryName() == "GROUND" then
					local point = self:getPosition()
					local newPoint = {}

					newPoint.x = point.x + math.random(-20,20)
					newPoint.y = point.z + math.random(-20,20)
					
					local smoke = ATMEFct.C_Smoke_create(_color, newPoint)
					smoke:activate(false)
				else
					ATMEFct.setError("AIUNIT_NOT_GROUND_UNIT")
				end
			else
				ATMEFct.errorOutputCore(nil, fctDefinition, "color must be a smoke color", false)
			end
		else
			ATMEFct.errorOutputCore(nil, fctDefinition, "color type must be string", true)
		end
	end

	function newUnit.fireIlluminationBomb(self, _power)
		local fctDefinition = ATMEFct.getErrorPrefix(newUnit) .. "fireIlluminationBomb(power)"
		
		if type(_power) == "number" then
			if _power >= 1 then
				if self:getGroup():getCategoryName() == "GROUND" then
					local point = self:getPosition()
					
					point.y = point.y + 200 + math.random(0, 100)

					trigger.action.illuminationBomb(point, _power)
				else
					ATMEFct.setError("AIUNIT_NOT_GROUND_UNIT")
				end
			else
				ATMEFct.errorOutputCore(nil, fctDefinition, "power must be >= 1", false)
			end
		else
			ATMEFct.errorOutputCore(nil, fctDefinition, "power type must be number", true)
		end
	end
	
	function newUnit.setFrequency(self, _modulation, _frequency)
		local fctDefinition = ATMEFct.getErrorPrefix(newUnit) .. "setFrequency(modulation, frequency)"
		
		if type(_modulation) == "string" and type(_frequency) == "number" then
			if self:getGroup():getCategoryName() ~= "SHIP" then -- Bug DCS avec les navires -> Plantage
				if _modulation == "FM" or _modulation == "AM" then
					local modulationValue = radio.modulation.AM
					
					if _modulation == "FM" then 
						modulationValue = radio.modulation.FM
					end
					
					local frequencyValue = math.floor(_frequency)
					if frequencyValue > 0 then
						if frequency ~= nil then
							self:transmissionStop(true)
						end
						
						frequency = frequencyValue
						modulation = _modulation
						
						local controller = self:getDCSUnit():getController()
						local command = { 
							id = "SetFrequency", 
							params = {
								frequency = frequencyValue, 
								modulation = modulationValue,
							},
						}
						
						controller:setCommand(command)
					else
						ATMEFct.errorOutputCore(nil, fctDefinition, "frequency type must > 0", false)
					end
				else
					ATMEFct.errorOutputCore(nil, fctDefinition, "modulation must be 'AM' or 'FM'", true)
				end
			else
				ATMEFct.errorOutputCore(nil, fctDefinition, "unit can't be a ship", false)
			end
		else
			if type(_modulation) ~= "string" then
				ATMEFct.errorOutputCore(nil, fctDefinition, "modulation type must be string", true)
			elseif type(_frequency) ~= "number" then
				ATMEFct.errorOutputCore(nil, fctDefinition, "frequency type must be number", false)
			end
		end
	end
	
	function newUnit.setVoice(self, _name)
		local fctDefinition = ATMEFct.getErrorPrefix(newUnit) .. "setVoice([name])"
		
		if _name == nil or type(_name) == "string" then
			if _name ~= nil then
				local d, f, temp = _name:find("^(%a[%a%d_]*)")
				
				if temp == _name then
					currentVoice = _name
				else
					ATMEFct.errorOutputCore(nil, fctDefinition, "name bad format", false)
				end
			else
				currentVoice = ""
			end
		else
			ATMEFct.errorOutputCore(nil, fctDefinition, "name type must be nil or string", true)
		end
	end
	
	function newUnit.getVoice(self)
		if currentVoice ~= "" then
			return currentVoice
		end
	end
	
	function newUnit.transmissionDelayed(self, _wait)
		local fctDefinition = ATMEFct.getErrorPrefix(newUnit) .. "transmissionDelayed(wait)"
		
		if type(_wait) == "boolean" then
			waitIfFrequencyLocked = _wait
		else
			ATMEFct.errorOutputCore(nil, fctDefinition, "wait type must be boolean", false)
		end
	end
	
	function newUnit.transmissionLock(self, _locked)
		local fctDefinition = ATMEFct.getErrorPrefix(newUnit) .. "transmissionLock(locked)"
		
		if type(_locked) == "boolean" then
			locked = _locked
		else
			ATMEFct.errorOutputCore(nil, fctDefinition, "locked type must be boolean", true)
		end
	end
	
	function newUnit.transmissionOnce(self, _text, _randomRead)
		local fctDefinition = ATMEFct.getErrorPrefix(newUnit) .. "transmissionOnce(text, [randomRead])"
		
		if type(_text) == "string" and (_randomRead == nil or type(_randomRead) == "boolean") then
			local randomRead = false

			if type(_randomRead) == "boolean" then
				randomRead = _randomRead
			end
			
			if frequency ~= nil then
				local idFrequency = "FR_" .. string.format("%09d", frequency) .. modulation

				local err, playlistNew = ATMEFct.C_Sound_getPlaylist(_text, randomRead)
				
				if err == true then
					ATMEFct.errorOutputCore(nil, fctDefinition, playlistNew, false)
					return
				end

				if playlistNew == nil then
					ATMEFct.errorOutputCore(nil, fctDefinition, "text string has no sound token", false)
					return
				end
				
				local extraDatas = {
					unitName = name,
					playlist = playlistNew,
					autoRestartDCS = false,
					readOnce = true,
					randomRead = randomRead,
					idFrequency = idFrequency,
					locked = locked,
					voice = currentVoice,
				}
				
				if ATMEDatas.lockedRadioFrequencies[idFrequency] == nil then
					local newRadioTransmission = ATMEFct.initDCSRadioTransmission(extraDatas)
					localMembers.radioTransmissionID = newRadioTransmission.entry
				elseif waitIfFrequencyLocked == true then			
					table.insert(ATMEDatas.lockedRadioFrequencies[idFrequency].bufferedRadioTransmissions, extraDatas)
				end
			end
		else
			if type(_text) ~= "string" then
				ATMEFct.errorOutputCore(nil, fctDefinition, "text type must be string", true)
			elseif _randomRead ~= nil and type(_randomRead) ~= "boolean" then
				ATMEFct.errorOutputCore(nil, fctDefinition, "randomRead type must be nil or boolean", false)
			end
		end	
	end

	function newUnit.transmissionLoop(self, _text)
		local fctDefinition = ATMEFct.getErrorPrefix(newUnit) .. "transmissionLoop(text)"
		
		if type(_text) == "string" then
			if frequency ~= nil then
				local idFrequency = "FR_" .. string.format("%09d", frequency) .. modulation
				local err, playlistNew = ATMEFct.C_Sound_getPlaylist(_text, false, true)

				if err == true then
					ATMEFct.errorOutputCore(nil, fctDefinition, playlistNew, false)
					return
				end

				if playlistNew == nil then
					ATMEFct.errorOutputCore(nil, fctDefinition, "text string has no sound token", false)
					return
				end
				
				
				local extraDatas = {
					unitName = name,
					playlist = {
						playlistNew[1],
					},
					autoRestartDCS = true,
					readOnce = true,
					randomRead = false,
					idFrequency = idFrequency,
					locked = locked,
					voice = currentVoice,
				}
				
				if ATMEDatas.lockedRadioFrequencies[idFrequency] == nil then
					local newRadioTransmission = ATMEFct.initDCSRadioTransmission(extraDatas)
					localMembers.radioTransmissionID = newRadioTransmission.entry
				elseif waitIfFrequencyLocked == true then			
					table.insert(ATMEDatas.lockedRadioFrequencies[idFrequency].bufferedRadioTransmissions, extraDatas)
				end
			end
		else
			ATMEFct.errorOutputCore(nil, fctDefinition, "text type must be string", true)
		end		
	end

	function newUnit.transmissionStart(self, _text, _randomRead)
		local fctDefinition = ATMEFct.getErrorPrefix(newUnit) .. "transmissionStart(text, [randomRead])"

		if type(_text) == "string" and (_randomRead == nil or type(_randomRead) == "boolean") then
			local randomRead = false

			if type(_randomRead) == "boolean" then
				randomRead = _randomRead
			end
			
			if frequency ~= nil then
				local idFrequency = "FR_" .. string.format("%09d", frequency) .. modulation
				local err, playlistNew = ATMEFct.C_Sound_getPlaylist(_text, randomRead)

				if err == true then
					ATMEFct.errorOutputCore(nil, fctDefinition, playlistNew, false)
					return
				end

				if playlistNew == nil then
					ATMEFct.errorOutputCore(nil, fctDefinition, "text string has no sound token", false)
					return
				end
				
				local extraDatas = {
					unitName = name,
					playlist = playlistNew,
					autoRestartDCS = false,
					readOnce = false,
					randomRead = randomRead,
					idFrequency = idFrequency,
					locked = locked,
					voice = currentVoice,
				}
				
				if ATMEDatas.lockedRadioFrequencies[idFrequency] == nil then
					local newRadioTransmission = ATMEFct.initDCSRadioTransmission(extraDatas)
					localMembers.radioTransmissionID = newRadioTransmission.entry
				elseif waitIfFrequencyLocked == true then			
					table.insert(ATMEDatas.lockedRadioFrequencies[idFrequency].bufferedRadioTransmissions, extraDatas)
				end
			end
		else
			if type(_text) ~= "string" then
				ATMEFct.errorOutputCore(nil, fctDefinition, "text type must be string", true)
			elseif _randomRead ~= nil and type(_randomRead) ~= "boolean" then
				ATMEFct.errorOutputCore(nil, fctDefinition, "randomRead type must be nil or boolean", false)
			end
		end			
	end	

	function newUnit.transmissionStop(self, _all)
		local fctDefinition = ATMEFct.getErrorPrefix(newUnit) .. "transmissionStop([all])"
		
		
		if _all == nil or type(_all) == "boolean" then
			local all = false

			if type(_all) == "boolean" then
				all = _all
			end

			if localMembers.radioTransmissionID > 0 then
				-- Suppression de toutes les transmissions en cours pour l'unité

				local radioTransmission = ATMEDatas.activatedRadioTransmissions:get(localMembers.radioTransmissionID)

				if radioTransmission ~= nil then
					ATMEFct.C_AIUnit_stopTransmission(radioTransmission)			
					ATMEDatas.activatedRadioTransmissions:remove(localMembers.radioTransmissionID)
					localMembers.radioTransmissionID = 0
					
					if ATMEDatas.lockedRadioFrequencies[radioTransmission.idFrequency] ~= nil then
						if all == true then
							local index = #ATMEDatas.lockedRadioFrequencies[radioTransmission.idFrequency].bufferedRadioTransmissions
							
							while index > 0 do
								if ATMEDatas.lockedRadioFrequencies[radioTransmission.idFrequency].bufferedRadioTransmissions[index].unitName == name then
									table.remove(ATMEDatas.lockedRadioFrequencies[radioTransmission.idFrequency].bufferedRadioTransmissions, index)
								end
								
								index = index - 1
							end
						else
							local extraDatas
							local found = false
							while #ATMEDatas.lockedRadioFrequencies[radioTransmission.idFrequency].bufferedRadioTransmissions > 0 and found == false do		
								-- On dépile les transmission en attente sans verrouillage sauf si c'est la dernière
								extraDatas = table.remove(ATMEDatas.lockedRadioFrequencies[radioTransmission.idFrequency].bufferedRadioTransmissions, 1)
								found = extraDatas.locked
							end
							
							if extraDatas ~= nil then
								local newRadioTransmission = ATMEFct.initDCSRadioTransmission(extraDatas)
								localMembers.radioTransmissionID = newRadioTransmission.entry
							end
						end
						
						if #ATMEDatas.lockedRadioFrequencies[radioTransmission.idFrequency].bufferedRadioTransmissions == 0 then
							ATMEDatas.lockedRadioFrequencies[radioTransmission.idFrequency] = nil
						end
					end
				else
					localMembers.radioTransmissionID = 0
				end
			end
		else
			ATMEFct.errorOutputCore(nil, fctDefinition, "all type must be nil or boolean", false)
		end
	end
	
	ATMEDatas.AIUnits[name] = newUnit
	ATMEDatas.allAIUnitsAndPlayers[name] = newUnit
	
	newUnit.modules = {}
	setmetatable(newUnit.modules, ATMEDatas.C_AIUnit_MT.mtModules)
	
	for _, _localModuleMembers in ATMEDatas.C_Module_MT:pairs() do
		localMembers.userPrivateDatas[_localModuleMembers.name] = {}
		
		if newUnit.modules[_localModuleMembers.name] == nil then
			newUnit.modules[_localModuleMembers.name] = {}
		end
	end
	
	if ATMEConst.personnelCarrierAttributes[newUnit:getTypeName()] ~= nil and newUnit:isHelicopter() == true then
		ATMEDatas.signalCapabilityUnits:push(name)
	end
	
	if ATMEDatas.groups[groupName] == nil then
		ATMEFct.C_Group_create(newUnit, _datas)
	else
		ATMEFct.C_Group_addUnit(ATMEDatas.groups[groupName], newUnit)
	end
	
	ATMEGroup = ATMEDatas.groups[groupName]
	
	for _, _localModuleMembers in ATMEDatas.C_Module_MT:pairs() do
		if ATMEDatas.groupsOnBoard[groupName] == nil then
			-- Les unités d'un groupe déchargé d'un autre véhicule ne génèrent pas 
			-- d'appel à onCreateAIUnitHandler
				
			if _localModuleMembers.handlers.onCreateAIUnitHandler ~= nil then
				-- Appel du module
				ATMEFct.outputCore(nil,"Appel onCreateAIUnitHandler du module " .. _localModuleMembers.name, 2)
				xpcall(function() _localModuleMembers.handlers.onCreateAIUnitHandler(newUnit) end, function() ATMEFct.errUserHandler('onCreateAIUnitHandler') end)
			end
		end
	end
	
	ATMEFct.outputCore(nil,"Create unit = " .. name, 2)
end

ATMEFct.C_AIUnit_delete = function(_AIUnit)
	local localMembers = ATMEDatas.C_AIUnit_MT:get(_AIUnit:getIndex())
	local flag = "EJECTION"
	if _AIUnit:isPilotDead() == true then
		flag = "DEAD"
	end

	for _, _localModuleMembers in ATMEDatas.C_Module_MT:pairs() do
		local localGroupMembers = ATMEDatas.C_Group_MT:get(_AIUnit:getGroup():getIndex())
		if localGroupMembers.onBoard == false then
			-- Les unités d'un groupe chargé dans un autre véhicule ne génèrent pas 
			-- d'appel à onDeleteAIUnitHandler
			
			if _localModuleMembers.handlers.onDeleteAIUnitHandler ~= nil then
				-- Appel du module
				ATMEFct.outputCore(nil,"Appel onDeleteAIUnitHandler du module " .. _localModuleMembers.name, 2)
				xpcall(function() _localModuleMembers.handlers.onDeleteAIUnitHandler(_AIUnit, localMembers.isEnabled, flag) end, function() ATMEFct.errUserHandler('onDeleteAIUnitHandler') end)
			end
		end
	end
	
	_AIUnit:transmissionStop(true)
	
	-- Suppression de l'unité dans les zones signalées où elle se trouve
	for _index, _ in pairs(localMembers.signalIndex) do
		local signal = ATMEDatas.signals:get(_index)
		
		signal.coalitionUnitsInZone[_AIUnit:getName()] = nil
		localMembers.signalIndex[_index] = nil
	end
	
	-- Suppression des tracking de franchissement pour cette unité
	for _, _multiSegment in pairs(localMembers.multiSegment2D) do
		local localMembersMultiSegment = ATMEDatas.C_MultiSegment2D_MT:get(_multiSegment:getIndex())
		ATMEFct.C_MultiSegment2D_remove(_multiSegment, localMembersMultiSegment, _AIUnit:getName())
		localMembers.multiSegment2D[_multiSegment] = nil
	end
	
	for _, _localModuleMembers in ATMEDatas.C_Module_MT:pairs() do
		_AIUnit.modules[_localModuleMembers.name] = nil
		localMembers.userPrivateDatas[_localModuleMembers.name] = nil
	end

	for _, _item in localMembers.onBoardGroupDatas:pairs() do
		-- Si un des groupes embarqués a un respawn automatique il est préparé
		local groupName = _item.groupDatas:getName()
		
		if _item.autoRespawn.activated == true then
			local respawnTime = _item.autoRespawn.time
			if _item.autoRespawn.random == true then
				respawnTime = math.random(_item.autoRespawn.minTime, _item.autoRespawn.maxTime)
			end
			
			ATMEDatas.groupsToRespawn[groupName] = {
				time = respawnTime + timer.getTime(),
				spawnDatas = _item.spawnDatas,
			}
		end
		
		ATMEDatas.groupsOnBoard[groupName] = nil
	end
	
	localMembers.onBoardGroupDatas:removeAll()
	
	local unitName = _AIUnit:getName()
	
	if ATMEDatas.spots[unitName] ~= nil then
		ATMEDatas.spots[unitName].spot:destroy()
		ATMEDatas.spots[unitName] = nil
		ATMEDatas.spotsToReassign[unitName] = nil
	end
	
	ATMEFct.C_Group_deleteUnit(_AIUnit:getGroup(), unitName)
	ATMEDatas.C_AIUnit_MT:remove(_AIUnit:getIndex())
	
	ATMEDatas.targetsTracking[unitName] = nil
	ATMEDatas.AIUnits[unitName] = nil
	ATMEDatas.allAIUnitsAndPlayers[unitName] = nil
	ATMEDatas.signalCapabilityUnitsToDelete[unitName] = true
	ATMEDatas.autoUnloadDatas[unitName] = nil
	
	ATMEFct.outputCore(nil,"Delete unit = " .. unitName, 2)
end

setmetatable(ATME.C_AIUnit,ATMEDatas.C_AIUnit_MT)


ATMEDatas.C_AIUnit_MT.mt.__metatable = "Private"
ATMEDatas.C_AIUnit_MT.mt.__index = ATME.C_AIUnit
ATMEDatas.C_AIUnit_MT.mt.__newindex = function(t, k, v)
	if ATMEDatas.C_AIUnit_MT.keys[k] ~= nil then 
		rawset(t, k, v)
	else
		ATMEFct.errorOutputCore(nil, "Function ATME.C_AIUnit : Bad key " .. k, "table locked", false)
	end
end

ATMEDatas.C_AIUnit_MT.mtModules.__metatable = "Private"
ATMEDatas.C_AIUnit_MT.mtModules.__newindex = function(t, k, v)
	if ATMEDatas.modules[k] ~= nil then
		rawset(t, k, v)
	else
		ATMEFct.errorOutputCore(nil,"ATME : ATME.C_AIUnit.modules Bad key " .. k, "table locked", false)
	end
end


----------------------------------------------------------------------------------------------------------
-- Classe ATME.C_StaticObject : gère les objets statiques au format ATME. Pas de contructeur accessible
-- pour les modules externes. 
-- Sont exclus les objets statiques FARP et Airfieds qui sont gérés par ATME.C_Airbase.
-- Les instances de cette classe sont intégralement gérées par le module ATME_Core. La création et la destruction
-- dépendent du contexte de début de mission et des événements qui se produisent dans DCS en cours de mission.
-- Les modules externes accèdent à cette gestion indirectement par les handlers définis dans ceux-ci et les méthodes
-- accessibles de cette classe. Ceci permet de garantir une cohérence sur les listes internes ATME.
----------------------------------------------------------------------------------------------------------

ATMEDatas.C_StaticObject_MT = {
	className = "C_StaticObject",
	mtModules = {},
	mt = {},
	
	keys = {
		["getCategory"] = true,
		["getLife"] = true,
		["getDCSStaticObject"] = true,
		["getName"] = true,
		["tagGetByID"] = true,
		["tagCompare"] = true,
		["tagGetCount"] = true,
		["getIndex"] = true,
		["getTypeName"] = true,
		["getPosition"] = true,
		["getAzimuth"] = true,
		["getCountryName"] = true,
		["getCoalitionName"] = true,
		["explode"] = true,
		["fireFlare"] = true,
		["fireSmoke"] = true,
		["fireIlluminationBomb"] = true, 
		["disable"] = true,
		["getUserPrivateDatas"] = true,
		["modules"] = true,
	},
	
	localMembers = ATMEFct.C_IndexList_create(),

	add = function(self, _name)
		local item = {
			isEnabled = true,
			userPrivateDatas = {},						-- Point d'entrée des données privées : un par module
			tagsName = ATMEFct.decompString(_name),
		}
		
		return self.localMembers:add(item)
	end,
	
	remove = function(self, _id)
		self.localMembers:remove(_id)
	end,
	
	get = function(self, _id)
		return self.localMembers:get(_id)
	end,
}

ATME.C_StaticObject = {
	getClassName = function(self)
		return ATMEDatas.C_StaticObject_MT.className
	end,
	
	getParentClass = function(self)
		return ATMEDatas.C_StaticObject_MT.parentClass
	end,
	
	getByName = function(_objectName)
		if type(_objectName) == "string" then
			return ATMEDatas.staticObjects[_objectName]
		else
			ATMEFct.errorOutputCore(nil, "Function ATME.C_StaticObject.getByName(name)", "name must be string", false)
		end	
	end,
}


ATMEFct.C_StaticObject_create = function(_object)
	local name = _object:getName()

	local newObject = {}
	
	local index = ATMEDatas.C_StaticObject_MT:add(name)
	local localMembers = ATMEDatas.C_StaticObject_MT:get(index)
	
	setmetatable(newObject, ATMEDatas.C_StaticObject_MT.mt)
	
	local object = _object
	local typeName = _object:getTypeName()
	local category
	

	if ATMEDatas.allStaticObjectsInMission[name] ~= nil then
		category = ATMEDatas.allStaticObjectsInMission[name].category
	else
		category = ATMEDatas.newStaticObjectsCategory[name]
		ATMEDatas.newStaticObjectsCategory[name] = nil
	end
	
	function newObject.getDCSStaticObject(self)
		return object
	end
	
	function newObject.getName(self)
		return name
	end
	
	function newObject.tagGetByID(self, _position)
		local fctDefinition = ATMEFct.getErrorPrefix(newObject) .. "tagGetByID(position)"
		
		if type(_position) == "number" then
			local pos = math.floor(_position)
			if localMembers.tagsName ~= nil and pos >= 1 and pos <= #localMembers.tagsName then
				return localMembers.tagsName[pos]
			end
		else
			ATMEFct.errorOutputCore(nil, fctDefinition, "position type must be number", true)
		end
	end
	
	function newObject.tagGetCount(self)
		if tagsName ~= nil then
			return #tagsName
		else
			return 0
		end
	end
	
	function newObject.tagCompare(self, _tagsToCompare)
		local fctDefinition = ATMEFct.getErrorPrefix(newObject) .. "tagCompare(tagsToCompare)"
		
		if type(_tagsToCompare) == "string" then
			if localMembers.tagsName ~= nil then
				local ok = ATMEFct.compareTags(localMembers.tagsName, _tagsToCompare)
				
				if ok ~= nil then
					return ok
				else
					ATMEFct.errorOutputCore(nil, fctDefinition, "tagsToCompare format must be 'T1|T2|..|Tn'", false)
				end
			else
				return false
			end
		else
			ATMEFct.errorOutputCore(nil, fctDefinition, "tagsToCompare type must be string", true)
		end
	end
	
	function newObject.getIndex(self)
		return index
	end
	
	function newObject.getCategory(self)
		-- Catégories objets statiques
		-- 		Ships
		-- 		Planes
		-- 		Helicopters
		-- 		Warehouses
		-- 		Cargos
		-- 		Unarmed (tous ce qui est véhicules terrestre)
		-- 		Fortifications
		
		return category
	end
	
	function newObject.getTypeName(self)
		return typeName
	end
	
	function newObject.getLife(self)
		return object:getLife()
	end
	
	function newObject.getPosition(self)
		return object:getPoint()
	end

	function newObject.getAzimuth(self)
		local vector = ATMEFct.C_Vector3D_create(nil, nil, object:getPosition().x)
		return vector:getAzimuth()
	end

	function newObject.getCountryName(self)
		local id = object:getCountry()
		return country.name[id]
	end

	function newObject.getCoalitionName(self)
		local id = object:getCoalition()
		return ATMEConst.coalitionNames[id]
	end
	
	function newObject.disable(self)
		localMembers.isEnabled = false
		
		object:destroy()
		ATMEFct.C_StaticObject_delete(self)
	end
	
	function newObject.getUserPrivateDatas(self, _module)
		local fctDefinition = ATMEFct.getErrorPrefix(newObject) .. "getUserPrivateDatas(module)"
		
		if ATME.isObjectClass(_module, ATME.C_Module) == true then
			return localMembers.userPrivateDatas[_module:getName()]
		else
			ATMEFct.errorOutputCore(nil, fctDefinition, "module type must be ATME.C_Module", true)
		end
	end

	function newObject.explode(self, _power)
		local fctDefinition = ATMEFct.getErrorPrefix(newObject) .. "explode(power)"
		
		if type(_power) == "number" then
			if _power >= 1 then
				ATME.explode(self:getPosition(), _power)
			else
				ATMEFct.errorOutputCore(nil, fctDefinition, "power must be >= 1", false)
			end
		else
			ATMEFct.errorOutputCore(nil, fctDefinition, "power type must be number", true)
		end
	end
	
	function newObject.fireFlare(self, _color)
		local fctDefinition = ATMEFct.getErrorPrefix(newObject) .. "fireFlare(color)"
		
		if type(_color) == "string" then
			if ATMEConst.flareColors[string.upper(_color)]~= nil then
				local flare = ATMEFct.C_Flare_create(_color, self:getPosition())
				flare:fireOnce()
			else
				ATMEFct.errorOutputCore(nil, fctDefinition, "color must be a flare color or RANDOM", false)
			end
		else
			ATMEFct.errorOutputCore(nil, fctDefinition, "color type must be string", true)
		end
	end

	function newObject.fireSmoke(self, _color)
		local fctDefinition = ATMEFct.getErrorPrefix(newObject) .. "fireSmoke(color)"
		
		if type(_color) == "string" then
			if ATMEConst.smokeColors[string.upper(_color)]~= nil then 
				local point = self:getPosition()
				local newPoint = {}

				newPoint.x = point.x + math.random(-20,20)
				newPoint.y = point.z + math.random(-20,20)
					
				local smoke = ATMEFct.C_Smoke_create(_color, newPoint)
				smoke:activate(false)
			else
				ATMEFct.errorOutputCore(nil, fctDefinition, "color must be a smoke color", false)
			end
		else
			ATMEFct.errorOutputCore(nil, fctDefinition, "color type must be string", true)
		end
	end

	function newObject.fireIlluminationBomb(self, _power)
		local fctDefinition = ATMEFct.getErrorPrefix(newObject) .. "fireIlluminationBomb(power)"
		
		if type(_power) == "number" then
			if _power >= 1 then
				local point = self:getPosition()
				
				point.y = point.y + 200 + math.random(0, 100)

				trigger.action.illuminationBomb(point, _power)
			else
				ATMEFct.errorOutputCore(nil, fctDefinition, "power must be >= 1", false)
			end
		else
			ATMEFct.errorOutputCore(nil, fctDefinition, "power type must be number", true)
		end
	end

	ATMEDatas.staticObjects[name] = newObject
	
	newObject.modules = {}
	setmetatable(newObject.modules, ATMEDatas.C_StaticObject_MT.mtModules)
	
	for _, _localModuleMembers in ATMEDatas.C_Module_MT:pairs() do
		localMembers.userPrivateDatas[_localModuleMembers.name] = {}
		
		if newObject.modules[_localModuleMembers.name] == nil then
			newObject.modules[_localModuleMembers.name] = {}
		end
		if _localModuleMembers.handlers.onCreateStaticObjectHandler ~= nil then
			-- Appel du module
			ATMEFct.outputCore(nil,"Appel onCreateStaticObjectHandler du module " .. _localModuleMembers.name, 2)
			xpcall(function() _localModuleMembers.handlers.onCreateStaticObjectHandler(newObject) end, function() ATMEFct.errUserHandler('onCreateStaticObjectHandler') end)
		end
	end
	
	ATMEFct.outputCore(nil,"Create static unit " .. name, 2)
end

ATMEFct.C_StaticObject_delete = function(_staticUnit)
	local localMembers = ATMEDatas.C_StaticObject_MT:get(_staticUnit:getIndex())
	
	for _, _localModuleMembers in ATMEDatas.C_Module_MT:pairs() do
		if _localModuleMembers.handlers.onDeleteStaticObjectHandler ~= nil then
			-- Appel du module
			ATMEFct.outputCore(nil,"Appel onDeleteStaticObjectHandler du module " .. _localModuleMembers.name, 2)
			xpcall(function() _localModuleMembers.handlers.onDeleteStaticObjectHandler(_staticUnit, localMembers.isEnabled) end, function() ATMEFct.errUserHandler('onDeleteStaticObjectHandler') end)
		end
		_staticUnit.modules[_localModuleMembers.name] = nil
		localMembers.userPrivateDatas[_localModuleMembers.name] = nil
	end
	
	ATMEDatas.C_StaticObject_MT:remove(_staticUnit:getIndex())
	
	ATMEDatas.staticObjects[_staticUnit:getName()] = nil
	ATMEFct.outputCore(nil,"Delete unit = " .. _staticUnit:getName(), 2)
end

setmetatable(ATME.C_StaticObject,ATMEDatas.C_StaticObject_MT)

ATMEDatas.C_StaticObject_MT.mt.__metatable = "Private"
ATMEDatas.C_StaticObject_MT.mt.__index = ATME.C_StaticObject
ATMEDatas.C_StaticObject_MT.mt.__newindex = function(t, k, v)
	if ATMEDatas.C_StaticObject_MT.keys[k] ~= nil then 
		rawset(t, k, v)
	else
		ATMEFct.errorOutputCore(nil, "Function ATME.C_StaticObject : Bad key " .. k, "table locked", false)
	end
end

ATMEDatas.C_StaticObject_MT.mtModules.__metatable = "Private"
ATMEDatas.C_StaticObject_MT.mtModules.__newindex = function(t, k, v)
	if ATMEDatas.modules[k] ~= nil then
		rawset(t, k, v)
	else
		ATMEFct.errorOutputCore(nil,"ATME : ATME.C_StaticObject.modules Bad key " .. k, "table locked", false)
	end
end


----------------------------------------------------------------------------------------------------------
-- Classe ATME.C_Race : gère les courses de joueurs. 
-- Contructeur non accessible pour les modules externes. 
-- Une course de joueurs est composées de portes définie par un côté gauche et un côté droit (sens de passage
-- de la porte par le joueur). Les temps sont gérés au 1/100è. une course est associée au module l'ayant créée
-- et donc les events ATME générés seront transmis uniquement ce module. Le description des events est données
-- dans la fonction _timerx100.
-- Le nombre maximal de portes est à 100.
----------------------------------------------------------------------------------------------------------

ATMEDatas.C_Race_MT = {
	className = "C_Race",
	mt = {},
	
	keys = {
		["getNbTurns"] = true,
		["getNbDoors"] = true,
		["getIndex"] = true,
		["getName"] = true,
		["tagGetByID"] = true,
		["tagCompare"] = true,
		["tagGetCount"] = true,
		["getDoorSides"] = true,
		["getLapAtDoor"] = true,
		["setLapAtDoor"] = true,
		["getDoorIndex"] = true,
		["displayForAllPlayers"] = true,
		["soundForAllPlayers"] = true,
		["addPlayer"] = true,
		["removePlayer"] = true,
		["removeAllPlayers"] = true,
		["isPlayerInRace"] = true,
		["getRanking"] = true,
		["setMaxAltitudeRule"] = true,
		["getMaxAltitudePenalty"] = true,
		["getMaxAltitude"] = true,
		["resetMaxAltitudeRule"] = true,
		["getPlayerNextDoorIndex"] = true,
		["getUserPrivateDatas"] = true,
	},
	
	localMembers = ATMEFct.C_IndexList_create(),
	
	add = function(self, _doorsIndex)
		local item = {
			missedDoorPenalty = 0,
			maxAltitude = -1,
			maxAltitudePenalty = 0,
			players = {},
			doorsIndex = _doorsIndex,
			bestPlayers = {},
			bestTurn = 
			{
				pseudo = "",
				bestTime = -1,
			},
			
			userPrivateDatas = {},
		}
		
		return self.localMembers:add(item)
	end,
	
	remove = function(self, _id)
		for _, _localModuleMembers in ATMEDatas.C_Module_MT:pairs() do
			self.localMembers:get(_id).userPrivateDatas[_localModuleMembers.name] = nil
		end
		self.localMembers:get(_id).userPrivateDatas = nil
		
		self.localMembers:remove(_id)
	end,
	
	get = function(self, _id)
		return self.localMembers:get(_id)
	end,
}

ATME.C_Race = {
	getClassName = function(self)
		return ATMEDatas.C_Race_MT.className
	end,
	
	getParentClass = function(self)
		return ATMEDatas.C_Race_MT.parentClass
	end,
	
	getByName = function(_raceName)
		if type(_raceName) == "string" then
			return ATMEDatas.races[_raceName]
		else
			ATMEFct.errorOutputCore(nil, "Function ATME.C_Race.getByName(name)", "name type must be string", false)
		end	
	end,
}

ATMEFct.C_Race_createEvent = function(_race, _type, _datas)
	local localMembers = ATMEDatas.C_Race_MT:get(_race:getIndex())
	
	_datas.race = _race

	local item = {
		type = _type,
		datas = _datas,
	}
	
	ATMEFct.C_CoreEvent_add(item)
end

ATMEFct.C_Race_create = function(_name, _leftSideDoorName, _rightSideDoorName, _nbTurns)
	local doors = ATMEFct.C_IndexList_create()
	local doorsIndex = {}
	
	local fctDefinition = "Constructor ATME.C_Race(name, leftSideDoorName, righSideDoorName, nbTurns)"
	
	for _i = 1, 100 do -- Identifiant de porte dans l'éditeur de mission : de #001 à #100
		local index = string.format("%03d", _i)
		if ATMEDatas.staticObjects[_leftSideDoorName .. "#" .. index] ~= nil then
			if ATMEDatas.staticObjects[_rightSideDoorName .. "#" .. index] ~= nil then
				local leftObject = ATME.C_StaticObject.getByName(_leftSideDoorName .. "#" .. index)
				local rightObject = ATME.C_StaticObject.getByName(_rightSideDoorName .. "#" .. index)
				
				local multiSegment = ATMEFct.C_MultiSegment2D_create(nil, nil, {leftObject:getPosition(), rightObject:getPosition()})
				local p1, p2, vector = multiSegment:getSegmentInfosByID(1)
				if vector:getHModule() < 500 then -- Largeur de porte maximale : 500m
					local door = {
						index = _i,
						leftObject = leftObject,
						rightObject = rightObject,
						segment = {
							p1 = p1,
							p2 = p2,
							vector = vector,
						},
						lap = false,
						bestTurn = {
							pseudo = "",
							bestTime = -1,
						},
					}
					door.id = doors:add(door)
					doorsIndex[_i] = door
				else
					ATMEFct.errorOutputCore(nil, fctDefinition, "Race " .. _name .. " - Door #" .. index .. " too large (>500m)", false)
				end
			else
				ATMEFct.errorOutputCore(nil, fctDefinition, "Race " .. _name .. " - Door #" .. index .. " no right side", false)
			end
		elseif ATMEDatas.staticObjects[_rightSideDoorName .. " #" .. index] ~= nil then
			ATMEFct.errorOutputCore(nil, fctDefinition, "Race " .. _name .. " - Door #" .. index .. " no left side", false)
		end
	end
	
	if ATMEDatas.exitATME == false then
		if doors:getCount() >= 2 then
			local newRace = {}
			local nbTurns = math.floor(_nbTurns)
			local name = _name
			local tagsName = ATMEFct.decompString(_name)
		
			local index = ATMEDatas.C_Race_MT:add(doorsIndex)
			local localMembers = ATMEDatas.C_Race_MT:get(index)
			
			setmetatable(newRace, ATMEDatas.C_Race_MT.mt)
		
			function newRace.getIndex(self)
				return index
			end
			
			function newRace.getName(self)
				return name
			end
			
			function newRace.tagGetByID(self, _position)
				local fctDefinition = ATMEFct.getErrorPrefix(newRace) .. "tagGetByID(position)"
				
				if type(_position) == "number" then
					local pos = math.floor(_position)
					if tagsName ~= nil and pos >= 1 and pos <= #tagsName then
						return tagsName[pos]
					end
				else
					ATMEFct.errorOutputCore(nil, fctDefinition, "position type must be number", true)
				end
			end
			
			function newRace.tagGetCount(self)
				if tagsName ~= nil then
					return #tagsName
				else
					return 0
				end
			end
			
			function newRace.tagCompare(self, _tagsToCompare)
				local fctDefinition = ATMEFct.getErrorPrefix(newRace) .. "tagCompare(tagsToCompare)"
				
				if type(_tagsToCompare) == "string" then
					if tagsName ~= nil then
						local ok = ATMEFct.compareTags(tagsName, _tagsToCompare)
						
						if ok ~= nil then
							return ok
						else
							ATMEFct.errorOutputCore(nil, fctDefinition, "tagsToCompare format must be 'T1|T2|..|Tn'", false)
						end
					else
						return false
					end
				else
					ATMEFct.errorOutputCore(nil, fctDefinition, "tagsToCompare type must be string", true)
				end
			end
		
			function newRace.getNbTurns(self)
				return nbTurns
			end
			
			function newRace.getNbDoors(self)
				return doors:getCount()
			end
			
			function newRace.getUserPrivateDatas(self, _module)
				local fctDefinition = ATMEFct.getErrorPrefix(newRace) .. "getUserPrivateDatas(module)"
				
				if ATME.isObjectClass(_module, ATME.C_Module) == true then
					return localMembers.userPrivateDatas[_module:getName()]
				else
					ATMEFct.errorOutputCore(nil, fctDefinition, "module type must be ATME.C_Module", true)
				end
			end
			
			function newRace.getDoorSides(self, _index)
				local fctDefinition = ATMEFct.getErrorPrefix(newRace) .. "getDoorSides(index)"
				
				if type(_index) == "number" then
					local index = math.floor(_index)
					if index > 0 and localMembers.doorsIndex[index] ~= nil then 
						local leftObject = localMembers.doorsIndex[index].leftObject
						local rightObject = localMembers.doorsIndex[index].rightObject
						
						return leftObject, rightObject
					else
						ATMEFct.errorOutputCore(nil, fctDefinition, "Race " .. name .. " - Door #" .. index .. " not found", false)
					end
				else
					ATMEFct.errorOutputCore(nil, fctDefinition, "index type must be number", true)
				end
			end
			
			function newRace.getLapAtDoor(self, _index)
				local fctDefinition = ATMEFct.getErrorPrefix(newRace) .. "getLapAtDoor(index)"
				
				if type(_index) == "number" then
					local index = math.floor(_index)
					if index > 0 and localMembers.doorsIndex[index] ~= nil then 
						return localMembers.doorsIndex[index].lap
					else
						ATMEFct.errorOutputCore(nil, fctDefinition, "Door #" .. index .. " not found", false)
					end
				else
					ATMEFct.errorOutputCore(nil, fctDefinition, "index type must be number", true)
				end
			end
			
			function newRace.setLapAtDoor(self, _index)
				local fctDefinition = ATMEFct.getErrorPrefix(newRace) .. "setLapAtDoor(index)"
				
				if type(_index) == "number" then
					local index = math.floor(_index)
					if index > 0 and localMembers.doorsIndex[index] ~= nil then 
						if localMembers.doorsIndex[index].id > 1 and  localMembers.doorsIndex[index].id < self:getNbDoors() then
							localMembers.doorsIndex[index].lap = true
						else
							ATMEFct.errorOutputCore(nil, fctDefinition, "Race " .. name .. " - No lap on first or last door", false)
						end
					else
						ATMEFct.errorOutputCore(nil, fctDefinition, "Race " .. name .. " - Door #" .. index .. " not found", false)
					end
				else
					ATMEFct.errorOutputCore(nil, fctDefinition, "index type must be number", true)
				end
			end
			
			function newRace.getDoorIndex(self, _offset)
				local fctDefinition = ATMEFct.getErrorPrefix(newRace) .. "getDoorIndex(offset)"
				
				if type(_offset) == "number" then
					local offset = math.floor(_offset)
					if offset > 0 and _offset <= doors:getCount() then
						return doors:get(offset).index
					else
						ATMEFct.errorOutputCore(nil, fctDefinition, "Race " .. name .. " - " .. _offset .. " must be > 0 and <= " .. doors:getCount(), false)
					end
				else
					ATMEFct.errorOutputCore(nil, fctDefinition, "offset type must be number", true)
				end
			end
			
			function newRace.getPlayerNextDoorIndex(self, _player)
				local fctDefinition = ATMEFct.getErrorPrefix(newRace) .. "getPlayerNextDoorIndex(player)"
				
				if ATME.isObjectClass(_player, ATME.C_Player) == true then
					if localMembers.players[_player:getName()] ~= nil then
						return self:getDoorIndex(localMembers.players[_player:getName()].nextDoor)
					else
						ATMEFct.errorOutputCore(nil, fctDefinition, "player " .. _player:getPseudo() .. " not in race " .. raceName, false)
					end
				else
					ATMEFct.errorOutputCore(nil, fctDefinition, "player type must be ATME.C_Player", true)
				end
			end
			
			function newRace.displayForAllPlayers(self, _text, _duration)
				local fctDefinition = ATMEFct.getErrorPrefix(newRace) .. "displayForAllPlayers(text, duration)"
				
				if type(_text) == "string" and type(_duration) == "number" then
					for _name, _player in pairs(localMembers.players) do
						_player.player:display(_text, _duration)
					end
				else
					if type(_text) ~= "string" then
						ATMEFct.errorOutputCore(nil, fctDefinition, "text type must be string", true)
					elseif type(_duration) ~= "number" then
						ATMEFct.errorOutputCore(nil, fctDefinition, "duration type must be number", false)
					end
				end
			end
			
			function newRace.soundForAllPlayers(self, _text)
				local fctDefinition = ATMEFct.getErrorPrefix(newRace) .. "soundForAllPlayers(text)"
				
				
				if type(_text) == "string" then
					local err, playlist = ATMEFct.C_Sound_getPlaylist(_text, false)

					if err == true then
						ATMEFct.errorOutputCore(nil, fctDefinition, playlist, false)
						return
					end

					if playlist == nil then
						ATMEFct.errorOutputCore(nil, fctDefinition, "text string has no sound token", false)
						return
					end
		
					for _, _player in pairs(localMembers.players) do
						ATMEFct.initSoundPlaylist({
													player = _player, 
													randomRead = false, 
													readOnce = true, 
													playlist = playlist,
												})
					end
				else
					ATMEFct.errorOutputCore(nil, fctDefinition, "text type must be string", true)
				end
			end
			
			function newRace.addPlayer(self, _player)
				local fctDefinition = ATMEFct.getErrorPrefix(newRace) .. "addPlayer(player)"
				
				if ATME.isObjectClass(_player, ATME.C_Player) == true then
					local found = false
					local raceName = ""
					for _, _race in pairs(ATMEDatas.races) do
						local localMembersLoop = ATMEDatas.C_Race_MT:get(_race:getIndex())
						
						if localMembersLoop.players[_player:getName()] ~= nil then
							found = true
							raceName = _race:getName()
						end
					end
					
					if found == false then
						newPlayer = {
							player = _player,
							bestTime = -1,
							recordTime = 0,
						}
						
						table.insert(localMembers.bestPlayers, newPlayer)
						
						localMembers.players[_player:getName()] = {
							player = _player,
							startTime = 0,
							startTurnTime = 0,
							bestTurnTime = -1,
							bestTime = -1,
							penalty = 0,
							nextDoor = 1,
							currentTurn = 1,
							oldPosition = _player:getPosition(),
						}
					else
						ATMEFct.errorOutputCore(nil, fctDefinition, "player " .. _player:getPseudo() .. " already in race " .. raceName, false)
					end
				else
					ATMEFct.errorOutputCore(nil, fctDefinition, "player type must be ATME.C_Player", true)
				end
			end
	
			function newRace.removePlayer(self, _player)
				local fctDefinition = ATMEFct.getErrorPrefix(newRace) .. "removePlayer(player)"
				if ATME.isObjectClass(_player, ATME.C_Player) == true then
					if localMembers.players[_player:getName()] ~= nil then
						local index = 1
						while index <= #localMembers.bestPlayers do
							if localMembers.bestPlayers[index].player == _player then
								table.remove(localMembers.bestPlayers, index)
							else
								index = index + 1
							end
						end
						
						localMembers.players[_player:getName()] = nil
					end
				else
					ATMEFct.errorOutputCore(nil, fctDefinition, "player type must be ATME.C_Player", true)
				end
			end
	
			function newRace.removeAllPlayers(self)
				for _name, _ in pairs(localMembers.players) do
					localMembers.players[_name] = nil
				end
				
				while #localMembers.bestPlayers > 0 do
					table.remove(localMembers.bestPlayers)
				end
			end
	
			function newRace.isPlayerInRace(self, _player)
				local fctDefinition = ATMEFct.getErrorPrefix(newRace) .. "isPlayerInRace(player)"
				
				if ATME.isObjectClass(_player, ATME.C_Player) == true then
					return localMembers.players[_player:getName()] ~= nil
				else
					ATMEFct.errorOutputCore(nil, fctDefinition, "player type must be ATME.C_Player", true)
				end
			end
	
			function newRace.getRanking(self)
				local ranking = {}
				
				for _, _item in ipairs(localMembers.bestPlayers) do
					local item = {
						player = _item.player,
						bestTime = _item.bestTime,
					}
					
					table.insert(ranking, item)
				end
				
				return ranking
			end
	
			function newRace.setMaxAltitudeRule(self, _maxAltitude, _penalty)
				local fctDefinition = ATMEFct.getErrorPrefix(newRace) .. "setMaxAltitudeRule(maxAltitude, penalty)"
				
				if type(_maxAltitude) == "number" and type(_penalty) == "number" then
					if _maxAltitude > 0 then
						localMembers.maxAltitude = _maxAltitude
						
						if _penalty >= 0 then
							localMembers.maxAltitudePenalty = _penalty
						else
							ATMEFct.errorOutputCore(nil, fctDefinition, "penalty must be >= 0", false)
						end
					else
						ATMEFct.errorOutputCore(nil, fctDefinition, "Bad altitude max", false)
					end
				else
					if type(_maxAltitude) ~= "number" then
						ATMEFct.errorOutputCore(nil, fctDefinition, "maxAltitude type must be number", true)
					elseif type(_penalty) ~= "number" then
						ATMEFct.errorOutputCore(nil, fctDefinition, "penalty type must be number", false)
					end
				end
			end
			
			function newRace.resetMaxAltitudeRule(self)
				localMembers.maxAltitude = -1
				localMembers.maxAltitudePenalty = 0
			end
	
			function newRace.getMaxAltitudePenalty(self)
				return localMembers.maxAltitudePenalty
			end
	
			function newRace.getMaxAltitude(self)
				return localMembers.maxAltitude
			end
			
			for _, _localModuleMembers in ATMEDatas.C_Module_MT:pairs() do
				localMembers.userPrivateDatas[_localModuleMembers.name] = {}
			end
			
			ATMEDatas.races[name] = newRace
			return newRace
		else
			ATMEFct.errorOutputCore(nil, fctDefinition, "Race " .. _name .. " must have two doors at least", false)
		end
	end
end

setmetatable(ATME.C_Race,ATMEDatas.C_Race_MT)

ATMEDatas.C_Race_MT.__call = function(t, _name, _leftSideDoorName, _rightSideDoorName, _nbTurns)
	local fctDefinition = "Constructor ATME.C_Race(name, leftSideDoorName, righSideDoorName, nbTurns)"
	
	if type(_name) == "string" and type(_leftSideDoorName) == "string" and type(_rightSideDoorName) == "string" and type(_nbTurns) == "number" then
		local d,f = string.find(_name, "|", 1)
		if d == nil then
			if ATMEDatas.races[_name] == nil then
				if _nbTurns >= 1 then
					return ATMEFct.C_Race_create(_name, _leftSideDoorName, _rightSideDoorName, math.floor(_nbTurns))
				else
					ATMEFct.errorOutputCore(nil, fctDefinition, "Race " .. _name .. " - nbTurns must be >= 1", false)
				end
			else
				return nil
			end
		else
			ATMEFct.errorOutputCore(nil, fctDefinition, "name can't contain '|' character", false)
		end
	else
		if type(_name) ~= "string" then
			ATMEFct.errorOutputCore(nil, fctDefinition, "name type must be string", false)
		elseif type(_leftSideDoorName) ~= "string" then
			ATMEFct.errorOutputCore(nil, fctDefinition, "leftSideDoorName type must be string", false)
		elseif type(_rightSideDoorName) ~= "string" then
			ATMEFct.errorOutputCore(nil, fctDefinition, "rightSideDoorName type must be string", false)
		elseif type(_nbTurns) ~= "number" then
			ATMEFct.errorOutputCore(nil, fctDefinition, "nbTurns type must be number", false)
		end
	end
end

ATMEDatas.C_Race_MT.mt.__metatable = "Private"
ATMEDatas.C_Race_MT.mt.__index = ATME.C_Race
ATMEDatas.C_Race_MT.mt.__newindex = function(t, k, v)
	if ATMEDatas.C_Race_MT.keys[k] ~= nil then 
		rawset(t, k, v)
	else
		ATMEFct.errorOutputCore(nil, "Function ATME.C_Race : Bad key " .. k, "table locked", false)
	end
end

----------------------------------------------------------------------------------------------------------
-- FIN DE DEFINITION DES CLASSES D'OBJETS DEFINIS DANS ATME
--
-- FONCTIONS DE GESTION ATME_CORE
----------------------------------------------------------------------------------------------------------

do
	----------------------------------------------------------------------------------------------------------
	-- Fonction de mise à jour (appelé par les 2 timers _timerMainFunction et _timer100x) des joueurs actifs :
	--		-> Tous les joueurs actifs dans la liste ATME au coup précédent sont listés
	--		-> On ajuste avec les joueurs toujours actifs (fonction DCS coalition.getPlayers)
	--		-> Les joeurs que ne sont pas actifs sont détruits de la liste ATME.
	-- Cette fonction est importante car ATME ne se base que sur l'événement DCS S_EVENT_BIRTH. En cas de changement
	-- de slot par exemple, cet événement est émis. Mais pas la destruction. 
	-- Les événements S_EVENT_PLAYER_ENTER ou S_EVENT_PLAYER_LEAVE ont buggé par le passé en multi,
	-- donc pas de gestion de ces événements pour la mise à jour interne ATME.
	--
	-- Elle permet lors dudit timer d'éviter les incohérences qui pourraient se produire dans la liste ATME joueurs.
	----------------------------------------------------------------------------------------------------------
	
	function ATME.onTrackWaypoints(_name, _idWaypoint)
		if ATMEDatas.exitATME == false then
			local group = ATME.C_Group.getByName(_name)
			if group ~= nil then
				local localMembers = ATMEDatas.C_Group_MT:get(group:getIndex())

				if localMembers.waypoints[_idWaypoint + 1].type ~= "Land" then
					ATMEFct.outputCore(nil, "Group " .. _name .. " passe au waypoint..." .. _idWaypoint + localMembers.offsetIdWaypoint .. " (offset = " .. localMembers.offsetIdWaypoint .. ") /  nb waypoints -> ".. localMembers.maxWaypoints, 2)
					localMembers.lastPassedWaypoint = _idWaypoint
					
					if group:isActivated() == true and group:isWaypointsTracking() == true then
						local idCurrentWP = _idWaypoint + localMembers.offsetIdWaypoint
						
						if (localMembers.disembark == false or (_idWaypoint > 1 and localMembers.disembark == true)) and 
											group:isFullWaypointsTracking() == true and _idWaypoint + 1 < localMembers.maxWaypoints then
							localMembers.disembark = false

							local event = {
								type = "TRACKING_WAYPOINT",
								datas = {
									groupName = _name,
									idWaypoint = idCurrentWP,
									point = {
										x = localMembers.waypoints[_idWaypoint + 1].x,
										y = localMembers.waypoints[_idWaypoint + 1].alt,
										z = localMembers.waypoints[_idWaypoint + 1].y,
									},
								},
							}
							
							ATMEFct.C_CoreEvent_add(event)
							
						elseif localMembers.maxWaypoints == _idWaypoint + 1 then
							local event = {
								type = "TRACKING_LAST_WAYPOINT",
								datas = {
									groupName = _name,
									point = {
										x = localMembers.waypoints[_idWaypoint + 1].x,
										y = localMembers.waypoints[_idWaypoint + 1].alt,
										z = localMembers.waypoints[_idWaypoint + 1].y,
									},
								},
							}
						
							ATMEFct.C_CoreEvent_add(event)
							
							-- Le dernier waypoint est passé hors aéronefs.
							localMembers.endOfRoute = true
						end
					end
					
					-- Patrouille si liée au nombre de tours -> Vérifications
					if localMembers.patrolWP.last - 1 == _idWaypoint then
						if localMembers.patrolWP.maxTurns > 0 then
							localMembers.patrolWP.nbTurns = localMembers.patrolWP.nbTurns + 1
							
							if localMembers.patrolWP.nbTurns < localMembers.patrolWP.maxTurns then
								localMembers.patrolWP.isArmed = true
							else
								group:resetPatrol()
							end
						else
							if localMembers.patrolWP.maxTime > 0 then
								if localMembers.patrolWP.maxTime >= timer.getTime() then
									localMembers.patrolWP.isArmed = true
								else
									group:resetPatrol()
								end
							elseif localMembers.patrolWP.maxRandom > 0 then
								if math.random() <= localMembers.patrolWP.maxRandom then
									localMembers.patrolWP.isArmed = true
								else
									group:resetPatrol()
								end
							else
								localMembers.patrolWP.isArmed = true
							end				
						end
					end
				end
			end
		end
	end
	

	
	local timerFcts = {
		[1] = function(_currentTipsCount)
			-- Contrôle des tracking de target
			for _name, _targetTracking in pairs(ATMEDatas.targetsTracking) do
				if ATMEDatas.AIUnits[_name] ~= nil then
					local targets = ATMEFct.C_AIUnit_getDetectedTargets(ATMEDatas.AIUnits[_name], _targetTracking.typeOfSensorName)
					for _targetName, _ in pairs(targets) do
						if targets[_targetName].stillDetected == false then
							if targets[_targetName].confirmed > 0 then
								targets[_targetName].confirmed = targets[_targetName].confirmed - 1	
							elseif targets[_targetName].confirmed == 0 and targets[_targetName].trackingOn == true then
								targets[_targetName] = nil

								local event = {
									type = "TARGET_END_TRACK",
									datas = {
										unitName = _name,
										targetName = _targetName,
									},
								}
								
								ATMEFct.C_CoreEvent_add(event)
							end
						else
							if targets[_targetName].confirmed < 5 then
								targets[_targetName].confirmed = targets[_targetName].confirmed + 1
							elseif targets[_targetName].confirmed == 5 then
								if targets[_targetName].trackingOn == false and (_targetTracking.flag == nil or ATME.getFlag(_targetTracking.flag) ~= 0) then	
									-- Event nouvelle target dans le tracking confirmée
									
									targets[_targetName].trackingOn = true
									local event = {
										type = "TARGET_NEW_TRACK",
										datas = {
											unitName = _name,
											targetName = _targetName,
										},
									}
									
									ATMEFct.C_CoreEvent_add(event)
								elseif targets[_targetName].trackingOn == true and _targetTracking.flag ~= nil and ATME.getFlag(_targetTracking.flag) == 0 then
									targets[_targetName].trackingOn = false
									local event = {
										type = "TARGET_END_TRACK",
										datas = {
											unitName = _name,
											targetName = _targetName,
										},
									}
									
									ATMEFct.C_CoreEvent_add(event)
								end
							end
						end
					end
				end
			end
		end,
	
		[2] = function(_currentTipsCount)
			-- Contrôle des zones signalées liées à un groupe
			for _index, _signal in ATMEDatas.signals:pairs() do
				if _signal.groupName ~= nil then
					local signalGroup = ATME.C_Group.getByName(_signal.groupName)

					if signalGroup ~= nil then
						local firstUnit = signalGroup:getFirstUnit()
						
						if firstUnit ~= nil then
							local isFired = capabilityUnitsInPickupZone(signalGroup, nil, signalGroup:getCoalitionName(), true, 
																			firstUnit:getPosition(), _signal, _index,
																			_currentTipsCount)
							
							local localGroupMembers = ATMEDatas.C_Group_MT:get(signalGroup:getIndex())
							if isFired == true and localGroupMembers.isStopped == false then
								signalGroup:stop()
							end
						end
					end
				end
			end
			
			-- Contrôle du débarquement automatique
			for _name, _datas in pairs(ATMEDatas.autoUnloadDatas) do
				if ATMEDatas.AIUnits[_name] == nil then
					-- L'unité de transport n'existe plus
					
					ATMEDatas.autoUnloadDatas[_name] = nil
				else
					local transportUnit = ATMEDatas.allAIUnitsAndPlayers[_name]
					
					local index = #_datas
					local found = false
					while index > 0 and found == false do
						if _datas[index].armed == false then
							if (transportUnit:isGroundVehicle() == true and transportUnit:getHSpeed() > 5) or 
								((transportUnit:isHelicopter() or transportUnit:isPlane()) and transportUnit:inAir() == true) then
								_datas[index].armed = true
								_datas[index].delay = 1
							end
						else
							if transportUnit:getHSpeed() == 0 and (transportUnit:isGroundVehicle() == true or 
								((transportUnit:isHelicopter() or transportUnit:isPlane()) and transportUnit:inAir() == false)) then
								if _datas[index].delay > 0 then
									_datas[index].delay = _datas[index].delay - 1
								else
									local localMembers = ATMEFct.C_Player_C_AIUnit_getLocalMembers(transportUnit)

									local currentOnBoardGroupDatas = localMembers.onBoardGroupDatas:get(_datas[index].id)
									if currentOnBoardGroupDatas ~= nil then
										ATMEFct.C_Player_C_AIUnit_unload(transportUnit, _datas[index].id, currentOnBoardGroupDatas, false)
									end
									
									found = true
									table.remove(_datas, index)
								end
							end
						end
						
						if found == false then
							index = index - 1
						end
					end

					if #_datas == 0 then
						-- Plus de unload pour cette unité de transport, c'est fini
						ATMEDatas.autoUnloadDatas[_name] = nil
					end
				end
			end
		end,
	}
	
	----------------------------------------------------------------------------------------------------------
	-- Fonction _timerMainFunction est appelée à l'initialisation voir plus bas, puis réarmée toutes les secondes.
	-- Cette fonction permet :
	--		- la mise à jour permanente des listes ATME des joueurs et unités AI.
	--      - la gestion des spawns multiples
	-- 		- la gestion des smokes (classe ATME.C_Smoke) qui doivent rester actifs et les tirs répétés de 
	-- 		   flares (classe ATME.C_Flare)
	-- 		- la gestion les radios transmissions permanentes affectées aux unités AI (classe ATME.AIUnit)
	--		- la gestion des sons répétés associés aux joueurs (classe ATME.C_Player)
	--      - la gestion d'entrée/sortie des aires (areas)
	--      - la gestion des pickupZones et des signaux éventuels
	--		- La réaffectation des spots IR ou laser
	--		- l'appel pour chaque module et chaque instance de ATME_C_Alarm du handler onTimerHandler
	--		- l'appel des onCreateHandlers suite à la création des unités et groupes, suivi éventuellement d'un onSpawnHandler
	-- 		- l'appel des fonctions de mise des joueurs
	--		- après ces appels, la liste des events actifs est remise à 0.
	--		- Traitement des event core retardés. Certains evénéments sont retardés pour garantir leur bonne prise en 
	--        par DCS.
	--      - Gestion des routes pour les patrouilles
	--
	-- 		Le tableau de fonctions timerFcts permet d'appeler certaines fonctions avec une fréquence moindre par
	--      une rotation des fonctions appelée. La période d'appel correspond 2 secondes.
	----------------------------------------------------------------------------------------------------------

	local currentTimerFct = 0
	local startOffset = 0
	local startOk = false
	local maxTimerFcts = #timerFcts
	
	local _timerMainFunction
    _timerMainFunction = function()
		if ATMEDatas.exitATME == false then
			-- Fonction des mises à jour de la liste des joueurs ... 
			-- Important pour éviter les incohérences, les timers étant asynchrones
			
			ATMEFct.outputCore(nil,"Start main timer", 2)
			
			local currentTipsCount = math.floor(timer.getTime())
			
			currentTimerFct = currentTimerFct + 1
			if currentTimerFct > maxTimerFcts then
				currentTimerFct = 1
			end
			
			timerFcts[currentTimerFct](currentTipsCount)
			
			-- Gestion du respawn automatique après destruction
			for _name, _item in pairs(ATMEDatas.groupsToRespawn) do
				if _item.time <= currentTipsCount then
					if _item.spawnDatas ~= nil then
						ATMEFct.C_CloningContext_spawn(_item.spawnDatas, 0)
					end
					
					ATMEDatas.groupsToRespawn[_name]= nil
				end
			end
			
			-- Contrôle des smokes qui se réactivent
			for _, _smoke in ATMEDatas.activatedSmokes:pairs() do
				local localMembers = ATMEDatas.C_Smoke_MT:get(_smoke:getIndex())
				
				if localMembers.timeStart + ATMEConst.maxTimeSmoke <= currentTipsCount then
					local color = ATMEConst.smokeColors[_smoke:getColor()]
					trigger.action.smoke(_smoke:getPoint(), color)
					localMembers.timeStart = currentTipsCount
				end
			end
			
			-- Contrôle des flares qui se réactivent
			for _, _flare in ATMEDatas.activatedFlares:pairs() do
				if _flare:getTimeStart() + _flare:getDuration() > currentTipsCount then
					if  math.random(1,2) == 1 then
						_flare:fireOnce()
					end
				else
					_flare:stop()
				end
			end
			
			-- Activation des taches missions avec délai
			local indexMission = 1
			while indexMission <= #ATMEDatas.missionsDelayed do
				if ATMEDatas.missionsDelayed[indexMission].controlled == true then
					if ATMEDatas.missionsDelayed[indexMission].delay > 0 then
						ATMEDatas.missionsDelayed[indexMission].delay = ATMEDatas.missionsDelayed[indexMission].delay - 1
						indexMission = indexMission + 1
					else
						local group = ATMEDatas.groups[ATMEDatas.missionsDelayed[indexMission].name]
						
						if group ~= nil then
							ATMEFct.C_CloningContext_setMission(group, ATMEDatas.missionsDelayed[indexMission].waypoints, ATMEDatas.missionsDelayed[indexMission].trackingOk, false)
						end
						table.remove(ATMEDatas.missionsDelayed, indexMission)
					end
				else
					local group = ATMEDatas.groups[ATMEDatas.missionsDelayed[indexMission].name]
					
					if group ~= nil then
						ATMEDatas.missionsDelayed[indexMission].controlled = group:isControlled()
						indexMission = indexMission + 1
					else
						table.remove(ATMEDatas.missionsDelayed, indexMission)
					end
				end
			end
			
			-- Contrôle des sons joueur qui se réactivent
			for _index, _sound in ATMEDatas.activatedSounds:pairs() do
				if _sound.tips == 0 then
					if #_sound.playlist > 0 then
						if _sound.randomRead == true then 
							_sound.currentReadIndex = math.random(1, #_sound.playlist)
						end
						
						_sound.tips = _sound.playlist[_sound.currentReadIndex].tips

						if _sound.playerName ~= nil then
							if ATMEDatas.players[_sound.playerName] ~= nil then
								trigger.action.outSoundForGroup(ATMEDatas.players[_sound.playerName]:getGroupId(), _sound.voice .. _sound.playlist[_sound.currentReadIndex].fileName)
								if _sound.playlist[_sound.currentReadIndex].subtitle.duration > 0 then
									trigger.action.outTextForGroup(ATMEDatas.players[_sound.playerName]:getGroupId(), _sound.playlist[_sound.currentReadIndex].subtitle.text, _sound.playlist[_sound.currentReadIndex].subtitle.duration)
								end
							else
								ATMEDatas.activatedSounds:remove(_index)
							end
						elseif _sound.coalition ~= nil then
							trigger.action.outSoundForCoalition(_sound.coalition, _sound.voice .. _sound.playlist[_sound.currentReadIndex].fileName)
							if _sound.playlist[_sound.currentReadIndex].subtitle.duration > 0 then
								trigger.action.outTextForCoalition(_sound.coalition, _sound.playlist[_sound.currentReadIndex].subtitle.text, _sound.playlist[_sound.currentReadIndex].subtitle.duration)
							end
						elseif _sound.country ~= nil then		
							trigger.action.outSoundForCountry(_sound.country, _sound.voice .. _sound.playlist[_sound.currentReadIndex].fileName)
							if _sound.playlist[_sound.currentReadIndex].subtitle.duration > 0 then
								trigger.action.outTextForCountry(_sound.country,_sound.playlist[_sound.currentReadIndex].subtitle.text, _sound.playlist[_sound.currentReadIndex].subtitle.duration)
							end
						else
							trigger.action.outSound(_sound.voice .. _sound.playlist[_sound.currentReadIndex].fileName)
							
							if _sound.playlist[_sound.currentReadIndex].subtitle.duration > 0 then
								trigger.action.outText(_sound.playlist[_sound.currentReadIndex].subtitle.text, _sound.playlist[_sound.currentReadIndex].subtitle.duration)
							end
						end
						
						if _sound.readOnce == true then
							table.remove(_sound.playlist, _sound.currentReadIndex)
						else
							if _sound.randomRead == false then 
								_sound.currentReadIndex = _sound.currentReadIndex + 1
								if _sound.currentReadIndex > #_sound.playlist then
									_sound.currentReadIndex = 1
								end
							end
						end
					elseif _sound.readOnce == true then
						if _sound.playerName ~= nil then
							ATMEDatas.players[_sound.playerName]:soundStop()
						else
							ATMEDatas.activatedSounds:remove(_index)
						end
					end
				end
				
				_sound.tips = _sound.tips - 1
			end
			
			-- Gestion des traitement sécables stockés en pile -> Si besoin lissage sur plusieurs secondes
			-- Deux niveaux de pile traités ici, un troisième pouvant exister dans les fonctions stackTimer.
			ATMEDatas.totalCharge = 0
			local nbStackL1 = ATMEDatas.stackTimer:getCount()
			
			while nbStackL1 > 0 and ATMEDatas.totalCharge < ATMEConst.stackTimerMaxTotalCharge do  -- Niveau 1
				local item = ATMEDatas.stackTimer:extract("HEAD")
				local localMembers = ATMEDatas[item.classMT]:get(item.object:getIndex())
				local nbStackL2 = localMembers.tracking.stack:getCount()
				
				if ATMEFct.stackTimerBeforeL2Fcts[item.id] ~= nil then
					ATMEFct.stackTimerBeforeL2Fcts[item.id](item.object, localMembers, currentTipsCount)
				end
				
				while nbStackL2 > 0 and ATMEDatas.totalCharge < ATMEConst.stackTimerMaxTotalCharge do	-- Niveau 2
					if ATMEFct.stackTimerInL2Fcts[item.id] ~= nil then
						ATMEFct.stackTimerInL2Fcts[item.id](item.object, localMembers, currentTipsCount)
					end
					nbStackL2 = nbStackL2 - 1
				end
				
				if ATMEFct.stackTimerAfterL2Fcts[item.id] ~= nil then
					ATMEFct.stackTimerAfterL2Fcts[item.id](item.object, localMembers, currentTipsCount)
				end
				
				--ATMEFct.outputCore(nil,"Charge : " .. ATMEDatas.totalCharge .. " / Total : " .. ATMEConst.stackTimerMaxTotalCharge .. "(Nb stack = " .. nbStackL1 .. ")", 1)
				
				ATMEDatas.stackTimer:push(item)
				nbStackL1 = nbStackL1 - 1
			end
			
			-- Gestion des spawns multiples
			ATMEFct.outputCore(nil, "Gestion des spawn multiples", 2)
			for _key, _item in pairs(ATMEDatas.spawnGroupDatasRepeat) do
				if _item.nbSpawn >= _item.maxQuantity then
					ATMEDatas.spawnGroupDatasRepeat[_key] = nil
				elseif _item.currentTime ~= nil then
					if _item.currentTime > 0 then
						_item.currentTime = _item.currentTime - 1
					else
						if _item.repeatRandom == true then
							_item.currentTime = math.random(_item.repeatPeriodMin, _item.repeatPeriodMax)
						else
							_item.currentTime = _item.repeatPeriodMin
						end

						_item.nbSpawn = _item.nbSpawn + 1

						_item.groupDatas:spawn(_item.arg)
					end
				end
			end
			
			ATMEFct.outputCore(nil, "Gestion des groupes avec tache on zone", 2)
			-- Tâches principales avec gestion de zone - pilotées par ATME
			for _name, _item in pairs(ATMEDatas.onZoneTaskReady) do
				if ATMEDatas.groups[_name] ~= nil then	-- Le groupe avec tâche sur zone existe
					
					local localGroupMembers = ATMEDatas.C_Group_MT:get(ATMEDatas.groups[_name]:getIndex())
					
					if _item.delay ~= nil and _item.delay > 0 then
						_item.delay = _item.delay - 1
					else
						if _item.delay ~= nil then
							if ATMEDatas.groups[_item.targetGroupName] ~= nil then
								ATMEFct.outputCore(nil, "Groupe : '" .. _name .. "' - Nouvelle Target '" .. _item.targetGroupName .. "'", 2)
								
								ATMEFct.onZoneTasks[localGroupMembers.onZoneTask["id"]](localGroupMembers.onZoneTask["params"], _item) 
								
								local controller = ATMEDatas.groups[_name]:getDCSGroup():getController()

								controller:setTask(localGroupMembers.onZoneTask)
					
								_item.isActive = true
							end
							
							_item.delay = nil
						end
						
						if ATMEDatas.groups[_item.targetGroupName] == nil then
							ATMEFct.outputCore(nil, "Groupe : '" .. _name .. "' - Target '" .. _item.targetGroupName .. "' détruit", 2)
							-- On réaffecte sur un nouveau groupe target si besoin.
							local targetsCoalition = "RED"
							if ATMEDatas.groups[_name]:getCoalitionName() == "RED" then
								targetsCoalition = "BLUE"
							end
							
							_item.targetGroupName = ATMEFct.C_Group_findTargetInZone2D(_item.zone, targetsCoalition)
							
							_item.isActive = false
						elseif ATMEDatas.groups[_item.targetGroupName]:isInZone2D(_item.zone, true) == false then
							ATMEFct.outputCore(nil, "Groupe : '" .. _name .. "' - Target '" .. _item.targetGroupName .. "' hors zone - suppression tâche", 2)
							local controller = ATMEDatas.groups[_name]:getDCSGroup():getController()

							ATMEDatas.groups[_name]:resetTask()
							_item.targetGroupName = ATMEFct.C_Group_findTargetInZone2D(_item.zone, targetsCoalition)
							_item.isActive = false
						end
						
						if _item.isActive == false then
							-- On active la tâche pour le groupe JTAC
							
							if _item.targetGroupName ~= nil then
								_item.delay = 3
							else
								ATMEFct.outputCore(nil, "Groupe : '" .. _name .. "' - Zone nettoyée", 2)
								ATMEDatas.onZoneTaskReady[_name] = nil
								localGroupMembers.onZoneTask = nil
								
								local event = {
									type = "TASK_ZONE_CLEANED",
									datas = {
										groupName = _name,
										zone = _item.zone,
									},
								}
								
								ATMEFct.C_CoreEvent_add(event)
							end
						end
					end
				end
			end
			
			-- Réaffectation des spots sur changement de cibles avec délai d'attente de destruction effective (nécessaire en multi)
			ATMEFct.outputCore(nil, "Reaffectation des spots sur changement de cibles", 2)
			for _name, _item in pairs(ATMEDatas.spotsToReassign) do
				if _item.delay == 0 then
					local targetName
					
					if _item.reassign == false then
						targetName = ATMEDatas.spots[_name].targetName
					else
						if _item.groupName ~= nil and ATMEDatas.groups[_item.groupName] ~= nil then
							targetName = ATMEFct.C_AIUnit_findTargetInGroup(ATMEDatas.groups[_item.groupName], ATMEDatas.spots[_name].ignoredTargets)
						elseif _item.zone ~= nil then
							local targetsCoalition = "RED"
							if ATMEDatas.AIUnits[_name]:getCoalitionName() == "RED" then
								targetsCoalition = "BLUE"
							end
							
							if ATMEDatas.allAIUnitsAndPlayers[ATMEDatas.spots[_name].targetName] ~= nil then
								if _item.outOfZone == true then
									ATMEFct.outputCore(nil, "Spot par unité " .. _name .. " : unité " .. ATMEDatas.spots[_name].targetName .. " -> Hors zone", 2)
									local event = {
										type = "SPOT_TARGET_OUT_OF_ZONE",
										datas = {
											unitName = _name,
											targetName = ATMEDatas.spots[_name].targetName,
										},
									}
									
									ATMEFct.C_CoreEvent_add(event)
								elseif _item.noLOS == true then
									if _item.neverHaveLOS == false then
										ATMEFct.outputCore(nil, "Spot par unité " .. _name .. " : unité " .. ATMEDatas.spots[_name].targetName .. " -> Plus de visée", 2)
										local event = {
											type = "SPOT_TARGET_NO_LOS",
											datas = {
												unitName = _name,
												targetName = ATMEDatas.spots[_name].targetName,
											},
										}
										
										ATMEFct.C_CoreEvent_add(event)
									end
								end
							end

							targetName = ATMEFct.C_AIUnit_findTargetInZone2D(_item.zone, targetsCoalition, ATMEDatas.spots[_name].ignoredTargets)
						end

						ATMEDatas.spots[_name].targetName = targetName
					end
					
					if targetName ~= nil then
						local point = ATMEDatas.allAIUnitsAndPlayers[targetName]:getPosition()
						local posUnit = ATMEDatas.AIUnits[_name]:getPosition()
						
						ATMEDatas.spots[_name].vector =  ATMEFct.C_Vector3D_create(nil, nil, posUnit, point)
						ATMEDatas.spots[_name].noLOS = 0
						ATMEDatas.spots[_name].ignoredTargetOn = false
						
						local offset = {x = 0, y = -2, z = 0}
						if ATMEDatas.spots[_name].fromAir == false then
							offset = {x = 0, y = 2, z = 0}
						end
								
						if ATMEDatas.spots[_name].code ~= nil then
							ATMEDatas.spots[_name].spot = Spot.createLaser(ATMEDatas.AIUnits[_name]:getDCSUnit(),
																			offset, 
																			point, 
																			ATMEDatas.spots[_name].code)
							ATMEFct.outputCore(nil, "Spot LASER par unité " .. _name .. " : ciblage unité " .. targetName, 2)
						else
							ATMEDatas.spots[_name].spot = Spot.createInfraRed(ATMEDatas.AIUnits[_name]:getDCSUnit(),
																		offset, 
																		point)
							ATMEFct.outputCore(nil, "Spot IR par unité " .. _name .. " : ciblage unité " .. targetName, 2)
						end
						
						local event = {
							type = "SPOT_NEW_TARGET",
							datas = {
								unitName = _name,
								targetName = targetName,
							},
						}
						
						ATMEFct.C_CoreEvent_add(event)
					else
						ATMEFct.outputCore(nil, "Spot par unité " .. _name .. " : plus d'unités à cibler. Arrêt", 2)
						ATMEDatas.spots[_name] = nil
					
						local event = {
							type = "SPOT_STOP",
							datas = {
								unitName = _name,
							},
						}

						ATMEFct.C_CoreEvent_add(event)
					end
					
					ATMEDatas.spotsToReassign[_name] = nil
				else
					_item.delay = _item.delay - 1
				end
			end
			
			-- Contrôle des chargements d'unités dans des véhicules
			for _index, _groupToBoard in ATMEDatas.groupsToBoard:pairs() do
				-- DEBUG ATMEFct.outputCore(nil, "Transport unit name = " .. _groupToBoard.transportUnitName .. " / toBoardGroupeName = " .. _groupToBoard.activeGroupName, 1)
				
				if ATMEDatas.allAIUnitsAndPlayers[_groupToBoard.transportUnitName] ~= nil then
					local transportUnit = ATMEDatas.allAIUnitsAndPlayers[_groupToBoard.transportUnitName]

					local transportUnitPosition = transportUnit:getPosition()
					local toBoardGroup = ATME.C_Group.getByName(_groupToBoard.activeGroupName)
					local localMembersTransportUnit = ATMEFct.C_Player_C_AIUnit_getLocalMembers(transportUnit)
					
					if toBoardGroup ~= nil then
						if transportUnit:isGroundVehicle() or ((transportUnit:isHelicopter() or transportUnit:isPlane()) and transportUnit:inAir() == false) then
							-- Vitesse des infanteries à 5 m/s soit un temps de parcours = dist/5
							-- Marge de sécurité à 10s en plus. Au delà, toute le groupe est chargé directement
							-- Ceci permet de contourner le problème d'une unité capricieuse qui louperait le transport et le rayon de chargement.
							
							if currentTipsCount < _groupToBoard.timeStart + _groupToBoard.initialDistance / 5 + 10 then
								-- ATMEFct.outputCore(nil, "Transport unit name = " .. _groupToBoard.transportUnitName .. " au sol " .. _groupToBoard.initialDistance / 5, 1)
								
								for _, _unit in pairs(toBoardGroup:getUnits()) do
									local v = ATMEFct.C_Vector3D_create(nil, nil, _unit:getPosition(), transportUnitPosition)
									local ok = ATMEFct.whichSide(_groupToBoard.A, _groupToBoard.B, _unit:getPosition()) == _groupToBoard.sideOfWP2

									if v:getHModule() < ATMEConst.personnelCarrierAttributes[transportUnit:getTypeName()].minDistance or ok == true then
										-- tant que l'unité de transport est au sol, les unités à transporter
										-- sont désactivées à l'approche de l'unité de transport. Distance paramétrée dans ATMEConst.personnelCarrierAttributes
										_groupToBoard.unitsOnBoard[_unit:getName()] = true
										_groupToBoard.nbUnitsOnBoard = _groupToBoard.nbUnitsOnBoard + 1
										
										-- DEBUG ATMEFct.outputCore(nil, "Unité " .. _unit:getName() .. " embarquée", 1)
										if toBoardGroup:getNbUnits() == 1 then
											local localGroupMembers = ATMEDatas.C_Group_MT:get(toBoardGroup:getIndex())
										
											localGroupMembers.onBoard = true	
										end
										
										_unit:disable()
									end
								end
							else
								for _, _unit in pairs(toBoardGroup:getUnits()) do
									_groupToBoard.unitsOnBoard[_unit:getName()] = true
									_groupToBoard.nbUnitsOnBoard = _groupToBoard.nbUnitsOnBoard + 1
									
									if toBoardGroup:getNbUnits() == 1 then
										local localGroupMembers = ATMEDatas.C_Group_MT:get(toBoardGroup:getIndex())
										
										localGroupMembers.onBoard = true
									end
									
									_unit:disable()
								end
							end
						else
							if _groupToBoard.nbUnitsOnBoard > 0 then
								-- Si l'unité de transport décolle, tout le groupe est disable
								-- Embarquement en urgence ! des pertes sont possibles
								-- DEBUG ATMEFct.outputCore(nil, "Urgence, transport " .. _groupToBoard.transportUnitName .. " décolle groupe " .. _groupToBoard.activeGroupName .. " embarqué", 1)
							
								local nb = 0

								for _, _unit in pairs(toBoardGroup:getUnits()) do
									if math.random(1,10) <= 7 - nb then
										_groupToBoard.unitsOnBoard[_unit:getName()] = true
										_groupToBoard.nbUnitsOnBoard = _groupToBoard.nbUnitsOnBoard + 1

									else 
										table.insert(_groupToBoard.unitsLost, _unit:getName())
										-- DEBUG ATMEFct.outputCore(nil, "Unité " .. _unit:getName() .. " perdue", 2)
									end
									
									if toBoardGroup:getNbUnits() == 1 then
										local localGroupMembers = ATMEDatas.C_Group_MT:get(toBoardGroup:getIndex())
										
										localGroupMembers.onBoard = true
									end
									
									_unit:disable()
									
									if nb < 7 then
										nb = nb + 1
									end
								end
							else
								toBoardGroup:stop()
								local index = 0
								for _i, _groupItem in ipairs(localMembersTransportUnit.groupsBoarding) do
									if _groupToBoard.activeGroupName == _groupItem.groupName then
										index = _i
									end
								end
								
								if index > 0 then
									table.remove(localMembersTransportUnit.groupsBoarding, index)
								end
								
								_groupToBoard.unitsOnBoard = nil
								_groupToBoard.unitsLost = nil

								local localMembers = ATMEDatas.C_Group_MT:get(toBoardGroup:getIndex())
								localMembers.boardingStarted = false
								ATMEDatas.groupsToBoard:remove(_index)
							end
						end
					else
						-- Le groupe à transporter est inexistant (détruit ou disable complet)
						if _groupToBoard.nbUnitsOnBoard > 0 then
							ATMEFct.outputCore(nil, "Transport " .. _groupToBoard.transportUnitName .. " : " .. _groupToBoard.nbUnitsOnBoard .. " unités embarqués", 2)
							ATMEFct.outputCore(nil, "Transport " .. _groupToBoard.transportUnitName .. " : " .. #_groupToBoard.unitsLost .. " unités perdues", 2)
							
							-- On ne conserve que les unités ayant réussi à monter

							localMembersTransportUnit.nbUnitsOnBoard = localMembersTransportUnit.nbUnitsOnBoard + _groupToBoard.nbUnitsOnBoard
							
							local index = 0
							for _i, _groupItem in ipairs(localMembersTransportUnit.groupsBoarding) do
								if _groupToBoard.activeGroupName == _groupItem.groupName then
									index = _i
								end
							end
							
							if index > 0 then
								table.remove(localMembersTransportUnit.groupsBoarding, index)
							end

							local idGroupOnBoard = ATMEFct.C_Player_C_AIUnit_addOnBoardGroup(transportUnit,  
																							{
																								name = _groupToBoard.activeGroupName,
																								spawnDatas = _groupToBoard.spawnDatas,
																								unitsOnBoard = _groupToBoard.unitsOnBoard,
																								nbUnitsOnBoard = _groupToBoard.nbUnitsOnBoard,
																								isWaypointsTracking = _groupToBoard.isWaypointsTracking, 
																								isFullWaypointsTracking = _groupToBoard.isFullWaypointsTracking,
																								waypoints = _groupToBoard.waypoints,
																								lastPassedWaypoint = _groupToBoard.lastPassedWaypoint,
																								offsetIdWaypoint = _groupToBoard.offsetIdWaypoint,
																								autoRespawn = _groupToBoard.autoRespawn,
																								nextWaypoint = _groupToBoard.nextWaypoint,
																							})

							-- Evénement de fin d'embarquement
							-- On ne stocke que le nom. La vérification de l'existance de l'unité ne se fera que lors
							-- de l'activation de l'événement. 
							-- ATTENTION : Ici name est le nom du group qui va être disable... Donc pas de réactivation
							-- à l'activation de l'événement.
							
							
							local event = {
								type = "TRANSPORT_END_OF_BOARDING",
								datas = {
									unitName = transportUnit:getName(),
									index = idGroupOnBoard,
									onBoardGroupName = _groupToBoard.activeGroupName,
									nbOnBoardUnits = _groupToBoard.unitsOnBoard,
									nbDeadUnits = #_groupToBoard.unitsLost,
								},
							}
							
							ATMEFct.C_CoreEvent_add(event)
						end
						
						_groupToBoard.unitsOnBoard = nil
						_groupToBoard.unitsLost = nil
						ATMEDatas.groupsToBoard:remove(_index)
					end
				else
					-- L'unité de transport est inexistante (détruit ou changement de slot)
					-- Tout est perdu. Seules restent les unités du groupe extérieures à l'unité de transport.
					
					_groupToBoard.unitsOnBoard = nil
					_groupToBoard.unitsLost = nil
					local toBoardGroup = ATME.C_Group.getByName(_groupToBoard.activeGroupName)
					if toBoardGroup ~= nil then
						local localMembers = ATMEDatas.C_Group_MT:get(toBoardGroup:getIndex())
						localMembers.boardingStarted = false
					end
					
					ATMEDatas.groupsToBoard:remove(_index)
				end
			end
			
			-- Vérification de l'existance des unités & groupes liés aux core events et
			-- récupération de l'unité/groupe à partir de son nom sinon suppression
			for _id, _coreEvent in events[activeEvents]:pairs() do
				local localCoreEventMembers = ATMEDatas.C_CoreEvent_MT:get(_coreEvent:getIndex())
				
				if localCoreEventMembers.delay == 0 then
					-- groupEventTypes contient les Core event liés au groupe
					if ATMEConst.groupEventTypes[localCoreEventMembers.type] == nil then
						local name = localCoreEventMembers.datas.unitName
			
						if ATMEDatas.allAIUnitsAndPlayers[name] == nil then
							events[activeEvents]:remove(_id)
						else
							localCoreEventMembers.datas.unit = ATMEDatas.allAIUnitsAndPlayers[name]
													
							if type(localCoreEventMembers.datas.linkedGroupName) == "string" then
								if ATMEDatas.groups[localCoreEventMembers.datas.linkedGroupName] ~= nil then
									-- Traitement des cas type TRANSPORT_END_OF_DISEMBARK, SIGNAL_UNIT_IN_ZONE et SIGNAL_UNIT_OUT_OF_ZONE
									-- Associe le groupe à partir de son nom si il existe toujours au moment du traitement.
								
									localCoreEventMembers.datas.linkedGroup = ATMEDatas.groups[localCoreEventMembers.datas.linkedGroupName]
								else
									events[activeEvents]:remove(_id)
								end
							elseif type(localCoreEventMembers.datas.targetName) == "string" then
								if ATMEDatas.allAIUnitsAndPlayers[localCoreEventMembers.datas.targetName] ~= nil then
									-- Traitement des cas SPOT_NEW_TARGET, SPOT_TARGET_OUT_OF_ZONE, SPOT_TARGET_NO_LOS,
									-- TARGET_NEW_TRACK, TARGET_END_TRACK, HIT_TARGET, SHOOTING_START
									
									localCoreEventMembers.datas.target = ATMEDatas.allAIUnitsAndPlayers[localCoreEventMembers.datas.targetName]
								else							
									events[activeEvents]:remove(_id)
								end
							end
						end
					else
						local name = localCoreEventMembers.datas.groupName
			
						if ATMEDatas.groups[name] == nil then
							events[activeEvents]:remove(_id)
						else
							localCoreEventMembers.datas.group = ATMEDatas.groups[name]
						end
					end
				end
			end
			
			-- Bug DCS contournement pour les loop radioTransmission
			-- On relance le loop si au moins un joueur s'est connecté
			if ATMEDatas.newPlayer == true then
				ATMEDatas.newPlayer = false
				
				for _, _radioTransmission in ATMEDatas.activatedRadioTransmissions:pairs() do
					if _radioTransmission.autoRestartDCS == true then
						_radioTransmission.replay = true
					end
				end
			end
			
			-- Affichage du nombre de joueurs
			if ATMEDatas.oldNbPlayers ~= ATMEDatas.nbPlayers then
				ATMEFct.outputCore(nil,"Nb players = " .. ATMEDatas.nbPlayers, 2)
				ATMEDatas.oldNbPlayers = ATMEDatas.nbPlayers
			end
			
			-- Pour les groupes créés et spawnés en attente, on enlève un cycle et on purge les groupes détruits entre temps
			for _name, _ in pairs(ATMEDatas.newCreatedGroups) do
				if ATMEDatas.groups[_name] ~= nil then
					if ATMEDatas.newCreatedGroups[_name].timerOffset > 0 then
						ATMEDatas.newCreatedGroups[_name].timerOffset = ATMEDatas.newCreatedGroups[_name].timerOffset - 1
					end
				else
					ATMEDatas.newCreatedGroups[_name] = nil
				end
			end

			-- On fige les événements qui vont être générés et émis aux handlers.
			-- On bascule activeEvents sur le nouveau pour prendre en compte au prochain coup les événements
			-- éventuellement générés par ces mêmes handlers (OnTimer)
			local fixedEvents = activeEvents
			activeEvents = 1 - activeEvents
			
			ATMEFct.outputCore(nil, "Gestion des Handlers par module", 2)
			-- Déclenchement des handlers
			for _, _localModuleMembers in ATMEDatas.C_Module_MT:pairs() do
				local eventsMgr = ATMEFct.C_EventsMgr_Create()
				
				-- Gestion des handlers des events de déclenchement d'alarme.
				for _name, _alarm in pairs(_localModuleMembers.alarms) do
					local localMembers = ATMEDatas.C_Alarm_MT:get(_alarm:getIndex())
					local flagValue = _alarm:getFlag()
					if flagValue ~= nil then
						if flagValue > 0 and localMembers.armed == false then
							if localMembers.isRelative == true then
								localMembers.timeStart = localMembers.initialTimeStart + currentTipsCount
							end
							
							localMembers.armed = true
							ATMEFct.outputCore(nil, "Module " .. _localModuleMembers.name .. " - Alarme " .. _alarm:getName() .. " armée sur flag on (timeStart = " .. localMembers.timeStart .. ")" , 2)
						elseif flagValue == 0 and localMembers.armed == true then
							localMembers.armed = false
							ATMEFct.outputCore(nil, "Module " .. _localModuleMembers.name .. " - Alarme " .. _alarm:getName() .. " désarmée sur flag off" , 2)
						end
						
						if localMembers.armed == false and localMembers.isRelative == false and localMembers.timeStart <= currentTipsCount then
							C_Alarm_delete(_localModuleMembers.alarms, _name)
						end
					end
					
					if localMembers.armed == true and localMembers.timeStart <= currentTipsCount then 
						ATMEFct.outputCore(nil,"Module " .. _localModuleMembers.name .. " - Alarme " .. _alarm:getName() .. " déclenché" , 2)
						
						if localMembers.maxTriggerings > 0 or localMembers.maxTriggerings == -1 then
							if localMembers.maxTriggerings > 0 then
								localMembers.maxTriggerings = localMembers.maxTriggerings - 1
							end
							
							if localMembers.eventCallback ~= nil then
								ATMEFct.outputCore(nil,"Appel handler de l'alarme " .. _name .. " pour le module " .. _localModuleMembers.name, 2)
								xpcall(function() localMembers.eventCallback(_alarm) end, function() ATMEFct.errUserHandler('alarmEventCallbackHandler') end)
								
								if localMembers.restarted == false or localMembers.maxTriggerings == 0 then
									if localMembers.maxTriggerings == 0 then
										if localMembers.maxTriggeringsCallback ~= nil then
											ATMEFct.outputCore(nil,"Appel handler maxTriggerings de l'alarme " .. _name .. " pour le module " .. _localModuleMembers.name, 2)
											xpcall(function() localMembers.maxTriggeringsCallback(_alarm) end, function() ATMEFct.errUserHandler('maxTriggeringsCallbackHandler') end)
										end
									end
									
									if localMembers.restarted == false then
										C_Alarm_delete(_localModuleMembers.alarms, _name)
									end
								end
								
								if localMembers.restarted == true then
									localMembers.restarted = false
								end
							else 
								ATMEFct.C_EventsMgr_addAlarmEvent(eventsMgr, _alarm)
								localMembers.inEventsMgr = true
							end
						end
					end
				end
				
				-- Gestion des handlers des events core
				for _id, _coreEvent in events[fixedEvents]:pairs() do
					local localCoreEventMembers = ATMEDatas.C_CoreEvent_MT:get(_coreEvent:getIndex())
					
					if localCoreEventMembers.delay == 0 then
						-- groupEventTypes contient les Core event liés au groupe
						if ATMEConst.groupEventTypes[localCoreEventMembers.type] == nil then
							local name = localCoreEventMembers.datas.unitName
							
							if _localModuleMembers.userAIUnitsAndPlayersCallbacks[name] ~= nil then
								ATMEFct.outputCore(nil,"Appel coreEvent handler de l'unité " .. name .. " pour le module " .. _localModuleMembers.name, 2)
								xpcall(function() _localModuleMembers.userAIUnitsAndPlayersCallbacks[name](_coreEvent) end, function() ATMEFct.errUserHandler('coreEventCallbackHandler') end)
							else
								ATMEFct.C_EventsMgr_addCoreEvent(eventsMgr, _coreEvent)
							end
						else
							local name = localCoreEventMembers.datas.groupName
				
							if _localModuleMembers.userGroupsCallbacks[name] ~= nil then
								ATMEFct.outputCore(nil,"Appel coreEvent handler du groupe " .. name .. " pour le module " .. _localModuleMembers.name, 2)
								xpcall(function() _localModuleMembers.userGroupsCallbacks[name](_coreEvent) end, function() ATMEFct.errUserHandler('coreEventCallbackHandler') end)
							else
								ATMEFct.C_EventsMgr_addCoreEvent(eventsMgr, _coreEvent)
							end
						end
					end
				end
				
				if _localModuleMembers.handlers.onTimerHandler ~= nil then
					ATMEFct.outputCore(nil,"Appel onTimerHandler du module " .. _localModuleMembers.name , 2)
					xpcall(function() _localModuleMembers.handlers.onTimerHandler(eventsMgr) end, function() ATMEFct.errUserHandler('onTimerHandler') end)
				end
				
				for _name, _alarm in pairs(_localModuleMembers.alarms) do
					local localMembers = ATMEDatas.C_Alarm_MT:get(_alarm:getIndex())
					if localMembers.inEventsMgr == true then
						if localMembers.restarted == false or localMembers.maxTriggerings == 0 then
							if localMembers.maxTriggerings == 0 then
								if localMembers.maxTriggeringsCallback ~= nil then
									ATMEFct.outputCore(nil,"Appel handler maxTriggerings de l'alarme " .. _name .. " pour le module " .. _localModuleMembers.name, 2)
									xpcall(function() localMembers.maxTriggeringsCallback(_alarm) end, function() ATMEFct.errUserHandler('maxTriggeringsCallbackHandler') end)
								end
							end
							
							if localMembers.restarted == false then
								C_Alarm_delete(_localModuleMembers.alarms, _name)
							end
						end
						
						if localMembers.restarted == true then
							localMembers.restarted = false
						end
					end
					
					localMembers.inEventsMgr = false
				end
				
				-- OnCreateGroup si le groupe est créé sinon on attend le prochain cycle
				-- OnSpawnGroup est appelé juste après si le groupe créé a été spawné.
				for _name, _newCreatedGroup in pairs(ATMEDatas.newCreatedGroups) do
					if _newCreatedGroup.timerOffset == 0 then
						if _localModuleMembers.handlers.onCreateGroupHandler ~= nil then
							-- Appel du module
							ATMEFct.outputCore(nil,"Appel onCreateGroupHandler du module " .. _localModuleMembers.name, 2)
							xpcall(function() _localModuleMembers.handlers.onCreateGroupHandler(ATMEDatas.groups[_name], ATMEDatas.groupsAlreadyDeleted[_name]) end, function() ATMEFct.errUserHandler('onCreateGroupHandler') end)
						end
						
						if _newCreatedGroup.isSpawned == true then
							if _localModuleMembers.handlers.onSpawnGroupHandler ~= nil then
								-- Appel du module
								ATMEFct.outputCore(nil,"Appel onSpawnGroupHandler du module " .. _localModuleMembers.name, 2)
								xpcall(function() _localModuleMembers.handlers.onSpawnGroupHandler(ATMEDatas.groups[_name]) end, function() ATMEFct.errUserHandler('onSpawnGroupHandler') end)
							end
						end
					end
				end
				
				-- OnUpdatePlayer
				for _, _player in pairs(ATMEDatas.players) do
					if _localModuleMembers.handlers.onUpdatePlayerHandler ~= nil then
						-- Appel du module
						ATMEFct.outputCore(nil,"Appel onUpdatePlayerHandler du module " .. _localModuleMembers.name, 2)
						xpcall(function() _localModuleMembers.handlers.onUpdatePlayerHandler(_player) end, function() ATMEFct.errUserHandler('onUpdatePlayerHandler') end)
					end
				end
				
				-- Nettoyage de l'instance eventMgr
				ATMEDatas.C_EventsMgr_MT:remove(eventsMgr:getIndex())
				eventsMgr = nil
			end
			
			ATMEFct.outputCore(nil, "Groupes en attente de création -> Suppression si delai 0", 2)
			-- Pour les groupes créés et/ou spawnés en attente, on enlève ceux à 0
			for _name, _ in pairs(ATMEDatas.newCreatedGroups) do
				if ATMEDatas.newCreatedGroups[_name].timerOffset == 0 then
					ATMEDatas.newCreatedGroups[_name] = nil
				end
			end
			
			ATMEFct.outputCore(nil,"Finalisation de traitement Core event avec délai", 2)
			-- Fin de traitement des Core event pour ce cycle de timer.
			-- On reporte les core events avec délai.
			for _id, _coreEvent in events[fixedEvents]:pairs() do
				local localCoreEventMembers = ATMEDatas.C_CoreEvent_MT:get(_coreEvent:getIndex())
				
				if localCoreEventMembers.delay > 0 then
					localCoreEventMembers.delay = localCoreEventMembers.delay - 1
					events[activeEvents]:add(_coreEvent)
				end
			end
			
			ATMEFct.C_CoreEvent_removeAll(fixedEvents)
			
			ATMEFct.outputCore(nil,"Traitement des patrouilles", 2)
			-- Traitement des patrouilles
			for _id, _patrol in ATMEDatas.patrolsToUpdate:pairs() do
				local group = ATME.C_Group.getByName(_patrol.name)

				if group ~= nil then
					local localMembers = ATMEDatas.C_Group_MT:get(group:getIndex())
					local idCommand
					
					if group:getCategoryName() == "GROUND" or group:getCategoryName() == "SHIP" then
						idCommand = 'GoToWaypoint'
					else
						idCommand = 'SwitchWaypoint'
					end
					
					if localMembers.patrolWP.isArmed == true then
						local controller = group:getDCSGroup():getController()
						local command = {
							id = idCommand, 
							params = { 
								fromWaypointIndex = localMembers.patrolWP.last,  
								goToWaypointIndex = localMembers.patrolWP.restart, 
							}, 
						}
						
						controller:setCommand(command)
						
						localMembers.patrolWP.isArmed = false
					end
				else
					ATMEDatas.patrolsToUpdate:remove(_id)
				end
			end
			
			-- Délai d'attente pour déclarer les initialisations OK : Actuellement 2 secondes pour considérer les groupes créés
			if startOk == false then
				startOffset = startOffset + 1
				if startOffset == 3 then
					for _, _localModuleMembers in ATMEDatas.C_Module_MT:pairs() do
						if _localModuleMembers.handlers.onModuleStartHandler ~= nil then
							-- Appel du module
							ATMEFct.outputCore(nil,"Appel onModuleStartHandler après initialisation des unités & joueurs du module " .. _localModuleMembers.name, 2)
							xpcall(function() _localModuleMembers.handlers.onModuleStartHandler(true) end, function() ATMEFct.errUserHandler('onModuleStartHandler') end)
						end
					end
					
					startOk = true
				end
			end
			
			ATMEFct.outputCore(nil,"End main timer", 2)
			timer.scheduleFunction(_timerMainFunction, {}, timer.getTime() + 1)
		end
	end

	----------------------------------------------------------------------------------------------------------
	-- Fonction _timer10x est appelée à l'initialisation voir plus bas puis réarmée tous les 1/10è de seconde.
	-- Permet un suivi plus fin pour certaines fonctionalités comme le tracking laser ou IR
	----------------------------------------------------------------------------------------------------------
	local _timer10x
	_timer10x = function()
	
		if ATMEDatas.exitATME == false then
			-- Suppression des spots actifs pour les unités AI au sol qui se mettent à bouger
			-- Tracking si pointeur sur objet dynamique
							
			for _name, _spot in pairs(ATMEDatas.spots) do
				if ATMEDatas.AIUnits[_name] ~= nil then
					if _spot.fromAir == false and ATMEDatas.AIUnits[_name]:getSpeed() > 0 then
						-- L'unité au sol (JTAC) se déplace, arrêt du spot
						
						_spot.spot:destroy()
						ATMEDatas.spots[_name] = nil
						ATMEDatas.spotsToReassign[_name] = nil
						
						local event = {
							type = "SPOT_STOP_UNIT_MOVE",
							datas = {
								unitName = _name,
							},
						}
						ATMEFct.outputCore(nil, "Spot par unité " .. _name .. " : Arrêt cause déplacement", 2)		
						ATMEFct.C_CoreEvent_add(event)
					else
						if _spot.spot == nil and ATMEDatas.spotsToReassign[_name] == nil then -- Pas de spot actif
							ATMEDatas.spotsToReassign[_name] = {
								delay = 1,
								reassign = false,
							}
						elseif _spot.spot ~= nil then -- Un spot est actif
							if ATMEDatas.allAIUnitsAndPlayers[_spot.targetName] ~= nil and _spot.ignoredTargetOn == false then
								local posUnit = ATMEDatas.AIUnits[_name]:getPosition()
								local point = ATMEDatas.allAIUnitsAndPlayers[_spot.targetName]:getPosition()
								
								if (_spot.fromAir == false and land.isVisible({x = posUnit.x, y = posUnit.y + 2, z = posUnit.z} , {x = point.x, y = point.y + 2, z = point.z}) == false) or 
								   (_spot.fromAir == true and land.isVisible({x = posUnit.x, y = posUnit.y - 2, z = posUnit.z}  , {x = point.x, y = point.y + 2, z = point.z}) == false) then
									_spot.noLOS = _spot.noLOS + 1
								else
									_spot.neverHaveLOS = false
									_spot.noLOS = 0
									_spot.ignoredTargets[_spot.targetName] = nil
								end
								
								if _spot.noLOS == 50 then -- Pas de ligne de visée pendant 5 secondes. Abandon
									_spot.spot:destroy()
									_spot.spot = nil
									ATMEDatas.spotsToReassign[_name] = {
										delay = 1,
										groupName = _spot.groupName,
										zone = _spot.zone,
										reassign = true,
										noLOS = true, 
										neverHaveLOS = _spot.neverHaveLOS,
									}
									_spot.ignoredTargets[_spot.targetName] = true
								elseif _spot.dynamicSpot == true and (ATMEDatas.allAIUnitsAndPlayers[_spot.targetName]:getSpeed() > 0 or _spot.fromAir == true) then							
									if _spot.zone == nil or 
										(_spot.zone ~= nil and ATMEFct.C_Group_Unit_isInZone2D(ATMEDatas.allAIUnitsAndPlayers[_spot.targetName], _spot.zone) == true) then
										-- La cible existe et elle est dynamique... Le spot suit la cible.
										
										_spot.vector =  ATMEFct.C_Vector3D_create(nil, nil, posUnit, point)
										_spot.spot:setPoint(point)
									else -- La cible est sortie de la zone de surveillance
										_spot.spot:destroy()
										_spot.spot = nil
										ATMEDatas.spotsToReassign[_name] = {
											delay = 1,
											zone = _spot.zone,
											outOfZone = true,
											reassign = true,
										}
									end
								end
							else -- La cible n'existe plus
								_spot.spot:destroy()
								_spot.spot = nil
								
								ATMEDatas.spotsToReassign[_name] = {
									delay = 1,
									groupName = _spot.groupName,
									zone = _spot.zone,
									reassign = true,
								}
							end
						end
					end
				end
			end
			
			-- Contrôle des radiosTransmissions 
			local transmissionsToActivate = {}
			for _index, _radioTransmission in ATMEDatas.activatedRadioTransmissions:pairs() do
				local lockedRadioFrequency = ATMEDatas.lockedRadioFrequencies[_radioTransmission.idFrequency]
				
				if lockedRadioFrequency == nil or lockedRadioFrequency.radioTransmissionEntry == _radioTransmission.entry then
					if _radioTransmission.timeToUnlock == nil then
						if _radioTransmission.tips10 == 0 then
							local lockedRadioFrequency = ATMEDatas.lockedRadioFrequencies[_radioTransmission.idFrequency]
							local toRemove = false

							if #_radioTransmission.playlist > 0 and _radioTransmission.replay == true then
								if _radioTransmission.randomRead == true then 
									_radioTransmission.currentReadIndex = math.random(1, #_radioTransmission.playlist)
								end
								
								if _radioTransmission.unitName == nil then
									ATMEFct.stopDCSRadioTransmission(_radioTransmission)
									ATMEFct.startDCSRadioTransmission(_radioTransmission)
									ATMEFct.outputCore(nil, "Boucle activatedRadioTransmissions ATME  " .. _radioTransmission.playlist[_radioTransmission.currentReadIndex].fileName, 2)
									
									if _radioTransmission.autoRestartDCS == false then
										_radioTransmission.tips10 = _radioTransmission.playlist[_radioTransmission.currentReadIndex].tips10
										if _radioTransmission.tips10 < 9 then
											_radioTransmission.tips10 = 9
										end
										ATMEFct.outputCore(nil, "Boucle activatedRadioTransmissions ATME  " .._radioTransmission.tips10, 2)
									else
										_radioTransmission.tips10 = 0
									end
								else
									if ATMEDatas.AIUnits[_radioTransmission.unitName] ~= nil then
										ATMEFct.outputCore(nil, "Boucle activatedRadioTransmissions " .. _radioTransmission.unitName .. " " .. _radioTransmission.playlist[_radioTransmission.currentReadIndex].fileName, 2)
										ATMEFct.C_AIUnit_stopTransmission(_radioTransmission)
										ATMEFct.C_AIUnit_startTransmission(_radioTransmission)
										if _radioTransmission.autoRestartDCS == false then
											_radioTransmission.tips10 = _radioTransmission.playlist[_radioTransmission.currentReadIndex].tips10
										else
											_radioTransmission.tips10 = 0
										end
									else
										toRemove = true
									end
								end
								
								if _radioTransmission.readOnce == true then
									if _radioTransmission.autoRestartDCS == true then
										-- Contournement du bug DCS à l'entrée joueur pour les transmissions Loop
										_radioTransmission.replay = false
									else
										_radioTransmission.currentReadIndex = _radioTransmission.currentReadIndex + 1
										if _radioTransmission.currentReadIndex > #_radioTransmission.playlist then
											
											toRemove = true
										end
									end
								else
									if _radioTransmission.randomRead == false then
										_radioTransmission.currentReadIndex = _radioTransmission.currentReadIndex + 1
										if _radioTransmission.currentReadIndex > #_radioTransmission.playlist then
											_radioTransmission.currentReadIndex = 1
										end
									end
								end
							else
								if _radioTransmission.unitName == nil then
									if _radioTransmission.autoRestartDCS == false then
										ATMEFct.stopDCSRadioTransmission(_radioTransmission)
										toRemove = true
									end
								else
									if _radioTransmission.autoRestartDCS == false then
										ATMEFct.C_AIUnit_stopTransmission(_radioTransmission)
										toRemove = true
									end
								end
							end
							
							if toRemove == true then
								ATMEFct.outputCore(nil, "Boucle activatedRadioTransmissions to remove", 2) 
								if lockedRadioFrequency ~= nil then
									if #lockedRadioFrequency.bufferedRadioTransmissions > 0 then 
										-- S'il a y des radios transmission en attente, pause entre deux transmissions sur la meme fréquence
										_radioTransmission.timeToUnlock = math.random(5, 15)
										ATMEFct.outputCore(nil, "Boucle activatedRadioTransmissions next", 2) 
									else
										ATMEFct.outputCore(nil, "Boucle activatedRadioTransmissions unlock", 2) 
										ATMEDatas.lockedRadioFrequencies[_radioTransmission.idFrequency] = nil
										ATMEDatas.activatedRadioTransmissions:remove(_index)
									end
								else
									ATMEFct.outputCore(nil, "Boucle activatedRadioTransmissions no lock actif", 2) 
									ATMEDatas.activatedRadioTransmissions:remove(_index)
								end
							end
						end
						
						_radioTransmission.tips10 = _radioTransmission.tips10 - 1
					else
						_radioTransmission.timeToUnlock = _radioTransmission.timeToUnlock - 1
						
						if _radioTransmission.timeToUnlock == 0 then
							-- Fin de pause entre deux transmission - Une transmission mémorisée est prête à être activée
							
							ATMEDatas.activatedRadioTransmissions:remove(_index)
							
							local extraDatas
							local found = false
							while #lockedRadioFrequency.bufferedRadioTransmissions > 0 and found == false do		
								extraDatas = table.remove(lockedRadioFrequency.bufferedRadioTransmissions, 1)
								found = extraDatas.locked
							end
							
							if extraDatas ~= nil then
								table.insert(transmissionsToActivate, extraDatas)
							end
						end
					end
				end
			end
			
			-- Activation des radio transmissions prêtes
			for _, _extraDatas in ipairs(transmissionsToActivate) do
				if _extraDatas.unitName ~= nil then
					local localMembers = ATMEDatas.C_AIUnit_MT:get(ATMEDatas.AIUnits[_extraDatas.unitName]:getIndex())
					local newRadioTransmission = ATMEFct.initDCSRadioTransmission(_extraDatas)
					ATMEFct.outputCore(nil, "Activation transmission en attente pour l'unité " .. _extraDatas.unitName, 2) 
					localMembers.radioTransmissionID = newRadioTransmission.entry
				else
					local newRadioTransmission = ATMEFct.initDCSRadioTransmission(_extraDatas)
					ATMEDatas.radioFrequencyId[idFrequency] = newRadioTransmission.entry
					ATMEFct.outputCore(nil, "Activation transmission lieu en attente", 2) 
				end
			end

			timer.scheduleFunction(_timer10x, {}, timer.getTime() + 0.1)
		end
	end
	
	----------------------------------------------------------------------------------------------------------
	-- Fonction _timer100x est appelée à l'initialisation voir plus bas puis réarmée tous les 1/100è de seconde.
	-- Cette fonction permet de mesurer les temps au 1/100è de seconde. Elle déclenche les events ATME :
	-- 	RACE_START : quand un joueur de la course franchit le départ
	--	RACE_TURN_TIME : quand un joueur boucle un tour par un nouveau franchissement de la ligne de départ,
	--					 pour les courses à plusieurs tours
	--	RACE_PLAYER_BEST_TURN_TIME : Meilleur temps au tour du joueur qui boucle son tour
	-- 	RACE_BEST_TURN_TIME : Record du tour pour la course depuis le début de la mission
	-- 	RACE_LAP_TIME : Temps intermédiaire pour le joueur franchissant une porte définie.
	--	RACE_BEST_LAP_TIME : Meilleur temps intermédiaire pour une porte définie depuis le début de la mission
	-- 	RACE_PLAYER_TOO_HIGH : Le joueur a dépassé l'altitude maximale autorisée
	--	RACE_FINAL_TIME : Temps final pour la course pour le joueur venant de franchir l'arrivée (dernière
	--					  porte de la course).
	--	RACE_PLAYER_BEST_FINAL_TIME : Meilleur temps final pour le joueur venant de franchir l'arrivée
	--	RACE_BEST_FINAL_TIME : Meilleur temps final depuis le début de la mission. Le classement général est
	--						   recalculé à partir de ce temps.
	--
	-- Le passage d'une porte est pris en compte que si la porte précédente a été passée (franchie ou loupée)
	--
	-- ATTENTION : Il y a un décallage de temps entre la création du cor event et l'activation vers les modules.
	-- 			   On ne stocke que le nom dde l'unité joueur. La vérification de l'existance de l'unité ne se 
	-- 			   fera que lors de l'activation de l'événement dans MainTimer.
	--			   En effet, l'unité peut être détruite entre temps.
	----------------------------------------------------------------------------------------------------------
	local _timer100x
	_timer100x = function()
		if ATMEDatas.exitATME == false then
			-- Fonction des mises à jour de la liste des joueurs ... 
			-- Important pour éviter les incohérences, les timers étant asynchrones
			
			local currentTime = timer.getTime()
			for _, _race in pairs(ATMEDatas.races) do
				local localMembers = ATMEDatas.C_Race_MT:get(_race:getIndex())
				local maxAltitude = _race:getMaxAltitude()
				for _rowBestPlayer, _item in ipairs(localMembers.bestPlayers) do
					local racePlayer = localMembers.players[_item.player:getName()]
					
					local playerPosition = racePlayer.player:getPosition()
				
					local okSegment, side = ATMEFct.C_MultiSegment2D_intersect(localMembers.doorsIndex[_race:getDoorIndex(racePlayer.nextDoor)].segment, racePlayer.oldPosition, playerPosition)

					if okSegment == true and side == -1 then
						-- Porte franchie
						-- ATMEFct.outputCore(nil, "Porte franchie", 2)
						if racePlayer.nextDoor == 1 and racePlayer.currentTurn == 1 then
							if racePlayer.player:getAGLAltitude() <= maxAltitude or maxAltitude == -1 then
							-- Franchissement de la ligne de départ
							
							racePlayer.startTime = currentTime
							racePlayer.startTurnTime = currentTime
							racePlayer.penalty = 0
							
							ATMEFct.C_Race_createEvent(_race, 
								"RACE_START", 
								{
									unitName = racePlayer.player:getName(),
								})
							else
								racePlayer.nextDoor = 0
							end
						elseif racePlayer.player:getAGLAltitude() > maxAltitude and maxAltitude ~= -1 then
							-- Test de l'altitude si on est en course (nextDoors <> 1 ou currentTurn <> 1)

							racePlayer.penalty = racePlayer.penalty + _race:getMaxAltitudePenalty()

							ATMEFct.C_Race_createEvent(_race, 
								"RACE_PLAYER_TOO_HIGH",
								{
									unitName = racePlayer.player:getName(),
									penalty = racePlayer.penalty,
								})
						end
					
						local totalPlayTime = currentTime - racePlayer.startTime + racePlayer.penalty
						
						if racePlayer.nextDoor == 1 and racePlayer.currentTurn > 1 then
							-- Franchissement de la ligne de départ et bouclage d'un tour
							local playTime = currentTime - racePlayer.startTurnTime + racePlayer.penalty
							ATMEFct.C_Race_createEvent(_race, 
									"RACE_TURN_TIME", 
									{
										unitName = racePlayer.player:getName(),
										playTime = playTime,
										totalPlayTime = totalPlayTime,
										penalty = racePlayer.penalty,
										turnNumber = racePlayer.currentTurn - 1,
									})
							
							if playTime < racePlayer.bestTurnTime or racePlayer.bestTurnTime < 0 then
								racePlayer.bestTurnTime = playTime
								ATMEFct.C_Race_createEvent(_race, 
									"RACE_PLAYER_BEST_TURN_TIME",
									{
										unitName = racePlayer.player:getName(),
										playTime = playTime,
										turnNumber = racePlayer.currentTurn - 1
									})
							end
							
							if playTime < localMembers.bestTurn.bestTime or localMembers.bestTurn.bestTime < 0 then
								localMembers.bestTurn.bestTime = playTime
								localMembers.bestTurn.pseudo = racePlayer.player:getPseudo()
								ATMEFct.C_Race_createEvent(_race, 
									"RACE_BEST_TURN_TIME",
									{
										unitName = racePlayer.player:getName(),
										playTime = playTime,
										turnNumber = racePlayer.currentTurn - 1
									})
							end

							racePlayer.startTurnTime = currentTime + racePlayer.penalty
						elseif _race:getLapAtDoor(_race:getDoorIndex(racePlayer.nextDoor)) == true then
							-- Portes avec temps intermédiaire
							local door = localMembers.doorsIndex[_race:getDoorIndex(racePlayer.nextDoor)]
							local playTime = currentTime - racePlayer.startTurnTime + racePlayer.penalty
							
							ATMEFct.C_Race_createEvent(_race, 
								"RACE_LAP_TIME", 
								{
									unitName = racePlayer.player:getName(),
									doorNumber = racePlayer.nextDoor,
									playTime = playTime,
									totalPlayTime = totalPlayTime,
									penalty = racePlayer.penalty,
									turnNumber = racePlayer.currentTurn - 1																		
								})
								
							if playTime < door.bestTurn.bestTime or door.bestTurn.bestTime < 0 then
								door.bestTurn.bestTime = playTime
								door.bestTurn.pseudo = racePlayer.player:getPseudo()
								ATMEFct.C_Race_createEvent(_race, 
									"RACE_BEST_LAP_TIME", 
									{
										unitName = racePlayer.player:getName(),
										doorNumber = racePlayer.nextDoor,
										playTime = playTime, 
										turnNumber = racePlayer.currentTurn - 1
									})
							end
						elseif racePlayer.nextDoor == _race:getNbDoors() then
							-- Franchissement de la ligne d'arrivée
							racePlayer.nextDoor = 0
							
							if racePlayer.currentTurn == _race:getNbTurns() then
								if totalPlayTime < racePlayer.bestTime or racePlayer.bestTime < 0 then
										racePlayer.bestTime = totalPlayTime
										ATMEFct.C_Race_createEvent(_race, 
											"RACE_PLAYER_BEST_FINAL_TIME", 
											{
												unitName = racePlayer.player:getName(),
												totalPlayTime = totalPlayTime,
											})
								end
								
								if totalPlayTime < _item.bestTime or _item.bestTime < 0 then
									_item.bestTime = totalPlayTime
									_item.recordTime = currentTime
									
									ATMEFct.C_Race_createEvent(_race, 
										"RACE_BEST_FINAL_TIME",
										{
											unitName = racePlayer.player:getName(),
											totalPlayTime = totalPlayTime, 
										})
								end
								
								ATMEFct.C_Race_createEvent(_race, 
									"RACE_FINAL_TIME", 
									{
										unitName = racePlayer.player:getName(),
										totalPlayTime = totalPlayTime,
										penalty = racePlayer.penalty,
									})
								
								racePlayer.currentTurn = 0
							end
							
							racePlayer.currentTurn = racePlayer.currentTurn + 1
						end
						
						racePlayer.nextDoor = racePlayer.nextDoor + 1
					end
					
					racePlayer.oldPosition = playerPosition
				end
				
				table.sort(localMembers.bestPlayers, 
								function(a, b)
									if a.bestTime >= 0 and b.bestTime >= 0 and a.bestTime ~= b.bestTime then
										return a.bestTime < b.bestTime
									elseif a.bestTime < 0 and b.bestTime >= 0 then
										return false
									elseif a.bestTime >=0 and b.bestTime < 0 then
										return true
									else
										return a.recordTime < b.recordTime
									end
								end)
			end
			-- DEBUG ATMEFct.outputCore(nil, "Current time = " .. currentTime, 1)
			-- DEBUG Penser à baisser la fréquence si activation affichage
			timer.scheduleFunction(_timer100x, {}, timer.getTime() + 0.01)
		end
	end
	
	
	----------------------------------------------------------------------------------------------------------
	-- Fonction gestion événements DCS ... essentielle ... appelée si l'événement se produit
	-- En l'état ne gère pas tous les événements mais uniquement ceux nécessaires
	----------------------------------------------------------------------------------------------------------	
	function customEventHandler:onEvent(_event)
		if ATMEDatas.exitATME == true then
			world.removeEventHandler(customEventHandler)
		else
			ATMEFct.outputCore(nil,"Event " .. _event.id .. " déclenché", 2)
			if _event.initiator ~= nil then
				if world.event.S_EVENT_BIRTH == _event.id then
					-- Si une unité est spawnée en cours de mission, on passe ici
					-- Valable aussi si c'est un joueur qui arrive ou change de slot après le début de mission
					
					local unitName = _event.initiator:getName()
					
					if ATMEDatas.allPlayerUnitsInMission[unitName] ~= nil then -- Player unit
						if ATMEDatas.players[unitName] ~= nil then
							ATMEFct.C_Player_delete(ATMEDatas.players[unitName])
						end
						ATMEDatas.newPlayer = true
						ATMEFct.C_Player_create(_event.initiator, ATMEDatas.allPlayerUnitsInMission[unitName].datas)
						ATMEFct.outputCore(nil,"Player " .. unitName .. " créé", 2)
					elseif StaticObject.getByName(unitName) ~= nil then
						if unitName ~= "static" then -- Bug DCS certains objets spawnés ont toujours leur nom à 'static'.
							if ATMEDatas.staticObjects[unitName] ~= nil then
								ATMEFct.C_StaticObject_delete(ATMEDatas.staticObjects[unitName])
							end
							
							ATMEFct.C_StaticObject_create(_event.initiator)
							ATMEFct.outputCore(nil,"StaticObject " .. unitName .. " créé", 2)
						else
							ATMEFct.outputCore(nil,"StaticObject spwané avec un nom valant 'static' - Ignoré par ATME", 2)
						end
					elseif ATMEDatas.allAIUnitsInMission[unitName] ~= nil and ATMEDatas.allAIUnitsInMission[unitName].datas ~= nil then
						-- Unités liées à un groupe avec joueurs. Apparaissent au changement de slot.
						ATMEFct.C_AIUnit_create(_event.initiator, ATMEDatas.allAIUnitsInMission[unitName].datas)
						ATMEFct.outputCore(nil,"Unit " .. unitName .. " créé & associée à un groupe avec joueur", 2)
					else
						local unit = ATME.C_AIUnit.getByName(unitName)
						local isLateActivation = false
						if unit ~= nil then
							-- On verifie s'il ne s'agit pas d'une unité dont le groupe est à activation retardée
							local group = unit:getGroup()
							local groupLocalMembers = ATMEDatas.C_Group_MT:get(group:getIndex())
							
							if groupLocalMembers.isEnabled == true then
								ATMEFct.C_AIUnit_delete(unit)
							else   -- Groupe à activation retardée
								groupLocalMembers.nbUnitsToEnable = groupLocalMembers.nbUnitsToEnable - 1
								isLateActivation = true
								
								if groupLocalMembers.nbUnitsToEnable == 0 then
									groupLocalMembers.isEnabled = true
									ATMEFct.outputCore(nil,"Activation du groupe " .. group:getName(), 2)
								end
							end
						end
						
						-- ATTENTION deux cas :
						-- 	1*	L'événement S_EVENT_BIRTH survient pendant l'appel de la fonction addgroup
						--		pour les unités au sol et en mer ou lors de l'activation retardée d'une unité.
						-- 		Les groupes à activation retardées n'ont pas à être traités car initialisés
						--		lors du démarrage d'ATME. Parfois le groupe n'est pas encore initialisé 
						-- 		pendant l'appel de la fonction addgroup. Aussi, dans ce cas, le traitement
						-- 		se fait juste après la fonction addgroup et dans ce cas, l'uité créée est
						--		mémorisée dans ATMEDatas.unitsReadyToCreate.
						--	2*	L'événement survient après le spawn pour les groupes d'aéronefs. Dans ce cas,
						--		l'unité est mémrorisée dans ATMEDatas.groupsReadyToBirth après la fonction
						--		addgroup. Le traitement se fait alors ici, lors de la création physique desactivateSpot
						--		unités du groupe.
						
						local found = false
						
						for _name, _group in pairs(ATMEDatas.groupsReadyToBirth) do
							-- Traitement du cas 1
							
							if _group.units[unitName] ~= nil then
								local datas = {
									idStart = _group.idStart,
									uncontrolled = _group.uncontrolled,
									visible = _group.visible,
									spawnDatas = _group.spawnDatas,
								}
								ATMEFct.C_AIUnit_create(_event.initiator, datas)
								found = true
							end
							
							_group.units[unitName] = nil
							_group.nbUnits = _group.nbUnits - 1
							
							if _group.nbUnits == 0 then
								ATMEDatas.groupsReadyToBirth[_name] = nil
								ATMEDatas.newCreatedGroups[_name].isSpawned = true
							end
						end

						if found == false and isLateActivation == false then
							-- Si found vaut false, alors on est dans le cas 2

							table.insert(ATMEDatas.unitsReadyToCreate, _event.initiator)
						end
					end
				elseif world.event.S_EVENT_PLAYER_LEAVE_UNIT == _event.id  then
					local unitName = _event.initiator:getName()
					
					if ATMEDatas.players[unitName] ~= nil then
						ATMEFct.C_Player_delete(ATMEDatas.players[unitName])
						ATMEFct.outputCore(nil,"Player " .. unitName .. "Abandon pour changement de slot", 2)
					end
				elseif world.event.S_EVENT_DEAD == _event.id or world.event.S_EVENT_CRASH == _event.id then
					if _event.initiator ~= nil then
						local unitName = _event.initiator:getName()
						
						if world.event.S_EVENT_DEAD == _event.id then
							if ATMEDatas.AIUnits[unitName] ~= nil then
								local localMembers = ATMEDatas.C_AIUnit_MT:get(ATMEDatas.AIUnits[unitName]:getIndex())
								localMembers.pilotDead = true
								ATMEFct.outputCore(nil,"AIUnit " .. unitName .. " pilote mort", 2)
							elseif ATMEDatas.players[unitName] ~= nil then
								local localMembers = ATMEDatas.C_Player_MT:get(ATMEDatas.players[unitName]:getIndex())
								localMembers.pilotDead = true
								ATMEFct.outputCore(nil,"Player " .. unitName .. " pilote mort", 2)
							end
						end
						
						if type(unitName) =="string" then -- Pour les objets statiques des maps, le nom est un nombre
							if ATMEDatas.AIUnits[unitName] ~= nil then
								ATMEFct.C_AIUnit_delete(ATMEDatas.AIUnits[unitName])
								ATMEFct.outputCore(nil,"AIUnit " .. unitName .. " détruite", 2)
							elseif ATMEDatas.players[unitName] ~= nil then
								
								ATMEFct.C_Player_delete(ATMEDatas.players[unitName])
								ATMEFct.outputCore(nil,"Player " .. unitName .. " détruit", 2)
							elseif ATMEDatas.staticObjects[unitName] ~= nil then
								ATMEFct.C_StaticObject_delete(ATMEDatas.staticObjects[unitName])
								ATMEFct.outputCore(nil,"StaticUnit " .. unitName .. " détruite", 2)
							end
						end
					end
				elseif world.event.S_EVENT_PILOT_DEAD == _event.id then
					if _event.initiator ~= nil then
						local unitName = _event.initiator:getName()
						if ATMEDatas.AIUnits[unitName] ~= nil then
							local localMembers = ATMEDatas.C_AIUnit_MT:get(ATMEDatas.AIUnits[unitName]:getIndex())
							localMembers.pilotDead = true
							ATMEFct.outputCore(nil,"AIUnit " .. unitName .. " pilote mort", 2)
						elseif ATMEDatas.players[unitName] ~= nil then
							local localMembers = ATMEDatas.C_Player_MT:get(ATMEDatas.players[unitName]:getIndex())
							localMembers.pilotDead = true
							ATMEFct.outputCore(nil,"Player " .. unitName .. " pilote mort", 2)
						end
					end
				elseif world.event.S_EVENT_EJECTION == _event.id then
					if _event.initiator ~= nil then
						local unitName = _event.initiator:getName()
						if ATMEDatas.AIUnits[unitName] ~= nil then
							local localMembers = ATMEDatas.C_AIUnit_MT:get(ATMEDatas.AIUnits[unitName]:getIndex())
							localMembers.pilotEjected = true
							ATMEFct.outputCore(nil,"AIUnit " .. unitName .. " pilote éjecté", 2)
						elseif ATMEDatas.players[unitName] ~= nil then
							local localMembers = ATMEDatas.C_Player_MT:get(ATMEDatas.players[unitName]:getIndex())
							localMembers.pilotEjected = true
							ATMEFct.outputCore(nil,"Player " .. unitName .. " pilote éjecté", 2)
						end
					end
				elseif world.event.S_EVENT_TAKEOFF == _event.id then
					local unitName = _event.initiator:getName()
					if ATMEDatas.players[unitName] ~= nil then
						local player = ATMEDatas.players[unitName]

						for _, _localModuleMembers in ATMEDatas.C_Module_MT:pairs() do
							if _localModuleMembers.handlers.onTakeoffPlayerHandler ~= nil then
								-- Appel du module
								ATMEFct.outputCore(nil,"Appel onTakeoffPlayerHandler du module " .. _localModuleMembers.name, 2)
								xpcall(function() _localModuleMembers.handlers.onTakeoffPlayerHandler(ATMEDatas.players[unitName]) end, function() ATMEFct.errUserHandler('onTakeoffPlayerHandler') end)
							end
						end
						ATMEFct.outputCore(nil,"Player " .. unitName .. " décollage", 2)
					elseif ATMEDatas.AIUnits[unitName] ~= nil then
						for _, _localModuleMembers in ATMEDatas.C_Module_MT:pairs() do
							if _localModuleMembers.handlers.onTakeoffAIUnitHandler ~= nil then
								-- Appel du module
								ATMEFct.outputCore(nil,"Appel onTakeoffAIUnitHandler du module " .. _localModuleMembers.name, 2)
								xpcall(function() _localModuleMembers.handlers.onTakeoffAIUnitHandler(ATMEDatas.AIUnits[unitName]) end, function() ATMEFct.errUserHandler('onTakeoffAIUnitHandler') end)
							end
						end
						ATMEFct.outputCore(nil,"AIUnit " .. unitName .. " décollage", 2)
					end
				elseif world.event.S_EVENT_LAND == _event.id then
					local unitName = _event.initiator:getName()
					if ATMEDatas.players[unitName] ~= nil then
						for _, _localModuleMembers in ATMEDatas.C_Module_MT:pairs() do
							if _localModuleMembers.handlers.onLandingPlayerHandler ~= nil then
								-- Appel du module
								ATMEFct.outputCore(nil,"Appel onLandingPlayerHandler du module " .._localModuleMembers.name, 2)
								xpcall(function() _localModuleMembers.handlers.onLandingPlayerHandler(ATMEDatas.players[unitName]) end, function() ATMEFct.errUserHandler('onLandingPlayerHandler') end)
							end
						end
						ATMEFct.outputCore(nil,"Player " .. unitName .. " atterri", 2)
					elseif ATMEDatas.AIUnits[unitName] ~= nil then
						for _, _localModuleMembers in ATMEDatas.C_Module_MT:pairs() do
							if _localModuleMembers.handlers.onLandingAIUnitHandler ~= nil then
								-- Appel du module
								ATMEFct.outputCore(nil,"Appel onLandingAIUnitHandler du module " .. _localModuleMembers.name, 2)
								xpcall(function() _localModuleMembers.handlers.onLandingAIUnitHandler(ATMEDatas.AIUnits[unitName]) end, function() ATMEFct.errUserHandler('onLandingAIUnitHandler') end)
							end
						end
						
						ATMEFct.outputCore(nil,"AIUnit " .. unitName .. " atterri", 2)
					end
				elseif world.event.S_EVENT_ENGINE_STARTUP  == _event.id then
					local unitName = _event.initiator:getName()

					if ATMEDatas.players[unitName] ~= nil then
						-- BUG DCS en multi, cet événement n'est pas émis pour les clients qui viennent se connecter
						-- au serveur. Ok pour le client issu du serveur.
						
						for _, _localModuleMembers in ATMEDatas.C_Module_MT:pairs() do
							if _localModuleMembers.handlers.onStartEnginePlayerHandler ~= nil then
								-- Appel du module
								ATMEFct.outputCore(nil,"Appel onStartEnginePlayerHandler du module " .. _localModuleMembers.name, 2)
								xpcall(function() _localModuleMembers.handlers.onStartEnginePlayerHandler(ATMEDatas.players[unitName]) end, function() ATMEFct.errUserHandler('onStartEnginePlayerHandler') end)
							end
						end
						
						local localMembers = ATMEDatas.C_Player_MT:get(ATMEDatas.players[unitName]:getIndex())
						localMembers.engineOn = true
						ATMEFct.outputCore(nil,"Player " .. unitName .. " mise en route moteurs", 2)
					elseif ATMEDatas.AIUnits[unitName] ~= nil then
						for _, _localModuleMembers in ATMEDatas.C_Module_MT:pairs() do
							if _localModuleMembers.handlers.onStartEngineAIUnitHandler ~= nil then
								-- Appel du module
								ATMEFct.outputCore(nil,"Appel onStartEngineAIUnitHandler du module " .. _localModuleMembers.name, 2)
								xpcall(function() _localModuleMembers.handlers.onStartEngineAIUnitHandler(ATMEDatas.AIUnits[unitName]) end, function() ATMEFct.errUserHandler('onStartEngineAIUnitHandler') end)
								ATMEFct.outputCore(nil,"Retour onStartEngineAIUnitHandler du module " .. _localModuleMembers.name, 2)
							end
						end
						
						ATMEFct.outputCore(nil,"AIUnit " .. unitName .. " mise en route moteurs", 2)
					end
				elseif world.event.S_EVENT_ENGINE_SHUTDOWN == _event.id then
					local unitName = _event.initiator:getName()
					if ATMEDatas.players[unitName] ~= nil then
						for _, _localModuleMembers in ATMEDatas.C_Module_MT:pairs() do
							if _localModuleMembers.handlers.onStopEnginePlayerHandler ~= nil then
								-- Appel du module
								ATMEFct.outputCore(nil,"Appel onStopEnginePlayerHandler du module " .. _localModuleMembers.name, 2)
								xpcall(function() _localModuleMembers.handlers.onStopEnginePlayerHandler(ATMEDatas.players[unitName]) end, function() ATMEFct.errUserHandler('onStopEnginePlayerHandler') end)
							end
						end
						local localMembers = ATMEDatas.C_Player_MT:get(ATMEDatas.players[unitName]:getIndex())
						localMembers.engineOn = false
						
						ATMEFct.outputCore(nil,"Player " .. unitName .. " arrêt moteurs", 2)
					elseif ATMEDatas.AIUnits[unitName] ~= nil then
						for _, _localModuleMembers in ATMEDatas.C_Module_MT:pairs() do
							if _localModuleMembers.handlers.onStopEngineAIUnitHandler ~= nil then
								-- Appel du module
								ATMEFct.outputCore(nil,"Appel onStopEngineAIUnitHandler du module " .. _localModuleMembers.name, 2)
								xpcall(function() _localModuleMembers.handlers.onStopEngineAIUnitHandler(ATMEDatas.AIUnits[unitName]) end, function() ATMEFct.errUserHandler('onStopEngineAIUnitHandler') end)
							end
						end
						
						local group = ATMEDatas.AIUnits[unitName]:getGroup()
						
						group:resetAutoRespawn()
						local localMembers = ATMEDatas.C_Group_MT:get(group:getIndex())
						if group:isActivated() == true and group:isWaypointsTracking() == true and localMembers.endOfRoute == false then
							
							local pos = ATMEDatas.AIUnits[unitName]:getPosition()
							
							local event = {
								type = "TRACKING_LAST_WAYPOINT",
								datas = {
									groupName = group:getName(),
									point = {
										x = pos.x,
										y = pos.y,
										z = pos.z,
									},
								},
							}
							
							ATMEFct.C_CoreEvent_add(event)
							
							-- Le dernier waypoint est l'extinction moteur pour les aéronefs.
							-- Une extinction par unité mais un seul core event.
							localMembers.endOfRoute = true
						end
						
						ATMEFct.outputCore(nil,"AIUnit " .. unitName .. " arrêt moteurs", 2)
					end
				elseif world.event.S_EVENT_SHOT == _event.id then
					local event = {
						type = "WEAPON_SHOOT",
						datas = {
							unitName = _event.initiator:getName(),
							time = _event.time,
						},
					}

					ATMEFct.C_CoreEvent_add(event)
				elseif world.event.S_EVENT_SHOOTING_START == _event.id then
					if _event.target ~= nil then
						local event = {
							type = "SHOOTING_START",
							datas = {
								unitName = _event.initiator:getName(),
								targetName = _event.target:getName(),
								time = _event.time,
							},
						}
						
						ATMEFct.C_CoreEvent_add(event)
					end
				elseif world.event.S_EVENT_SHOOTING_END == _event.id then
					local event = {
						type = "SHOOTING_END",
						datas = {
							unitName = _event.initiator:getName(),
							time = _event.time,
						},
					}
					
					ATMEFct.C_CoreEvent_add(event)
				elseif world.event.S_EVENT_HIT == _event.id then
					if _event.target ~= nil then
						local event = {
							type = "HIT_TARGET",
							datas = {
								unitName = _event.initiator:getName(),
								time = _event.time,
								targetName = _event.target:getName(),
							},
						}
						
						ATMEFct.C_CoreEvent_add(event)
					end
				elseif world.event.S_EVENT_BASE_CAPTURED == _event.id then
					local unitName = _event.initiator:getName()
					if ATMEDatas.players[unitName] ~= nil then
						for _, _localModuleMembers in ATMEDatas.C_Module_MT:pairs() do
							if _localModuleMembers.handlers.onBaseCapturedHandler ~= nil then
								-- Appel du module
								local datas = {
									time = _event.time,
									airbase = _event.place,
									subPlace = _event.subPlace,
								}
								
								ATMEFct.outputCore(nil,"Appel onBaseCapturedPlayerHandler du module " .. _localModuleMembers.name, 2)
								
								xpcall(function() _localModuleMembers.handlers.onBaseCapturedPlayerHandler(ATMEDatas.players[unitName], datas) end, function() ATMEFct.errUserHandler('onBaseCapturedPlayerHandler') end)
							end
						end
						
						ATMEFct.outputCore(nil,"Player " .. unitName .. " capture de la base : " .. _event.place:getName(), 2)
					elseif ATMEDatas.AIUnits[unitName] ~= nil then
						for _, _localModuleMembers in ATMEDatas.C_Module_MT:pairs() do
							if _localModuleMembers.handlers.onBaseCapturedHandler ~= nil then
								-- Appel du module
								local datas = {
									time = _event.time,
									airbase = _event.place,
									subPlace = _event.subPlace,
								}
								
								ATMEFct.outputCore(nil,"Appel onBaseCapturedAIUnitHandler du module " .. _localModuleMembers.name, 2)
								
								xpcall(function() _localModuleMembers.handlers.onBaseCapturedAIUnitHandler(ATMEDatas.AIUnits[unitName], datas) end, function() ATMEFct.errUserHandler('onBaseCapturedAIUnitHandler') end)
							end
						end
						
						ATMEFct.outputCore(nil,"Unit " .. unitName .. " capture de la base : " .. _event.place:getName(), 2)
					end
					
				elseif world.event.S_EVENT_REFUELING == _event.id then
					local event = {
						type = "REFUELING",
						datas = {
							unitName = _event.initiator:getName(),
							time = _event.time,
						},
					}
					
					ATMEFct.C_CoreEvent_add(event)
				elseif world.event.S_EVENT_REFUELING_STOP == _event.id then
					local event = {
						type = "REFUELING_STOP",
						datas = {
							unitName = _event.initiator:getName(),
							time = _event.time,
						},
					}
					
					ATMEFct.C_CoreEvent_add(event)
				end
			else -- _event.initiator == nil
				if world.event.S_EVENT_MISSION_END == _event.id then
					ATMEFct.outputCore(nil, "Fin de Mission", 2)
					for _, _localModuleMembers in ATMEDatas.C_Module_MT:pairs() do
						if _localModuleMembers.handlers.onEndMissionHandler ~= nil then
							-- Appel du module
							
							ATMEFct.outputCore(nil,"Appel onEndMissionHandler du module " .. _localModuleMembers.name, 2)
							
							xpcall(function() _localModuleMembers.handlers.onEndMissionHandler() end, function() ATMEFct.errUserHandler('onEndMissionHandler') end)
						end
					end
				end
			end  
		end
	end
	
	----------------------------------------------------------------------------------------------------------
	-- Fonction d'initialisation des objets définis dans la mission
	-- Adapté de MIST - MIssion Scripting Tools
	-- Complétée par la recherche des FARP et AirFields nécessaires à la gestion des airbases.
	--¨Permet notamment de récupérer le groupId pour les joueurs en multijoueur, utilisé ensuite des les fonctions
	-- DCS associées (BUG DCS sur le Group.getId du groupe d'un joueur en multijoueur).
	----------------------------------------------------------------------------------------------------------
	local function initObjectsInMission()
		for _coalitionName, _coalitionDatas in pairs(env.mission.coalition) do
			if (_coalitionName == 'red' or _coalitionName == 'blue') and type(_coalitionDatas) == 'table' then
				if _coalitionDatas.country then
					for _country_id, _countryDatas in pairs(_coalitionDatas.country) do
						for _typeName, _datas in pairs(_countryDatas) do
							if _typeName == "helicopter" or _typeName == "ship" or _typeName == "plane" or _typeName == "vehicle" or _typeName == "static" then	
								local isStatic = _typeName == "static"
								for _, _groupDatas in pairs(_datas.group) do
									if _groupDatas ~= nil and _groupDatas.units ~= nil then
										local currentGroupName = env.getValueDictByKey(_groupDatas.name)
										local d,f = string.find(currentGroupName, "|", 1)
										
										if d == nil then
											d,f = string.find(currentGroupName:upper(), "%s+SPAWNED%s+", 1)
											if d == nil then
												if isStatic == false then
													local uncontrolled = _groupDatas.uncontrolled
													local visible
													
													if _typeName == "ship" or _typeName == "vehicle" then
														uncontrolled = false
														if _groupDatas.lateActivation == nil or _groupDatas.lateActivation == false then
															visible = true
														else
															visible = _groupDatas.visible
														end
													else
														visible = _groupDatas.lateActivation == false
													end
													
													ATMEDatas.allGroupsInMission[currentGroupName] = {
														name = currentGroupName,
														country = _countryDatas.id,
														coalition = string.upper(_coalitionName),
														groupId = _groupDatas.groupId,								-- Uniquement défini pour les groupes initiaux.
														category = ATMEConst.groupCategories[_typeName],
														type = _typeName,
														uncontrolled = uncontrolled,
														units = {},
														visible = visible,
														taskSelected = true,
														lateActivation = _groupDatas.lateActivation,
														hidden = _groupDatas.hidden,
														start_time = 0,
														task = _groupDatas.task,
														tasks = _groupDatas.tasks,
														radioSet = _groupDatas.radioSet,
														modulation = _groupDatas.modulation,
														frequency = _groupDatas.frequency,
														communication = _groupDatas.communication,
														waypoints = {},
													}
													
													ATMEDatas.allInitialGroupNames[currentGroupName] =  {
														groupName = currentGroupName,
														unitsName = {},
													}
													
													local firstPlayerFound = false
													
													for _key, _unitDatas in ipairs(_groupDatas.units) do
														local unitName = env.getValueDictByKey(_unitDatas.name)
														local d,f = string.find(unitName, "|", 1)
											
														if d == nil then
															d,f = string.find(unitName:upper(), "%s+SPAWNED%s+", 1)
															if d == nil then
																ATMEDatas.allGroupsInMission[currentGroupName].units[unitName] = {
																	name = unitName,
																	row = _key,
																	type = _unitDatas.type,
																	id = _unitDatas.unitId,
																	livery_id = _unitDatas.livery_id,
																	speed = _unitDatas.speed,
																	psi = _unitDatas.psi,
																	payload = _unitDatas.payload,
																	skill = _unitDatas.skill,
																	x = _unitDatas.x,
																	y = _unitDatas.y,
																	playerCanDrive = _unitDatas.playerCanDrive,
																	heading = _unitDatas.heading,
																	alt = _unitDatas.alt,
																	alt_type = _unitDatas.alt_type,
																	callsign = _unitDatas.callsign,
																	onboard_num = _unitDatas.onboard_num,
																	parking = _unitDatas.parking,
																	parking_id = _unitDatas.parking_id,
																}
																
																ATMEDatas.allInitialGroupNames[currentGroupName].unitsName[_key] = unitName
																
																if _unitDatas.skill == "Client" or _unitDatas.skill == "Player" then
																	if firstPlayerFound == false then
																		ATMEDatas.allPlayerUnitsInMission[unitName] = {
																			group = ATMEDatas.allGroupsInMission[currentGroupName],
																			unit = ATMEDatas.allGroupsInMission[currentGroupName].units[unitName],
																		}
																		
																		-- Test here because of DCS ME bug when changing unit to player -> possibiliy to change uncontrolled.
																		if ATMEDatas.allPlayerUnitsInMission[unitName].group.uncontrolled == true then
																			env.error("[ATME] Player " .. unitName .. " has uncontrolled attribute set to true in ME\nATME stopped", true)
																			return true
																		end
																		
																		firstPlayerFound = true
																	else
																		env.error("[ATME] Player " .. unitName .. " can't be in a group with already another player\nATME stopped", true)
																		return true
																	end
																else
																	ATMEDatas.allAIUnitsInMission[unitName] = {
																		group = ATMEDatas.allGroupsInMission[currentGroupName],
																		unit = ATMEDatas.allGroupsInMission[currentGroupName].units[unitName],
																	}
																end
															else
																env.error("[ATME] Unit name " .. unitName .. " can't contain 'Spawned' word\nATME stopped", true)
																return true
															end
														else
															env.error("[ATME] Unit name " .. unitName .. " can't contain '|' character\nATME stopped", true)
															return true
														end
													end
													
													if _groupDatas.route ~= nil and _groupDatas.route.points and #_groupDatas.route.points > 0 then
														for _pointNum, _point in ipairs(_groupDatas.route.points) do
															local pointName =  env.getValueDictByKey(_point.name)
															ATMEDatas.allGroupsInMission[currentGroupName].waypoints[#ATMEDatas.allGroupsInMission[currentGroupName].waypoints + 1] = {
																name = pointName,
																x = _point.x,
																y = _point.y,
																speed = _point.speed,
																speed_locked = _point.speed_locked,
																alt = _point.alt,
																alt_type = _point.alt_type,
																ETA = _point.ETA,
																ETA_locked = _point.ETA_locked,
																airdromeId = _point.airdromeId,
																helipadId = _point.helipadId,
																type = _point.type,
																action = _point.action,
																task = _point.task,
																properties = _point.properties,
																formation_template = _point.formation_template,
															}
														end
													end
												else 
													for _, _unitDatas in pairs(_groupDatas.units) do
														local unitName = env.getValueDictByKey(_unitDatas.name)
														local d,f = string.find(unitName, "|", 1)
											
														if d == nil then
															d,f = string.find(unitName:upper(), "%s+SPAWNED%s+", 1)
															if d == nil then
																if _unitDatas.category ~= "GrassAirfields" and _unitDatas.category ~= "Heliports" then
																	ATMEDatas.allStaticObjectsInMission[unitName] = {
																		name = unitName,
																		type = _unitDatas.type,
																		x = _unitDatas.x,
																		y = _unitDatas.y,
																		canCargo = _unitDatas.canCargo,
																		heading = _unitDatas.heading,
																		category = _unitDatas.category,
																		dead = _groupDatas.dead,
																		shape_name = _unitDatas.shape_name,
																		mass = _unitDatas.mass,
																		rate =_unitDatas.rate,
																		livery_id = _unitDatas.livery_id,
																	}
																else
																	ATMEDatas.allStaticAirbasesInMission[unitName] = {
																		name = unitName,
																		type = _unitDatas.type,
																		id = _unitDatas.unitId,
																		x = _unitDatas.x,
																		y = _unitDatas.y,
																		canCargo = _unitDatas.canCargo,
																		heading = _unitDatas.heading,
																		category = _unitDatas.category,
																		coalition = string.upper(_coalitionName),
																		dead = _groupDatas.dead,
																	}
																end
															else
																env.error("[ATME] Static Unit name " .. unitName .. " can't contain 'Spawned' word\nATME stopped", true)
																return true
															end
														else
															env.error("[ATME] Static Unit name " .. unitName .. " can't contain '|' character\nATME stopped", true)
															return true
														end
													end
												end
											else
												env.error("[ATME] Group name " .. currentGroupName .. " can't contain 'Spawned' word\nATME stopped", true)
												return true
											end
										else
											env.error("[ATME] Group name " .. currentGroupName .. " can't contain '|' character\nATME stopped", true)
											return true
										end
									end
								end 
							end
						end
					end
				end
			end
		end
		
		return false
	end
	
	local _timerStartMission
	_timerStartMission = function()
		for _id, _current in ipairs(world.getAirbases()) do
			local desc = _current:getDesc()
			if desc.attributes["Airfields"] == true then
				ATMEFct.C_Airbase_create_basic("AIRBASE", _current)
			elseif desc.attributes["Helipad"] == true then
				ATMEFct.C_Airbase_create_basic("HELIPAD", _current)
			elseif desc.attributes["HelicopterCarrier"] or desc.attributes["AircraftCarrier"] == true then
				ATMEFct.C_Airbase_create_basic("SHIP", _current)
			end
		end
		
		world.addEventHandler(customEventHandler)

		for _, _object in pairs(ATMEDatas.allStaticObjectsInMission) do
			local objectName = _object.name
			local object = StaticObject.getByName(objectName)
			
			if object ~= nil then 
				-- Bug DCS : Certains objets comme M1 Barrage Balloon sont encore avec object = nil.
				-- Non pris en compte par ATME
				ATMEFct.C_StaticObject_create(object)
			else
				ATMEFct.outputCore(nil,"Static object " .. objectName .. " ignoré par ATME : nil dans la fonction run", 2)
			end
		end

		for _, _localModuleMembers in ATMEDatas.C_Module_MT:pairs() do
			if _localModuleMembers.handlers.onModuleStartHandler ~= nil then
				-- Appel du module
				ATMEFct.outputCore(nil,"Appel onModuleStartHandler avant initialisation des unités & joueurs du module " .. _localModuleMembers.name, 2)
				xpcall(function() _localModuleMembers.handlers.onModuleStartHandler(false) end, function() ATMEFct.errUserHandler('onModuleStartHandler') end)
			end
		end
		
		-- On notera que les unités avec une activation retardées sont bien créées ! 
		-- ATTENTION ... Vrai pour les unités joueurs et les unités AI
		for _name, _group in pairs(ATMEDatas.allGroupsInMission) do
			local nbUnits = 0
			
			local spawnDatas = {
				country = _group.country,
				category = _group.category,
				type = _group.type,
				initialNames = ATMEDatas.allInitialGroupNames[_name],
				datas = {
					name = _name,
					groupId = _group.groupId,
					hidden = _group.hidden,
					start_time = 0,
					task = _group.task,
					visible = false,
					taskSelected = true,
					task = _group.task,
					lateActivation = false,
					tasks = {},
					units = {},
					route = {
						points = _group.waypoints,
					},
				},
			}
			
			for _unitName, _unit in pairs(_group.units) do
				spawnDatas.datas.units[_unit.row] = {
					row = _unit.row,
					type = _unit.type,
					name = _unitName,
					skill = _unit.skill,
					x = _unit.x,
					y = _unit.y,
					alt = _unit.alt,
					alt_type = _unit.alt_type,
					playerCanDrive = _unit.playerCanDrive,
					heading = _unit.heading,
					payload = _unit.payload,
					speed = _unit.speed,
					callsign = _unit.callsign,
					onboard_num = _unit.onboard_num,
					psi = _unit.psi,
					livery_id = _unit.livery_id,
				}
			end
			
			local datas = {
				uncontrolled = _group.uncontrolled,
				visible = _group.visible,
				spawnDatas = spawnDatas,
				idStart = 0,
			}
			
			for _, _unit in pairs(_group.units) do
				if _unit.skill ~= "Player" and _unit.skill ~= "Client" then
					local unit = Unit.getByName(_unit.name)
					if unit ~= nil then
						ATMEFct.C_AIUnit_create(unit, datas)
					else
						ATMEDatas.allAIUnitsInMission[_unit.name].datas = datas
					end
				else
					ATMEDatas.allPlayerUnitsInMission[_unit.name].datas = datas
				end
				
				nbUnits = nbUnits + 1
			end
			
			if _group.lateActivation == true then
				local group = ATME.C_Group.getByName(_group.name)
				local currentLocalMembers = ATMEDatas.C_Group_MT:get(group:getIndex())
				currentLocalMembers.isEnabled = false
				currentLocalMembers.nbUnitsToEnable = nbUnits
				ATMEFct.outputCore(nil,"Activation retardee pour " .. _group.name, 2)
			end
		end

		for i = 1, 2 do
			local newPlayerUnits = coalition.getPlayers(i)
			for _, _newPlayer in ipairs(newPlayerUnits) do
				ATMEFct.C_Player_create(_newPlayer, ATMEDatas.allPlayerUnitsInMission[_newPlayer:getName()].datas)
			end
		end
		
		ATMEDatas.isRunning = true
		ATMEDatas.newPlayer = true

		_timerMainFunction()
		_timer10x()
		_timer100x()
	end
	
	----------------------------------------------------------------------------------------------------------
	-- Fonction de démmarrage d'ATME à faire après le chargement de tous les modules. Cette fonction se mets dans
	-- l'éditeur de mission par un script lua.
	----------------------------------------------------------------------------------------------------------
	ATME.run = function(_language)
		local fctDefinition = ATMEFct.getErrorPrefix() .. "run(language)"
		
		if ATMEDatas.exitATME == false then
			if type(_language) == "string" and ATMEConst.supportedLanguages[_language] ~= nil then
				ATMEDatas.language = _language
				
				-- Permet de lancer ATME dès le début de la mission.
				if timer.getTime() < 1 then
					timer.scheduleFunction(_timerStartMission, {}, timer.getTime() + 1)
				else
					_timerStartMission()
				end
			else
				if type(_language) ~= "string" then
					ATMEFct.errorOutputCore(nil, fctDefinition, "language type must be string", false)
				elseif ATMEConst.supportedLanguages[_language] == nil then
					ATMEFct.errorOutputCore(nil, fctDefinition, "language must be FR, GER, RUS, EN", false)
				end
			end
		end
	end
	
	----------------------------------------------------------------------------------------------------------
	-- Fonction MAIN d'initialisation générale appelée une seule fois au lancement du fichier script
	----------------------------------------------------------------------------------------------------------
	do
		env.info("[ATME] - Init starts - version " .. versionATME, false)
		
		ATMEDatas.exitATME = initObjectsInMission()
		ATMEDatas.theatreName = string.upper(env.mission.theatre)
		
		env.info("[ATME] - Init ok - Theatre : " .. ATMEDatas.theatreName, false)
	end
end